/******/ (function() { // webpackBootstrap
/******/ 	var __webpack_modules__ = ({

/***/ 67266:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ compile; }
/* harmony export */ });
/* harmony import */ var _tannin_postfix__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(65854);
/* harmony import */ var _tannin_evaluate__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(730);



/**
 * Given a C expression, returns a function which can be called to evaluate its
 * result.
 *
 * @example
 *
 * ```js
 * import compile from '@tannin/compile';
 *
 * const evaluate = compile( 'n > 1' );
 *
 * evaluate( { n: 2 } );
 * // ⇒ true
 * ```
 *
 * @param {string} expression C expression.
 *
 * @return {(variables?:{[variable:string]:*})=>*} Compiled evaluator.
 */
function compile( expression ) {
	var terms = (0,_tannin_postfix__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)( expression );

	return function( variables ) {
		return (0,_tannin_evaluate__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)( terms, variables );
	};
}


/***/ }),

/***/ 730:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ evaluate; }
/* harmony export */ });
/**
 * Operator callback functions.
 *
 * @type {Object}
 */
var OPERATORS = {
	'!': function( a ) {
		return ! a;
	},
	'*': function( a, b ) {
		return a * b;
	},
	'/': function( a, b ) {
		return a / b;
	},
	'%': function( a, b ) {
		return a % b;
	},
	'+': function( a, b ) {
		return a + b;
	},
	'-': function( a, b ) {
		return a - b;
	},
	'<': function( a, b ) {
		return a < b;
	},
	'<=': function( a, b ) {
		return a <= b;
	},
	'>': function( a, b ) {
		return a > b;
	},
	'>=': function( a, b ) {
		return a >= b;
	},
	'==': function( a, b ) {
		return a === b;
	},
	'!=': function( a, b ) {
		return a !== b;
	},
	'&&': function( a, b ) {
		return a && b;
	},
	'||': function( a, b ) {
		return a || b;
	},
	'?:': function( a, b, c ) {
		if ( a ) {
			throw b;
		}

		return c;
	},
};

/**
 * Given an array of postfix terms and operand variables, returns the result of
 * the postfix evaluation.
 *
 * @example
 *
 * ```js
 * import evaluate from '@tannin/evaluate';
 *
 * // 3 + 4 * 5 / 6 ⇒ '3 4 5 * 6 / +'
 * const terms = [ '3', '4', '5', '*', '6', '/', '+' ];
 *
 * evaluate( terms, {} );
 * // ⇒ 6.333333333333334
 * ```
 *
 * @param {string[]} postfix   Postfix terms.
 * @param {Object}   variables Operand variables.
 *
 * @return {*} Result of evaluation.
 */
function evaluate( postfix, variables ) {
	var stack = [],
		i, j, args, getOperatorResult, term, value;

	for ( i = 0; i < postfix.length; i++ ) {
		term = postfix[ i ];

		getOperatorResult = OPERATORS[ term ];
		if ( getOperatorResult ) {
			// Pop from stack by number of function arguments.
			j = getOperatorResult.length;
			args = Array( j );
			while ( j-- ) {
				args[ j ] = stack.pop();
			}

			try {
				value = getOperatorResult.apply( null, args );
			} catch ( earlyReturn ) {
				return earlyReturn;
			}
		} else if ( variables.hasOwnProperty( term ) ) {
			value = variables[ term ];
		} else {
			value = +term;
		}

		stack.push( value );
	}

	return stack[ 0 ];
}


/***/ }),

/***/ 11184:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ pluralForms; }
/* harmony export */ });
/* harmony import */ var _tannin_compile__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(67266);


/**
 * Given a C expression, returns a function which, when called with a value,
 * evaluates the result with the value assumed to be the "n" variable of the
 * expression. The result will be coerced to its numeric equivalent.
 *
 * @param {string} expression C expression.
 *
 * @return {Function} Evaluator function.
 */
function pluralForms( expression ) {
	var evaluate = (0,_tannin_compile__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)( expression );

	return function( n ) {
		return +evaluate( { n: n } );
	};
}


/***/ }),

/***/ 65854:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ postfix; }
/* harmony export */ });
var PRECEDENCE, OPENERS, TERMINATORS, PATTERN;

/**
 * Operator precedence mapping.
 *
 * @type {Object}
 */
PRECEDENCE = {
	'(': 9,
	'!': 8,
	'*': 7,
	'/': 7,
	'%': 7,
	'+': 6,
	'-': 6,
	'<': 5,
	'<=': 5,
	'>': 5,
	'>=': 5,
	'==': 4,
	'!=': 4,
	'&&': 3,
	'||': 2,
	'?': 1,
	'?:': 1,
};

/**
 * Characters which signal pair opening, to be terminated by terminators.
 *
 * @type {string[]}
 */
OPENERS = [ '(', '?' ];

/**
 * Characters which signal pair termination, the value an array with the
 * opener as its first member. The second member is an optional operator
 * replacement to push to the stack.
 *
 * @type {string[]}
 */
TERMINATORS = {
	')': [ '(' ],
	':': [ '?', '?:' ],
};

/**
 * Pattern matching operators and openers.
 *
 * @type {RegExp}
 */
PATTERN = /<=|>=|==|!=|&&|\|\||\?:|\(|!|\*|\/|%|\+|-|<|>|\?|\)|:/;

/**
 * Given a C expression, returns the equivalent postfix (Reverse Polish)
 * notation terms as an array.
 *
 * If a postfix string is desired, simply `.join( ' ' )` the result.
 *
 * @example
 *
 * ```js
 * import postfix from '@tannin/postfix';
 *
 * postfix( 'n > 1' );
 * // ⇒ [ 'n', '1', '>' ]
 * ```
 *
 * @param {string} expression C expression.
 *
 * @return {string[]} Postfix terms.
 */
function postfix( expression ) {
	var terms = [],
		stack = [],
		match, operator, term, element;

	while ( ( match = expression.match( PATTERN ) ) ) {
		operator = match[ 0 ];

		// Term is the string preceding the operator match. It may contain
		// whitespace, and may be empty (if operator is at beginning).
		term = expression.substr( 0, match.index ).trim();
		if ( term ) {
			terms.push( term );
		}

		while ( ( element = stack.pop() ) ) {
			if ( TERMINATORS[ operator ] ) {
				if ( TERMINATORS[ operator ][ 0 ] === element ) {
					// Substitution works here under assumption that because
					// the assigned operator will no longer be a terminator, it
					// will be pushed to the stack during the condition below.
					operator = TERMINATORS[ operator ][ 1 ] || operator;
					break;
				}
			} else if ( OPENERS.indexOf( element ) >= 0 || PRECEDENCE[ element ] < PRECEDENCE[ operator ] ) {
				// Push to stack if either an opener or when pop reveals an
				// element of lower precedence.
				stack.push( element );
				break;
			}

			// For each popped from stack, push to terms.
			terms.push( element );
		}

		if ( ! TERMINATORS[ operator ] ) {
			stack.push( operator );
		}

		// Slice matched fragment from expression to continue match.
		expression = expression.substr( match.index + operator.length );
	}

	// Push remainder of operand, if exists, to terms.
	expression = expression.trim();
	if ( expression ) {
		terms.push( expression );
	}

	// Pop remaining items from stack into terms.
	return terms.concat( stack.reverse() );
}


/***/ }),

/***/ 96668:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ sprintf; }
/* harmony export */ });
/**
 * Regular expression matching format placeholder syntax.
 *
 * The pattern for matching named arguments is a naive and incomplete matcher
 * against valid JavaScript identifier names.
 *
 * via Mathias Bynens:
 *
 * >An identifier must start with $, _, or any character in the Unicode
 * >categories “Uppercase letter (Lu)”, “Lowercase letter (Ll)”, “Titlecase
 * >letter (Lt)”, “Modifier letter (Lm)”, “Other letter (Lo)”, or “Letter
 * >number (Nl)”.
 * >
 * >The rest of the string can contain the same characters, plus any U+200C zero
 * >width non-joiner characters, U+200D zero width joiner characters, and
 * >characters in the Unicode categories “Non-spacing mark (Mn)”, “Spacing
 * >combining mark (Mc)”, “Decimal digit number (Nd)”, or “Connector
 * >punctuation (Pc)”.
 *
 * If browser support is constrained to those supporting ES2015, this could be
 * made more accurate using the `u` flag:
 *
 * ```
 * /^[$_\p{L}\p{Nl}][$_\p{L}\p{Nl}\u200C\u200D\p{Mn}\p{Mc}\p{Nd}\p{Pc}]*$/u;
 * ```
 *
 * @see http://www.pixelbeat.org/programming/gcc/format_specs.html
 * @see https://mathiasbynens.be/notes/javascript-identifiers#valid-identifier-names
 *
 * @type {RegExp}
 */
var PATTERN = /%(((\d+)\$)|(\(([$_a-zA-Z][$_a-zA-Z0-9]*)\)))?[ +0#-]*\d*(\.(\d+|\*))?(ll|[lhqL])?([cduxXefgsp%])/g;
//               ▲         ▲                    ▲       ▲  ▲            ▲           ▲ type
//               │         │                    │       │  │            └ Length (unsupported)
//               │         │                    │       │  └ Precision / max width
//               │         │                    │       └ Min width (unsupported)
//               │         │                    └ Flags (unsupported)
//               └ Index   └ Name (for named arguments)

/**
 * Given a format string, returns string with arguments interpolatation.
 * Arguments can either be provided directly via function arguments spread, or
 * with an array as the second argument.
 *
 * @see https://en.wikipedia.org/wiki/Printf_format_string
 *
 * @example
 *
 * ```js
 * import sprintf from '@tannin/sprintf';
 *
 * sprintf( 'Hello %s!', 'world' );
 * // ⇒ 'Hello world!'
 * ```
 *
 * @param {string} string printf format string
 * @param {Array}  [args] String arguments.
 *
 * @return {string} Formatted string.
 */
function sprintf( string, args ) {
	var i;

	if ( ! Array.isArray( args ) ) {
		// Construct a copy of arguments from index one, used for replace
		// function placeholder substitution.
		args = new Array( arguments.length - 1 );
		for ( i = 1; i < arguments.length; i++ ) {
			args[ i - 1 ] = arguments[ i ];
		}
	}

	i = 1;

	return string.replace( PATTERN, function() {
		var index, name, precision, type, value;

		index = arguments[ 3 ];
		name = arguments[ 5 ];
		precision = arguments[ 7 ];
		type = arguments[ 9 ];

		// There's no placeholder substitution in the explicit "%", meaning it
		// is not necessary to increment argument index.
		if ( type === '%' ) {
			return '%';
		}

		// Asterisk precision determined by peeking / shifting next argument.
		if ( precision === '*' ) {
			precision = args[ i - 1 ];
			i++;
		}

		if ( name !== undefined ) {
			// If it's a named argument, use name.
			if ( args[ 0 ] && typeof args[ 0 ] === 'object' &&
					args[ 0 ].hasOwnProperty( name ) ) {
				value = args[ 0 ][ name ];
			}
		} else {
			// If not a positional argument, use counter value.
			if ( index === undefined ) {
				index = i;
			}

			i++;

			// Positional argument.
			value = args[ index - 1 ];
		}

		// Parse as type.
		if ( type === 'f' ) {
			value = parseFloat( value ) || 0;
		} else if ( type === 'd' ) {
			value = parseInt( value ) || 0;
		}

		// Apply precision.
		if ( precision !== undefined ) {
			if ( type === 'f' ) {
				value = value.toFixed( precision );
			} else if ( type === 's' ) {
				value = value.substr( 0, precision );
			}
		}

		// To avoid "undefined" concatenation, return empty string if no
		// placeholder substitution can be performed.
		return value !== undefined && value !== null ? value : '';
	} );
}


/***/ }),

/***/ 5869:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/**
 * WordPress dependencies
 */

/** @typedef {{icon: JSX.Element, size?: number} & import('@wordpress/primitives').SVGProps} IconProps */

/**
 * Return an SVG icon.
 *
 * @param {IconProps} props icon is the SVG component to render
 *                          size is a number specifiying the icon size in pixels
 *                          Other props will be passed to wrapped SVG component
 *
 * @return {JSX.Element}  Icon component
 */

function Icon(_ref) {
  let {
    icon,
    size = 24,
    ...props
  } = _ref;
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.cloneElement)(icon, {
    width: size,
    height: size,
    ...props
  });
}

/* harmony default export */ __webpack_exports__["Z"] = (Icon);
//# sourceMappingURL=index.js.map

/***/ }),

/***/ 58706:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const arrowRight = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M14.3 6.7l-1.1 1.1 4 4H4v1.5h13.3l-4.1 4.4 1.1 1.1 5.8-6.3z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (arrowRight);
//# sourceMappingURL=arrow-right.js.map

/***/ }),

/***/ 94140:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const arrowUp = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M12.5 3.9L6.7 9.7l1.1 1.1 4-4V20h1.4V6.7l4.5 4.1 1.1-1.1z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (arrowUp);
//# sourceMappingURL=arrow-up.js.map

/***/ }),

/***/ 26176:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const captureVideo = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  viewBox: "0 0 24 24",
  xmlns: "http://www.w3.org/2000/svg"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M14 5H4c-1.1 0-2 .9-2 2v10c0 1.1.9 2 2 2h10c1.1 0 2-.9 2-2V7c0-1.1-.9-2-2-2zm.5 12c0 .3-.2.5-.5.5H4c-.3 0-.5-.2-.5-.5V7c0-.3.2-.5.5-.5h10c.3 0 .5.2.5.5v10zm2.5-7v4l5 3V7l-5 3zm3.5 4.4l-2-1.2v-2.3l2-1.2v4.7z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (captureVideo);
//# sourceMappingURL=capture-video.js.map

/***/ }),

/***/ 43383:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const chevronDown = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  viewBox: "0 0 24 24",
  xmlns: "http://www.w3.org/2000/svg"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M17.5 11.6L12 16l-5.5-4.4.9-1.2L12 14l4.5-3.6 1 1.2z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (chevronDown);
//# sourceMappingURL=chevron-down.js.map

/***/ }),

/***/ 21100:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const chevronLeft = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M14.6 7l-1.2-1L8 12l5.4 6 1.2-1-4.6-5z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (chevronLeft);
//# sourceMappingURL=chevron-left.js.map

/***/ }),

/***/ 26715:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const chevronUp = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  viewBox: "0 0 24 24",
  xmlns: "http://www.w3.org/2000/svg"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M6.5 12.4L12 8l5.5 4.4-.9 1.2L12 10l-4.5 3.6-1-1.2z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (chevronUp);
//# sourceMappingURL=chevron-up.js.map

/***/ }),

/***/ 60199:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const closeSmall = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M12 13.06l3.712 3.713 1.061-1.06L13.061 12l3.712-3.712-1.06-1.06L12 10.938 8.288 7.227l-1.061 1.06L10.939 12l-3.712 3.712 1.06 1.061L12 13.061z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (closeSmall);
//# sourceMappingURL=close-small.js.map

/***/ }),

/***/ 48632:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const commentContent = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  viewBox: "0 0 24 24",
  xmlns: "http://www.w3.org/2000/svg"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  fillRule: "evenodd",
  clipRule: "evenodd",
  d: "M6.68822 16.625L5.5 17.8145L5.5 5.5L18.5 5.5L18.5 16.625L6.68822 16.625ZM7.31 18.125L19 18.125C19.5523 18.125 20 17.6773 20 17.125L20 5C20 4.44772 19.5523 4 19 4H5C4.44772 4 4 4.44772 4 5V19.5247C4 19.8173 4.16123 20.086 4.41935 20.2237C4.72711 20.3878 5.10601 20.3313 5.35252 20.0845L7.31 18.125ZM16 9.99997H8V8.49997H16V9.99997ZM8 14H13V12.5H8V14Z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (commentContent);
//# sourceMappingURL=comment-content.js.map

/***/ }),

/***/ 77343:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const comment = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  viewBox: "0 0 24 24",
  xmlns: "http://www.w3.org/2000/svg"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M18 4H6c-1.1 0-2 .9-2 2v12.9c0 .6.5 1.1 1.1 1.1.3 0 .5-.1.8-.3L8.5 17H18c1.1 0 2-.9 2-2V6c0-1.1-.9-2-2-2zm.5 11c0 .3-.2.5-.5.5H7.9l-2.4 2.4V6c0-.3.2-.5.5-.5h12c.3 0 .5.2.5.5v9z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (comment);
//# sourceMappingURL=comment.js.map

/***/ }),

/***/ 10812:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const desktop = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M20.5 16h-.7V8c0-1.1-.9-2-2-2H6.2c-1.1 0-2 .9-2 2v8h-.7c-.8 0-1.5.7-1.5 1.5h20c0-.8-.7-1.5-1.5-1.5zM5.7 8c0-.3.2-.5.5-.5h11.6c.3 0 .5.2.5.5v7.6H5.7V8z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (desktop);
//# sourceMappingURL=desktop.js.map

/***/ }),

/***/ 22042:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const external = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M18.2 17c0 .7-.6 1.2-1.2 1.2H7c-.7 0-1.2-.6-1.2-1.2V7c0-.7.6-1.2 1.2-1.2h3.2V4.2H7C5.5 4.2 4.2 5.5 4.2 7v10c0 1.5 1.2 2.8 2.8 2.8h10c1.5 0 2.8-1.2 2.8-2.8v-3.6h-1.5V17zM14.9 3v1.5h3.7l-6.4 6.4 1.1 1.1 6.4-6.4v3.7h1.5V3h-6.3z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (external);
//# sourceMappingURL=external.js.map

/***/ }),

/***/ 86642:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const formatListNumbered = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M11.1 15.8H20v-1.5h-8.9v1.5zm0-8.6v1.5H20V7.2h-8.9zM5 6.7V10h1V5.3L3.8 6l.4 1 .8-.3zm-.4 5.7c-.3.1-.5.2-.7.3l.1 1.1c.2-.2.5-.4.8-.5.3-.1.6 0 .7.1.2.3 0 .8-.2 1.1-.5.8-.9 1.6-1.4 2.5h2.7v-1h-1c.3-.6.8-1.4.9-2.1.1-.3 0-.8-.2-1.1-.5-.6-1.3-.5-1.7-.4z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (formatListNumbered);
//# sourceMappingURL=format-list-numbered.js.map

/***/ }),

/***/ 93519:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const globe = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M12 3.3c-4.8 0-8.8 3.9-8.8 8.8 0 4.8 3.9 8.8 8.8 8.8 4.8 0 8.8-3.9 8.8-8.8s-4-8.8-8.8-8.8zm6.5 5.5h-2.6C15.4 7.3 14.8 6 14 5c2 .6 3.6 2 4.5 3.8zm.7 3.2c0 .6-.1 1.2-.2 1.8h-2.9c.1-.6.1-1.2.1-1.8s-.1-1.2-.1-1.8H19c.2.6.2 1.2.2 1.8zM12 18.7c-1-.7-1.8-1.9-2.3-3.5h4.6c-.5 1.6-1.3 2.9-2.3 3.5zm-2.6-4.9c-.1-.6-.1-1.1-.1-1.8 0-.6.1-1.2.1-1.8h5.2c.1.6.1 1.1.1 1.8s-.1 1.2-.1 1.8H9.4zM4.8 12c0-.6.1-1.2.2-1.8h2.9c-.1.6-.1 1.2-.1 1.8 0 .6.1 1.2.1 1.8H5c-.2-.6-.2-1.2-.2-1.8zM12 5.3c1 .7 1.8 1.9 2.3 3.5H9.7c.5-1.6 1.3-2.9 2.3-3.5zM10 5c-.8 1-1.4 2.3-1.8 3.8H5.5C6.4 7 8 5.6 10 5zM5.5 15.3h2.6c.4 1.5 1 2.8 1.8 3.7-1.8-.6-3.5-2-4.4-3.7zM14 19c.8-1 1.4-2.2 1.8-3.7h2.6C17.6 17 16 18.4 14 19z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (globe);
//# sourceMappingURL=globe.js.map

/***/ }),

/***/ 5614:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const info = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M12 3.2c-4.8 0-8.8 3.9-8.8 8.8 0 4.8 3.9 8.8 8.8 8.8 4.8 0 8.8-3.9 8.8-8.8 0-4.8-4-8.8-8.8-8.8zm0 16c-4 0-7.2-3.3-7.2-7.2C4.8 8 8 4.8 12 4.8s7.2 3.3 7.2 7.2c0 4-3.2 7.2-7.2 7.2zM11 17h2v-6h-2v6zm0-8h2V7h-2v2z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (info);
//# sourceMappingURL=info.js.map

/***/ }),

/***/ 63103:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const lineSolid = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M5 11.25h14v1.5H5z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (lineSolid);
//# sourceMappingURL=line-solid.js.map

/***/ }),

/***/ 39739:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const page = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M7 5.5h10a.5.5 0 01.5.5v12a.5.5 0 01-.5.5H7a.5.5 0 01-.5-.5V6a.5.5 0 01.5-.5zM17 4H7a2 2 0 00-2 2v12a2 2 0 002 2h10a2 2 0 002-2V6a2 2 0 00-2-2zm-1 3.75H8v1.5h8v-1.5zM8 11h8v1.5H8V11zm6 3.25H8v1.5h6v-1.5z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (page);
//# sourceMappingURL=page.js.map

/***/ }),

/***/ 17108:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const search = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  xmlns: "http://www.w3.org/2000/svg",
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M13.5 6C10.5 6 8 8.5 8 11.5c0 1.1.3 2.1.9 3l-3.4 3 1 1.1 3.4-2.9c1 .9 2.2 1.4 3.6 1.4 3 0 5.5-2.5 5.5-5.5C19 8.5 16.5 6 13.5 6zm0 9.5c-2.2 0-4-1.8-4-4s1.8-4 4-4 4 1.8 4 4-1.8 4-4 4z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (search);
//# sourceMappingURL=search.js.map

/***/ }),

/***/ 81835:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70444);
/* harmony import */ var _wordpress_primitives__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__);


/**
 * WordPress dependencies
 */

const video = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.SVG, {
  viewBox: "0 0 24 24",
  xmlns: "http://www.w3.org/2000/svg"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_primitives__WEBPACK_IMPORTED_MODULE_1__.Path, {
  d: "M18.7 3H5.3C4 3 3 4 3 5.3v13.4C3 20 4 21 5.3 21h13.4c1.3 0 2.3-1 2.3-2.3V5.3C21 4 20 3 18.7 3zm.8 15.7c0 .4-.4.8-.8.8H5.3c-.4 0-.8-.4-.8-.8V5.3c0-.4.4-.8.8-.8h13.4c.4 0 .8.4.8.8v13.4zM10 15l5-3-5-3v6z"
}));
/* harmony default export */ __webpack_exports__["Z"] = (video);
//# sourceMappingURL=video.js.map

/***/ }),

/***/ 75173:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Ox": function() { return /* reexport safe */ _pinned_items__WEBPACK_IMPORTED_MODULE_0__.Z; }
/* harmony export */ });
/* harmony import */ var _pinned_items__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20749);












//# sourceMappingURL=index.js.map

/***/ }),

/***/ 20749:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(7896);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(55609);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(_wordpress_components__WEBPACK_IMPORTED_MODULE_3__);



/**
 * External dependencies
 */


/**
 * WordPress dependencies
 */



function PinnedItems(_ref) {
  let {
    scope,
    ...props
  } = _ref;
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_3__.Fill, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)({
    name: `PinnedItems/${scope}`
  }, props));
}

function PinnedItemsSlot(_ref2) {
  let {
    scope,
    className,
    ...props
  } = _ref2;
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_3__.Slot, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)({
    name: `PinnedItems/${scope}`
  }, props), fills => !(0,lodash__WEBPACK_IMPORTED_MODULE_1__.isEmpty)(fills) && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: classnames__WEBPACK_IMPORTED_MODULE_2___default()(className, 'interface-pinned-items')
  }, fills));
}

PinnedItems.Slot = PinnedItemsSlot;
/* harmony default export */ __webpack_exports__["Z"] = (PinnedItems);
//# sourceMappingURL=index.js.map

/***/ }),

/***/ 85192:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Ox": function() { return /* reexport safe */ _components__WEBPACK_IMPORTED_MODULE_0__.Ox; }
/* harmony export */ });
/* harmony import */ var _components__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(75173);
/* harmony import */ var _store__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(97014);


//# sourceMappingURL=index.js.map

/***/ }),

/***/ 36262:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "setDefaultComplementaryArea": function() { return /* binding */ setDefaultComplementaryArea; },
/* harmony export */   "enableComplementaryArea": function() { return /* binding */ enableComplementaryArea; },
/* harmony export */   "disableComplementaryArea": function() { return /* binding */ disableComplementaryArea; },
/* harmony export */   "pinItem": function() { return /* binding */ pinItem; },
/* harmony export */   "unpinItem": function() { return /* binding */ unpinItem; },
/* harmony export */   "toggleFeature": function() { return /* binding */ toggleFeature; },
/* harmony export */   "setFeatureValue": function() { return /* binding */ setFeatureValue; },
/* harmony export */   "setFeatureDefaults": function() { return /* binding */ setFeatureDefaults; }
/* harmony export */ });
/* harmony import */ var _wordpress_deprecated__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(37180);
/* harmony import */ var _wordpress_deprecated__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_deprecated__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(55815);
/* harmony import */ var _wordpress_preferences__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__);
/**
 * WordPress dependencies
 */


/**
 * Set a default complementary area.
 *
 * @param {string} scope Complementary area scope.
 * @param {string} area  Area identifier.
 *
 * @return {Object} Action object.
 */

const setDefaultComplementaryArea = (scope, area) => ({
  type: 'SET_DEFAULT_COMPLEMENTARY_AREA',
  scope,
  area
});
/**
 * Enable the complementary area.
 *
 * @param {string} scope Complementary area scope.
 * @param {string} area  Area identifier.
 */

const enableComplementaryArea = (scope, area) => _ref => {
  let {
    registry,
    dispatch
  } = _ref;

  // Return early if there's no area.
  if (!area) {
    return;
  }

  const isComplementaryAreaVisible = registry.select(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__.store).get(scope, 'isComplementaryAreaVisible');

  if (!isComplementaryAreaVisible) {
    registry.dispatch(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__.store).set(scope, 'isComplementaryAreaVisible', true);
  }

  dispatch({
    type: 'ENABLE_COMPLEMENTARY_AREA',
    scope,
    area
  });
};
/**
 * Disable the complementary area.
 *
 * @param {string} scope Complementary area scope.
 */

const disableComplementaryArea = scope => _ref2 => {
  let {
    registry
  } = _ref2;
  const isComplementaryAreaVisible = registry.select(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__.store).get(scope, 'isComplementaryAreaVisible');

  if (isComplementaryAreaVisible) {
    registry.dispatch(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__.store).set(scope, 'isComplementaryAreaVisible', false);
  }
};
/**
 * Pins an item.
 *
 * @param {string} scope Item scope.
 * @param {string} item  Item identifier.
 *
 * @return {Object} Action object.
 */

const pinItem = (scope, item) => _ref3 => {
  let {
    registry
  } = _ref3;

  // Return early if there's no item.
  if (!item) {
    return;
  }

  const pinnedItems = registry.select(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__.store).get(scope, 'pinnedItems'); // The item is already pinned, there's nothing to do.

  if ((pinnedItems === null || pinnedItems === void 0 ? void 0 : pinnedItems[item]) === true) {
    return;
  }

  registry.dispatch(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__.store).set(scope, 'pinnedItems', { ...pinnedItems,
    [item]: true
  });
};
/**
 * Unpins an item.
 *
 * @param {string} scope Item scope.
 * @param {string} item  Item identifier.
 */

const unpinItem = (scope, item) => _ref4 => {
  let {
    registry
  } = _ref4;

  // Return early if there's no item.
  if (!item) {
    return;
  }

  const pinnedItems = registry.select(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__.store).get(scope, 'pinnedItems');
  registry.dispatch(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__.store).set(scope, 'pinnedItems', { ...pinnedItems,
    [item]: false
  });
};
/**
 * Returns an action object used in signalling that a feature should be toggled.
 *
 * @param {string} scope       The feature scope (e.g. core/edit-post).
 * @param {string} featureName The feature name.
 */

function toggleFeature(scope, featureName) {
  return function (_ref5) {
    let {
      registry
    } = _ref5;
    _wordpress_deprecated__WEBPACK_IMPORTED_MODULE_0___default()(`dispatch( 'core/interface' ).toggleFeature`, {
      since: '6.0',
      alternative: `dispatch( 'core/preferences' ).toggle`
    });
    registry.dispatch(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__.store).toggle(scope, featureName);
  };
}
/**
 * Returns an action object used in signalling that a feature should be set to
 * a true or false value
 *
 * @param {string}  scope       The feature scope (e.g. core/edit-post).
 * @param {string}  featureName The feature name.
 * @param {boolean} value       The value to set.
 *
 * @return {Object} Action object.
 */

function setFeatureValue(scope, featureName, value) {
  return function (_ref6) {
    let {
      registry
    } = _ref6;
    _wordpress_deprecated__WEBPACK_IMPORTED_MODULE_0___default()(`dispatch( 'core/interface' ).setFeatureValue`, {
      since: '6.0',
      alternative: `dispatch( 'core/preferences' ).set`
    });
    registry.dispatch(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__.store).set(scope, featureName, !!value);
  };
}
/**
 * Returns an action object used in signalling that defaults should be set for features.
 *
 * @param {string}                  scope    The feature scope (e.g. core/edit-post).
 * @param {Object<string, boolean>} defaults A key/value map of feature names to values.
 *
 * @return {Object} Action object.
 */

function setFeatureDefaults(scope, defaults) {
  return function (_ref7) {
    let {
      registry
    } = _ref7;
    _wordpress_deprecated__WEBPACK_IMPORTED_MODULE_0___default()(`dispatch( 'core/interface' ).setFeatureDefaults`, {
      since: '6.0',
      alternative: `dispatch( 'core/preferences' ).setDefaults`
    });
    registry.dispatch(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_1__.store).setDefaults(scope, defaults);
  };
}
//# sourceMappingURL=actions.js.map

/***/ }),

/***/ 112:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "G": function() { return /* binding */ STORE_NAME; }
/* harmony export */ });
/**
 * The identifier for the data store.
 *
 * @type {string}
 */
const STORE_NAME = 'core/interface';
//# sourceMappingURL=constants.js.map

/***/ }),

/***/ 97014:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export store */
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _actions__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(36262);
/* harmony import */ var _selectors__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(37844);
/* harmony import */ var _reducer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(87350);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(112);
/**
 * WordPress dependencies
 */

/**
 * Internal dependencies
 */





/**
 * Store definition for the interface namespace.
 *
 * @see https://github.com/WordPress/gutenberg/blob/HEAD/packages/data/README.md#createReduxStore
 *
 * @type {Object}
 */

const store = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.createReduxStore)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_NAME */ .G, {
  reducer: _reducer__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z,
  actions: _actions__WEBPACK_IMPORTED_MODULE_3__,
  selectors: _selectors__WEBPACK_IMPORTED_MODULE_4__
}); // Once we build a more generic persistence plugin that works across types of stores
// we'd be able to replace this with a register call.

(0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.register)(store);
//# sourceMappingURL=index.js.map

/***/ }),

/***/ 87350:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export complementaryAreas */
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_0__);
/**
 * WordPress dependencies
 */

function complementaryAreas() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case 'SET_DEFAULT_COMPLEMENTARY_AREA':
      {
        const {
          scope,
          area
        } = action; // If there's already an area, don't overwrite it.

        if (state[scope]) {
          return state;
        }

        return { ...state,
          [scope]: area
        };
      }

    case 'ENABLE_COMPLEMENTARY_AREA':
      {
        const {
          scope,
          area
        } = action;
        return { ...state,
          [scope]: area
        };
      }
  }

  return state;
}
/* harmony default export */ __webpack_exports__["Z"] = ((0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.combineReducers)({
  complementaryAreas
}));
//# sourceMappingURL=reducer.js.map

/***/ }),

/***/ 37844:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "getActiveComplementaryArea": function() { return /* binding */ getActiveComplementaryArea; },
/* harmony export */   "isItemPinned": function() { return /* binding */ isItemPinned; },
/* harmony export */   "isFeatureActive": function() { return /* binding */ isFeatureActive; }
/* harmony export */ });
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_deprecated__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(37180);
/* harmony import */ var _wordpress_deprecated__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_deprecated__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _wordpress_preferences__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(55815);
/* harmony import */ var _wordpress_preferences__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_2__);
/**
 * WordPress dependencies
 */



/**
 * Returns the complementary area that is active in a given scope.
 *
 * @param {Object} state Global application state.
 * @param {string} scope Item scope.
 *
 * @return {string | null | undefined} The complementary area that is active in the given scope.
 */

const getActiveComplementaryArea = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.createRegistrySelector)(select => (state, scope) => {
  var _state$complementaryA;

  const isComplementaryAreaVisible = select(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_2__.store).get(scope, 'isComplementaryAreaVisible'); // Return `undefined` to indicate that the user has never toggled
  // visibility, this is the vanilla default. Other code relies on this
  // nuance in the return value.

  if (isComplementaryAreaVisible === undefined) {
    return undefined;
  } // Return `null` to indicate the user hid the complementary area.


  if (!isComplementaryAreaVisible) {
    return null;
  }

  return state === null || state === void 0 ? void 0 : (_state$complementaryA = state.complementaryAreas) === null || _state$complementaryA === void 0 ? void 0 : _state$complementaryA[scope];
});
/**
 * Returns a boolean indicating if an item is pinned or not.
 *
 * @param {Object} state Global application state.
 * @param {string} scope Scope.
 * @param {string} item  Item to check.
 *
 * @return {boolean} True if the item is pinned and false otherwise.
 */

const isItemPinned = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.createRegistrySelector)(select => (state, scope, item) => {
  var _pinnedItems$item;

  const pinnedItems = select(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_2__.store).get(scope, 'pinnedItems');
  return (_pinnedItems$item = pinnedItems === null || pinnedItems === void 0 ? void 0 : pinnedItems[item]) !== null && _pinnedItems$item !== void 0 ? _pinnedItems$item : true;
});
/**
 * Returns a boolean indicating whether a feature is active for a particular
 * scope.
 *
 * @param {Object} state       The store state.
 * @param {string} scope       The scope of the feature (e.g. core/edit-post).
 * @param {string} featureName The name of the feature.
 *
 * @return {boolean} Is the feature enabled?
 */

const isFeatureActive = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.createRegistrySelector)(select => (state, scope, featureName) => {
  _wordpress_deprecated__WEBPACK_IMPORTED_MODULE_1___default()(`select( 'core/interface' ).isFeatureActive( scope, featureName )`, {
    since: '6.0',
    alternative: `select( 'core/preferences' ).get( scope, featureName )`
  });
  return !!select(_wordpress_preferences__WEBPACK_IMPORTED_MODULE_2__.store).get(scope, featureName);
});
//# sourceMappingURL=selectors.js.map

/***/ }),

/***/ 95885:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "QT": function() { return /* binding */ useI18n; }
/* harmony export */ });
/* unused harmony exports I18nProvider, withI18n */
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(65736);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__);



/**
 * External dependencies
 */

/**
 * WordPress dependencies
 */



/**
 * Utility to make a new context value
 *
 * @param  i18n
 */
function makeContextValue(i18n) {
  return {
    __: i18n.__.bind(i18n),
    _x: i18n._x.bind(i18n),
    _n: i18n._n.bind(i18n),
    _nx: i18n._nx.bind(i18n),
    isRTL: i18n.isRTL.bind(i18n),
    hasTranslation: i18n.hasTranslation.bind(i18n)
  };
}

const I18nContext = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createContext)(makeContextValue(_wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__.defaultI18n));

/**
 * The `I18nProvider` should be mounted above any localized components:
 *
 * @example
 * ```js
 * import { createI18n } from '@wordpress/react-i18n';
 * import { I18nProvider } from '@wordpress/react-i18n';
 * const i18n = createI18n();
 *
 * ReactDom.render(
 * 	<I18nProvider i18n={ i18n }>
 * 		<App />
 * 	</I18nProvider>,
 * 	el
 * );
 * ```
 *
 * You can also instantiate the provider without the `i18n` prop. In that case it will use the
 * default `I18n` instance exported from `@wordpress/i18n`.
 *
 * @param  props i18n provider props.
 * @return Children wrapped in the I18nProvider.
 */
function I18nProvider(props) {
  const {
    children,
    i18n = defaultI18n
  } = props;
  const [update, forceUpdate] = useReducer(() => [], []); // Rerender translations whenever the i18n instance fires a change event.

  useEffect(() => i18n.subscribe(forceUpdate), [i18n]);
  const value = useMemo(() => makeContextValue(i18n), [i18n, update]);
  return createElement(I18nContext.Provider, {
    value: value
  }, children);
}
/**
 * React hook providing access to i18n functions. It exposes the `__`, `_x`, `_n`, `_nx`,
 * `isRTL` and `hasTranslation` functions from [`@wordpress/i18n`](../i18n).
 * Refer to their documentation there.
 *
 * @example
 * ```js
 * import { useI18n } from '@wordpress/react-i18n';
 *
 * function MyComponent() {
 * 	const { __ } = useI18n();
 * 	return __( 'Hello, world!' );
 * }
 * ```
 */

const useI18n = () => (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useContext)(I18nContext);

/**
 * React higher-order component that passes the i18n translate functions (the same set
 * as exposed by the `useI18n` hook) to the wrapped component as props.
 *
 * @example
 * ```js
 * import { withI18n } from '@wordpress/react-i18n';
 *
 * function MyComponent( { __ } ) {
 * 	return __( 'Hello, world!' );
 * }
 *
 * export default withI18n( MyComponent );
 * ```
 *
 * @param  InnerComponent React component to be wrapped and receive the i18n functions like `__`
 * @return The wrapped component
 */
function withI18n(InnerComponent) {
  const EnhancedComponent = props => {
    const i18nProps = useI18n();
    return createElement(InnerComponent, _extends({}, props, i18nProps));
  };

  const innerComponentName = InnerComponent.displayName || InnerComponent.name || 'Component';
  EnhancedComponent.displayName = `WithI18n(${innerComponentName})`;
  return EnhancedComponent;
}
//# sourceMappingURL=index.js.map

/***/ }),

/***/ 61777:
/***/ (function(module) {

module.exports = after

function after(count, callback, err_cb) {
    var bail = false
    err_cb = err_cb || noop
    proxy.count = count

    return (count === 0) ? callback() : proxy

    function proxy(err, result) {
        if (proxy.count <= 0) {
            throw new Error('after called too many times')
        }
        --proxy.count

        // after first error, rest are passed to err_cb
        if (err) {
            bail = true
            callback(err)
            // future error callbacks will go to error handler
            callback = err_cb
        } else if (proxy.count === 0 && !bail) {
            callback(null, result)
        }
    }
}

function noop() {}


/***/ }),

/***/ 33437:
/***/ (function(module) {


/**
 * Array#filter.
 *
 * @param {Array} arr
 * @param {Function} fn
 * @param {Object=} self
 * @return {Array}
 * @throw TypeError
 */

module.exports = function (arr, fn, self) {
  if (arr.filter) return arr.filter(fn, self);
  if (void 0 === arr || null === arr) throw new TypeError;
  if ('function' != typeof fn) throw new TypeError;
  var ret = [];
  for (var i = 0; i < arr.length; i++) {
    if (!hasOwn.call(arr, i)) continue;
    var val = arr[i];
    if (fn.call(self, val, i, arr)) ret.push(val);
  }
  return ret;
};

var hasOwn = Object.prototype.hasOwnProperty;


/***/ }),

/***/ 50696:
/***/ (function(module) {

/**
 * An abstraction for slicing an arraybuffer even when
 * ArrayBuffer.prototype.slice is not supported
 *
 * @api public
 */

module.exports = function(arraybuffer, start, end) {
  var bytes = arraybuffer.byteLength;
  start = start || 0;
  end = end || bytes;

  if (arraybuffer.slice) { return arraybuffer.slice(start, end); }

  if (start < 0) { start += bytes; }
  if (end < 0) { end += bytes; }
  if (end > bytes) { end = bytes; }

  if (start >= bytes || start >= end || bytes === 0) {
    return new ArrayBuffer(0);
  }

  var abv = new Uint8Array(arraybuffer);
  var result = new Uint8Array(end - start);
  for (var i = start, ii = 0; i < end; i++, ii++) {
    result[ii] = abv[i];
  }
  return result.buffer;
};


/***/ }),

/***/ 87911:
/***/ (function(module) {


/**
 * Expose `Backoff`.
 */

module.exports = Backoff;

/**
 * Initialize backoff timer with `opts`.
 *
 * - `min` initial timeout in milliseconds [100]
 * - `max` max timeout [10000]
 * - `jitter` [0]
 * - `factor` [2]
 *
 * @param {Object} opts
 * @api public
 */

function Backoff(opts) {
  opts = opts || {};
  this.ms = opts.min || 100;
  this.max = opts.max || 10000;
  this.factor = opts.factor || 2;
  this.jitter = opts.jitter > 0 && opts.jitter <= 1 ? opts.jitter : 0;
  this.attempts = 0;
}

/**
 * Return the backoff duration.
 *
 * @return {Number}
 * @api public
 */

Backoff.prototype.duration = function(){
  var ms = this.ms * Math.pow(this.factor, this.attempts++);
  if (this.jitter) {
    var rand =  Math.random();
    var deviation = Math.floor(rand * this.jitter * ms);
    ms = (Math.floor(rand * 10) & 1) == 0  ? ms - deviation : ms + deviation;
  }
  return Math.min(ms, this.max) | 0;
};

/**
 * Reset the number of attempts.
 *
 * @api public
 */

Backoff.prototype.reset = function(){
  this.attempts = 0;
};

/**
 * Set the minimum duration
 *
 * @api public
 */

Backoff.prototype.setMin = function(min){
  this.ms = min;
};

/**
 * Set the maximum duration
 *
 * @api public
 */

Backoff.prototype.setMax = function(max){
  this.max = max;
};

/**
 * Set the jitter
 *
 * @api public
 */

Backoff.prototype.setJitter = function(jitter){
  this.jitter = jitter;
};



/***/ }),

/***/ 28328:
/***/ (function(__unused_webpack_module, exports) {

/*
 * base64-arraybuffer
 * https://github.com/niklasvh/base64-arraybuffer
 *
 * Copyright (c) 2012 Niklas von Hertzen
 * Licensed under the MIT license.
 */
(function(){
  "use strict";

  var chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";

  // Use a lookup table to find the index.
  var lookup = new Uint8Array(256);
  for (var i = 0; i < chars.length; i++) {
    lookup[chars.charCodeAt(i)] = i;
  }

  exports.encode = function(arraybuffer) {
    var bytes = new Uint8Array(arraybuffer),
    i, len = bytes.length, base64 = "";

    for (i = 0; i < len; i+=3) {
      base64 += chars[bytes[i] >> 2];
      base64 += chars[((bytes[i] & 3) << 4) | (bytes[i + 1] >> 4)];
      base64 += chars[((bytes[i + 1] & 15) << 2) | (bytes[i + 2] >> 6)];
      base64 += chars[bytes[i + 2] & 63];
    }

    if ((len % 3) === 2) {
      base64 = base64.substring(0, base64.length - 1) + "=";
    } else if (len % 3 === 1) {
      base64 = base64.substring(0, base64.length - 2) + "==";
    }

    return base64;
  };

  exports.decode =  function(base64) {
    var bufferLength = base64.length * 0.75,
    len = base64.length, i, p = 0,
    encoded1, encoded2, encoded3, encoded4;

    if (base64[base64.length - 1] === "=") {
      bufferLength--;
      if (base64[base64.length - 2] === "=") {
        bufferLength--;
      }
    }

    var arraybuffer = new ArrayBuffer(bufferLength),
    bytes = new Uint8Array(arraybuffer);

    for (i = 0; i < len; i+=4) {
      encoded1 = lookup[base64.charCodeAt(i)];
      encoded2 = lookup[base64.charCodeAt(i+1)];
      encoded3 = lookup[base64.charCodeAt(i+2)];
      encoded4 = lookup[base64.charCodeAt(i+3)];

      bytes[p++] = (encoded1 << 2) | (encoded2 >> 4);
      bytes[p++] = ((encoded2 & 15) << 4) | (encoded3 >> 2);
      bytes[p++] = ((encoded3 & 3) << 6) | (encoded4 & 63);
    }

    return arraybuffer;
  };
})();


/***/ }),

/***/ 23055:
/***/ (function(module) {

/**
 * Create a blob builder even when vendor prefixes exist
 */

var BlobBuilder = typeof BlobBuilder !== 'undefined' ? BlobBuilder :
  typeof WebKitBlobBuilder !== 'undefined' ? WebKitBlobBuilder :
  typeof MSBlobBuilder !== 'undefined' ? MSBlobBuilder :
  typeof MozBlobBuilder !== 'undefined' ? MozBlobBuilder : 
  false;

/**
 * Check if Blob constructor is supported
 */

var blobSupported = (function() {
  try {
    var a = new Blob(['hi']);
    return a.size === 2;
  } catch(e) {
    return false;
  }
})();

/**
 * Check if Blob constructor supports ArrayBufferViews
 * Fails in Safari 6, so we need to map to ArrayBuffers there.
 */

var blobSupportsArrayBufferView = blobSupported && (function() {
  try {
    var b = new Blob([new Uint8Array([1,2])]);
    return b.size === 2;
  } catch(e) {
    return false;
  }
})();

/**
 * Check if BlobBuilder is supported
 */

var blobBuilderSupported = BlobBuilder
  && BlobBuilder.prototype.append
  && BlobBuilder.prototype.getBlob;

/**
 * Helper function that maps ArrayBufferViews to ArrayBuffers
 * Used by BlobBuilder constructor and old browsers that didn't
 * support it in the Blob constructor.
 */

function mapArrayBufferViews(ary) {
  return ary.map(function(chunk) {
    if (chunk.buffer instanceof ArrayBuffer) {
      var buf = chunk.buffer;

      // if this is a subarray, make a copy so we only
      // include the subarray region from the underlying buffer
      if (chunk.byteLength !== buf.byteLength) {
        var copy = new Uint8Array(chunk.byteLength);
        copy.set(new Uint8Array(buf, chunk.byteOffset, chunk.byteLength));
        buf = copy.buffer;
      }

      return buf;
    }

    return chunk;
  });
}

function BlobBuilderConstructor(ary, options) {
  options = options || {};

  var bb = new BlobBuilder();
  mapArrayBufferViews(ary).forEach(function(part) {
    bb.append(part);
  });

  return (options.type) ? bb.getBlob(options.type) : bb.getBlob();
};

function BlobConstructor(ary, options) {
  return new Blob(mapArrayBufferViews(ary), options || {});
};

if (typeof Blob !== 'undefined') {
  BlobBuilderConstructor.prototype = Blob.prototype;
  BlobConstructor.prototype = Blob.prototype;
}

module.exports = (function() {
  if (blobSupported) {
    return blobSupportsArrayBufferView ? Blob : BlobConstructor;
  } else if (blobBuilderSupported) {
    return BlobBuilderConstructor;
  } else {
    return undefined;
  }
})();


/***/ }),

/***/ 26744:
/***/ (function(module) {

module.exports = {
  "100": "Continue",
  "101": "Switching Protocols",
  "102": "Processing",
  "200": "OK",
  "201": "Created",
  "202": "Accepted",
  "203": "Non-Authoritative Information",
  "204": "No Content",
  "205": "Reset Content",
  "206": "Partial Content",
  "207": "Multi-Status",
  "208": "Already Reported",
  "226": "IM Used",
  "300": "Multiple Choices",
  "301": "Moved Permanently",
  "302": "Found",
  "303": "See Other",
  "304": "Not Modified",
  "305": "Use Proxy",
  "307": "Temporary Redirect",
  "308": "Permanent Redirect",
  "400": "Bad Request",
  "401": "Unauthorized",
  "402": "Payment Required",
  "403": "Forbidden",
  "404": "Not Found",
  "405": "Method Not Allowed",
  "406": "Not Acceptable",
  "407": "Proxy Authentication Required",
  "408": "Request Timeout",
  "409": "Conflict",
  "410": "Gone",
  "411": "Length Required",
  "412": "Precondition Failed",
  "413": "Payload Too Large",
  "414": "URI Too Long",
  "415": "Unsupported Media Type",
  "416": "Range Not Satisfiable",
  "417": "Expectation Failed",
  "418": "I'm a teapot",
  "421": "Misdirected Request",
  "422": "Unprocessable Entity",
  "423": "Locked",
  "424": "Failed Dependency",
  "425": "Unordered Collection",
  "426": "Upgrade Required",
  "428": "Precondition Required",
  "429": "Too Many Requests",
  "431": "Request Header Fields Too Large",
  "500": "Internal Server Error",
  "501": "Not Implemented",
  "502": "Bad Gateway",
  "503": "Service Unavailable",
  "504": "Gateway Timeout",
  "505": "HTTP Version Not Supported",
  "506": "Variant Also Negotiates",
  "507": "Insufficient Storage",
  "508": "Loop Detected",
  "509": "Bandwidth Limit Exceeded",
  "510": "Not Extended",
  "511": "Network Authentication Required"
}


/***/ }),

/***/ 62680:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var GetIntrinsic = __webpack_require__(67286);

var callBind = __webpack_require__(89429);

var $indexOf = callBind(GetIntrinsic('String.prototype.indexOf'));

module.exports = function callBoundIntrinsic(name, allowMissing) {
	var intrinsic = GetIntrinsic(name, !!allowMissing);
	if (typeof intrinsic === 'function' && $indexOf(name, '.prototype.') > -1) {
		return callBind(intrinsic);
	}
	return intrinsic;
};


/***/ }),

/***/ 89429:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var bind = __webpack_require__(4090);
var GetIntrinsic = __webpack_require__(67286);

var $apply = GetIntrinsic('%Function.prototype.apply%');
var $call = GetIntrinsic('%Function.prototype.call%');
var $reflectApply = GetIntrinsic('%Reflect.apply%', true) || bind.call($call, $apply);

var $gOPD = GetIntrinsic('%Object.getOwnPropertyDescriptor%', true);
var $defineProperty = GetIntrinsic('%Object.defineProperty%', true);
var $max = GetIntrinsic('%Math.max%');

if ($defineProperty) {
	try {
		$defineProperty({}, 'a', { value: 1 });
	} catch (e) {
		// IE 8 has a broken defineProperty
		$defineProperty = null;
	}
}

module.exports = function callBind(originalFunction) {
	var func = $reflectApply(bind, $call, arguments);
	if ($gOPD && $defineProperty) {
		var desc = $gOPD(func, 'length');
		if (desc.configurable) {
			// original length, plus the receiver, minus any additional arguments (after the receiver)
			$defineProperty(
				func,
				'length',
				{ value: 1 + $max(0, originalFunction.length - (arguments.length - 1)) }
			);
		}
	}
	return func;
};

var applyBind = function applyBind() {
	return $reflectApply(bind, $apply, arguments);
};

if ($defineProperty) {
	$defineProperty(module.exports, 'apply', { value: applyBind });
} else {
	module.exports.apply = applyBind;
}


/***/ }),

/***/ 72779:
/***/ (function(module, exports) {

var __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/*!
  Copyright (c) 2018 Jed Watson.
  Licensed under the MIT License (MIT), see
  http://jedwatson.github.io/classnames
*/
/* global define */

(function () {
	'use strict';

	var hasOwn = {}.hasOwnProperty;

	function classNames() {
		var classes = [];

		for (var i = 0; i < arguments.length; i++) {
			var arg = arguments[i];
			if (!arg) continue;

			var argType = typeof arg;

			if (argType === 'string' || argType === 'number') {
				classes.push(arg);
			} else if (Array.isArray(arg)) {
				if (arg.length) {
					var inner = classNames.apply(null, arg);
					if (inner) {
						classes.push(inner);
					}
				}
			} else if (argType === 'object') {
				if (arg.toString === Object.prototype.toString) {
					for (var key in arg) {
						if (hasOwn.call(arg, key) && arg[key]) {
							classes.push(key);
						}
					}
				} else {
					classes.push(arg.toString());
				}
			}
		}

		return classes.join(' ');
	}

	if ( true && module.exports) {
		classNames.default = classNames;
		module.exports = classNames;
	} else if (true) {
		// register as 'classnames', consistent with npm package name
		!(__WEBPACK_AMD_DEFINE_ARRAY__ = [], __WEBPACK_AMD_DEFINE_RESULT__ = (function () {
			return classNames;
		}).apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	} else {}
}());


/***/ }),

/***/ 6277:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "default": function() { return /* export default binding */ __WEBPACK_DEFAULT_EXPORT__; }
/* harmony export */ });
function toVal(mix) {
	var k, y, str='';

	if (typeof mix === 'string' || typeof mix === 'number') {
		str += mix;
	} else if (typeof mix === 'object') {
		if (Array.isArray(mix)) {
			for (k=0; k < mix.length; k++) {
				if (mix[k]) {
					if (y = toVal(mix[k])) {
						str && (str += ' ');
						str += y;
					}
				}
			}
		} else {
			for (k in mix) {
				if (mix[k]) {
					str && (str += ' ');
					str += k;
				}
			}
		}
	}

	return str;
}

/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__() {
	var i=0, tmp, x, str='';
	while (i < arguments.length) {
		if (tmp = arguments[i++]) {
			if (x = toVal(tmp)) {
				str && (str += ' ');
				str += x
			}
		}
	}
	return str;
}


/***/ }),

/***/ 42150:
/***/ (function(module) {

/**
 * Slice reference.
 */

var slice = [].slice;

/**
 * Bind `obj` to `fn`.
 *
 * @param {Object} obj
 * @param {Function|String} fn or string
 * @return {Function}
 * @api public
 */

module.exports = function(obj, fn){
  if ('string' == typeof fn) fn = obj[fn];
  if ('function' != typeof fn) throw new Error('bind() requires a function');
  var args = slice.call(arguments, 2);
  return function(){
    return fn.apply(obj, args.concat(slice.call(arguments)));
  }
};


/***/ }),

/***/ 99238:
/***/ (function(module) {


module.exports = function(a, b){
  var fn = function(){};
  fn.prototype = b.prototype;
  a.prototype = new fn;
  a.prototype.constructor = a;
};

/***/ }),

/***/ 13421:
/***/ (function(__unused_webpack_module, exports) {

"use strict";
/*!
 * cookie
 * Copyright(c) 2012-2014 Roman Shtylman
 * Copyright(c) 2015 Douglas Christopher Wilson
 * MIT Licensed
 */



/**
 * Module exports.
 * @public
 */

exports.parse = parse;
exports.serialize = serialize;

/**
 * Module variables.
 * @private
 */

var decode = decodeURIComponent;
var encode = encodeURIComponent;
var pairSplitRegExp = /; */;

/**
 * RegExp to match field-content in RFC 7230 sec 3.2
 *
 * field-content = field-vchar [ 1*( SP / HTAB ) field-vchar ]
 * field-vchar   = VCHAR / obs-text
 * obs-text      = %x80-FF
 */

var fieldContentRegExp = /^[\u0009\u0020-\u007e\u0080-\u00ff]+$/;

/**
 * Parse a cookie header.
 *
 * Parse the given cookie header string into an object
 * The object has the various cookies as keys(names) => values
 *
 * @param {string} str
 * @param {object} [options]
 * @return {object}
 * @public
 */

function parse(str, options) {
  if (typeof str !== 'string') {
    throw new TypeError('argument str must be a string');
  }

  var obj = {}
  var opt = options || {};
  var pairs = str.split(pairSplitRegExp);
  var dec = opt.decode || decode;

  for (var i = 0; i < pairs.length; i++) {
    var pair = pairs[i];
    var eq_idx = pair.indexOf('=');

    // skip things that don't look like key=value
    if (eq_idx < 0) {
      continue;
    }

    var key = pair.substr(0, eq_idx).trim()
    var val = pair.substr(++eq_idx, pair.length).trim();

    // quoted values
    if ('"' == val[0]) {
      val = val.slice(1, -1);
    }

    // only assign once
    if (undefined == obj[key]) {
      obj[key] = tryDecode(val, dec);
    }
  }

  return obj;
}

/**
 * Serialize data into a cookie header.
 *
 * Serialize the a name value pair into a cookie string suitable for
 * http headers. An optional options object specified cookie parameters.
 *
 * serialize('foo', 'bar', { httpOnly: true })
 *   => "foo=bar; httpOnly"
 *
 * @param {string} name
 * @param {string} val
 * @param {object} [options]
 * @return {string}
 * @public
 */

function serialize(name, val, options) {
  var opt = options || {};
  var enc = opt.encode || encode;

  if (typeof enc !== 'function') {
    throw new TypeError('option encode is invalid');
  }

  if (!fieldContentRegExp.test(name)) {
    throw new TypeError('argument name is invalid');
  }

  var value = enc(val);

  if (value && !fieldContentRegExp.test(value)) {
    throw new TypeError('argument val is invalid');
  }

  var str = name + '=' + value;

  if (null != opt.maxAge) {
    var maxAge = opt.maxAge - 0;

    if (isNaN(maxAge) || !isFinite(maxAge)) {
      throw new TypeError('option maxAge is invalid')
    }

    str += '; Max-Age=' + Math.floor(maxAge);
  }

  if (opt.domain) {
    if (!fieldContentRegExp.test(opt.domain)) {
      throw new TypeError('option domain is invalid');
    }

    str += '; Domain=' + opt.domain;
  }

  if (opt.path) {
    if (!fieldContentRegExp.test(opt.path)) {
      throw new TypeError('option path is invalid');
    }

    str += '; Path=' + opt.path;
  }

  if (opt.expires) {
    if (typeof opt.expires.toUTCString !== 'function') {
      throw new TypeError('option expires is invalid');
    }

    str += '; Expires=' + opt.expires.toUTCString();
  }

  if (opt.httpOnly) {
    str += '; HttpOnly';
  }

  if (opt.secure) {
    str += '; Secure';
  }

  if (opt.sameSite) {
    var sameSite = typeof opt.sameSite === 'string'
      ? opt.sameSite.toLowerCase() : opt.sameSite;

    switch (sameSite) {
      case true:
        str += '; SameSite=Strict';
        break;
      case 'lax':
        str += '; SameSite=Lax';
        break;
      case 'strict':
        str += '; SameSite=Strict';
        break;
      case 'none':
        str += '; SameSite=None';
        break;
      default:
        throw new TypeError('option sameSite is invalid');
    }
  }

  return str;
}

/**
 * Try decoding a string using a decoding function.
 *
 * @param {string} str
 * @param {function} decode
 * @private
 */

function tryDecode(str, decode) {
  try {
    return decode(str);
  } catch (e) {
    return str;
  }
}


/***/ }),

/***/ 77111:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var isCallable = __webpack_require__(26733);
var tryToString = __webpack_require__(59821);

var TypeError = global.TypeError;

// `Assert: IsCallable(argument) is true`
module.exports = function (argument) {
  if (isCallable(argument)) return argument;
  throw TypeError(tryToString(argument) + ' is not a function');
};


/***/ }),

/***/ 88505:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var isCallable = __webpack_require__(26733);

var String = global.String;
var TypeError = global.TypeError;

module.exports = function (argument) {
  if (typeof argument == 'object' || isCallable(argument)) return argument;
  throw TypeError("Can't set " + String(argument) + ' as a prototype');
};


/***/ }),

/***/ 21176:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var isObject = __webpack_require__(85052);

var String = global.String;
var TypeError = global.TypeError;

// `Assert: Type(argument) is Object`
module.exports = function (argument) {
  if (isObject(argument)) return argument;
  throw TypeError(String(argument) + ' is not an object');
};


/***/ }),

/***/ 53339:
/***/ (function(module) {

// eslint-disable-next-line es/no-typed-arrays -- safe
module.exports = typeof ArrayBuffer != 'undefined' && typeof DataView != 'undefined';


/***/ }),

/***/ 9918:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";

var NATIVE_ARRAY_BUFFER = __webpack_require__(53339);
var DESCRIPTORS = __webpack_require__(7400);
var global = __webpack_require__(9859);
var isCallable = __webpack_require__(26733);
var isObject = __webpack_require__(85052);
var hasOwn = __webpack_require__(98270);
var classof = __webpack_require__(81589);
var tryToString = __webpack_require__(59821);
var createNonEnumerableProperty = __webpack_require__(75762);
var redefine = __webpack_require__(27487);
var defineProperty = (__webpack_require__(31787).f);
var isPrototypeOf = __webpack_require__(91321);
var getPrototypeOf = __webpack_require__(67567);
var setPrototypeOf = __webpack_require__(56540);
var wellKnownSymbol = __webpack_require__(70095);
var uid = __webpack_require__(81441);

var Int8Array = global.Int8Array;
var Int8ArrayPrototype = Int8Array && Int8Array.prototype;
var Uint8ClampedArray = global.Uint8ClampedArray;
var Uint8ClampedArrayPrototype = Uint8ClampedArray && Uint8ClampedArray.prototype;
var TypedArray = Int8Array && getPrototypeOf(Int8Array);
var TypedArrayPrototype = Int8ArrayPrototype && getPrototypeOf(Int8ArrayPrototype);
var ObjectPrototype = Object.prototype;
var TypeError = global.TypeError;

var TO_STRING_TAG = wellKnownSymbol('toStringTag');
var TYPED_ARRAY_TAG = uid('TYPED_ARRAY_TAG');
var TYPED_ARRAY_CONSTRUCTOR = uid('TYPED_ARRAY_CONSTRUCTOR');
// Fixing native typed arrays in Opera Presto crashes the browser, see #595
var NATIVE_ARRAY_BUFFER_VIEWS = NATIVE_ARRAY_BUFFER && !!setPrototypeOf && classof(global.opera) !== 'Opera';
var TYPED_ARRAY_TAG_REQIRED = false;
var NAME, Constructor, Prototype;

var TypedArrayConstructorsList = {
  Int8Array: 1,
  Uint8Array: 1,
  Uint8ClampedArray: 1,
  Int16Array: 2,
  Uint16Array: 2,
  Int32Array: 4,
  Uint32Array: 4,
  Float32Array: 4,
  Float64Array: 8
};

var BigIntArrayConstructorsList = {
  BigInt64Array: 8,
  BigUint64Array: 8
};

var isView = function isView(it) {
  if (!isObject(it)) return false;
  var klass = classof(it);
  return klass === 'DataView'
    || hasOwn(TypedArrayConstructorsList, klass)
    || hasOwn(BigIntArrayConstructorsList, klass);
};

var isTypedArray = function (it) {
  if (!isObject(it)) return false;
  var klass = classof(it);
  return hasOwn(TypedArrayConstructorsList, klass)
    || hasOwn(BigIntArrayConstructorsList, klass);
};

var aTypedArray = function (it) {
  if (isTypedArray(it)) return it;
  throw TypeError('Target is not a typed array');
};

var aTypedArrayConstructor = function (C) {
  if (isCallable(C) && (!setPrototypeOf || isPrototypeOf(TypedArray, C))) return C;
  throw TypeError(tryToString(C) + ' is not a typed array constructor');
};

var exportTypedArrayMethod = function (KEY, property, forced) {
  if (!DESCRIPTORS) return;
  if (forced) for (var ARRAY in TypedArrayConstructorsList) {
    var TypedArrayConstructor = global[ARRAY];
    if (TypedArrayConstructor && hasOwn(TypedArrayConstructor.prototype, KEY)) try {
      delete TypedArrayConstructor.prototype[KEY];
    } catch (error) { /* empty */ }
  }
  if (!TypedArrayPrototype[KEY] || forced) {
    redefine(TypedArrayPrototype, KEY, forced ? property
      : NATIVE_ARRAY_BUFFER_VIEWS && Int8ArrayPrototype[KEY] || property);
  }
};

var exportTypedArrayStaticMethod = function (KEY, property, forced) {
  var ARRAY, TypedArrayConstructor;
  if (!DESCRIPTORS) return;
  if (setPrototypeOf) {
    if (forced) for (ARRAY in TypedArrayConstructorsList) {
      TypedArrayConstructor = global[ARRAY];
      if (TypedArrayConstructor && hasOwn(TypedArrayConstructor, KEY)) try {
        delete TypedArrayConstructor[KEY];
      } catch (error) { /* empty */ }
    }
    if (!TypedArray[KEY] || forced) {
      // V8 ~ Chrome 49-50 `%TypedArray%` methods are non-writable non-configurable
      try {
        return redefine(TypedArray, KEY, forced ? property : NATIVE_ARRAY_BUFFER_VIEWS && TypedArray[KEY] || property);
      } catch (error) { /* empty */ }
    } else return;
  }
  for (ARRAY in TypedArrayConstructorsList) {
    TypedArrayConstructor = global[ARRAY];
    if (TypedArrayConstructor && (!TypedArrayConstructor[KEY] || forced)) {
      redefine(TypedArrayConstructor, KEY, property);
    }
  }
};

for (NAME in TypedArrayConstructorsList) {
  Constructor = global[NAME];
  Prototype = Constructor && Constructor.prototype;
  if (Prototype) createNonEnumerableProperty(Prototype, TYPED_ARRAY_CONSTRUCTOR, Constructor);
  else NATIVE_ARRAY_BUFFER_VIEWS = false;
}

for (NAME in BigIntArrayConstructorsList) {
  Constructor = global[NAME];
  Prototype = Constructor && Constructor.prototype;
  if (Prototype) createNonEnumerableProperty(Prototype, TYPED_ARRAY_CONSTRUCTOR, Constructor);
}

// WebKit bug - typed arrays constructors prototype is Object.prototype
if (!NATIVE_ARRAY_BUFFER_VIEWS || !isCallable(TypedArray) || TypedArray === Function.prototype) {
  // eslint-disable-next-line no-shadow -- safe
  TypedArray = function TypedArray() {
    throw TypeError('Incorrect invocation');
  };
  if (NATIVE_ARRAY_BUFFER_VIEWS) for (NAME in TypedArrayConstructorsList) {
    if (global[NAME]) setPrototypeOf(global[NAME], TypedArray);
  }
}

if (!NATIVE_ARRAY_BUFFER_VIEWS || !TypedArrayPrototype || TypedArrayPrototype === ObjectPrototype) {
  TypedArrayPrototype = TypedArray.prototype;
  if (NATIVE_ARRAY_BUFFER_VIEWS) for (NAME in TypedArrayConstructorsList) {
    if (global[NAME]) setPrototypeOf(global[NAME].prototype, TypedArrayPrototype);
  }
}

// WebKit bug - one more object in Uint8ClampedArray prototype chain
if (NATIVE_ARRAY_BUFFER_VIEWS && getPrototypeOf(Uint8ClampedArrayPrototype) !== TypedArrayPrototype) {
  setPrototypeOf(Uint8ClampedArrayPrototype, TypedArrayPrototype);
}

if (DESCRIPTORS && !hasOwn(TypedArrayPrototype, TO_STRING_TAG)) {
  TYPED_ARRAY_TAG_REQIRED = true;
  defineProperty(TypedArrayPrototype, TO_STRING_TAG, { get: function () {
    return isObject(this) ? this[TYPED_ARRAY_TAG] : undefined;
  } });
  for (NAME in TypedArrayConstructorsList) if (global[NAME]) {
    createNonEnumerableProperty(global[NAME], TYPED_ARRAY_TAG, NAME);
  }
}

module.exports = {
  NATIVE_ARRAY_BUFFER_VIEWS: NATIVE_ARRAY_BUFFER_VIEWS,
  TYPED_ARRAY_CONSTRUCTOR: TYPED_ARRAY_CONSTRUCTOR,
  TYPED_ARRAY_TAG: TYPED_ARRAY_TAG_REQIRED && TYPED_ARRAY_TAG,
  aTypedArray: aTypedArray,
  aTypedArrayConstructor: aTypedArrayConstructor,
  exportTypedArrayMethod: exportTypedArrayMethod,
  exportTypedArrayStaticMethod: exportTypedArrayStaticMethod,
  isView: isView,
  isTypedArray: isTypedArray,
  TypedArray: TypedArray,
  TypedArrayPrototype: TypedArrayPrototype
};


/***/ }),

/***/ 19540:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var toIndexedObject = __webpack_require__(10905);
var toAbsoluteIndex = __webpack_require__(43231);
var lengthOfArrayLike = __webpack_require__(39646);

// `Array.prototype.{ indexOf, includes }` methods implementation
var createMethod = function (IS_INCLUDES) {
  return function ($this, el, fromIndex) {
    var O = toIndexedObject($this);
    var length = lengthOfArrayLike(O);
    var index = toAbsoluteIndex(fromIndex, length);
    var value;
    // Array#includes uses SameValueZero equality algorithm
    // eslint-disable-next-line no-self-compare -- NaN check
    if (IS_INCLUDES && el != el) while (length > index) {
      value = O[index++];
      // eslint-disable-next-line no-self-compare -- NaN check
      if (value != value) return true;
    // Array#indexOf ignores holes, Array#includes - not
    } else for (;length > index; index++) {
      if ((IS_INCLUDES || index in O) && O[index] === el) return IS_INCLUDES || index || 0;
    } return !IS_INCLUDES && -1;
  };
};

module.exports = {
  // `Array.prototype.includes` method
  // https://tc39.es/ecma262/#sec-array.prototype.includes
  includes: createMethod(true),
  // `Array.prototype.indexOf` method
  // https://tc39.es/ecma262/#sec-array.prototype.indexof
  indexOf: createMethod(false)
};


/***/ }),

/***/ 1909:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var uncurryThis = __webpack_require__(65968);

module.exports = uncurryThis([].slice);


/***/ }),

/***/ 27079:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var uncurryThis = __webpack_require__(65968);

var toString = uncurryThis({}.toString);
var stringSlice = uncurryThis(''.slice);

module.exports = function (it) {
  return stringSlice(toString(it), 8, -1);
};


/***/ }),

/***/ 81589:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var TO_STRING_TAG_SUPPORT = __webpack_require__(71601);
var isCallable = __webpack_require__(26733);
var classofRaw = __webpack_require__(27079);
var wellKnownSymbol = __webpack_require__(70095);

var TO_STRING_TAG = wellKnownSymbol('toStringTag');
var Object = global.Object;

// ES3 wrong here
var CORRECT_ARGUMENTS = classofRaw(function () { return arguments; }()) == 'Arguments';

// fallback for IE11 Script Access Denied error
var tryGet = function (it, key) {
  try {
    return it[key];
  } catch (error) { /* empty */ }
};

// getting tag from ES6+ `Object.prototype.toString`
module.exports = TO_STRING_TAG_SUPPORT ? classofRaw : function (it) {
  var O, tag, result;
  return it === undefined ? 'Undefined' : it === null ? 'Null'
    // @@toStringTag case
    : typeof (tag = tryGet(O = Object(it), TO_STRING_TAG)) == 'string' ? tag
    // builtinTag case
    : CORRECT_ARGUMENTS ? classofRaw(O)
    // ES3 arguments fallback
    : (result = classofRaw(O)) == 'Object' && isCallable(O.callee) ? 'Arguments' : result;
};


/***/ }),

/***/ 77081:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var hasOwn = __webpack_require__(98270);
var ownKeys = __webpack_require__(4826);
var getOwnPropertyDescriptorModule = __webpack_require__(97933);
var definePropertyModule = __webpack_require__(31787);

module.exports = function (target, source) {
  var keys = ownKeys(source);
  var defineProperty = definePropertyModule.f;
  var getOwnPropertyDescriptor = getOwnPropertyDescriptorModule.f;
  for (var i = 0; i < keys.length; i++) {
    var key = keys[i];
    if (!hasOwn(target, key)) defineProperty(target, key, getOwnPropertyDescriptor(source, key));
  }
};


/***/ }),

/***/ 27528:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var fails = __webpack_require__(24229);

module.exports = !fails(function () {
  function F() { /* empty */ }
  F.prototype.constructor = null;
  // eslint-disable-next-line es/no-object-getprototypeof -- required for testing
  return Object.getPrototypeOf(new F()) !== F.prototype;
});


/***/ }),

/***/ 75762:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var DESCRIPTORS = __webpack_require__(7400);
var definePropertyModule = __webpack_require__(31787);
var createPropertyDescriptor = __webpack_require__(65358);

module.exports = DESCRIPTORS ? function (object, key, value) {
  return definePropertyModule.f(object, key, createPropertyDescriptor(1, value));
} : function (object, key, value) {
  object[key] = value;
  return object;
};


/***/ }),

/***/ 65358:
/***/ (function(module) {

module.exports = function (bitmap, value) {
  return {
    enumerable: !(bitmap & 1),
    configurable: !(bitmap & 2),
    writable: !(bitmap & 4),
    value: value
  };
};


/***/ }),

/***/ 7400:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var fails = __webpack_require__(24229);

// Detect IE8's incomplete defineProperty implementation
module.exports = !fails(function () {
  // eslint-disable-next-line es/no-object-defineproperty -- required for testing
  return Object.defineProperty({}, 1, { get: function () { return 7; } })[1] != 7;
});


/***/ }),

/***/ 22635:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var isObject = __webpack_require__(85052);

var document = global.document;
// typeof document.createElement is 'object' in old IE
var EXISTS = isObject(document) && isObject(document.createElement);

module.exports = function (it) {
  return EXISTS ? document.createElement(it) : {};
};


/***/ }),

/***/ 32023:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var userAgent = __webpack_require__(80598);

module.exports = /(?:ipad|iphone|ipod).*applewebkit/i.test(userAgent);


/***/ }),

/***/ 28801:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var classof = __webpack_require__(27079);
var global = __webpack_require__(9859);

module.exports = classof(global.process) == 'process';


/***/ }),

/***/ 80598:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var getBuiltIn = __webpack_require__(31333);

module.exports = getBuiltIn('navigator', 'userAgent') || '';


/***/ }),

/***/ 6358:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var userAgent = __webpack_require__(80598);

var process = global.process;
var Deno = global.Deno;
var versions = process && process.versions || Deno && Deno.version;
var v8 = versions && versions.v8;
var match, version;

if (v8) {
  match = v8.split('.');
  // in old Chrome, versions of V8 isn't V8 = Chrome / 10
  // but their correct versions are not interesting for us
  version = match[0] > 0 && match[0] < 4 ? 1 : +(match[0] + match[1]);
}

// BrowserFS NodeJS `process` polyfill incorrectly set `.v8` to `0.0`
// so check `userAgent` even if `.v8` exists, but 0
if (!version && userAgent) {
  match = userAgent.match(/Edge\/(\d+)/);
  if (!match || match[1] >= 74) {
    match = userAgent.match(/Chrome\/(\d+)/);
    if (match) version = +match[1];
  }
}

module.exports = version;


/***/ }),

/***/ 13837:
/***/ (function(module) {

// IE8- don't enum bug keys
module.exports = [
  'constructor',
  'hasOwnProperty',
  'isPrototypeOf',
  'propertyIsEnumerable',
  'toLocaleString',
  'toString',
  'valueOf'
];


/***/ }),

/***/ 23103:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var getOwnPropertyDescriptor = (__webpack_require__(97933).f);
var createNonEnumerableProperty = __webpack_require__(75762);
var redefine = __webpack_require__(27487);
var setGlobal = __webpack_require__(12079);
var copyConstructorProperties = __webpack_require__(77081);
var isForced = __webpack_require__(46541);

/*
  options.target      - name of the target object
  options.global      - target is the global object
  options.stat        - export as static methods of target
  options.proto       - export as prototype methods of target
  options.real        - real prototype method for the `pure` version
  options.forced      - export even if the native feature is available
  options.bind        - bind methods to the target, required for the `pure` version
  options.wrap        - wrap constructors to preventing global pollution, required for the `pure` version
  options.unsafe      - use the simple assignment of property instead of delete + defineProperty
  options.sham        - add a flag to not completely full polyfills
  options.enumerable  - export as enumerable property
  options.noTargetGet - prevent calling a getter on target
  options.name        - the .name of the function if it does not match the key
*/
module.exports = function (options, source) {
  var TARGET = options.target;
  var GLOBAL = options.global;
  var STATIC = options.stat;
  var FORCED, target, key, targetProperty, sourceProperty, descriptor;
  if (GLOBAL) {
    target = global;
  } else if (STATIC) {
    target = global[TARGET] || setGlobal(TARGET, {});
  } else {
    target = (global[TARGET] || {}).prototype;
  }
  if (target) for (key in source) {
    sourceProperty = source[key];
    if (options.noTargetGet) {
      descriptor = getOwnPropertyDescriptor(target, key);
      targetProperty = descriptor && descriptor.value;
    } else targetProperty = target[key];
    FORCED = isForced(GLOBAL ? key : TARGET + (STATIC ? '.' : '#') + key, options.forced);
    // contained in target
    if (!FORCED && targetProperty !== undefined) {
      if (typeof sourceProperty == typeof targetProperty) continue;
      copyConstructorProperties(sourceProperty, targetProperty);
    }
    // add a flag to not completely full polyfills
    if (options.sham || (targetProperty && targetProperty.sham)) {
      createNonEnumerableProperty(sourceProperty, 'sham', true);
    }
    // extend global
    redefine(target, key, sourceProperty, options);
  }
};


/***/ }),

/***/ 24229:
/***/ (function(module) {

module.exports = function (exec) {
  try {
    return !!exec();
  } catch (error) {
    return true;
  }
};


/***/ }),

/***/ 53171:
/***/ (function(module) {

var FunctionPrototype = Function.prototype;
var apply = FunctionPrototype.apply;
var bind = FunctionPrototype.bind;
var call = FunctionPrototype.call;

// eslint-disable-next-line es/no-reflect -- safe
module.exports = typeof Reflect == 'object' && Reflect.apply || (bind ? call.bind(apply) : function () {
  return call.apply(apply, arguments);
});


/***/ }),

/***/ 97636:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var uncurryThis = __webpack_require__(65968);
var aCallable = __webpack_require__(77111);

var bind = uncurryThis(uncurryThis.bind);

// optional / simple context binding
module.exports = function (fn, that) {
  aCallable(fn);
  return that === undefined ? fn : bind ? bind(fn, that) : function (/* ...args */) {
    return fn.apply(that, arguments);
  };
};


/***/ }),

/***/ 20266:
/***/ (function(module) {

var call = Function.prototype.call;

module.exports = call.bind ? call.bind(call) : function () {
  return call.apply(call, arguments);
};


/***/ }),

/***/ 51805:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var DESCRIPTORS = __webpack_require__(7400);
var hasOwn = __webpack_require__(98270);

var FunctionPrototype = Function.prototype;
// eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
var getDescriptor = DESCRIPTORS && Object.getOwnPropertyDescriptor;

var EXISTS = hasOwn(FunctionPrototype, 'name');
// additional protection from minified / mangled / dropped function names
var PROPER = EXISTS && (function something() { /* empty */ }).name === 'something';
var CONFIGURABLE = EXISTS && (!DESCRIPTORS || (DESCRIPTORS && getDescriptor(FunctionPrototype, 'name').configurable));

module.exports = {
  EXISTS: EXISTS,
  PROPER: PROPER,
  CONFIGURABLE: CONFIGURABLE
};


/***/ }),

/***/ 65968:
/***/ (function(module) {

var FunctionPrototype = Function.prototype;
var bind = FunctionPrototype.bind;
var call = FunctionPrototype.call;
var callBind = bind && bind.bind(call);

module.exports = bind ? function (fn) {
  return fn && callBind(call, fn);
} : function (fn) {
  return fn && function () {
    return call.apply(fn, arguments);
  };
};


/***/ }),

/***/ 31333:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var isCallable = __webpack_require__(26733);

var aFunction = function (argument) {
  return isCallable(argument) ? argument : undefined;
};

module.exports = function (namespace, method) {
  return arguments.length < 2 ? aFunction(global[namespace]) : global[namespace] && global[namespace][method];
};


/***/ }),

/***/ 55300:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var aCallable = __webpack_require__(77111);

// `GetMethod` abstract operation
// https://tc39.es/ecma262/#sec-getmethod
module.exports = function (V, P) {
  var func = V[P];
  return func == null ? undefined : aCallable(func);
};


/***/ }),

/***/ 9859:
/***/ (function(module) {

var check = function (it) {
  return it && it.Math == Math && it;
};

// https://github.com/zloirock/core-js/issues/86#issuecomment-115759028
module.exports =
  // eslint-disable-next-line es/no-global-this -- safe
  check(typeof globalThis == 'object' && globalThis) ||
  check(typeof window == 'object' && window) ||
  // eslint-disable-next-line no-restricted-globals -- safe
  check(typeof self == 'object' && self) ||
  check(typeof window == 'object' && window) ||
  // eslint-disable-next-line no-new-func -- fallback
  (function () { return this; })() || Function('return this')();


/***/ }),

/***/ 98270:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var uncurryThis = __webpack_require__(65968);
var toObject = __webpack_require__(92991);

var hasOwnProperty = uncurryThis({}.hasOwnProperty);

// `HasOwnProperty` abstract operation
// https://tc39.es/ecma262/#sec-hasownproperty
module.exports = Object.hasOwn || function hasOwn(it, key) {
  return hasOwnProperty(toObject(it), key);
};


/***/ }),

/***/ 95977:
/***/ (function(module) {

module.exports = {};


/***/ }),

/***/ 53777:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var getBuiltIn = __webpack_require__(31333);

module.exports = getBuiltIn('document', 'documentElement');


/***/ }),

/***/ 64394:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var DESCRIPTORS = __webpack_require__(7400);
var fails = __webpack_require__(24229);
var createElement = __webpack_require__(22635);

// Thank's IE8 for his funny defineProperty
module.exports = !DESCRIPTORS && !fails(function () {
  // eslint-disable-next-line es/no-object-defineproperty -- requied for testing
  return Object.defineProperty(createElement('div'), 'a', {
    get: function () { return 7; }
  }).a != 7;
});


/***/ }),

/***/ 9337:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var uncurryThis = __webpack_require__(65968);
var fails = __webpack_require__(24229);
var classof = __webpack_require__(27079);

var Object = global.Object;
var split = uncurryThis(''.split);

// fallback for non-array-like ES3 and non-enumerable old V8 strings
module.exports = fails(function () {
  // throws an error in rhino, see https://github.com/mozilla/rhino/issues/346
  // eslint-disable-next-line no-prototype-builtins -- safe
  return !Object('z').propertyIsEnumerable(0);
}) ? function (it) {
  return classof(it) == 'String' ? split(it, '') : Object(it);
} : Object;


/***/ }),

/***/ 8511:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var uncurryThis = __webpack_require__(65968);
var isCallable = __webpack_require__(26733);
var store = __webpack_require__(85353);

var functionToString = uncurryThis(Function.toString);

// this helper broken in `core-js@3.4.1-3.4.4`, so we can't use `shared` helper
if (!isCallable(store.inspectSource)) {
  store.inspectSource = function (it) {
    return functionToString(it);
  };
}

module.exports = store.inspectSource;


/***/ }),

/***/ 56407:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var NATIVE_WEAK_MAP = __webpack_require__(18694);
var global = __webpack_require__(9859);
var uncurryThis = __webpack_require__(65968);
var isObject = __webpack_require__(85052);
var createNonEnumerableProperty = __webpack_require__(75762);
var hasOwn = __webpack_require__(98270);
var shared = __webpack_require__(85353);
var sharedKey = __webpack_require__(44399);
var hiddenKeys = __webpack_require__(95977);

var OBJECT_ALREADY_INITIALIZED = 'Object already initialized';
var TypeError = global.TypeError;
var WeakMap = global.WeakMap;
var set, get, has;

var enforce = function (it) {
  return has(it) ? get(it) : set(it, {});
};

var getterFor = function (TYPE) {
  return function (it) {
    var state;
    if (!isObject(it) || (state = get(it)).type !== TYPE) {
      throw TypeError('Incompatible receiver, ' + TYPE + ' required');
    } return state;
  };
};

if (NATIVE_WEAK_MAP || shared.state) {
  var store = shared.state || (shared.state = new WeakMap());
  var wmget = uncurryThis(store.get);
  var wmhas = uncurryThis(store.has);
  var wmset = uncurryThis(store.set);
  set = function (it, metadata) {
    if (wmhas(store, it)) throw new TypeError(OBJECT_ALREADY_INITIALIZED);
    metadata.facade = it;
    wmset(store, it, metadata);
    return metadata;
  };
  get = function (it) {
    return wmget(store, it) || {};
  };
  has = function (it) {
    return wmhas(store, it);
  };
} else {
  var STATE = sharedKey('state');
  hiddenKeys[STATE] = true;
  set = function (it, metadata) {
    if (hasOwn(it, STATE)) throw new TypeError(OBJECT_ALREADY_INITIALIZED);
    metadata.facade = it;
    createNonEnumerableProperty(it, STATE, metadata);
    return metadata;
  };
  get = function (it) {
    return hasOwn(it, STATE) ? it[STATE] : {};
  };
  has = function (it) {
    return hasOwn(it, STATE);
  };
}

module.exports = {
  set: set,
  get: get,
  has: has,
  enforce: enforce,
  getterFor: getterFor
};


/***/ }),

/***/ 26733:
/***/ (function(module) {

// `IsCallable` abstract operation
// https://tc39.es/ecma262/#sec-iscallable
module.exports = function (argument) {
  return typeof argument == 'function';
};


/***/ }),

/***/ 46541:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var fails = __webpack_require__(24229);
var isCallable = __webpack_require__(26733);

var replacement = /#|\.prototype\./;

var isForced = function (feature, detection) {
  var value = data[normalize(feature)];
  return value == POLYFILL ? true
    : value == NATIVE ? false
    : isCallable(detection) ? fails(detection)
    : !!detection;
};

var normalize = isForced.normalize = function (string) {
  return String(string).replace(replacement, '.').toLowerCase();
};

var data = isForced.data = {};
var NATIVE = isForced.NATIVE = 'N';
var POLYFILL = isForced.POLYFILL = 'P';

module.exports = isForced;


/***/ }),

/***/ 85052:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var isCallable = __webpack_require__(26733);

module.exports = function (it) {
  return typeof it == 'object' ? it !== null : isCallable(it);
};


/***/ }),

/***/ 24231:
/***/ (function(module) {

module.exports = false;


/***/ }),

/***/ 49395:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var getBuiltIn = __webpack_require__(31333);
var isCallable = __webpack_require__(26733);
var isPrototypeOf = __webpack_require__(91321);
var USE_SYMBOL_AS_UID = __webpack_require__(66969);

var Object = global.Object;

module.exports = USE_SYMBOL_AS_UID ? function (it) {
  return typeof it == 'symbol';
} : function (it) {
  var $Symbol = getBuiltIn('Symbol');
  return isCallable($Symbol) && isPrototypeOf($Symbol.prototype, Object(it));
};


/***/ }),

/***/ 39646:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var toLength = __webpack_require__(34237);

// `LengthOfArrayLike` abstract operation
// https://tc39.es/ecma262/#sec-lengthofarraylike
module.exports = function (obj) {
  return toLength(obj.length);
};


/***/ }),

/***/ 63839:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/* eslint-disable es/no-symbol -- required for testing */
var V8_VERSION = __webpack_require__(6358);
var fails = __webpack_require__(24229);

// eslint-disable-next-line es/no-object-getownpropertysymbols -- required for testing
module.exports = !!Object.getOwnPropertySymbols && !fails(function () {
  var symbol = Symbol();
  // Chrome 38 Symbol has incorrect toString conversion
  // `get-own-property-symbols` polyfill symbols converted to object are not Symbol instances
  return !String(symbol) || !(Object(symbol) instanceof Symbol) ||
    // Chrome 38-40 symbols are not inherited from DOM collections prototypes to instances
    !Symbol.sham && V8_VERSION && V8_VERSION < 41;
});


/***/ }),

/***/ 18694:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var isCallable = __webpack_require__(26733);
var inspectSource = __webpack_require__(8511);

var WeakMap = global.WeakMap;

module.exports = isCallable(WeakMap) && /native code/.test(inspectSource(WeakMap));


/***/ }),

/***/ 31787:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

var global = __webpack_require__(9859);
var DESCRIPTORS = __webpack_require__(7400);
var IE8_DOM_DEFINE = __webpack_require__(64394);
var anObject = __webpack_require__(21176);
var toPropertyKey = __webpack_require__(39310);

var TypeError = global.TypeError;
// eslint-disable-next-line es/no-object-defineproperty -- safe
var $defineProperty = Object.defineProperty;

// `Object.defineProperty` method
// https://tc39.es/ecma262/#sec-object.defineproperty
exports.f = DESCRIPTORS ? $defineProperty : function defineProperty(O, P, Attributes) {
  anObject(O);
  P = toPropertyKey(P);
  anObject(Attributes);
  if (IE8_DOM_DEFINE) try {
    return $defineProperty(O, P, Attributes);
  } catch (error) { /* empty */ }
  if ('get' in Attributes || 'set' in Attributes) throw TypeError('Accessors not supported');
  if ('value' in Attributes) O[P] = Attributes.value;
  return O;
};


/***/ }),

/***/ 97933:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

var DESCRIPTORS = __webpack_require__(7400);
var call = __webpack_require__(20266);
var propertyIsEnumerableModule = __webpack_require__(19195);
var createPropertyDescriptor = __webpack_require__(65358);
var toIndexedObject = __webpack_require__(10905);
var toPropertyKey = __webpack_require__(39310);
var hasOwn = __webpack_require__(98270);
var IE8_DOM_DEFINE = __webpack_require__(64394);

// eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
var $getOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;

// `Object.getOwnPropertyDescriptor` method
// https://tc39.es/ecma262/#sec-object.getownpropertydescriptor
exports.f = DESCRIPTORS ? $getOwnPropertyDescriptor : function getOwnPropertyDescriptor(O, P) {
  O = toIndexedObject(O);
  P = toPropertyKey(P);
  if (IE8_DOM_DEFINE) try {
    return $getOwnPropertyDescriptor(O, P);
  } catch (error) { /* empty */ }
  if (hasOwn(O, P)) return createPropertyDescriptor(!call(propertyIsEnumerableModule.f, O, P), O[P]);
};


/***/ }),

/***/ 78151:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

var internalObjectKeys = __webpack_require__(90140);
var enumBugKeys = __webpack_require__(13837);

var hiddenKeys = enumBugKeys.concat('length', 'prototype');

// `Object.getOwnPropertyNames` method
// https://tc39.es/ecma262/#sec-object.getownpropertynames
// eslint-disable-next-line es/no-object-getownpropertynames -- safe
exports.f = Object.getOwnPropertyNames || function getOwnPropertyNames(O) {
  return internalObjectKeys(O, hiddenKeys);
};


/***/ }),

/***/ 10894:
/***/ (function(__unused_webpack_module, exports) {

// eslint-disable-next-line es/no-object-getownpropertysymbols -- safe
exports.f = Object.getOwnPropertySymbols;


/***/ }),

/***/ 67567:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var hasOwn = __webpack_require__(98270);
var isCallable = __webpack_require__(26733);
var toObject = __webpack_require__(92991);
var sharedKey = __webpack_require__(44399);
var CORRECT_PROTOTYPE_GETTER = __webpack_require__(27528);

var IE_PROTO = sharedKey('IE_PROTO');
var Object = global.Object;
var ObjectPrototype = Object.prototype;

// `Object.getPrototypeOf` method
// https://tc39.es/ecma262/#sec-object.getprototypeof
module.exports = CORRECT_PROTOTYPE_GETTER ? Object.getPrototypeOf : function (O) {
  var object = toObject(O);
  if (hasOwn(object, IE_PROTO)) return object[IE_PROTO];
  var constructor = object.constructor;
  if (isCallable(constructor) && object instanceof constructor) {
    return constructor.prototype;
  } return object instanceof Object ? ObjectPrototype : null;
};


/***/ }),

/***/ 91321:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var uncurryThis = __webpack_require__(65968);

module.exports = uncurryThis({}.isPrototypeOf);


/***/ }),

/***/ 90140:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var uncurryThis = __webpack_require__(65968);
var hasOwn = __webpack_require__(98270);
var toIndexedObject = __webpack_require__(10905);
var indexOf = (__webpack_require__(19540).indexOf);
var hiddenKeys = __webpack_require__(95977);

var push = uncurryThis([].push);

module.exports = function (object, names) {
  var O = toIndexedObject(object);
  var i = 0;
  var result = [];
  var key;
  for (key in O) !hasOwn(hiddenKeys, key) && hasOwn(O, key) && push(result, key);
  // Don't enum bug & hidden keys
  while (names.length > i) if (hasOwn(O, key = names[i++])) {
    ~indexOf(result, key) || push(result, key);
  }
  return result;
};


/***/ }),

/***/ 19195:
/***/ (function(__unused_webpack_module, exports) {

"use strict";

var $propertyIsEnumerable = {}.propertyIsEnumerable;
// eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
var getOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;

// Nashorn ~ JDK8 bug
var NASHORN_BUG = getOwnPropertyDescriptor && !$propertyIsEnumerable.call({ 1: 2 }, 1);

// `Object.prototype.propertyIsEnumerable` method implementation
// https://tc39.es/ecma262/#sec-object.prototype.propertyisenumerable
exports.f = NASHORN_BUG ? function propertyIsEnumerable(V) {
  var descriptor = getOwnPropertyDescriptor(this, V);
  return !!descriptor && descriptor.enumerable;
} : $propertyIsEnumerable;


/***/ }),

/***/ 56540:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/* eslint-disable no-proto -- safe */
var uncurryThis = __webpack_require__(65968);
var anObject = __webpack_require__(21176);
var aPossiblePrototype = __webpack_require__(88505);

// `Object.setPrototypeOf` method
// https://tc39.es/ecma262/#sec-object.setprototypeof
// Works with __proto__ only. Old v8 can't work with null proto objects.
// eslint-disable-next-line es/no-object-setprototypeof -- safe
module.exports = Object.setPrototypeOf || ('__proto__' in {} ? function () {
  var CORRECT_SETTER = false;
  var test = {};
  var setter;
  try {
    // eslint-disable-next-line es/no-object-getownpropertydescriptor -- safe
    setter = uncurryThis(Object.getOwnPropertyDescriptor(Object.prototype, '__proto__').set);
    setter(test, []);
    CORRECT_SETTER = test instanceof Array;
  } catch (error) { /* empty */ }
  return function setPrototypeOf(O, proto) {
    anObject(O);
    aPossiblePrototype(proto);
    if (CORRECT_SETTER) setter(O, proto);
    else O.__proto__ = proto;
    return O;
  };
}() : undefined);


/***/ }),

/***/ 32914:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var call = __webpack_require__(20266);
var isCallable = __webpack_require__(26733);
var isObject = __webpack_require__(85052);

var TypeError = global.TypeError;

// `OrdinaryToPrimitive` abstract operation
// https://tc39.es/ecma262/#sec-ordinarytoprimitive
module.exports = function (input, pref) {
  var fn, val;
  if (pref === 'string' && isCallable(fn = input.toString) && !isObject(val = call(fn, input))) return val;
  if (isCallable(fn = input.valueOf) && !isObject(val = call(fn, input))) return val;
  if (pref !== 'string' && isCallable(fn = input.toString) && !isObject(val = call(fn, input))) return val;
  throw TypeError("Can't convert object to primitive value");
};


/***/ }),

/***/ 4826:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var getBuiltIn = __webpack_require__(31333);
var uncurryThis = __webpack_require__(65968);
var getOwnPropertyNamesModule = __webpack_require__(78151);
var getOwnPropertySymbolsModule = __webpack_require__(10894);
var anObject = __webpack_require__(21176);

var concat = uncurryThis([].concat);

// all object keys, includes non-enumerable and symbols
module.exports = getBuiltIn('Reflect', 'ownKeys') || function ownKeys(it) {
  var keys = getOwnPropertyNamesModule.f(anObject(it));
  var getOwnPropertySymbols = getOwnPropertySymbolsModule.f;
  return getOwnPropertySymbols ? concat(keys, getOwnPropertySymbols(it)) : keys;
};


/***/ }),

/***/ 27487:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var isCallable = __webpack_require__(26733);
var hasOwn = __webpack_require__(98270);
var createNonEnumerableProperty = __webpack_require__(75762);
var setGlobal = __webpack_require__(12079);
var inspectSource = __webpack_require__(8511);
var InternalStateModule = __webpack_require__(56407);
var CONFIGURABLE_FUNCTION_NAME = (__webpack_require__(51805).CONFIGURABLE);

var getInternalState = InternalStateModule.get;
var enforceInternalState = InternalStateModule.enforce;
var TEMPLATE = String(String).split('String');

(module.exports = function (O, key, value, options) {
  var unsafe = options ? !!options.unsafe : false;
  var simple = options ? !!options.enumerable : false;
  var noTargetGet = options ? !!options.noTargetGet : false;
  var name = options && options.name !== undefined ? options.name : key;
  var state;
  if (isCallable(value)) {
    if (String(name).slice(0, 7) === 'Symbol(') {
      name = '[' + String(name).replace(/^Symbol\(([^)]*)\)/, '$1') + ']';
    }
    if (!hasOwn(value, 'name') || (CONFIGURABLE_FUNCTION_NAME && value.name !== name)) {
      createNonEnumerableProperty(value, 'name', name);
    }
    state = enforceInternalState(value);
    if (!state.source) {
      state.source = TEMPLATE.join(typeof name == 'string' ? name : '');
    }
  }
  if (O === global) {
    if (simple) O[key] = value;
    else setGlobal(key, value);
    return;
  } else if (!unsafe) {
    delete O[key];
  } else if (!noTargetGet && O[key]) {
    simple = true;
  }
  if (simple) O[key] = value;
  else createNonEnumerableProperty(O, key, value);
// add fake Function#toString for correct work wrapped methods / constructors with methods like LoDash isNative
})(Function.prototype, 'toString', function toString() {
  return isCallable(this) && getInternalState(this).source || inspectSource(this);
});


/***/ }),

/***/ 58885:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);

var TypeError = global.TypeError;

// `RequireObjectCoercible` abstract operation
// https://tc39.es/ecma262/#sec-requireobjectcoercible
module.exports = function (it) {
  if (it == undefined) throw TypeError("Can't call method on " + it);
  return it;
};


/***/ }),

/***/ 12079:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);

// eslint-disable-next-line es/no-object-defineproperty -- safe
var defineProperty = Object.defineProperty;

module.exports = function (key, value) {
  try {
    defineProperty(global, key, { value: value, configurable: true, writable: true });
  } catch (error) {
    global[key] = value;
  } return value;
};


/***/ }),

/***/ 44399:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var shared = __webpack_require__(33036);
var uid = __webpack_require__(81441);

var keys = shared('keys');

module.exports = function (key) {
  return keys[key] || (keys[key] = uid(key));
};


/***/ }),

/***/ 85353:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var setGlobal = __webpack_require__(12079);

var SHARED = '__core-js_shared__';
var store = global[SHARED] || setGlobal(SHARED, {});

module.exports = store;


/***/ }),

/***/ 33036:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var IS_PURE = __webpack_require__(24231);
var store = __webpack_require__(85353);

(module.exports = function (key, value) {
  return store[key] || (store[key] = value !== undefined ? value : {});
})('versions', []).push({
  version: '3.19.1',
  mode: IS_PURE ? 'pure' : 'global',
  copyright: '© 2021 Denis Pushkarev (zloirock.ru)'
});


/***/ }),

/***/ 55795:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var apply = __webpack_require__(53171);
var bind = __webpack_require__(97636);
var isCallable = __webpack_require__(26733);
var hasOwn = __webpack_require__(98270);
var fails = __webpack_require__(24229);
var html = __webpack_require__(53777);
var arraySlice = __webpack_require__(1909);
var createElement = __webpack_require__(22635);
var IS_IOS = __webpack_require__(32023);
var IS_NODE = __webpack_require__(28801);

var set = global.setImmediate;
var clear = global.clearImmediate;
var process = global.process;
var Dispatch = global.Dispatch;
var Function = global.Function;
var MessageChannel = global.MessageChannel;
var String = global.String;
var counter = 0;
var queue = {};
var ONREADYSTATECHANGE = 'onreadystatechange';
var location, defer, channel, port;

try {
  // Deno throws a ReferenceError on `location` access without `--location` flag
  location = global.location;
} catch (error) { /* empty */ }

var run = function (id) {
  if (hasOwn(queue, id)) {
    var fn = queue[id];
    delete queue[id];
    fn();
  }
};

var runner = function (id) {
  return function () {
    run(id);
  };
};

var listener = function (event) {
  run(event.data);
};

var post = function (id) {
  // old engines have not location.origin
  global.postMessage(String(id), location.protocol + '//' + location.host);
};

// Node.js 0.9+ & IE10+ has setImmediate, otherwise:
if (!set || !clear) {
  set = function setImmediate(fn) {
    var args = arraySlice(arguments, 1);
    queue[++counter] = function () {
      apply(isCallable(fn) ? fn : Function(fn), undefined, args);
    };
    defer(counter);
    return counter;
  };
  clear = function clearImmediate(id) {
    delete queue[id];
  };
  // Node.js 0.8-
  if (IS_NODE) {
    defer = function (id) {
      process.nextTick(runner(id));
    };
  // Sphere (JS game engine) Dispatch API
  } else if (Dispatch && Dispatch.now) {
    defer = function (id) {
      Dispatch.now(runner(id));
    };
  // Browsers with MessageChannel, includes WebWorkers
  // except iOS - https://github.com/zloirock/core-js/issues/624
  } else if (MessageChannel && !IS_IOS) {
    channel = new MessageChannel();
    port = channel.port2;
    channel.port1.onmessage = listener;
    defer = bind(port.postMessage, port);
  // Browsers with postMessage, skip WebWorkers
  // IE8 has postMessage, but it's sync & typeof its postMessage is 'object'
  } else if (
    global.addEventListener &&
    isCallable(global.postMessage) &&
    !global.importScripts &&
    location && location.protocol !== 'file:' &&
    !fails(post)
  ) {
    defer = post;
    global.addEventListener('message', listener, false);
  // IE8-
  } else if (ONREADYSTATECHANGE in createElement('script')) {
    defer = function (id) {
      html.appendChild(createElement('script'))[ONREADYSTATECHANGE] = function () {
        html.removeChild(this);
        run(id);
      };
    };
  // Rest old browsers
  } else {
    defer = function (id) {
      setTimeout(runner(id), 0);
    };
  }
}

module.exports = {
  set: set,
  clear: clear
};


/***/ }),

/***/ 43231:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var toIntegerOrInfinity = __webpack_require__(43329);

var max = Math.max;
var min = Math.min;

// Helper for a popular repeating case of the spec:
// Let integer be ? ToInteger(index).
// If integer < 0, let result be max((length + integer), 0); else let result be min(integer, length).
module.exports = function (index, length) {
  var integer = toIntegerOrInfinity(index);
  return integer < 0 ? max(integer + length, 0) : min(integer, length);
};


/***/ }),

/***/ 10905:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

// toObject with fallback for non-array-like ES3 strings
var IndexedObject = __webpack_require__(9337);
var requireObjectCoercible = __webpack_require__(58885);

module.exports = function (it) {
  return IndexedObject(requireObjectCoercible(it));
};


/***/ }),

/***/ 43329:
/***/ (function(module) {

var ceil = Math.ceil;
var floor = Math.floor;

// `ToIntegerOrInfinity` abstract operation
// https://tc39.es/ecma262/#sec-tointegerorinfinity
module.exports = function (argument) {
  var number = +argument;
  // eslint-disable-next-line no-self-compare -- safe
  return number !== number || number === 0 ? 0 : (number > 0 ? floor : ceil)(number);
};


/***/ }),

/***/ 34237:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var toIntegerOrInfinity = __webpack_require__(43329);

var min = Math.min;

// `ToLength` abstract operation
// https://tc39.es/ecma262/#sec-tolength
module.exports = function (argument) {
  return argument > 0 ? min(toIntegerOrInfinity(argument), 0x1FFFFFFFFFFFFF) : 0; // 2 ** 53 - 1 == 9007199254740991
};


/***/ }),

/***/ 92991:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var requireObjectCoercible = __webpack_require__(58885);

var Object = global.Object;

// `ToObject` abstract operation
// https://tc39.es/ecma262/#sec-toobject
module.exports = function (argument) {
  return Object(requireObjectCoercible(argument));
};


/***/ }),

/***/ 84262:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var toPositiveInteger = __webpack_require__(72002);

var RangeError = global.RangeError;

module.exports = function (it, BYTES) {
  var offset = toPositiveInteger(it);
  if (offset % BYTES) throw RangeError('Wrong offset');
  return offset;
};


/***/ }),

/***/ 72002:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var toIntegerOrInfinity = __webpack_require__(43329);

var RangeError = global.RangeError;

module.exports = function (it) {
  var result = toIntegerOrInfinity(it);
  if (result < 0) throw RangeError("The argument can't be less than 0");
  return result;
};


/***/ }),

/***/ 92066:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var call = __webpack_require__(20266);
var isObject = __webpack_require__(85052);
var isSymbol = __webpack_require__(49395);
var getMethod = __webpack_require__(55300);
var ordinaryToPrimitive = __webpack_require__(32914);
var wellKnownSymbol = __webpack_require__(70095);

var TypeError = global.TypeError;
var TO_PRIMITIVE = wellKnownSymbol('toPrimitive');

// `ToPrimitive` abstract operation
// https://tc39.es/ecma262/#sec-toprimitive
module.exports = function (input, pref) {
  if (!isObject(input) || isSymbol(input)) return input;
  var exoticToPrim = getMethod(input, TO_PRIMITIVE);
  var result;
  if (exoticToPrim) {
    if (pref === undefined) pref = 'default';
    result = call(exoticToPrim, input, pref);
    if (!isObject(result) || isSymbol(result)) return result;
    throw TypeError("Can't convert object to primitive value");
  }
  if (pref === undefined) pref = 'number';
  return ordinaryToPrimitive(input, pref);
};


/***/ }),

/***/ 39310:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var toPrimitive = __webpack_require__(92066);
var isSymbol = __webpack_require__(49395);

// `ToPropertyKey` abstract operation
// https://tc39.es/ecma262/#sec-topropertykey
module.exports = function (argument) {
  var key = toPrimitive(argument, 'string');
  return isSymbol(key) ? key : key + '';
};


/***/ }),

/***/ 71601:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var wellKnownSymbol = __webpack_require__(70095);

var TO_STRING_TAG = wellKnownSymbol('toStringTag');
var test = {};

test[TO_STRING_TAG] = 'z';

module.exports = String(test) === '[object z]';


/***/ }),

/***/ 59821:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);

var String = global.String;

module.exports = function (argument) {
  try {
    return String(argument);
  } catch (error) {
    return 'Object';
  }
};


/***/ }),

/***/ 81441:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var uncurryThis = __webpack_require__(65968);

var id = 0;
var postfix = Math.random();
var toString = uncurryThis(1.0.toString);

module.exports = function (key) {
  return 'Symbol(' + (key === undefined ? '' : key) + ')_' + toString(++id + postfix, 36);
};


/***/ }),

/***/ 66969:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/* eslint-disable es/no-symbol -- required for testing */
var NATIVE_SYMBOL = __webpack_require__(63839);

module.exports = NATIVE_SYMBOL
  && !Symbol.sham
  && typeof Symbol.iterator == 'symbol';


/***/ }),

/***/ 70095:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var global = __webpack_require__(9859);
var shared = __webpack_require__(33036);
var hasOwn = __webpack_require__(98270);
var uid = __webpack_require__(81441);
var NATIVE_SYMBOL = __webpack_require__(63839);
var USE_SYMBOL_AS_UID = __webpack_require__(66969);

var WellKnownSymbolsStore = shared('wks');
var Symbol = global.Symbol;
var symbolFor = Symbol && Symbol['for'];
var createWellKnownSymbol = USE_SYMBOL_AS_UID ? Symbol : Symbol && Symbol.withoutSetter || uid;

module.exports = function (name) {
  if (!hasOwn(WellKnownSymbolsStore, name) || !(NATIVE_SYMBOL || typeof WellKnownSymbolsStore[name] == 'string')) {
    var description = 'Symbol.' + name;
    if (NATIVE_SYMBOL && hasOwn(Symbol, name)) {
      WellKnownSymbolsStore[name] = Symbol[name];
    } else if (USE_SYMBOL_AS_UID && symbolFor) {
      WellKnownSymbolsStore[name] = symbolFor(description);
    } else {
      WellKnownSymbolsStore[name] = createWellKnownSymbol(description);
    }
  } return WellKnownSymbolsStore[name];
};


/***/ }),

/***/ 65688:
/***/ (function(__unused_webpack_module, __unused_webpack_exports, __webpack_require__) {

"use strict";

var global = __webpack_require__(9859);
var ArrayBufferViewCore = __webpack_require__(9918);
var lengthOfArrayLike = __webpack_require__(39646);
var toOffset = __webpack_require__(84262);
var toObject = __webpack_require__(92991);
var fails = __webpack_require__(24229);

var RangeError = global.RangeError;
var aTypedArray = ArrayBufferViewCore.aTypedArray;
var exportTypedArrayMethod = ArrayBufferViewCore.exportTypedArrayMethod;

var FORCED = fails(function () {
  // eslint-disable-next-line es/no-typed-arrays -- required for testing
  new Int8Array(1).set({});
});

// `%TypedArray%.prototype.set` method
// https://tc39.es/ecma262/#sec-%typedarray%.prototype.set
exportTypedArrayMethod('set', function set(arrayLike /* , offset */) {
  aTypedArray(this);
  var offset = toOffset(arguments.length > 1 ? arguments[1] : undefined, 1);
  var length = this.length;
  var src = toObject(arrayLike);
  var len = lengthOfArrayLike(src);
  var index = 0;
  if (len + offset > length) throw RangeError('Wrong length');
  while (index < len) this[offset + index] = src[index++];
}, FORCED);


/***/ }),

/***/ 46106:
/***/ (function(__unused_webpack_module, __unused_webpack_exports, __webpack_require__) {

var $ = __webpack_require__(23103);
var global = __webpack_require__(9859);
var task = __webpack_require__(55795);

var FORCED = !global.setImmediate || !global.clearImmediate;

// http://w3c.github.io/setImmediate/
$({ global: true, bind: true, enumerable: true, forced: FORCED }, {
  // `setImmediate` method
  // http://w3c.github.io/setImmediate/#si-setImmediate
  setImmediate: task.set,
  // `clearImmediate` method
  // http://w3c.github.io/setImmediate/#si-clearImmediate
  clearImmediate: task.clear
});


/***/ }),

/***/ 74334:
/***/ (function(module) {

(function () {
	'use strict';

	var table = [],
		poly = 0xEDB88320; // reverse polynomial

	// build the table
	function makeTable() {
		var c, n, k;

		for (n = 0; n < 256; n += 1) {
			c = n;
			for (k = 0; k < 8; k += 1) {
				if (c & 1) {
					c = poly ^ (c >>> 1);
				} else {
					c = c >>> 1;
				}
			}
			table[n] = c >>> 0;
		}
	}

	function strToArr(str) {
		// sweet hack to turn string into a 'byte' array
		return Array.prototype.map.call(str, function (c) {
			return c.charCodeAt(0);
		});
	}

	/*
	 * Compute CRC of array directly.
	 *
	 * This is slower for repeated calls, so append mode is not supported.
	 */
	function crcDirect(arr) {
		var crc = -1, // initial contents of LFBSR
			i, j, l, temp;

		for (i = 0, l = arr.length; i < l; i += 1) {
			temp = (crc ^ arr[i]) & 0xff;

			// read 8 bits one at a time
			for (j = 0; j < 8; j += 1) {
				if ((temp & 1) === 1) {
					temp = (temp >>> 1) ^ poly;
				} else {
					temp = (temp >>> 1);
				}
			}
			crc = (crc >>> 8) ^ temp;
		}

		// flip bits
		return crc ^ -1;
	}

	/*
	 * Compute CRC with the help of a pre-calculated table.
	 *
	 * This supports append mode, if the second parameter is set.
	 */
	function crcTable(arr, append) {
		var crc, i, l;

		// if we're in append mode, don't reset crc
		// if arr is null or undefined, reset table and return
		if (typeof crcTable.crc === 'undefined' || !append || !arr) {
			crcTable.crc = 0 ^ -1;

			if (!arr) {
				return;
			}
		}

		// store in temp variable for minor speed gain
		crc = crcTable.crc;

		for (i = 0, l = arr.length; i < l; i += 1) {
			crc = (crc >>> 8) ^ table[(crc ^ arr[i]) & 0xff];
		}

		crcTable.crc = crc;

		return crc ^ -1;
	}

	// build the table
	// this isn't that costly, and most uses will be for table assisted mode
	makeTable();

	module.exports = function (val, direct) {
		var val = (typeof val === 'string') ? strToArr(val) : val,
			ret = direct ? crcDirect(val) : crcTable(val);

		// convert to 2's complement hex
		return (ret >>> 0).toString(16);
	};
	module.exports.direct = crcDirect;
	module.exports.table = crcTable;
}());


/***/ }),

/***/ 65881:
/***/ (function(module) {

/**
 * Helpers.
 */

var s = 1000;
var m = s * 60;
var h = m * 60;
var d = h * 24;
var w = d * 7;
var y = d * 365.25;

/**
 * Parse or format the given `val`.
 *
 * Options:
 *
 *  - `long` verbose formatting [false]
 *
 * @param {String|Number} val
 * @param {Object} [options]
 * @throws {Error} throw an error if val is not a non-empty string or a number
 * @return {String|Number}
 * @api public
 */

module.exports = function(val, options) {
  options = options || {};
  var type = typeof val;
  if (type === 'string' && val.length > 0) {
    return parse(val);
  } else if (type === 'number' && isFinite(val)) {
    return options.long ? fmtLong(val) : fmtShort(val);
  }
  throw new Error(
    'val is not a non-empty string or a valid number. val=' +
      JSON.stringify(val)
  );
};

/**
 * Parse the given `str` and return milliseconds.
 *
 * @param {String} str
 * @return {Number}
 * @api private
 */

function parse(str) {
  str = String(str);
  if (str.length > 100) {
    return;
  }
  var match = /^(-?(?:\d+)?\.?\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|weeks?|w|years?|yrs?|y)?$/i.exec(
    str
  );
  if (!match) {
    return;
  }
  var n = parseFloat(match[1]);
  var type = (match[2] || 'ms').toLowerCase();
  switch (type) {
    case 'years':
    case 'year':
    case 'yrs':
    case 'yr':
    case 'y':
      return n * y;
    case 'weeks':
    case 'week':
    case 'w':
      return n * w;
    case 'days':
    case 'day':
    case 'd':
      return n * d;
    case 'hours':
    case 'hour':
    case 'hrs':
    case 'hr':
    case 'h':
      return n * h;
    case 'minutes':
    case 'minute':
    case 'mins':
    case 'min':
    case 'm':
      return n * m;
    case 'seconds':
    case 'second':
    case 'secs':
    case 'sec':
    case 's':
      return n * s;
    case 'milliseconds':
    case 'millisecond':
    case 'msecs':
    case 'msec':
    case 'ms':
      return n;
    default:
      return undefined;
  }
}

/**
 * Short format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function fmtShort(ms) {
  var msAbs = Math.abs(ms);
  if (msAbs >= d) {
    return Math.round(ms / d) + 'd';
  }
  if (msAbs >= h) {
    return Math.round(ms / h) + 'h';
  }
  if (msAbs >= m) {
    return Math.round(ms / m) + 'm';
  }
  if (msAbs >= s) {
    return Math.round(ms / s) + 's';
  }
  return ms + 'ms';
}

/**
 * Long format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function fmtLong(ms) {
  var msAbs = Math.abs(ms);
  if (msAbs >= d) {
    return plural(ms, msAbs, d, 'day');
  }
  if (msAbs >= h) {
    return plural(ms, msAbs, h, 'hour');
  }
  if (msAbs >= m) {
    return plural(ms, msAbs, m, 'minute');
  }
  if (msAbs >= s) {
    return plural(ms, msAbs, s, 'second');
  }
  return ms + ' ms';
}

/**
 * Pluralization helper.
 */

function plural(ms, msAbs, n, name) {
  var isPlural = msAbs >= n * 1.5;
  return Math.round(ms / n) + ' ' + name + (isPlural ? 's' : '');
}


/***/ }),

/***/ 24869:
/***/ (function(module) {

module.exports = function deepFreeze (o) {
  Object.freeze(o);

  Object.getOwnPropertyNames(o).forEach(function (prop) {
    if (o.hasOwnProperty(prop)
    && o[prop] !== null
    && (typeof o[prop] === "object" || typeof o[prop] === "function")
    && !Object.isFrozen(o[prop])) {
      deepFreeze(o[prop]);
    }
  });
  
  return o;
};


/***/ }),

/***/ 44065:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {


module.exports = __webpack_require__(14980);

/**
 * Exports parser
 *
 * @api public
 *
 */
module.exports.parser = __webpack_require__(90820);


/***/ }),

/***/ 14980:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/**
 * Module dependencies.
 */

var transports = __webpack_require__(8113);
var Emitter = __webpack_require__(17056);
var debug = __webpack_require__(39712)('engine.io-client:socket');
var index = __webpack_require__(92543);
var parser = __webpack_require__(90820);
var parseuri = __webpack_require__(14243);
var parseqs = __webpack_require__(54355);

/**
 * Module exports.
 */

module.exports = Socket;

/**
 * Socket constructor.
 *
 * @param {String|Object} uri or options
 * @param {Object} options
 * @api public
 */

function Socket (uri, opts) {
  if (!(this instanceof Socket)) return new Socket(uri, opts);

  opts = opts || {};

  if (uri && 'object' === typeof uri) {
    opts = uri;
    uri = null;
  }

  if (uri) {
    uri = parseuri(uri);
    opts.hostname = uri.host;
    opts.secure = uri.protocol === 'https' || uri.protocol === 'wss';
    opts.port = uri.port;
    if (uri.query) opts.query = uri.query;
  } else if (opts.host) {
    opts.hostname = parseuri(opts.host).host;
  }

  this.secure = null != opts.secure ? opts.secure
    : (typeof location !== 'undefined' && 'https:' === location.protocol);

  if (opts.hostname && !opts.port) {
    // if no port is specified manually, use the protocol default
    opts.port = this.secure ? '443' : '80';
  }

  this.agent = opts.agent || false;
  this.hostname = opts.hostname ||
    (typeof location !== 'undefined' ? location.hostname : 'localhost');
  this.port = opts.port || (typeof location !== 'undefined' && location.port
      ? location.port
      : (this.secure ? 443 : 80));
  this.query = opts.query || {};
  if ('string' === typeof this.query) this.query = parseqs.decode(this.query);
  this.upgrade = false !== opts.upgrade;
  this.path = (opts.path || '/engine.io').replace(/\/$/, '') + '/';
  this.forceJSONP = !!opts.forceJSONP;
  this.jsonp = false !== opts.jsonp;
  this.forceBase64 = !!opts.forceBase64;
  this.enablesXDR = !!opts.enablesXDR;
  this.withCredentials = false !== opts.withCredentials;
  this.timestampParam = opts.timestampParam || 't';
  this.timestampRequests = opts.timestampRequests;
  this.transports = opts.transports || ['polling', 'websocket'];
  this.transportOptions = opts.transportOptions || {};
  this.readyState = '';
  this.writeBuffer = [];
  this.prevBufferLen = 0;
  this.policyPort = opts.policyPort || 843;
  this.rememberUpgrade = opts.rememberUpgrade || false;
  this.binaryType = null;
  this.onlyBinaryUpgrades = opts.onlyBinaryUpgrades;
  this.perMessageDeflate = false !== opts.perMessageDeflate ? (opts.perMessageDeflate || {}) : false;

  if (true === this.perMessageDeflate) this.perMessageDeflate = {};
  if (this.perMessageDeflate && null == this.perMessageDeflate.threshold) {
    this.perMessageDeflate.threshold = 1024;
  }

  // SSL options for Node.js client
  this.pfx = opts.pfx || null;
  this.key = opts.key || null;
  this.passphrase = opts.passphrase || null;
  this.cert = opts.cert || null;
  this.ca = opts.ca || null;
  this.ciphers = opts.ciphers || null;
  this.rejectUnauthorized = opts.rejectUnauthorized === undefined ? true : opts.rejectUnauthorized;
  this.forceNode = !!opts.forceNode;

  // detect ReactNative environment
  this.isReactNative = (typeof navigator !== 'undefined' && typeof navigator.product === 'string' && navigator.product.toLowerCase() === 'reactnative');

  // other options for Node.js or ReactNative client
  if (typeof self === 'undefined' || this.isReactNative) {
    if (opts.extraHeaders && Object.keys(opts.extraHeaders).length > 0) {
      this.extraHeaders = opts.extraHeaders;
    }

    if (opts.localAddress) {
      this.localAddress = opts.localAddress;
    }
  }

  // set on handshake
  this.id = null;
  this.upgrades = null;
  this.pingInterval = null;
  this.pingTimeout = null;

  // set on heartbeat
  this.pingIntervalTimer = null;
  this.pingTimeoutTimer = null;

  this.open();
}

Socket.priorWebsocketSuccess = false;

/**
 * Mix in `Emitter`.
 */

Emitter(Socket.prototype);

/**
 * Protocol version.
 *
 * @api public
 */

Socket.protocol = parser.protocol; // this is an int

/**
 * Expose deps for legacy compatibility
 * and standalone browser access.
 */

Socket.Socket = Socket;
Socket.Transport = __webpack_require__(5344);
Socket.transports = __webpack_require__(8113);
Socket.parser = __webpack_require__(90820);

/**
 * Creates transport of the given type.
 *
 * @param {String} transport name
 * @return {Transport}
 * @api private
 */

Socket.prototype.createTransport = function (name) {
  debug('creating transport "%s"', name);
  var query = clone(this.query);

  // append engine.io protocol identifier
  query.EIO = parser.protocol;

  // transport name
  query.transport = name;

  // per-transport options
  var options = this.transportOptions[name] || {};

  // session id if we already have one
  if (this.id) query.sid = this.id;

  var transport = new transports[name]({
    query: query,
    socket: this,
    agent: options.agent || this.agent,
    hostname: options.hostname || this.hostname,
    port: options.port || this.port,
    secure: options.secure || this.secure,
    path: options.path || this.path,
    forceJSONP: options.forceJSONP || this.forceJSONP,
    jsonp: options.jsonp || this.jsonp,
    forceBase64: options.forceBase64 || this.forceBase64,
    enablesXDR: options.enablesXDR || this.enablesXDR,
    withCredentials: options.withCredentials || this.withCredentials,
    timestampRequests: options.timestampRequests || this.timestampRequests,
    timestampParam: options.timestampParam || this.timestampParam,
    policyPort: options.policyPort || this.policyPort,
    pfx: options.pfx || this.pfx,
    key: options.key || this.key,
    passphrase: options.passphrase || this.passphrase,
    cert: options.cert || this.cert,
    ca: options.ca || this.ca,
    ciphers: options.ciphers || this.ciphers,
    rejectUnauthorized: options.rejectUnauthorized || this.rejectUnauthorized,
    perMessageDeflate: options.perMessageDeflate || this.perMessageDeflate,
    extraHeaders: options.extraHeaders || this.extraHeaders,
    forceNode: options.forceNode || this.forceNode,
    localAddress: options.localAddress || this.localAddress,
    requestTimeout: options.requestTimeout || this.requestTimeout,
    protocols: options.protocols || void (0),
    isReactNative: this.isReactNative
  });

  return transport;
};

function clone (obj) {
  var o = {};
  for (var i in obj) {
    if (obj.hasOwnProperty(i)) {
      o[i] = obj[i];
    }
  }
  return o;
}

/**
 * Initializes transport to use and starts probe.
 *
 * @api private
 */
Socket.prototype.open = function () {
  var transport;
  if (this.rememberUpgrade && Socket.priorWebsocketSuccess && this.transports.indexOf('websocket') !== -1) {
    transport = 'websocket';
  } else if (0 === this.transports.length) {
    // Emit error on next tick so it can be listened to
    var self = this;
    setTimeout(function () {
      self.emit('error', 'No transports available');
    }, 0);
    return;
  } else {
    transport = this.transports[0];
  }
  this.readyState = 'opening';

  // Retry with the next transport if the transport is disabled (jsonp: false)
  try {
    transport = this.createTransport(transport);
  } catch (e) {
    this.transports.shift();
    this.open();
    return;
  }

  transport.open();
  this.setTransport(transport);
};

/**
 * Sets the current transport. Disables the existing one (if any).
 *
 * @api private
 */

Socket.prototype.setTransport = function (transport) {
  debug('setting transport %s', transport.name);
  var self = this;

  if (this.transport) {
    debug('clearing existing transport %s', this.transport.name);
    this.transport.removeAllListeners();
  }

  // set up transport
  this.transport = transport;

  // set up transport listeners
  transport
  .on('drain', function () {
    self.onDrain();
  })
  .on('packet', function (packet) {
    self.onPacket(packet);
  })
  .on('error', function (e) {
    self.onError(e);
  })
  .on('close', function () {
    self.onClose('transport close');
  });
};

/**
 * Probes a transport.
 *
 * @param {String} transport name
 * @api private
 */

Socket.prototype.probe = function (name) {
  debug('probing transport "%s"', name);
  var transport = this.createTransport(name, { probe: 1 });
  var failed = false;
  var self = this;

  Socket.priorWebsocketSuccess = false;

  function onTransportOpen () {
    if (self.onlyBinaryUpgrades) {
      var upgradeLosesBinary = !this.supportsBinary && self.transport.supportsBinary;
      failed = failed || upgradeLosesBinary;
    }
    if (failed) return;

    debug('probe transport "%s" opened', name);
    transport.send([{ type: 'ping', data: 'probe' }]);
    transport.once('packet', function (msg) {
      if (failed) return;
      if ('pong' === msg.type && 'probe' === msg.data) {
        debug('probe transport "%s" pong', name);
        self.upgrading = true;
        self.emit('upgrading', transport);
        if (!transport) return;
        Socket.priorWebsocketSuccess = 'websocket' === transport.name;

        debug('pausing current transport "%s"', self.transport.name);
        self.transport.pause(function () {
          if (failed) return;
          if ('closed' === self.readyState) return;
          debug('changing transport and sending upgrade packet');

          cleanup();

          self.setTransport(transport);
          transport.send([{ type: 'upgrade' }]);
          self.emit('upgrade', transport);
          transport = null;
          self.upgrading = false;
          self.flush();
        });
      } else {
        debug('probe transport "%s" failed', name);
        var err = new Error('probe error');
        err.transport = transport.name;
        self.emit('upgradeError', err);
      }
    });
  }

  function freezeTransport () {
    if (failed) return;

    // Any callback called by transport should be ignored since now
    failed = true;

    cleanup();

    transport.close();
    transport = null;
  }

  // Handle any error that happens while probing
  function onerror (err) {
    var error = new Error('probe error: ' + err);
    error.transport = transport.name;

    freezeTransport();

    debug('probe transport "%s" failed because of error: %s', name, err);

    self.emit('upgradeError', error);
  }

  function onTransportClose () {
    onerror('transport closed');
  }

  // When the socket is closed while we're probing
  function onclose () {
    onerror('socket closed');
  }

  // When the socket is upgraded while we're probing
  function onupgrade (to) {
    if (transport && to.name !== transport.name) {
      debug('"%s" works - aborting "%s"', to.name, transport.name);
      freezeTransport();
    }
  }

  // Remove all listeners on the transport and on self
  function cleanup () {
    transport.removeListener('open', onTransportOpen);
    transport.removeListener('error', onerror);
    transport.removeListener('close', onTransportClose);
    self.removeListener('close', onclose);
    self.removeListener('upgrading', onupgrade);
  }

  transport.once('open', onTransportOpen);
  transport.once('error', onerror);
  transport.once('close', onTransportClose);

  this.once('close', onclose);
  this.once('upgrading', onupgrade);

  transport.open();
};

/**
 * Called when connection is deemed open.
 *
 * @api public
 */

Socket.prototype.onOpen = function () {
  debug('socket open');
  this.readyState = 'open';
  Socket.priorWebsocketSuccess = 'websocket' === this.transport.name;
  this.emit('open');
  this.flush();

  // we check for `readyState` in case an `open`
  // listener already closed the socket
  if ('open' === this.readyState && this.upgrade && this.transport.pause) {
    debug('starting upgrade probes');
    for (var i = 0, l = this.upgrades.length; i < l; i++) {
      this.probe(this.upgrades[i]);
    }
  }
};

/**
 * Handles a packet.
 *
 * @api private
 */

Socket.prototype.onPacket = function (packet) {
  if ('opening' === this.readyState || 'open' === this.readyState ||
      'closing' === this.readyState) {
    debug('socket receive: type "%s", data "%s"', packet.type, packet.data);

    this.emit('packet', packet);

    // Socket is live - any packet counts
    this.emit('heartbeat');

    switch (packet.type) {
      case 'open':
        this.onHandshake(JSON.parse(packet.data));
        break;

      case 'pong':
        this.setPing();
        this.emit('pong');
        break;

      case 'error':
        var err = new Error('server error');
        err.code = packet.data;
        this.onError(err);
        break;

      case 'message':
        this.emit('data', packet.data);
        this.emit('message', packet.data);
        break;
    }
  } else {
    debug('packet received with socket readyState "%s"', this.readyState);
  }
};

/**
 * Called upon handshake completion.
 *
 * @param {Object} handshake obj
 * @api private
 */

Socket.prototype.onHandshake = function (data) {
  this.emit('handshake', data);
  this.id = data.sid;
  this.transport.query.sid = data.sid;
  this.upgrades = this.filterUpgrades(data.upgrades);
  this.pingInterval = data.pingInterval;
  this.pingTimeout = data.pingTimeout;
  this.onOpen();
  // In case open handler closes socket
  if ('closed' === this.readyState) return;
  this.setPing();

  // Prolong liveness of socket on heartbeat
  this.removeListener('heartbeat', this.onHeartbeat);
  this.on('heartbeat', this.onHeartbeat);
};

/**
 * Resets ping timeout.
 *
 * @api private
 */

Socket.prototype.onHeartbeat = function (timeout) {
  clearTimeout(this.pingTimeoutTimer);
  var self = this;
  self.pingTimeoutTimer = setTimeout(function () {
    if ('closed' === self.readyState) return;
    self.onClose('ping timeout');
  }, timeout || (self.pingInterval + self.pingTimeout));
};

/**
 * Pings server every `this.pingInterval` and expects response
 * within `this.pingTimeout` or closes connection.
 *
 * @api private
 */

Socket.prototype.setPing = function () {
  var self = this;
  clearTimeout(self.pingIntervalTimer);
  self.pingIntervalTimer = setTimeout(function () {
    debug('writing ping packet - expecting pong within %sms', self.pingTimeout);
    self.ping();
    self.onHeartbeat(self.pingTimeout);
  }, self.pingInterval);
};

/**
* Sends a ping packet.
*
* @api private
*/

Socket.prototype.ping = function () {
  var self = this;
  this.sendPacket('ping', function () {
    self.emit('ping');
  });
};

/**
 * Called on `drain` event
 *
 * @api private
 */

Socket.prototype.onDrain = function () {
  this.writeBuffer.splice(0, this.prevBufferLen);

  // setting prevBufferLen = 0 is very important
  // for example, when upgrading, upgrade packet is sent over,
  // and a nonzero prevBufferLen could cause problems on `drain`
  this.prevBufferLen = 0;

  if (0 === this.writeBuffer.length) {
    this.emit('drain');
  } else {
    this.flush();
  }
};

/**
 * Flush write buffers.
 *
 * @api private
 */

Socket.prototype.flush = function () {
  if ('closed' !== this.readyState && this.transport.writable &&
    !this.upgrading && this.writeBuffer.length) {
    debug('flushing %d packets in socket', this.writeBuffer.length);
    this.transport.send(this.writeBuffer);
    // keep track of current length of writeBuffer
    // splice writeBuffer and callbackBuffer on `drain`
    this.prevBufferLen = this.writeBuffer.length;
    this.emit('flush');
  }
};

/**
 * Sends a message.
 *
 * @param {String} message.
 * @param {Function} callback function.
 * @param {Object} options.
 * @return {Socket} for chaining.
 * @api public
 */

Socket.prototype.write =
Socket.prototype.send = function (msg, options, fn) {
  this.sendPacket('message', msg, options, fn);
  return this;
};

/**
 * Sends a packet.
 *
 * @param {String} packet type.
 * @param {String} data.
 * @param {Object} options.
 * @param {Function} callback function.
 * @api private
 */

Socket.prototype.sendPacket = function (type, data, options, fn) {
  if ('function' === typeof data) {
    fn = data;
    data = undefined;
  }

  if ('function' === typeof options) {
    fn = options;
    options = null;
  }

  if ('closing' === this.readyState || 'closed' === this.readyState) {
    return;
  }

  options = options || {};
  options.compress = false !== options.compress;

  var packet = {
    type: type,
    data: data,
    options: options
  };
  this.emit('packetCreate', packet);
  this.writeBuffer.push(packet);
  if (fn) this.once('flush', fn);
  this.flush();
};

/**
 * Closes the connection.
 *
 * @api private
 */

Socket.prototype.close = function () {
  if ('opening' === this.readyState || 'open' === this.readyState) {
    this.readyState = 'closing';

    var self = this;

    if (this.writeBuffer.length) {
      this.once('drain', function () {
        if (this.upgrading) {
          waitForUpgrade();
        } else {
          close();
        }
      });
    } else if (this.upgrading) {
      waitForUpgrade();
    } else {
      close();
    }
  }

  function close () {
    self.onClose('forced close');
    debug('socket closing - telling transport to close');
    self.transport.close();
  }

  function cleanupAndClose () {
    self.removeListener('upgrade', cleanupAndClose);
    self.removeListener('upgradeError', cleanupAndClose);
    close();
  }

  function waitForUpgrade () {
    // wait for upgrade to finish since we can't send packets while pausing a transport
    self.once('upgrade', cleanupAndClose);
    self.once('upgradeError', cleanupAndClose);
  }

  return this;
};

/**
 * Called upon transport error
 *
 * @api private
 */

Socket.prototype.onError = function (err) {
  debug('socket error %j', err);
  Socket.priorWebsocketSuccess = false;
  this.emit('error', err);
  this.onClose('transport error', err);
};

/**
 * Called upon transport close.
 *
 * @api private
 */

Socket.prototype.onClose = function (reason, desc) {
  if ('opening' === this.readyState || 'open' === this.readyState || 'closing' === this.readyState) {
    debug('socket close with reason: "%s"', reason);
    var self = this;

    // clear timers
    clearTimeout(this.pingIntervalTimer);
    clearTimeout(this.pingTimeoutTimer);

    // stop event from firing again for transport
    this.transport.removeAllListeners('close');

    // ensure transport won't stay open
    this.transport.close();

    // ignore further transport communication
    this.transport.removeAllListeners();

    // set ready state
    this.readyState = 'closed';

    // clear session id
    this.id = null;

    // emit close event
    this.emit('close', reason, desc);

    // clean buffers after, so users can still
    // grab the buffers on `close` event
    self.writeBuffer = [];
    self.prevBufferLen = 0;
  }
};

/**
 * Filters upgrades, returning only those matching client transports.
 *
 * @param {Array} server upgrades
 * @api private
 *
 */

Socket.prototype.filterUpgrades = function (upgrades) {
  var filteredUpgrades = [];
  for (var i = 0, j = upgrades.length; i < j; i++) {
    if (~index(this.transports, upgrades[i])) filteredUpgrades.push(upgrades[i]);
  }
  return filteredUpgrades;
};


/***/ }),

/***/ 5344:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/**
 * Module dependencies.
 */

var parser = __webpack_require__(90820);
var Emitter = __webpack_require__(17056);

/**
 * Module exports.
 */

module.exports = Transport;

/**
 * Transport abstract constructor.
 *
 * @param {Object} options.
 * @api private
 */

function Transport (opts) {
  this.path = opts.path;
  this.hostname = opts.hostname;
  this.port = opts.port;
  this.secure = opts.secure;
  this.query = opts.query;
  this.timestampParam = opts.timestampParam;
  this.timestampRequests = opts.timestampRequests;
  this.readyState = '';
  this.agent = opts.agent || false;
  this.socket = opts.socket;
  this.enablesXDR = opts.enablesXDR;
  this.withCredentials = opts.withCredentials;

  // SSL options for Node.js client
  this.pfx = opts.pfx;
  this.key = opts.key;
  this.passphrase = opts.passphrase;
  this.cert = opts.cert;
  this.ca = opts.ca;
  this.ciphers = opts.ciphers;
  this.rejectUnauthorized = opts.rejectUnauthorized;
  this.forceNode = opts.forceNode;

  // results of ReactNative environment detection
  this.isReactNative = opts.isReactNative;

  // other options for Node.js client
  this.extraHeaders = opts.extraHeaders;
  this.localAddress = opts.localAddress;
}

/**
 * Mix in `Emitter`.
 */

Emitter(Transport.prototype);

/**
 * Emits an error.
 *
 * @param {String} str
 * @return {Transport} for chaining
 * @api public
 */

Transport.prototype.onError = function (msg, desc) {
  var err = new Error(msg);
  err.type = 'TransportError';
  err.description = desc;
  this.emit('error', err);
  return this;
};

/**
 * Opens the transport.
 *
 * @api public
 */

Transport.prototype.open = function () {
  if ('closed' === this.readyState || '' === this.readyState) {
    this.readyState = 'opening';
    this.doOpen();
  }

  return this;
};

/**
 * Closes the transport.
 *
 * @api private
 */

Transport.prototype.close = function () {
  if ('opening' === this.readyState || 'open' === this.readyState) {
    this.doClose();
    this.onClose();
  }

  return this;
};

/**
 * Sends multiple packets.
 *
 * @param {Array} packets
 * @api private
 */

Transport.prototype.send = function (packets) {
  if ('open' === this.readyState) {
    this.write(packets);
  } else {
    throw new Error('Transport not open');
  }
};

/**
 * Called upon open
 *
 * @api private
 */

Transport.prototype.onOpen = function () {
  this.readyState = 'open';
  this.writable = true;
  this.emit('open');
};

/**
 * Called with data.
 *
 * @param {String} data
 * @api private
 */

Transport.prototype.onData = function (data) {
  var packet = parser.decodePacket(data, this.socket.binaryType);
  this.onPacket(packet);
};

/**
 * Called with a decoded packet.
 */

Transport.prototype.onPacket = function (packet) {
  this.emit('packet', packet);
};

/**
 * Called upon close.
 *
 * @api private
 */

Transport.prototype.onClose = function () {
  this.readyState = 'closed';
  this.emit('close');
};


/***/ }),

/***/ 8113:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

/**
 * Module dependencies
 */

var XMLHttpRequest = __webpack_require__(26891);
var XHR = __webpack_require__(91962);
var JSONP = __webpack_require__(18320);
var websocket = __webpack_require__(68479);

/**
 * Export transports.
 */

exports.polling = polling;
exports.websocket = websocket;

/**
 * Polling transport polymorphic constructor.
 * Decides on xhr vs jsonp based on feature detection.
 *
 * @api private
 */

function polling (opts) {
  var xhr;
  var xd = false;
  var xs = false;
  var jsonp = false !== opts.jsonp;

  if (typeof location !== 'undefined') {
    var isSSL = 'https:' === location.protocol;
    var port = location.port;

    // some user agents have empty `location.port`
    if (!port) {
      port = isSSL ? 443 : 80;
    }

    xd = opts.hostname !== location.hostname || port !== opts.port;
    xs = opts.secure !== isSSL;
  }

  opts.xdomain = xd;
  opts.xscheme = xs;
  xhr = new XMLHttpRequest(opts);

  if ('open' in xhr && !opts.forceJSONP) {
    return new XHR(opts);
  } else {
    if (!jsonp) throw new Error('JSONP disabled');
    return new JSONP(opts);
  }
}


/***/ }),

/***/ 18320:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/**
 * Module requirements.
 */

var Polling = __webpack_require__(65869);
var inherit = __webpack_require__(99238);

/**
 * Module exports.
 */

module.exports = JSONPPolling;

/**
 * Cached regular expressions.
 */

var rNewline = /\n/g;
var rEscapedNewline = /\\n/g;

/**
 * Global JSONP callbacks.
 */

var callbacks;

/**
 * Noop.
 */

function empty () { }

/**
 * Until https://github.com/tc39/proposal-global is shipped.
 */
function glob () {
  return typeof self !== 'undefined' ? self
      : typeof window !== 'undefined' ? window
      : typeof window !== 'undefined' ? window : {};
}

/**
 * JSONP Polling constructor.
 *
 * @param {Object} opts.
 * @api public
 */

function JSONPPolling (opts) {
  Polling.call(this, opts);

  this.query = this.query || {};

  // define global callbacks array if not present
  // we do this here (lazily) to avoid unneeded global pollution
  if (!callbacks) {
    // we need to consider multiple engines in the same page
    var global = glob();
    callbacks = global.___eio = (global.___eio || []);
  }

  // callback identifier
  this.index = callbacks.length;

  // add callback to jsonp global
  var self = this;
  callbacks.push(function (msg) {
    self.onData(msg);
  });

  // append to query string
  this.query.j = this.index;

  // prevent spurious errors from being emitted when the window is unloaded
  if (typeof addEventListener === 'function') {
    addEventListener('beforeunload', function () {
      if (self.script) self.script.onerror = empty;
    }, false);
  }
}

/**
 * Inherits from Polling.
 */

inherit(JSONPPolling, Polling);

/*
 * JSONP only supports binary as base64 encoded strings
 */

JSONPPolling.prototype.supportsBinary = false;

/**
 * Closes the socket.
 *
 * @api private
 */

JSONPPolling.prototype.doClose = function () {
  if (this.script) {
    this.script.parentNode.removeChild(this.script);
    this.script = null;
  }

  if (this.form) {
    this.form.parentNode.removeChild(this.form);
    this.form = null;
    this.iframe = null;
  }

  Polling.prototype.doClose.call(this);
};

/**
 * Starts a poll cycle.
 *
 * @api private
 */

JSONPPolling.prototype.doPoll = function () {
  var self = this;
  var script = document.createElement('script');

  if (this.script) {
    this.script.parentNode.removeChild(this.script);
    this.script = null;
  }

  script.async = true;
  script.src = this.uri();
  script.onerror = function (e) {
    self.onError('jsonp poll error', e);
  };

  var insertAt = document.getElementsByTagName('script')[0];
  if (insertAt) {
    insertAt.parentNode.insertBefore(script, insertAt);
  } else {
    (document.head || document.body).appendChild(script);
  }
  this.script = script;

  var isUAgecko = 'undefined' !== typeof navigator && /gecko/i.test(navigator.userAgent);

  if (isUAgecko) {
    setTimeout(function () {
      var iframe = document.createElement('iframe');
      document.body.appendChild(iframe);
      document.body.removeChild(iframe);
    }, 100);
  }
};

/**
 * Writes with a hidden iframe.
 *
 * @param {String} data to send
 * @param {Function} called upon flush.
 * @api private
 */

JSONPPolling.prototype.doWrite = function (data, fn) {
  var self = this;

  if (!this.form) {
    var form = document.createElement('form');
    var area = document.createElement('textarea');
    var id = this.iframeId = 'eio_iframe_' + this.index;
    var iframe;

    form.className = 'socketio';
    form.style.position = 'absolute';
    form.style.top = '-1000px';
    form.style.left = '-1000px';
    form.target = id;
    form.method = 'POST';
    form.setAttribute('accept-charset', 'utf-8');
    area.name = 'd';
    form.appendChild(area);
    document.body.appendChild(form);

    this.form = form;
    this.area = area;
  }

  this.form.action = this.uri();

  function complete () {
    initIframe();
    fn();
  }

  function initIframe () {
    if (self.iframe) {
      try {
        self.form.removeChild(self.iframe);
      } catch (e) {
        self.onError('jsonp polling iframe removal error', e);
      }
    }

    try {
      // ie6 dynamic iframes with target="" support (thanks Chris Lambacher)
      var html = '<iframe src="javascript:0" name="' + self.iframeId + '">';
      iframe = document.createElement(html);
    } catch (e) {
      iframe = document.createElement('iframe');
      iframe.name = self.iframeId;
      iframe.src = 'javascript:0';
    }

    iframe.id = self.iframeId;

    self.form.appendChild(iframe);
    self.iframe = iframe;
  }

  initIframe();

  // escape \n to prevent it from being converted into \r\n by some UAs
  // double escaping is required for escaped new lines because unescaping of new lines can be done safely on server-side
  data = data.replace(rEscapedNewline, '\\\n');
  this.area.value = data.replace(rNewline, '\\n');

  try {
    this.form.submit();
  } catch (e) {}

  if (this.iframe.attachEvent) {
    this.iframe.onreadystatechange = function () {
      if (self.iframe.readyState === 'complete') {
        complete();
      }
    };
  } else {
    this.iframe.onload = complete;
  }
};


/***/ }),

/***/ 91962:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/* global attachEvent */

/**
 * Module requirements.
 */

var XMLHttpRequest = __webpack_require__(26891);
var Polling = __webpack_require__(65869);
var Emitter = __webpack_require__(17056);
var inherit = __webpack_require__(99238);
var debug = __webpack_require__(39712)('engine.io-client:polling-xhr');

/**
 * Module exports.
 */

module.exports = XHR;
module.exports.Request = Request;

/**
 * Empty function
 */

function empty () {}

/**
 * XHR Polling constructor.
 *
 * @param {Object} opts
 * @api public
 */

function XHR (opts) {
  Polling.call(this, opts);
  this.requestTimeout = opts.requestTimeout;
  this.extraHeaders = opts.extraHeaders;

  if (typeof location !== 'undefined') {
    var isSSL = 'https:' === location.protocol;
    var port = location.port;

    // some user agents have empty `location.port`
    if (!port) {
      port = isSSL ? 443 : 80;
    }

    this.xd = (typeof location !== 'undefined' && opts.hostname !== location.hostname) ||
      port !== opts.port;
    this.xs = opts.secure !== isSSL;
  }
}

/**
 * Inherits from Polling.
 */

inherit(XHR, Polling);

/**
 * XHR supports binary
 */

XHR.prototype.supportsBinary = true;

/**
 * Creates a request.
 *
 * @param {String} method
 * @api private
 */

XHR.prototype.request = function (opts) {
  opts = opts || {};
  opts.uri = this.uri();
  opts.xd = this.xd;
  opts.xs = this.xs;
  opts.agent = this.agent || false;
  opts.supportsBinary = this.supportsBinary;
  opts.enablesXDR = this.enablesXDR;
  opts.withCredentials = this.withCredentials;

  // SSL options for Node.js client
  opts.pfx = this.pfx;
  opts.key = this.key;
  opts.passphrase = this.passphrase;
  opts.cert = this.cert;
  opts.ca = this.ca;
  opts.ciphers = this.ciphers;
  opts.rejectUnauthorized = this.rejectUnauthorized;
  opts.requestTimeout = this.requestTimeout;

  // other options for Node.js client
  opts.extraHeaders = this.extraHeaders;

  return new Request(opts);
};

/**
 * Sends data.
 *
 * @param {String} data to send.
 * @param {Function} called upon flush.
 * @api private
 */

XHR.prototype.doWrite = function (data, fn) {
  var isBinary = typeof data !== 'string' && data !== undefined;
  var req = this.request({ method: 'POST', data: data, isBinary: isBinary });
  var self = this;
  req.on('success', fn);
  req.on('error', function (err) {
    self.onError('xhr post error', err);
  });
  this.sendXhr = req;
};

/**
 * Starts a poll cycle.
 *
 * @api private
 */

XHR.prototype.doPoll = function () {
  debug('xhr poll');
  var req = this.request();
  var self = this;
  req.on('data', function (data) {
    self.onData(data);
  });
  req.on('error', function (err) {
    self.onError('xhr poll error', err);
  });
  this.pollXhr = req;
};

/**
 * Request constructor
 *
 * @param {Object} options
 * @api public
 */

function Request (opts) {
  this.method = opts.method || 'GET';
  this.uri = opts.uri;
  this.xd = !!opts.xd;
  this.xs = !!opts.xs;
  this.async = false !== opts.async;
  this.data = undefined !== opts.data ? opts.data : null;
  this.agent = opts.agent;
  this.isBinary = opts.isBinary;
  this.supportsBinary = opts.supportsBinary;
  this.enablesXDR = opts.enablesXDR;
  this.withCredentials = opts.withCredentials;
  this.requestTimeout = opts.requestTimeout;

  // SSL options for Node.js client
  this.pfx = opts.pfx;
  this.key = opts.key;
  this.passphrase = opts.passphrase;
  this.cert = opts.cert;
  this.ca = opts.ca;
  this.ciphers = opts.ciphers;
  this.rejectUnauthorized = opts.rejectUnauthorized;

  // other options for Node.js client
  this.extraHeaders = opts.extraHeaders;

  this.create();
}

/**
 * Mix in `Emitter`.
 */

Emitter(Request.prototype);

/**
 * Creates the XHR object and sends the request.
 *
 * @api private
 */

Request.prototype.create = function () {
  var opts = { agent: this.agent, xdomain: this.xd, xscheme: this.xs, enablesXDR: this.enablesXDR };

  // SSL options for Node.js client
  opts.pfx = this.pfx;
  opts.key = this.key;
  opts.passphrase = this.passphrase;
  opts.cert = this.cert;
  opts.ca = this.ca;
  opts.ciphers = this.ciphers;
  opts.rejectUnauthorized = this.rejectUnauthorized;

  var xhr = this.xhr = new XMLHttpRequest(opts);
  var self = this;

  try {
    debug('xhr open %s: %s', this.method, this.uri);
    xhr.open(this.method, this.uri, this.async);
    try {
      if (this.extraHeaders) {
        xhr.setDisableHeaderCheck && xhr.setDisableHeaderCheck(true);
        for (var i in this.extraHeaders) {
          if (this.extraHeaders.hasOwnProperty(i)) {
            xhr.setRequestHeader(i, this.extraHeaders[i]);
          }
        }
      }
    } catch (e) {}

    if ('POST' === this.method) {
      try {
        if (this.isBinary) {
          xhr.setRequestHeader('Content-type', 'application/octet-stream');
        } else {
          xhr.setRequestHeader('Content-type', 'text/plain;charset=UTF-8');
        }
      } catch (e) {}
    }

    try {
      xhr.setRequestHeader('Accept', '*/*');
    } catch (e) {}

    // ie6 check
    if ('withCredentials' in xhr) {
      xhr.withCredentials = this.withCredentials;
    }

    if (this.requestTimeout) {
      xhr.timeout = this.requestTimeout;
    }

    if (this.hasXDR()) {
      xhr.onload = function () {
        self.onLoad();
      };
      xhr.onerror = function () {
        self.onError(xhr.responseText);
      };
    } else {
      xhr.onreadystatechange = function () {
        if (xhr.readyState === 2) {
          try {
            var contentType = xhr.getResponseHeader('Content-Type');
            if (self.supportsBinary && contentType === 'application/octet-stream' || contentType === 'application/octet-stream; charset=UTF-8') {
              xhr.responseType = 'arraybuffer';
            }
          } catch (e) {}
        }
        if (4 !== xhr.readyState) return;
        if (200 === xhr.status || 1223 === xhr.status) {
          self.onLoad();
        } else {
          // make sure the `error` event handler that's user-set
          // does not throw in the same tick and gets caught here
          setTimeout(function () {
            self.onError(typeof xhr.status === 'number' ? xhr.status : 0);
          }, 0);
        }
      };
    }

    debug('xhr data %s', this.data);
    xhr.send(this.data);
  } catch (e) {
    // Need to defer since .create() is called directly fhrom the constructor
    // and thus the 'error' event can only be only bound *after* this exception
    // occurs.  Therefore, also, we cannot throw here at all.
    setTimeout(function () {
      self.onError(e);
    }, 0);
    return;
  }

  if (typeof document !== 'undefined') {
    this.index = Request.requestsCount++;
    Request.requests[this.index] = this;
  }
};

/**
 * Called upon successful response.
 *
 * @api private
 */

Request.prototype.onSuccess = function () {
  this.emit('success');
  this.cleanup();
};

/**
 * Called if we have data.
 *
 * @api private
 */

Request.prototype.onData = function (data) {
  this.emit('data', data);
  this.onSuccess();
};

/**
 * Called upon error.
 *
 * @api private
 */

Request.prototype.onError = function (err) {
  this.emit('error', err);
  this.cleanup(true);
};

/**
 * Cleans up house.
 *
 * @api private
 */

Request.prototype.cleanup = function (fromError) {
  if ('undefined' === typeof this.xhr || null === this.xhr) {
    return;
  }
  // xmlhttprequest
  if (this.hasXDR()) {
    this.xhr.onload = this.xhr.onerror = empty;
  } else {
    this.xhr.onreadystatechange = empty;
  }

  if (fromError) {
    try {
      this.xhr.abort();
    } catch (e) {}
  }

  if (typeof document !== 'undefined') {
    delete Request.requests[this.index];
  }

  this.xhr = null;
};

/**
 * Called upon load.
 *
 * @api private
 */

Request.prototype.onLoad = function () {
  var data;
  try {
    var contentType;
    try {
      contentType = this.xhr.getResponseHeader('Content-Type');
    } catch (e) {}
    if (contentType === 'application/octet-stream' || contentType === 'application/octet-stream; charset=UTF-8') {
      data = this.xhr.response || this.xhr.responseText;
    } else {
      data = this.xhr.responseText;
    }
  } catch (e) {
    this.onError(e);
  }
  if (null != data) {
    this.onData(data);
  }
};

/**
 * Check if it has XDomainRequest.
 *
 * @api private
 */

Request.prototype.hasXDR = function () {
  return typeof XDomainRequest !== 'undefined' && !this.xs && this.enablesXDR;
};

/**
 * Aborts the request.
 *
 * @api public
 */

Request.prototype.abort = function () {
  this.cleanup();
};

/**
 * Aborts pending requests when unloading the window. This is needed to prevent
 * memory leaks (e.g. when using IE) and to ensure that no spurious error is
 * emitted.
 */

Request.requestsCount = 0;
Request.requests = {};

if (typeof document !== 'undefined') {
  if (typeof attachEvent === 'function') {
    attachEvent('onunload', unloadHandler);
  } else if (typeof addEventListener === 'function') {
    var terminationEvent = 'onpagehide' in self ? 'pagehide' : 'unload';
    addEventListener(terminationEvent, unloadHandler, false);
  }
}

function unloadHandler () {
  for (var i in Request.requests) {
    if (Request.requests.hasOwnProperty(i)) {
      Request.requests[i].abort();
    }
  }
}


/***/ }),

/***/ 65869:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/**
 * Module dependencies.
 */

var Transport = __webpack_require__(5344);
var parseqs = __webpack_require__(54355);
var parser = __webpack_require__(90820);
var inherit = __webpack_require__(99238);
var yeast = __webpack_require__(34973);
var debug = __webpack_require__(39712)('engine.io-client:polling');

/**
 * Module exports.
 */

module.exports = Polling;

/**
 * Is XHR2 supported?
 */

var hasXHR2 = (function () {
  var XMLHttpRequest = __webpack_require__(26891);
  var xhr = new XMLHttpRequest({ xdomain: false });
  return null != xhr.responseType;
})();

/**
 * Polling interface.
 *
 * @param {Object} opts
 * @api private
 */

function Polling (opts) {
  var forceBase64 = (opts && opts.forceBase64);
  if (!hasXHR2 || forceBase64) {
    this.supportsBinary = false;
  }
  Transport.call(this, opts);
}

/**
 * Inherits from Transport.
 */

inherit(Polling, Transport);

/**
 * Transport name.
 */

Polling.prototype.name = 'polling';

/**
 * Opens the socket (triggers polling). We write a PING message to determine
 * when the transport is open.
 *
 * @api private
 */

Polling.prototype.doOpen = function () {
  this.poll();
};

/**
 * Pauses polling.
 *
 * @param {Function} callback upon buffers are flushed and transport is paused
 * @api private
 */

Polling.prototype.pause = function (onPause) {
  var self = this;

  this.readyState = 'pausing';

  function pause () {
    debug('paused');
    self.readyState = 'paused';
    onPause();
  }

  if (this.polling || !this.writable) {
    var total = 0;

    if (this.polling) {
      debug('we are currently polling - waiting to pause');
      total++;
      this.once('pollComplete', function () {
        debug('pre-pause polling complete');
        --total || pause();
      });
    }

    if (!this.writable) {
      debug('we are currently writing - waiting to pause');
      total++;
      this.once('drain', function () {
        debug('pre-pause writing complete');
        --total || pause();
      });
    }
  } else {
    pause();
  }
};

/**
 * Starts polling cycle.
 *
 * @api public
 */

Polling.prototype.poll = function () {
  debug('polling');
  this.polling = true;
  this.doPoll();
  this.emit('poll');
};

/**
 * Overloads onData to detect payloads.
 *
 * @api private
 */

Polling.prototype.onData = function (data) {
  var self = this;
  debug('polling got data %s', data);
  var callback = function (packet, index, total) {
    // if its the first message we consider the transport open
    if ('opening' === self.readyState) {
      self.onOpen();
    }

    // if its a close packet, we close the ongoing requests
    if ('close' === packet.type) {
      self.onClose();
      return false;
    }

    // otherwise bypass onData and handle the message
    self.onPacket(packet);
  };

  // decode payload
  parser.decodePayload(data, this.socket.binaryType, callback);

  // if an event did not trigger closing
  if ('closed' !== this.readyState) {
    // if we got data we're not polling
    this.polling = false;
    this.emit('pollComplete');

    if ('open' === this.readyState) {
      this.poll();
    } else {
      debug('ignoring poll - transport state "%s"', this.readyState);
    }
  }
};

/**
 * For polling, send a close packet.
 *
 * @api private
 */

Polling.prototype.doClose = function () {
  var self = this;

  function close () {
    debug('writing close packet');
    self.write([{ type: 'close' }]);
  }

  if ('open' === this.readyState) {
    debug('transport open - closing');
    close();
  } else {
    // in case we're trying to close while
    // handshaking is in progress (GH-164)
    debug('transport not open - deferring close');
    this.once('open', close);
  }
};

/**
 * Writes a packets payload.
 *
 * @param {Array} data packets
 * @param {Function} drain callback
 * @api private
 */

Polling.prototype.write = function (packets) {
  var self = this;
  this.writable = false;
  var callbackfn = function () {
    self.writable = true;
    self.emit('drain');
  };

  parser.encodePayload(packets, this.supportsBinary, function (data) {
    self.doWrite(data, callbackfn);
  });
};

/**
 * Generates uri for connection.
 *
 * @api private
 */

Polling.prototype.uri = function () {
  var query = this.query || {};
  var schema = this.secure ? 'https' : 'http';
  var port = '';

  // cache busting is forced
  if (false !== this.timestampRequests) {
    query[this.timestampParam] = yeast();
  }

  if (!this.supportsBinary && !query.sid) {
    query.b64 = 1;
  }

  query = parseqs.encode(query);

  // avoid port if default for schema
  if (this.port && (('https' === schema && Number(this.port) !== 443) ||
     ('http' === schema && Number(this.port) !== 80))) {
    port = ':' + this.port;
  }

  // prepend ? to query
  if (query.length) {
    query = '?' + query;
  }

  var ipv6 = this.hostname.indexOf(':') !== -1;
  return schema + '://' + (ipv6 ? '[' + this.hostname + ']' : this.hostname) + port + this.path + query;
};


/***/ }),

/***/ 68479:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/**
 * Module dependencies.
 */

var Transport = __webpack_require__(5344);
var parser = __webpack_require__(90820);
var parseqs = __webpack_require__(54355);
var inherit = __webpack_require__(99238);
var yeast = __webpack_require__(34973);
var debug = __webpack_require__(39712)('engine.io-client:websocket');

var BrowserWebSocket, NodeWebSocket;

if (typeof WebSocket !== 'undefined') {
  BrowserWebSocket = WebSocket;
} else if (typeof self !== 'undefined') {
  BrowserWebSocket = self.WebSocket || self.MozWebSocket;
}

if (typeof window === 'undefined') {
  try {
    NodeWebSocket = __webpack_require__(18864);
  } catch (e) { }
}

/**
 * Get either the `WebSocket` or `MozWebSocket` globals
 * in the browser or try to resolve WebSocket-compatible
 * interface exposed by `ws` for Node-like environment.
 */

var WebSocketImpl = BrowserWebSocket || NodeWebSocket;

/**
 * Module exports.
 */

module.exports = WS;

/**
 * WebSocket transport constructor.
 *
 * @api {Object} connection options
 * @api public
 */

function WS (opts) {
  var forceBase64 = (opts && opts.forceBase64);
  if (forceBase64) {
    this.supportsBinary = false;
  }
  this.perMessageDeflate = opts.perMessageDeflate;
  this.usingBrowserWebSocket = BrowserWebSocket && !opts.forceNode;
  this.protocols = opts.protocols;
  if (!this.usingBrowserWebSocket) {
    WebSocketImpl = NodeWebSocket;
  }
  Transport.call(this, opts);
}

/**
 * Inherits from Transport.
 */

inherit(WS, Transport);

/**
 * Transport name.
 *
 * @api public
 */

WS.prototype.name = 'websocket';

/*
 * WebSockets support binary
 */

WS.prototype.supportsBinary = true;

/**
 * Opens socket.
 *
 * @api private
 */

WS.prototype.doOpen = function () {
  if (!this.check()) {
    // let probe timeout
    return;
  }

  var uri = this.uri();
  var protocols = this.protocols;
  var opts = {
    agent: this.agent,
    perMessageDeflate: this.perMessageDeflate
  };

  // SSL options for Node.js client
  opts.pfx = this.pfx;
  opts.key = this.key;
  opts.passphrase = this.passphrase;
  opts.cert = this.cert;
  opts.ca = this.ca;
  opts.ciphers = this.ciphers;
  opts.rejectUnauthorized = this.rejectUnauthorized;
  if (this.extraHeaders) {
    opts.headers = this.extraHeaders;
  }
  if (this.localAddress) {
    opts.localAddress = this.localAddress;
  }

  try {
    this.ws =
      this.usingBrowserWebSocket && !this.isReactNative
        ? protocols
          ? new WebSocketImpl(uri, protocols)
          : new WebSocketImpl(uri)
        : new WebSocketImpl(uri, protocols, opts);
  } catch (err) {
    return this.emit('error', err);
  }

  if (this.ws.binaryType === undefined) {
    this.supportsBinary = false;
  }

  if (this.ws.supports && this.ws.supports.binary) {
    this.supportsBinary = true;
    this.ws.binaryType = 'nodebuffer';
  } else {
    this.ws.binaryType = 'arraybuffer';
  }

  this.addEventListeners();
};

/**
 * Adds event listeners to the socket
 *
 * @api private
 */

WS.prototype.addEventListeners = function () {
  var self = this;

  this.ws.onopen = function () {
    self.onOpen();
  };
  this.ws.onclose = function () {
    self.onClose();
  };
  this.ws.onmessage = function (ev) {
    self.onData(ev.data);
  };
  this.ws.onerror = function (e) {
    self.onError('websocket error', e);
  };
};

/**
 * Writes data to socket.
 *
 * @param {Array} array of packets.
 * @api private
 */

WS.prototype.write = function (packets) {
  var self = this;
  this.writable = false;

  // encodePacket efficient as it uses WS framing
  // no need for encodePayload
  var total = packets.length;
  for (var i = 0, l = total; i < l; i++) {
    (function (packet) {
      parser.encodePacket(packet, self.supportsBinary, function (data) {
        if (!self.usingBrowserWebSocket) {
          // always create a new object (GH-437)
          var opts = {};
          if (packet.options) {
            opts.compress = packet.options.compress;
          }

          if (self.perMessageDeflate) {
            var len = 'string' === typeof data ? Buffer.byteLength(data) : data.length;
            if (len < self.perMessageDeflate.threshold) {
              opts.compress = false;
            }
          }
        }

        // Sometimes the websocket has already been closed but the browser didn't
        // have a chance of informing us about it yet, in that case send will
        // throw an error
        try {
          if (self.usingBrowserWebSocket) {
            // TypeError is thrown when passing the second argument on Safari
            self.ws.send(data);
          } else {
            self.ws.send(data, opts);
          }
        } catch (e) {
          debug('websocket closed before onclose event');
        }

        --total || done();
      });
    })(packets[i]);
  }

  function done () {
    self.emit('flush');

    // fake drain
    // defer to next tick to allow Socket to clear writeBuffer
    setTimeout(function () {
      self.writable = true;
      self.emit('drain');
    }, 0);
  }
};

/**
 * Called upon close
 *
 * @api private
 */

WS.prototype.onClose = function () {
  Transport.prototype.onClose.call(this);
};

/**
 * Closes socket.
 *
 * @api private
 */

WS.prototype.doClose = function () {
  if (typeof this.ws !== 'undefined') {
    this.ws.close();
  }
};

/**
 * Generates uri for connection.
 *
 * @api private
 */

WS.prototype.uri = function () {
  var query = this.query || {};
  var schema = this.secure ? 'wss' : 'ws';
  var port = '';

  // avoid port if default for schema
  if (this.port && (('wss' === schema && Number(this.port) !== 443) ||
    ('ws' === schema && Number(this.port) !== 80))) {
    port = ':' + this.port;
  }

  // append timestamp to URI
  if (this.timestampRequests) {
    query[this.timestampParam] = yeast();
  }

  // communicate binary support capabilities
  if (!this.supportsBinary) {
    query.b64 = 1;
  }

  query = parseqs.encode(query);

  // prepend ? to query
  if (query.length) {
    query = '?' + query;
  }

  var ipv6 = this.hostname.indexOf(':') !== -1;
  return schema + '://' + (ipv6 ? '[' + this.hostname + ']' : this.hostname) + port + this.path + query;
};

/**
 * Feature detection for WebSocket.
 *
 * @return {Boolean} whether this transport is available.
 * @api public
 */

WS.prototype.check = function () {
  return !!WebSocketImpl && !('__initialize' in WebSocketImpl && this.name === WS.prototype.name);
};


/***/ }),

/***/ 26891:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

// browser shim for xmlhttprequest module

var hasCORS = __webpack_require__(95460);

module.exports = function (opts) {
  var xdomain = opts.xdomain;

  // scheme must be same when usign XDomainRequest
  // http://blogs.msdn.com/b/ieinternals/archive/2010/05/13/xdomainrequest-restrictions-limitations-and-workarounds.aspx
  var xscheme = opts.xscheme;

  // XDomainRequest has a flow of not sending cookie, therefore it should be disabled as a default.
  // https://github.com/Automattic/engine.io-client/pull/217
  var enablesXDR = opts.enablesXDR;

  // XMLHttpRequest can be disabled on IE
  try {
    if ('undefined' !== typeof XMLHttpRequest && (!xdomain || hasCORS)) {
      return new XMLHttpRequest();
    }
  } catch (e) { }

  // Use XDomainRequest for IE8 if enablesXDR is true
  // because loading bar keeps flashing when using jsonp-polling
  // https://github.com/yujiosaka/socke.io-ie8-loading-example
  try {
    if ('undefined' !== typeof XDomainRequest && !xscheme && enablesXDR) {
      return new XDomainRequest();
    }
  } catch (e) { }

  if (!xdomain) {
    try {
      return new self[['Active'].concat('Object').join('X')]('Microsoft.XMLHTTP');
    } catch (e) { }
  }
};


/***/ }),

/***/ 17056:
/***/ (function(module) {


/**
 * Expose `Emitter`.
 */

if (true) {
  module.exports = Emitter;
}

/**
 * Initialize a new `Emitter`.
 *
 * @api public
 */

function Emitter(obj) {
  if (obj) return mixin(obj);
};

/**
 * Mixin the emitter properties.
 *
 * @param {Object} obj
 * @return {Object}
 * @api private
 */

function mixin(obj) {
  for (var key in Emitter.prototype) {
    obj[key] = Emitter.prototype[key];
  }
  return obj;
}

/**
 * Listen on the given `event` with `fn`.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Emitter}
 * @api public
 */

Emitter.prototype.on =
Emitter.prototype.addEventListener = function(event, fn){
  this._callbacks = this._callbacks || {};
  (this._callbacks['$' + event] = this._callbacks['$' + event] || [])
    .push(fn);
  return this;
};

/**
 * Adds an `event` listener that will be invoked a single
 * time then automatically removed.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Emitter}
 * @api public
 */

Emitter.prototype.once = function(event, fn){
  function on() {
    this.off(event, on);
    fn.apply(this, arguments);
  }

  on.fn = fn;
  this.on(event, on);
  return this;
};

/**
 * Remove the given callback for `event` or all
 * registered callbacks.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Emitter}
 * @api public
 */

Emitter.prototype.off =
Emitter.prototype.removeListener =
Emitter.prototype.removeAllListeners =
Emitter.prototype.removeEventListener = function(event, fn){
  this._callbacks = this._callbacks || {};

  // all
  if (0 == arguments.length) {
    this._callbacks = {};
    return this;
  }

  // specific event
  var callbacks = this._callbacks['$' + event];
  if (!callbacks) return this;

  // remove all handlers
  if (1 == arguments.length) {
    delete this._callbacks['$' + event];
    return this;
  }

  // remove specific handler
  var cb;
  for (var i = 0; i < callbacks.length; i++) {
    cb = callbacks[i];
    if (cb === fn || cb.fn === fn) {
      callbacks.splice(i, 1);
      break;
    }
  }
  return this;
};

/**
 * Emit `event` with the given args.
 *
 * @param {String} event
 * @param {Mixed} ...
 * @return {Emitter}
 */

Emitter.prototype.emit = function(event){
  this._callbacks = this._callbacks || {};
  var args = [].slice.call(arguments, 1)
    , callbacks = this._callbacks['$' + event];

  if (callbacks) {
    callbacks = callbacks.slice(0);
    for (var i = 0, len = callbacks.length; i < len; ++i) {
      callbacks[i].apply(this, args);
    }
  }

  return this;
};

/**
 * Return array of callbacks for `event`.
 *
 * @param {String} event
 * @return {Array}
 * @api public
 */

Emitter.prototype.listeners = function(event){
  this._callbacks = this._callbacks || {};
  return this._callbacks['$' + event] || [];
};

/**
 * Check if this emitter has `event` handlers.
 *
 * @param {String} event
 * @return {Boolean}
 * @api public
 */

Emitter.prototype.hasListeners = function(event){
  return !! this.listeners(event).length;
};


/***/ }),

/***/ 90820:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

/**
 * Module dependencies.
 */

var keys = __webpack_require__(62298);
var hasBinary = __webpack_require__(54632);
var sliceBuffer = __webpack_require__(50696);
var after = __webpack_require__(61777);
var utf8 = __webpack_require__(68544);

var base64encoder;
if (typeof ArrayBuffer !== 'undefined') {
  base64encoder = __webpack_require__(28328);
}

/**
 * Check if we are running an android browser. That requires us to use
 * ArrayBuffer with polling transports...
 *
 * http://ghinda.net/jpeg-blob-ajax-android/
 */

var isAndroid = typeof navigator !== 'undefined' && /Android/i.test(navigator.userAgent);

/**
 * Check if we are running in PhantomJS.
 * Uploading a Blob with PhantomJS does not work correctly, as reported here:
 * https://github.com/ariya/phantomjs/issues/11395
 * @type boolean
 */
var isPhantomJS = typeof navigator !== 'undefined' && /PhantomJS/i.test(navigator.userAgent);

/**
 * When true, avoids using Blobs to encode payloads.
 * @type boolean
 */
var dontSendBlobs = isAndroid || isPhantomJS;

/**
 * Current protocol version.
 */

exports.protocol = 3;

/**
 * Packet types.
 */

var packets = exports.packets = {
    open:     0    // non-ws
  , close:    1    // non-ws
  , ping:     2
  , pong:     3
  , message:  4
  , upgrade:  5
  , noop:     6
};

var packetslist = keys(packets);

/**
 * Premade error packet.
 */

var err = { type: 'error', data: 'parser error' };

/**
 * Create a blob api even for blob builder when vendor prefixes exist
 */

var Blob = __webpack_require__(23055);

/**
 * Encodes a packet.
 *
 *     <packet type id> [ <data> ]
 *
 * Example:
 *
 *     5hello world
 *     3
 *     4
 *
 * Binary is encoded in an identical principle
 *
 * @api private
 */

exports.encodePacket = function (packet, supportsBinary, utf8encode, callback) {
  if (typeof supportsBinary === 'function') {
    callback = supportsBinary;
    supportsBinary = false;
  }

  if (typeof utf8encode === 'function') {
    callback = utf8encode;
    utf8encode = null;
  }

  var data = (packet.data === undefined)
    ? undefined
    : packet.data.buffer || packet.data;

  if (typeof ArrayBuffer !== 'undefined' && data instanceof ArrayBuffer) {
    return encodeArrayBuffer(packet, supportsBinary, callback);
  } else if (typeof Blob !== 'undefined' && data instanceof Blob) {
    return encodeBlob(packet, supportsBinary, callback);
  }

  // might be an object with { base64: true, data: dataAsBase64String }
  if (data && data.base64) {
    return encodeBase64Object(packet, callback);
  }

  // Sending data as a utf-8 string
  var encoded = packets[packet.type];

  // data fragment is optional
  if (undefined !== packet.data) {
    encoded += utf8encode ? utf8.encode(String(packet.data), { strict: false }) : String(packet.data);
  }

  return callback('' + encoded);

};

function encodeBase64Object(packet, callback) {
  // packet data is an object { base64: true, data: dataAsBase64String }
  var message = 'b' + exports.packets[packet.type] + packet.data.data;
  return callback(message);
}

/**
 * Encode packet helpers for binary types
 */

function encodeArrayBuffer(packet, supportsBinary, callback) {
  if (!supportsBinary) {
    return exports.encodeBase64Packet(packet, callback);
  }

  var data = packet.data;
  var contentArray = new Uint8Array(data);
  var resultBuffer = new Uint8Array(1 + data.byteLength);

  resultBuffer[0] = packets[packet.type];
  for (var i = 0; i < contentArray.length; i++) {
    resultBuffer[i+1] = contentArray[i];
  }

  return callback(resultBuffer.buffer);
}

function encodeBlobAsArrayBuffer(packet, supportsBinary, callback) {
  if (!supportsBinary) {
    return exports.encodeBase64Packet(packet, callback);
  }

  var fr = new FileReader();
  fr.onload = function() {
    exports.encodePacket({ type: packet.type, data: fr.result }, supportsBinary, true, callback);
  };
  return fr.readAsArrayBuffer(packet.data);
}

function encodeBlob(packet, supportsBinary, callback) {
  if (!supportsBinary) {
    return exports.encodeBase64Packet(packet, callback);
  }

  if (dontSendBlobs) {
    return encodeBlobAsArrayBuffer(packet, supportsBinary, callback);
  }

  var length = new Uint8Array(1);
  length[0] = packets[packet.type];
  var blob = new Blob([length.buffer, packet.data]);

  return callback(blob);
}

/**
 * Encodes a packet with binary data in a base64 string
 *
 * @param {Object} packet, has `type` and `data`
 * @return {String} base64 encoded message
 */

exports.encodeBase64Packet = function(packet, callback) {
  var message = 'b' + exports.packets[packet.type];
  if (typeof Blob !== 'undefined' && packet.data instanceof Blob) {
    var fr = new FileReader();
    fr.onload = function() {
      var b64 = fr.result.split(',')[1];
      callback(message + b64);
    };
    return fr.readAsDataURL(packet.data);
  }

  var b64data;
  try {
    b64data = String.fromCharCode.apply(null, new Uint8Array(packet.data));
  } catch (e) {
    // iPhone Safari doesn't let you apply with typed arrays
    var typed = new Uint8Array(packet.data);
    var basic = new Array(typed.length);
    for (var i = 0; i < typed.length; i++) {
      basic[i] = typed[i];
    }
    b64data = String.fromCharCode.apply(null, basic);
  }
  message += btoa(b64data);
  return callback(message);
};

/**
 * Decodes a packet. Changes format to Blob if requested.
 *
 * @return {Object} with `type` and `data` (if any)
 * @api private
 */

exports.decodePacket = function (data, binaryType, utf8decode) {
  if (data === undefined) {
    return err;
  }
  // String data
  if (typeof data === 'string') {
    if (data.charAt(0) === 'b') {
      return exports.decodeBase64Packet(data.substr(1), binaryType);
    }

    if (utf8decode) {
      data = tryDecode(data);
      if (data === false) {
        return err;
      }
    }
    var type = data.charAt(0);

    if (Number(type) != type || !packetslist[type]) {
      return err;
    }

    if (data.length > 1) {
      return { type: packetslist[type], data: data.substring(1) };
    } else {
      return { type: packetslist[type] };
    }
  }

  var asArray = new Uint8Array(data);
  var type = asArray[0];
  var rest = sliceBuffer(data, 1);
  if (Blob && binaryType === 'blob') {
    rest = new Blob([rest]);
  }
  return { type: packetslist[type], data: rest };
};

function tryDecode(data) {
  try {
    data = utf8.decode(data, { strict: false });
  } catch (e) {
    return false;
  }
  return data;
}

/**
 * Decodes a packet encoded in a base64 string
 *
 * @param {String} base64 encoded message
 * @return {Object} with `type` and `data` (if any)
 */

exports.decodeBase64Packet = function(msg, binaryType) {
  var type = packetslist[msg.charAt(0)];
  if (!base64encoder) {
    return { type: type, data: { base64: true, data: msg.substr(1) } };
  }

  var data = base64encoder.decode(msg.substr(1));

  if (binaryType === 'blob' && Blob) {
    data = new Blob([data]);
  }

  return { type: type, data: data };
};

/**
 * Encodes multiple messages (payload).
 *
 *     <length>:data
 *
 * Example:
 *
 *     11:hello world2:hi
 *
 * If any contents are binary, they will be encoded as base64 strings. Base64
 * encoded strings are marked with a b before the length specifier
 *
 * @param {Array} packets
 * @api private
 */

exports.encodePayload = function (packets, supportsBinary, callback) {
  if (typeof supportsBinary === 'function') {
    callback = supportsBinary;
    supportsBinary = null;
  }

  var isBinary = hasBinary(packets);

  if (supportsBinary && isBinary) {
    if (Blob && !dontSendBlobs) {
      return exports.encodePayloadAsBlob(packets, callback);
    }

    return exports.encodePayloadAsArrayBuffer(packets, callback);
  }

  if (!packets.length) {
    return callback('0:');
  }

  function setLengthHeader(message) {
    return message.length + ':' + message;
  }

  function encodeOne(packet, doneCallback) {
    exports.encodePacket(packet, !isBinary ? false : supportsBinary, false, function(message) {
      doneCallback(null, setLengthHeader(message));
    });
  }

  map(packets, encodeOne, function(err, results) {
    return callback(results.join(''));
  });
};

/**
 * Async array map using after
 */

function map(ary, each, done) {
  var result = new Array(ary.length);
  var next = after(ary.length, done);

  var eachWithIndex = function(i, el, cb) {
    each(el, function(error, msg) {
      result[i] = msg;
      cb(error, result);
    });
  };

  for (var i = 0; i < ary.length; i++) {
    eachWithIndex(i, ary[i], next);
  }
}

/*
 * Decodes data when a payload is maybe expected. Possible binary contents are
 * decoded from their base64 representation
 *
 * @param {String} data, callback method
 * @api public
 */

exports.decodePayload = function (data, binaryType, callback) {
  if (typeof data !== 'string') {
    return exports.decodePayloadAsBinary(data, binaryType, callback);
  }

  if (typeof binaryType === 'function') {
    callback = binaryType;
    binaryType = null;
  }

  var packet;
  if (data === '') {
    // parser error - ignoring payload
    return callback(err, 0, 1);
  }

  var length = '', n, msg;

  for (var i = 0, l = data.length; i < l; i++) {
    var chr = data.charAt(i);

    if (chr !== ':') {
      length += chr;
      continue;
    }

    if (length === '' || (length != (n = Number(length)))) {
      // parser error - ignoring payload
      return callback(err, 0, 1);
    }

    msg = data.substr(i + 1, n);

    if (length != msg.length) {
      // parser error - ignoring payload
      return callback(err, 0, 1);
    }

    if (msg.length) {
      packet = exports.decodePacket(msg, binaryType, false);

      if (err.type === packet.type && err.data === packet.data) {
        // parser error in individual packet - ignoring payload
        return callback(err, 0, 1);
      }

      var ret = callback(packet, i + n, l);
      if (false === ret) return;
    }

    // advance cursor
    i += n;
    length = '';
  }

  if (length !== '') {
    // parser error - ignoring payload
    return callback(err, 0, 1);
  }

};

/**
 * Encodes multiple messages (payload) as binary.
 *
 * <1 = binary, 0 = string><number from 0-9><number from 0-9>[...]<number
 * 255><data>
 *
 * Example:
 * 1 3 255 1 2 3, if the binary contents are interpreted as 8 bit integers
 *
 * @param {Array} packets
 * @return {ArrayBuffer} encoded payload
 * @api private
 */

exports.encodePayloadAsArrayBuffer = function(packets, callback) {
  if (!packets.length) {
    return callback(new ArrayBuffer(0));
  }

  function encodeOne(packet, doneCallback) {
    exports.encodePacket(packet, true, true, function(data) {
      return doneCallback(null, data);
    });
  }

  map(packets, encodeOne, function(err, encodedPackets) {
    var totalLength = encodedPackets.reduce(function(acc, p) {
      var len;
      if (typeof p === 'string'){
        len = p.length;
      } else {
        len = p.byteLength;
      }
      return acc + len.toString().length + len + 2; // string/binary identifier + separator = 2
    }, 0);

    var resultArray = new Uint8Array(totalLength);

    var bufferIndex = 0;
    encodedPackets.forEach(function(p) {
      var isString = typeof p === 'string';
      var ab = p;
      if (isString) {
        var view = new Uint8Array(p.length);
        for (var i = 0; i < p.length; i++) {
          view[i] = p.charCodeAt(i);
        }
        ab = view.buffer;
      }

      if (isString) { // not true binary
        resultArray[bufferIndex++] = 0;
      } else { // true binary
        resultArray[bufferIndex++] = 1;
      }

      var lenStr = ab.byteLength.toString();
      for (var i = 0; i < lenStr.length; i++) {
        resultArray[bufferIndex++] = parseInt(lenStr[i]);
      }
      resultArray[bufferIndex++] = 255;

      var view = new Uint8Array(ab);
      for (var i = 0; i < view.length; i++) {
        resultArray[bufferIndex++] = view[i];
      }
    });

    return callback(resultArray.buffer);
  });
};

/**
 * Encode as Blob
 */

exports.encodePayloadAsBlob = function(packets, callback) {
  function encodeOne(packet, doneCallback) {
    exports.encodePacket(packet, true, true, function(encoded) {
      var binaryIdentifier = new Uint8Array(1);
      binaryIdentifier[0] = 1;
      if (typeof encoded === 'string') {
        var view = new Uint8Array(encoded.length);
        for (var i = 0; i < encoded.length; i++) {
          view[i] = encoded.charCodeAt(i);
        }
        encoded = view.buffer;
        binaryIdentifier[0] = 0;
      }

      var len = (encoded instanceof ArrayBuffer)
        ? encoded.byteLength
        : encoded.size;

      var lenStr = len.toString();
      var lengthAry = new Uint8Array(lenStr.length + 1);
      for (var i = 0; i < lenStr.length; i++) {
        lengthAry[i] = parseInt(lenStr[i]);
      }
      lengthAry[lenStr.length] = 255;

      if (Blob) {
        var blob = new Blob([binaryIdentifier.buffer, lengthAry.buffer, encoded]);
        doneCallback(null, blob);
      }
    });
  }

  map(packets, encodeOne, function(err, results) {
    return callback(new Blob(results));
  });
};

/*
 * Decodes data when a payload is maybe expected. Strings are decoded by
 * interpreting each byte as a key code for entries marked to start with 0. See
 * description of encodePayloadAsBinary
 *
 * @param {ArrayBuffer} data, callback method
 * @api public
 */

exports.decodePayloadAsBinary = function (data, binaryType, callback) {
  if (typeof binaryType === 'function') {
    callback = binaryType;
    binaryType = null;
  }

  var bufferTail = data;
  var buffers = [];

  while (bufferTail.byteLength > 0) {
    var tailArray = new Uint8Array(bufferTail);
    var isString = tailArray[0] === 0;
    var msgLength = '';

    for (var i = 1; ; i++) {
      if (tailArray[i] === 255) break;

      // 310 = char length of Number.MAX_VALUE
      if (msgLength.length > 310) {
        return callback(err, 0, 1);
      }

      msgLength += tailArray[i];
    }

    bufferTail = sliceBuffer(bufferTail, 2 + msgLength.length);
    msgLength = parseInt(msgLength);

    var msg = sliceBuffer(bufferTail, 0, msgLength);
    if (isString) {
      try {
        msg = String.fromCharCode.apply(null, new Uint8Array(msg));
      } catch (e) {
        // iPhone Safari doesn't let you apply to typed arrays
        var typed = new Uint8Array(msg);
        msg = '';
        for (var i = 0; i < typed.length; i++) {
          msg += String.fromCharCode(typed[i]);
        }
      }
    }

    buffers.push(msg);
    bufferTail = sliceBuffer(bufferTail, msgLength);
  }

  var total = buffers.length;
  buffers.forEach(function(buffer, i) {
    callback(exports.decodePacket(buffer, binaryType, true), i, total);
  });
};


/***/ }),

/***/ 62298:
/***/ (function(module) {


/**
 * Gets the keys for an object.
 *
 * @return {Array} keys
 * @api private
 */

module.exports = Object.keys || function keys (obj){
  var arr = [];
  var has = Object.prototype.hasOwnProperty;

  for (var i in obj) {
    if (has.call(obj, i)) {
      arr.push(i);
    }
  }
  return arr;
};


/***/ }),

/***/ 68544:
/***/ (function(module) {

/*! https://mths.be/utf8js v2.1.2 by @mathias */

var stringFromCharCode = String.fromCharCode;

// Taken from https://mths.be/punycode
function ucs2decode(string) {
	var output = [];
	var counter = 0;
	var length = string.length;
	var value;
	var extra;
	while (counter < length) {
		value = string.charCodeAt(counter++);
		if (value >= 0xD800 && value <= 0xDBFF && counter < length) {
			// high surrogate, and there is a next character
			extra = string.charCodeAt(counter++);
			if ((extra & 0xFC00) == 0xDC00) { // low surrogate
				output.push(((value & 0x3FF) << 10) + (extra & 0x3FF) + 0x10000);
			} else {
				// unmatched surrogate; only append this code unit, in case the next
				// code unit is the high surrogate of a surrogate pair
				output.push(value);
				counter--;
			}
		} else {
			output.push(value);
		}
	}
	return output;
}

// Taken from https://mths.be/punycode
function ucs2encode(array) {
	var length = array.length;
	var index = -1;
	var value;
	var output = '';
	while (++index < length) {
		value = array[index];
		if (value > 0xFFFF) {
			value -= 0x10000;
			output += stringFromCharCode(value >>> 10 & 0x3FF | 0xD800);
			value = 0xDC00 | value & 0x3FF;
		}
		output += stringFromCharCode(value);
	}
	return output;
}

function checkScalarValue(codePoint, strict) {
	if (codePoint >= 0xD800 && codePoint <= 0xDFFF) {
		if (strict) {
			throw Error(
				'Lone surrogate U+' + codePoint.toString(16).toUpperCase() +
				' is not a scalar value'
			);
		}
		return false;
	}
	return true;
}
/*--------------------------------------------------------------------------*/

function createByte(codePoint, shift) {
	return stringFromCharCode(((codePoint >> shift) & 0x3F) | 0x80);
}

function encodeCodePoint(codePoint, strict) {
	if ((codePoint & 0xFFFFFF80) == 0) { // 1-byte sequence
		return stringFromCharCode(codePoint);
	}
	var symbol = '';
	if ((codePoint & 0xFFFFF800) == 0) { // 2-byte sequence
		symbol = stringFromCharCode(((codePoint >> 6) & 0x1F) | 0xC0);
	}
	else if ((codePoint & 0xFFFF0000) == 0) { // 3-byte sequence
		if (!checkScalarValue(codePoint, strict)) {
			codePoint = 0xFFFD;
		}
		symbol = stringFromCharCode(((codePoint >> 12) & 0x0F) | 0xE0);
		symbol += createByte(codePoint, 6);
	}
	else if ((codePoint & 0xFFE00000) == 0) { // 4-byte sequence
		symbol = stringFromCharCode(((codePoint >> 18) & 0x07) | 0xF0);
		symbol += createByte(codePoint, 12);
		symbol += createByte(codePoint, 6);
	}
	symbol += stringFromCharCode((codePoint & 0x3F) | 0x80);
	return symbol;
}

function utf8encode(string, opts) {
	opts = opts || {};
	var strict = false !== opts.strict;

	var codePoints = ucs2decode(string);
	var length = codePoints.length;
	var index = -1;
	var codePoint;
	var byteString = '';
	while (++index < length) {
		codePoint = codePoints[index];
		byteString += encodeCodePoint(codePoint, strict);
	}
	return byteString;
}

/*--------------------------------------------------------------------------*/

function readContinuationByte() {
	if (byteIndex >= byteCount) {
		throw Error('Invalid byte index');
	}

	var continuationByte = byteArray[byteIndex] & 0xFF;
	byteIndex++;

	if ((continuationByte & 0xC0) == 0x80) {
		return continuationByte & 0x3F;
	}

	// If we end up here, it’s not a continuation byte
	throw Error('Invalid continuation byte');
}

function decodeSymbol(strict) {
	var byte1;
	var byte2;
	var byte3;
	var byte4;
	var codePoint;

	if (byteIndex > byteCount) {
		throw Error('Invalid byte index');
	}

	if (byteIndex == byteCount) {
		return false;
	}

	// Read first byte
	byte1 = byteArray[byteIndex] & 0xFF;
	byteIndex++;

	// 1-byte sequence (no continuation bytes)
	if ((byte1 & 0x80) == 0) {
		return byte1;
	}

	// 2-byte sequence
	if ((byte1 & 0xE0) == 0xC0) {
		byte2 = readContinuationByte();
		codePoint = ((byte1 & 0x1F) << 6) | byte2;
		if (codePoint >= 0x80) {
			return codePoint;
		} else {
			throw Error('Invalid continuation byte');
		}
	}

	// 3-byte sequence (may include unpaired surrogates)
	if ((byte1 & 0xF0) == 0xE0) {
		byte2 = readContinuationByte();
		byte3 = readContinuationByte();
		codePoint = ((byte1 & 0x0F) << 12) | (byte2 << 6) | byte3;
		if (codePoint >= 0x0800) {
			return checkScalarValue(codePoint, strict) ? codePoint : 0xFFFD;
		} else {
			throw Error('Invalid continuation byte');
		}
	}

	// 4-byte sequence
	if ((byte1 & 0xF8) == 0xF0) {
		byte2 = readContinuationByte();
		byte3 = readContinuationByte();
		byte4 = readContinuationByte();
		codePoint = ((byte1 & 0x07) << 0x12) | (byte2 << 0x0C) |
			(byte3 << 0x06) | byte4;
		if (codePoint >= 0x010000 && codePoint <= 0x10FFFF) {
			return codePoint;
		}
	}

	throw Error('Invalid UTF-8 detected');
}

var byteArray;
var byteCount;
var byteIndex;
function utf8decode(byteString, opts) {
	opts = opts || {};
	var strict = false !== opts.strict;

	byteArray = ucs2decode(byteString);
	byteCount = byteArray.length;
	byteIndex = 0;
	var codePoints = [];
	var tmp;
	while ((tmp = decodeSymbol(strict)) !== false) {
		codePoints.push(tmp);
	}
	return ucs2encode(codePoints);
}

module.exports = {
	version: '2.1.2',
	encode: utf8encode,
	decode: utf8decode
};


/***/ }),

/***/ 22699:
/***/ (function(module) {

"use strict";
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.



var R = typeof Reflect === 'object' ? Reflect : null
var ReflectApply = R && typeof R.apply === 'function'
  ? R.apply
  : function ReflectApply(target, receiver, args) {
    return Function.prototype.apply.call(target, receiver, args);
  }

var ReflectOwnKeys
if (R && typeof R.ownKeys === 'function') {
  ReflectOwnKeys = R.ownKeys
} else if (Object.getOwnPropertySymbols) {
  ReflectOwnKeys = function ReflectOwnKeys(target) {
    return Object.getOwnPropertyNames(target)
      .concat(Object.getOwnPropertySymbols(target));
  };
} else {
  ReflectOwnKeys = function ReflectOwnKeys(target) {
    return Object.getOwnPropertyNames(target);
  };
}

function ProcessEmitWarning(warning) {
  if (console && console.warn) console.warn(warning);
}

var NumberIsNaN = Number.isNaN || function NumberIsNaN(value) {
  return value !== value;
}

function EventEmitter() {
  EventEmitter.init.call(this);
}
module.exports = EventEmitter;
module.exports.once = once;

// Backwards-compat with node 0.10.x
EventEmitter.EventEmitter = EventEmitter;

EventEmitter.prototype._events = undefined;
EventEmitter.prototype._eventsCount = 0;
EventEmitter.prototype._maxListeners = undefined;

// By default EventEmitters will print a warning if more than 10 listeners are
// added to it. This is a useful default which helps finding memory leaks.
var defaultMaxListeners = 10;

function checkListener(listener) {
  if (typeof listener !== 'function') {
    throw new TypeError('The "listener" argument must be of type Function. Received type ' + typeof listener);
  }
}

Object.defineProperty(EventEmitter, 'defaultMaxListeners', {
  enumerable: true,
  get: function() {
    return defaultMaxListeners;
  },
  set: function(arg) {
    if (typeof arg !== 'number' || arg < 0 || NumberIsNaN(arg)) {
      throw new RangeError('The value of "defaultMaxListeners" is out of range. It must be a non-negative number. Received ' + arg + '.');
    }
    defaultMaxListeners = arg;
  }
});

EventEmitter.init = function() {

  if (this._events === undefined ||
      this._events === Object.getPrototypeOf(this)._events) {
    this._events = Object.create(null);
    this._eventsCount = 0;
  }

  this._maxListeners = this._maxListeners || undefined;
};

// Obviously not all Emitters should be limited to 10. This function allows
// that to be increased. Set to zero for unlimited.
EventEmitter.prototype.setMaxListeners = function setMaxListeners(n) {
  if (typeof n !== 'number' || n < 0 || NumberIsNaN(n)) {
    throw new RangeError('The value of "n" is out of range. It must be a non-negative number. Received ' + n + '.');
  }
  this._maxListeners = n;
  return this;
};

function _getMaxListeners(that) {
  if (that._maxListeners === undefined)
    return EventEmitter.defaultMaxListeners;
  return that._maxListeners;
}

EventEmitter.prototype.getMaxListeners = function getMaxListeners() {
  return _getMaxListeners(this);
};

EventEmitter.prototype.emit = function emit(type) {
  var args = [];
  for (var i = 1; i < arguments.length; i++) args.push(arguments[i]);
  var doError = (type === 'error');

  var events = this._events;
  if (events !== undefined)
    doError = (doError && events.error === undefined);
  else if (!doError)
    return false;

  // If there is no 'error' event listener then throw.
  if (doError) {
    var er;
    if (args.length > 0)
      er = args[0];
    if (er instanceof Error) {
      // Note: The comments on the `throw` lines are intentional, they show
      // up in Node's output if this results in an unhandled exception.
      throw er; // Unhandled 'error' event
    }
    // At least give some kind of context to the user
    var err = new Error('Unhandled error.' + (er ? ' (' + er.message + ')' : ''));
    err.context = er;
    throw err; // Unhandled 'error' event
  }

  var handler = events[type];

  if (handler === undefined)
    return false;

  if (typeof handler === 'function') {
    ReflectApply(handler, this, args);
  } else {
    var len = handler.length;
    var listeners = arrayClone(handler, len);
    for (var i = 0; i < len; ++i)
      ReflectApply(listeners[i], this, args);
  }

  return true;
};

function _addListener(target, type, listener, prepend) {
  var m;
  var events;
  var existing;

  checkListener(listener);

  events = target._events;
  if (events === undefined) {
    events = target._events = Object.create(null);
    target._eventsCount = 0;
  } else {
    // To avoid recursion in the case that type === "newListener"! Before
    // adding it to the listeners, first emit "newListener".
    if (events.newListener !== undefined) {
      target.emit('newListener', type,
                  listener.listener ? listener.listener : listener);

      // Re-assign `events` because a newListener handler could have caused the
      // this._events to be assigned to a new object
      events = target._events;
    }
    existing = events[type];
  }

  if (existing === undefined) {
    // Optimize the case of one listener. Don't need the extra array object.
    existing = events[type] = listener;
    ++target._eventsCount;
  } else {
    if (typeof existing === 'function') {
      // Adding the second element, need to change to array.
      existing = events[type] =
        prepend ? [listener, existing] : [existing, listener];
      // If we've already got an array, just append.
    } else if (prepend) {
      existing.unshift(listener);
    } else {
      existing.push(listener);
    }

    // Check for listener leak
    m = _getMaxListeners(target);
    if (m > 0 && existing.length > m && !existing.warned) {
      existing.warned = true;
      // No error code for this since it is a Warning
      // eslint-disable-next-line no-restricted-syntax
      var w = new Error('Possible EventEmitter memory leak detected. ' +
                          existing.length + ' ' + String(type) + ' listeners ' +
                          'added. Use emitter.setMaxListeners() to ' +
                          'increase limit');
      w.name = 'MaxListenersExceededWarning';
      w.emitter = target;
      w.type = type;
      w.count = existing.length;
      ProcessEmitWarning(w);
    }
  }

  return target;
}

EventEmitter.prototype.addListener = function addListener(type, listener) {
  return _addListener(this, type, listener, false);
};

EventEmitter.prototype.on = EventEmitter.prototype.addListener;

EventEmitter.prototype.prependListener =
    function prependListener(type, listener) {
      return _addListener(this, type, listener, true);
    };

function onceWrapper() {
  if (!this.fired) {
    this.target.removeListener(this.type, this.wrapFn);
    this.fired = true;
    if (arguments.length === 0)
      return this.listener.call(this.target);
    return this.listener.apply(this.target, arguments);
  }
}

function _onceWrap(target, type, listener) {
  var state = { fired: false, wrapFn: undefined, target: target, type: type, listener: listener };
  var wrapped = onceWrapper.bind(state);
  wrapped.listener = listener;
  state.wrapFn = wrapped;
  return wrapped;
}

EventEmitter.prototype.once = function once(type, listener) {
  checkListener(listener);
  this.on(type, _onceWrap(this, type, listener));
  return this;
};

EventEmitter.prototype.prependOnceListener =
    function prependOnceListener(type, listener) {
      checkListener(listener);
      this.prependListener(type, _onceWrap(this, type, listener));
      return this;
    };

// Emits a 'removeListener' event if and only if the listener was removed.
EventEmitter.prototype.removeListener =
    function removeListener(type, listener) {
      var list, events, position, i, originalListener;

      checkListener(listener);

      events = this._events;
      if (events === undefined)
        return this;

      list = events[type];
      if (list === undefined)
        return this;

      if (list === listener || list.listener === listener) {
        if (--this._eventsCount === 0)
          this._events = Object.create(null);
        else {
          delete events[type];
          if (events.removeListener)
            this.emit('removeListener', type, list.listener || listener);
        }
      } else if (typeof list !== 'function') {
        position = -1;

        for (i = list.length - 1; i >= 0; i--) {
          if (list[i] === listener || list[i].listener === listener) {
            originalListener = list[i].listener;
            position = i;
            break;
          }
        }

        if (position < 0)
          return this;

        if (position === 0)
          list.shift();
        else {
          spliceOne(list, position);
        }

        if (list.length === 1)
          events[type] = list[0];

        if (events.removeListener !== undefined)
          this.emit('removeListener', type, originalListener || listener);
      }

      return this;
    };

EventEmitter.prototype.off = EventEmitter.prototype.removeListener;

EventEmitter.prototype.removeAllListeners =
    function removeAllListeners(type) {
      var listeners, events, i;

      events = this._events;
      if (events === undefined)
        return this;

      // not listening for removeListener, no need to emit
      if (events.removeListener === undefined) {
        if (arguments.length === 0) {
          this._events = Object.create(null);
          this._eventsCount = 0;
        } else if (events[type] !== undefined) {
          if (--this._eventsCount === 0)
            this._events = Object.create(null);
          else
            delete events[type];
        }
        return this;
      }

      // emit removeListener for all listeners on all events
      if (arguments.length === 0) {
        var keys = Object.keys(events);
        var key;
        for (i = 0; i < keys.length; ++i) {
          key = keys[i];
          if (key === 'removeListener') continue;
          this.removeAllListeners(key);
        }
        this.removeAllListeners('removeListener');
        this._events = Object.create(null);
        this._eventsCount = 0;
        return this;
      }

      listeners = events[type];

      if (typeof listeners === 'function') {
        this.removeListener(type, listeners);
      } else if (listeners !== undefined) {
        // LIFO order
        for (i = listeners.length - 1; i >= 0; i--) {
          this.removeListener(type, listeners[i]);
        }
      }

      return this;
    };

function _listeners(target, type, unwrap) {
  var events = target._events;

  if (events === undefined)
    return [];

  var evlistener = events[type];
  if (evlistener === undefined)
    return [];

  if (typeof evlistener === 'function')
    return unwrap ? [evlistener.listener || evlistener] : [evlistener];

  return unwrap ?
    unwrapListeners(evlistener) : arrayClone(evlistener, evlistener.length);
}

EventEmitter.prototype.listeners = function listeners(type) {
  return _listeners(this, type, true);
};

EventEmitter.prototype.rawListeners = function rawListeners(type) {
  return _listeners(this, type, false);
};

EventEmitter.listenerCount = function(emitter, type) {
  if (typeof emitter.listenerCount === 'function') {
    return emitter.listenerCount(type);
  } else {
    return listenerCount.call(emitter, type);
  }
};

EventEmitter.prototype.listenerCount = listenerCount;
function listenerCount(type) {
  var events = this._events;

  if (events !== undefined) {
    var evlistener = events[type];

    if (typeof evlistener === 'function') {
      return 1;
    } else if (evlistener !== undefined) {
      return evlistener.length;
    }
  }

  return 0;
}

EventEmitter.prototype.eventNames = function eventNames() {
  return this._eventsCount > 0 ? ReflectOwnKeys(this._events) : [];
};

function arrayClone(arr, n) {
  var copy = new Array(n);
  for (var i = 0; i < n; ++i)
    copy[i] = arr[i];
  return copy;
}

function spliceOne(list, index) {
  for (; index + 1 < list.length; index++)
    list[index] = list[index + 1];
  list.pop();
}

function unwrapListeners(arr) {
  var ret = new Array(arr.length);
  for (var i = 0; i < ret.length; ++i) {
    ret[i] = arr[i].listener || arr[i];
  }
  return ret;
}

function once(emitter, name) {
  return new Promise(function (resolve, reject) {
    function errorListener(err) {
      emitter.removeListener(name, resolver);
      reject(err);
    }

    function resolver() {
      if (typeof emitter.removeListener === 'function') {
        emitter.removeListener('error', errorListener);
      }
      resolve([].slice.call(arguments));
    };

    eventTargetAgnosticAddListener(emitter, name, resolver, { once: true });
    if (name !== 'error') {
      addErrorHandlerIfEventEmitter(emitter, errorListener, { once: true });
    }
  });
}

function addErrorHandlerIfEventEmitter(emitter, handler, flags) {
  if (typeof emitter.on === 'function') {
    eventTargetAgnosticAddListener(emitter, 'error', handler, flags);
  }
}

function eventTargetAgnosticAddListener(emitter, name, listener, flags) {
  if (typeof emitter.on === 'function') {
    if (flags.once) {
      emitter.once(name, listener);
    } else {
      emitter.on(name, listener);
    }
  } else if (typeof emitter.addEventListener === 'function') {
    // EventTarget does not have `error` event semantics like Node
    // EventEmitters, we do not listen for `error` events here.
    emitter.addEventListener(name, function wrapListener(arg) {
      // IE does not have builtin `{ once: true }` support so we
      // have to do it manually.
      if (flags.once) {
        emitter.removeEventListener(name, wrapListener);
      }
      listener(arg);
    });
  } else {
    throw new TypeError('The "emitter" argument must be of type EventEmitter. Received type ' + typeof emitter);
  }
}


/***/ }),

/***/ 85695:
/***/ (function(module) {

"use strict";


module.exports = function (data, opts) {
    if (!opts) opts = {};
    if (typeof opts === 'function') opts = { cmp: opts };
    var cycles = (typeof opts.cycles === 'boolean') ? opts.cycles : false;

    var cmp = opts.cmp && (function (f) {
        return function (node) {
            return function (a, b) {
                var aobj = { key: a, value: node[a] };
                var bobj = { key: b, value: node[b] };
                return f(aobj, bobj);
            };
        };
    })(opts.cmp);

    var seen = [];
    return (function stringify (node) {
        if (node && node.toJSON && typeof node.toJSON === 'function') {
            node = node.toJSON();
        }

        if (node === undefined) return;
        if (typeof node == 'number') return isFinite(node) ? '' + node : 'null';
        if (typeof node !== 'object') return JSON.stringify(node);

        var i, out;
        if (Array.isArray(node)) {
            out = '[';
            for (i = 0; i < node.length; i++) {
                if (i) out += ',';
                out += stringify(node[i]) || 'null';
            }
            return out + ']';
        }

        if (node === null) return 'null';

        if (seen.indexOf(node) !== -1) {
            if (cycles) return JSON.stringify('__cycle__');
            throw new TypeError('Converting circular structure to JSON');
        }

        var seenIndex = seen.push(node) - 1;
        var keys = Object.keys(node).sort(cmp && cmp(node));
        out = '';
        for (i = 0; i < keys.length; i++) {
            var key = keys[i];
            var value = stringify(node[key]);

            if (!value) continue;
            if (out) out += ',';
            out += JSON.stringify(key) + ':' + value;
        }
        seen.splice(seenIndex, 1);
        return '{' + out + '}';
    })(data);
};


/***/ }),

/***/ 46388:
/***/ (function(module) {


var hasOwn = Object.prototype.hasOwnProperty;
var toString = Object.prototype.toString;

module.exports = function forEach (obj, fn, ctx) {
    if (toString.call(fn) !== '[object Function]') {
        throw new TypeError('iterator must be a function');
    }
    var l = obj.length;
    if (l === +l) {
        for (var i = 0; i < l; i++) {
            fn.call(ctx, obj[i], i, obj);
        }
    } else {
        for (var k in obj) {
            if (hasOwn.call(obj, k)) {
                fn.call(ctx, obj[k], k, obj);
            }
        }
    }
};



/***/ }),

/***/ 37795:
/***/ (function(module) {

"use strict";


/* eslint no-invalid-this: 1 */

var ERROR_MESSAGE = 'Function.prototype.bind called on incompatible ';
var slice = Array.prototype.slice;
var toStr = Object.prototype.toString;
var funcType = '[object Function]';

module.exports = function bind(that) {
    var target = this;
    if (typeof target !== 'function' || toStr.call(target) !== funcType) {
        throw new TypeError(ERROR_MESSAGE + target);
    }
    var args = slice.call(arguments, 1);

    var bound;
    var binder = function () {
        if (this instanceof bound) {
            var result = target.apply(
                this,
                args.concat(slice.call(arguments))
            );
            if (Object(result) === result) {
                return result;
            }
            return this;
        } else {
            return target.apply(
                that,
                args.concat(slice.call(arguments))
            );
        }
    };

    var boundLength = Math.max(0, target.length - args.length);
    var boundArgs = [];
    for (var i = 0; i < boundLength; i++) {
        boundArgs.push('$' + i);
    }

    bound = Function('binder', 'return function (' + boundArgs.join(',') + '){ return binder.apply(this,arguments); }')(binder);

    if (target.prototype) {
        var Empty = function Empty() {};
        Empty.prototype = target.prototype;
        bound.prototype = new Empty();
        Empty.prototype = null;
    }

    return bound;
};


/***/ }),

/***/ 4090:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var implementation = __webpack_require__(37795);

module.exports = Function.prototype.bind || implementation;


/***/ }),

/***/ 88616:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var util = __webpack_require__(43335)
var isProperty = __webpack_require__(30892)

var INDENT_START = /[\{\[]/
var INDENT_END = /[\}\]]/

// from https://mathiasbynens.be/notes/reserved-keywords
var RESERVED = [
  'do',
  'if',
  'in',
  'for',
  'let',
  'new',
  'try',
  'var',
  'case',
  'else',
  'enum',
  'eval',
  'null',
  'this',
  'true',
  'void',
  'with',
  'await',
  'break',
  'catch',
  'class',
  'const',
  'false',
  'super',
  'throw',
  'while',
  'yield',
  'delete',
  'export',
  'import',
  'public',
  'return',
  'static',
  'switch',
  'typeof',
  'default',
  'extends',
  'finally',
  'package',
  'private',
  'continue',
  'debugger',
  'function',
  'arguments',
  'interface',
  'protected',
  'implements',
  'instanceof',
  'NaN',
  'undefined'
]

var RESERVED_MAP = {}

for (var i = 0; i < RESERVED.length; i++) {
  RESERVED_MAP[RESERVED[i]] = true
}

var isVariable = function (name) {
  return isProperty(name) && !RESERVED_MAP.hasOwnProperty(name)
}

var formats = {
  s: function(s) {
    return '' + s
  },
  d: function(d) {
    return '' + Number(d)
  },
  o: function(o) {
    return JSON.stringify(o)
  }
}

var genfun = function() {
  var lines = []
  var indent = 0
  var vars = {}

  var push = function(str) {
    var spaces = ''
    while (spaces.length < indent*2) spaces += '  '
    lines.push(spaces+str)
  }

  var pushLine = function(line) {
    if (INDENT_END.test(line.trim()[0]) && INDENT_START.test(line[line.length-1])) {
      indent--
      push(line)
      indent++
      return
    }
    if (INDENT_START.test(line[line.length-1])) {
      push(line)
      indent++
      return
    }
    if (INDENT_END.test(line.trim()[0])) {
      indent--
      push(line)
      return
    }

    push(line)
  }

  var line = function(fmt) {
    if (!fmt) return line

    if (arguments.length === 1 && fmt.indexOf('\n') > -1) {
      var lines = fmt.trim().split('\n')
      for (var i = 0; i < lines.length; i++) {
        pushLine(lines[i].trim())
      }
    } else {
      pushLine(util.format.apply(util, arguments))
    }

    return line
  }

  line.scope = {}
  line.formats = formats

  line.sym = function(name) {
    if (!name || !isVariable(name)) name = 'tmp'
    if (!vars[name]) vars[name] = 0
    return name + (vars[name]++ || '')
  }

  line.property = function(obj, name) {
    if (arguments.length === 1) {
      name = obj
      obj = ''
    }

    name = name + ''

    if (isProperty(name)) return (obj ? obj + '.' + name : name)
    return obj ? obj + '[' + JSON.stringify(name) + ']' : JSON.stringify(name)
  }

  line.toString = function() {
    return lines.join('\n')
  }

  line.toFunction = function(scope) {
    if (!scope) scope = {}

    var src = 'return ('+line.toString()+')'

    Object.keys(line.scope).forEach(function (key) {
      if (!scope[key]) scope[key] = line.scope[key]
    })

    var keys = Object.keys(scope).map(function(key) {
      return key
    })

    var vals = keys.map(function(key) {
      return scope[key]
    })

    return Function.apply(null, keys.concat(src)).apply(null, vals)
  }

  if (arguments.length) line.apply(null, arguments)

  return line
}

genfun.formats = formats
module.exports = genfun


/***/ }),

/***/ 6000:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var isProperty = __webpack_require__(30892)

var gen = function(obj, prop) {
  return isProperty(prop) ? obj+'.'+prop : obj+'['+JSON.stringify(prop)+']'
}

gen.valid = isProperty
gen.property = function (prop) {
 return isProperty(prop) ? prop : JSON.stringify(prop)
}

module.exports = gen


/***/ }),

/***/ 67286:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var undefined;

var $SyntaxError = SyntaxError;
var $Function = Function;
var $TypeError = TypeError;

// eslint-disable-next-line consistent-return
var getEvalledConstructor = function (expressionSyntax) {
	try {
		return $Function('"use strict"; return (' + expressionSyntax + ').constructor;')();
	} catch (e) {}
};

var $gOPD = Object.getOwnPropertyDescriptor;
if ($gOPD) {
	try {
		$gOPD({}, '');
	} catch (e) {
		$gOPD = null; // this is IE 8, which has a broken gOPD
	}
}

var throwTypeError = function () {
	throw new $TypeError();
};
var ThrowTypeError = $gOPD
	? (function () {
		try {
			// eslint-disable-next-line no-unused-expressions, no-caller, no-restricted-properties
			arguments.callee; // IE 8 does not throw here
			return throwTypeError;
		} catch (calleeThrows) {
			try {
				// IE 8 throws on Object.getOwnPropertyDescriptor(arguments, '')
				return $gOPD(arguments, 'callee').get;
			} catch (gOPDthrows) {
				return throwTypeError;
			}
		}
	}())
	: throwTypeError;

var hasSymbols = __webpack_require__(32636)();

var getProto = Object.getPrototypeOf || function (x) { return x.__proto__; }; // eslint-disable-line no-proto

var needsEval = {};

var TypedArray = typeof Uint8Array === 'undefined' ? undefined : getProto(Uint8Array);

var INTRINSICS = {
	'%AggregateError%': typeof AggregateError === 'undefined' ? undefined : AggregateError,
	'%Array%': Array,
	'%ArrayBuffer%': typeof ArrayBuffer === 'undefined' ? undefined : ArrayBuffer,
	'%ArrayIteratorPrototype%': hasSymbols ? getProto([][Symbol.iterator]()) : undefined,
	'%AsyncFromSyncIteratorPrototype%': undefined,
	'%AsyncFunction%': needsEval,
	'%AsyncGenerator%': needsEval,
	'%AsyncGeneratorFunction%': needsEval,
	'%AsyncIteratorPrototype%': needsEval,
	'%Atomics%': typeof Atomics === 'undefined' ? undefined : Atomics,
	'%BigInt%': typeof BigInt === 'undefined' ? undefined : BigInt,
	'%Boolean%': Boolean,
	'%DataView%': typeof DataView === 'undefined' ? undefined : DataView,
	'%Date%': Date,
	'%decodeURI%': decodeURI,
	'%decodeURIComponent%': decodeURIComponent,
	'%encodeURI%': encodeURI,
	'%encodeURIComponent%': encodeURIComponent,
	'%Error%': Error,
	'%eval%': eval, // eslint-disable-line no-eval
	'%EvalError%': EvalError,
	'%Float32Array%': typeof Float32Array === 'undefined' ? undefined : Float32Array,
	'%Float64Array%': typeof Float64Array === 'undefined' ? undefined : Float64Array,
	'%FinalizationRegistry%': typeof FinalizationRegistry === 'undefined' ? undefined : FinalizationRegistry,
	'%Function%': $Function,
	'%GeneratorFunction%': needsEval,
	'%Int8Array%': typeof Int8Array === 'undefined' ? undefined : Int8Array,
	'%Int16Array%': typeof Int16Array === 'undefined' ? undefined : Int16Array,
	'%Int32Array%': typeof Int32Array === 'undefined' ? undefined : Int32Array,
	'%isFinite%': isFinite,
	'%isNaN%': isNaN,
	'%IteratorPrototype%': hasSymbols ? getProto(getProto([][Symbol.iterator]())) : undefined,
	'%JSON%': typeof JSON === 'object' ? JSON : undefined,
	'%Map%': typeof Map === 'undefined' ? undefined : Map,
	'%MapIteratorPrototype%': typeof Map === 'undefined' || !hasSymbols ? undefined : getProto(new Map()[Symbol.iterator]()),
	'%Math%': Math,
	'%Number%': Number,
	'%Object%': Object,
	'%parseFloat%': parseFloat,
	'%parseInt%': parseInt,
	'%Promise%': typeof Promise === 'undefined' ? undefined : Promise,
	'%Proxy%': typeof Proxy === 'undefined' ? undefined : Proxy,
	'%RangeError%': RangeError,
	'%ReferenceError%': ReferenceError,
	'%Reflect%': typeof Reflect === 'undefined' ? undefined : Reflect,
	'%RegExp%': RegExp,
	'%Set%': typeof Set === 'undefined' ? undefined : Set,
	'%SetIteratorPrototype%': typeof Set === 'undefined' || !hasSymbols ? undefined : getProto(new Set()[Symbol.iterator]()),
	'%SharedArrayBuffer%': typeof SharedArrayBuffer === 'undefined' ? undefined : SharedArrayBuffer,
	'%String%': String,
	'%StringIteratorPrototype%': hasSymbols ? getProto(''[Symbol.iterator]()) : undefined,
	'%Symbol%': hasSymbols ? Symbol : undefined,
	'%SyntaxError%': $SyntaxError,
	'%ThrowTypeError%': ThrowTypeError,
	'%TypedArray%': TypedArray,
	'%TypeError%': $TypeError,
	'%Uint8Array%': typeof Uint8Array === 'undefined' ? undefined : Uint8Array,
	'%Uint8ClampedArray%': typeof Uint8ClampedArray === 'undefined' ? undefined : Uint8ClampedArray,
	'%Uint16Array%': typeof Uint16Array === 'undefined' ? undefined : Uint16Array,
	'%Uint32Array%': typeof Uint32Array === 'undefined' ? undefined : Uint32Array,
	'%URIError%': URIError,
	'%WeakMap%': typeof WeakMap === 'undefined' ? undefined : WeakMap,
	'%WeakRef%': typeof WeakRef === 'undefined' ? undefined : WeakRef,
	'%WeakSet%': typeof WeakSet === 'undefined' ? undefined : WeakSet
};

var doEval = function doEval(name) {
	var value;
	if (name === '%AsyncFunction%') {
		value = getEvalledConstructor('async function () {}');
	} else if (name === '%GeneratorFunction%') {
		value = getEvalledConstructor('function* () {}');
	} else if (name === '%AsyncGeneratorFunction%') {
		value = getEvalledConstructor('async function* () {}');
	} else if (name === '%AsyncGenerator%') {
		var fn = doEval('%AsyncGeneratorFunction%');
		if (fn) {
			value = fn.prototype;
		}
	} else if (name === '%AsyncIteratorPrototype%') {
		var gen = doEval('%AsyncGenerator%');
		if (gen) {
			value = getProto(gen.prototype);
		}
	}

	INTRINSICS[name] = value;

	return value;
};

var LEGACY_ALIASES = {
	'%ArrayBufferPrototype%': ['ArrayBuffer', 'prototype'],
	'%ArrayPrototype%': ['Array', 'prototype'],
	'%ArrayProto_entries%': ['Array', 'prototype', 'entries'],
	'%ArrayProto_forEach%': ['Array', 'prototype', 'forEach'],
	'%ArrayProto_keys%': ['Array', 'prototype', 'keys'],
	'%ArrayProto_values%': ['Array', 'prototype', 'values'],
	'%AsyncFunctionPrototype%': ['AsyncFunction', 'prototype'],
	'%AsyncGenerator%': ['AsyncGeneratorFunction', 'prototype'],
	'%AsyncGeneratorPrototype%': ['AsyncGeneratorFunction', 'prototype', 'prototype'],
	'%BooleanPrototype%': ['Boolean', 'prototype'],
	'%DataViewPrototype%': ['DataView', 'prototype'],
	'%DatePrototype%': ['Date', 'prototype'],
	'%ErrorPrototype%': ['Error', 'prototype'],
	'%EvalErrorPrototype%': ['EvalError', 'prototype'],
	'%Float32ArrayPrototype%': ['Float32Array', 'prototype'],
	'%Float64ArrayPrototype%': ['Float64Array', 'prototype'],
	'%FunctionPrototype%': ['Function', 'prototype'],
	'%Generator%': ['GeneratorFunction', 'prototype'],
	'%GeneratorPrototype%': ['GeneratorFunction', 'prototype', 'prototype'],
	'%Int8ArrayPrototype%': ['Int8Array', 'prototype'],
	'%Int16ArrayPrototype%': ['Int16Array', 'prototype'],
	'%Int32ArrayPrototype%': ['Int32Array', 'prototype'],
	'%JSONParse%': ['JSON', 'parse'],
	'%JSONStringify%': ['JSON', 'stringify'],
	'%MapPrototype%': ['Map', 'prototype'],
	'%NumberPrototype%': ['Number', 'prototype'],
	'%ObjectPrototype%': ['Object', 'prototype'],
	'%ObjProto_toString%': ['Object', 'prototype', 'toString'],
	'%ObjProto_valueOf%': ['Object', 'prototype', 'valueOf'],
	'%PromisePrototype%': ['Promise', 'prototype'],
	'%PromiseProto_then%': ['Promise', 'prototype', 'then'],
	'%Promise_all%': ['Promise', 'all'],
	'%Promise_reject%': ['Promise', 'reject'],
	'%Promise_resolve%': ['Promise', 'resolve'],
	'%RangeErrorPrototype%': ['RangeError', 'prototype'],
	'%ReferenceErrorPrototype%': ['ReferenceError', 'prototype'],
	'%RegExpPrototype%': ['RegExp', 'prototype'],
	'%SetPrototype%': ['Set', 'prototype'],
	'%SharedArrayBufferPrototype%': ['SharedArrayBuffer', 'prototype'],
	'%StringPrototype%': ['String', 'prototype'],
	'%SymbolPrototype%': ['Symbol', 'prototype'],
	'%SyntaxErrorPrototype%': ['SyntaxError', 'prototype'],
	'%TypedArrayPrototype%': ['TypedArray', 'prototype'],
	'%TypeErrorPrototype%': ['TypeError', 'prototype'],
	'%Uint8ArrayPrototype%': ['Uint8Array', 'prototype'],
	'%Uint8ClampedArrayPrototype%': ['Uint8ClampedArray', 'prototype'],
	'%Uint16ArrayPrototype%': ['Uint16Array', 'prototype'],
	'%Uint32ArrayPrototype%': ['Uint32Array', 'prototype'],
	'%URIErrorPrototype%': ['URIError', 'prototype'],
	'%WeakMapPrototype%': ['WeakMap', 'prototype'],
	'%WeakSetPrototype%': ['WeakSet', 'prototype']
};

var bind = __webpack_require__(4090);
var hasOwn = __webpack_require__(23198);
var $concat = bind.call(Function.call, Array.prototype.concat);
var $spliceApply = bind.call(Function.apply, Array.prototype.splice);
var $replace = bind.call(Function.call, String.prototype.replace);
var $strSlice = bind.call(Function.call, String.prototype.slice);

/* adapted from https://github.com/lodash/lodash/blob/4.17.15/dist/lodash.js#L6735-L6744 */
var rePropName = /[^%.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]|(?=(?:\.|\[\])(?:\.|\[\]|%$))/g;
var reEscapeChar = /\\(\\)?/g; /** Used to match backslashes in property paths. */
var stringToPath = function stringToPath(string) {
	var first = $strSlice(string, 0, 1);
	var last = $strSlice(string, -1);
	if (first === '%' && last !== '%') {
		throw new $SyntaxError('invalid intrinsic syntax, expected closing `%`');
	} else if (last === '%' && first !== '%') {
		throw new $SyntaxError('invalid intrinsic syntax, expected opening `%`');
	}
	var result = [];
	$replace(string, rePropName, function (match, number, quote, subString) {
		result[result.length] = quote ? $replace(subString, reEscapeChar, '$1') : number || match;
	});
	return result;
};
/* end adaptation */

var getBaseIntrinsic = function getBaseIntrinsic(name, allowMissing) {
	var intrinsicName = name;
	var alias;
	if (hasOwn(LEGACY_ALIASES, intrinsicName)) {
		alias = LEGACY_ALIASES[intrinsicName];
		intrinsicName = '%' + alias[0] + '%';
	}

	if (hasOwn(INTRINSICS, intrinsicName)) {
		var value = INTRINSICS[intrinsicName];
		if (value === needsEval) {
			value = doEval(intrinsicName);
		}
		if (typeof value === 'undefined' && !allowMissing) {
			throw new $TypeError('intrinsic ' + name + ' exists, but is not available. Please file an issue!');
		}

		return {
			alias: alias,
			name: intrinsicName,
			value: value
		};
	}

	throw new $SyntaxError('intrinsic ' + name + ' does not exist!');
};

module.exports = function GetIntrinsic(name, allowMissing) {
	if (typeof name !== 'string' || name.length === 0) {
		throw new $TypeError('intrinsic name must be a non-empty string');
	}
	if (arguments.length > 1 && typeof allowMissing !== 'boolean') {
		throw new $TypeError('"allowMissing" argument must be a boolean');
	}

	var parts = stringToPath(name);
	var intrinsicBaseName = parts.length > 0 ? parts[0] : '';

	var intrinsic = getBaseIntrinsic('%' + intrinsicBaseName + '%', allowMissing);
	var intrinsicRealName = intrinsic.name;
	var value = intrinsic.value;
	var skipFurtherCaching = false;

	var alias = intrinsic.alias;
	if (alias) {
		intrinsicBaseName = alias[0];
		$spliceApply(parts, $concat([0, 1], alias));
	}

	for (var i = 1, isOwn = true; i < parts.length; i += 1) {
		var part = parts[i];
		var first = $strSlice(part, 0, 1);
		var last = $strSlice(part, -1);
		if (
			(
				(first === '"' || first === "'" || first === '`')
				|| (last === '"' || last === "'" || last === '`')
			)
			&& first !== last
		) {
			throw new $SyntaxError('property names with quotes must have matching quotes');
		}
		if (part === 'constructor' || !isOwn) {
			skipFurtherCaching = true;
		}

		intrinsicBaseName += '.' + part;
		intrinsicRealName = '%' + intrinsicBaseName + '%';

		if (hasOwn(INTRINSICS, intrinsicRealName)) {
			value = INTRINSICS[intrinsicRealName];
		} else if (value != null) {
			if (!(part in value)) {
				if (!allowMissing) {
					throw new $TypeError('base intrinsic for ' + name + ' exists, but the property is not available.');
				}
				return void undefined;
			}
			if ($gOPD && (i + 1) >= parts.length) {
				var desc = $gOPD(value, part);
				isOwn = !!desc;

				// By convention, when a data property is converted to an accessor
				// property to emulate a data property that does not suffer from
				// the override mistake, that accessor's getter is marked with
				// an `originalValue` property. Here, when we detect this, we
				// uphold the illusion by pretending to see that original data
				// property, i.e., returning the value rather than the getter
				// itself.
				if (isOwn && 'get' in desc && !('originalValue' in desc.get)) {
					value = desc.get;
				} else {
					value = value[part];
				}
			} else {
				isOwn = hasOwn(value, part);
				value = value[part];
			}

			if (isOwn && !skipFurtherCaching) {
				INTRINSICS[intrinsicRealName] = value;
			}
		}
	}
	return value;
};


/***/ }),

/***/ 88111:
/***/ (function(module) {

"use strict";

module.exports = function (input) {
	if (typeof input !== 'string') {
		throw new TypeError('get-src expected a string');
	}
	var re = /src="(.*?)"/gm;
	var url = re.exec(input);

	if (url && url.length >= 2) {
		return url[1];
	}
};


/***/ }),

/***/ 17451:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";

var getSrc = __webpack_require__(88111);

module.exports = function (str) {
	if (typeof str !== 'string') {
		throw new TypeError('get-video-id expects a string');
	}

	if (/<iframe/gi.test(str)) {
		str = getSrc(str);
	}

	// remove surrounding whitespaces or linefeeds
	str = str.trim();

	// remove the '-nocookie' flag from youtube urls
	str = str.replace('-nocookie', '');

	// remove any leading `www.`
	str = str.replace('/www.', '/');

	var metadata = {};

	// Try to handle google redirection uri
	if (/\/\/google/.test(str)) {
		// Find the redirection uri
		var matches = str.match(/url=([^&]+)&/);

		// Decode the found uri and replace current url string - continue with final link
		if (matches) {
			// Javascript can get encoded URI
			str = decodeURIComponent(matches[1]);
		}
	}

	if (/youtube|youtu\.be|y2u\.be|i.ytimg\./.test(str)) {
		metadata = {
			id: youtube(str),
			service: 'youtube'
		};
	} else if (/vimeo/.test(str)) {
		metadata = {
			id: vimeo(str),
			service: 'vimeo'
		};
	} else if (/vine/.test(str)) {
		metadata = {
			id: vine(str),
			service: 'vine'
		};
	} else if (/videopress/.test(str)) {
		metadata = {
			id: videopress(str),
			service: 'videopress'
		};
	}
	return metadata;
};

/**
 * Get the vimeo id.
 * @param {string} str - the url from which you want to extract the id
 * @returns {string|undefined}
 */
function vimeo(str) {
	if (str.indexOf('#') > -1) {
		str = str.split('#')[0];
	}
	if (str.indexOf('?') > -1 && str.indexOf('clip_id=') === -1) {
		str = str.split('?')[0];
	}

	var id;
	var arr;

	var vimeoPipe = [
		'https?:\/\/vimeo\.com\/[0-9]+$',
		'https?:\/\/player\.vimeo\.com\/video\/[0-9]+$',
		'https?:\/\/vimeo\.com\/channels',
		'groups',
		'album'
	].join('|');

	var vimeoRegex = new RegExp(vimeoPipe, 'gim');

	if (vimeoRegex.test(str)) {
		arr = str.split('/');
		if (arr && arr.length) {
			id = arr.pop();
		}
	} else if (/clip_id=/gim.test(str)) {
		arr = str.split('clip_id=');
		if (arr && arr.length) {
			id = arr[1].split('&')[0];
		}
	}

	return id;
}

/**
 * Get the vine id.
 * @param {string} str - the url from which you want to extract the id
 * @returns {string|undefined}
 */
function vine(str) {
	var regex = /https:\/\/vine\.co\/v\/([a-zA-Z0-9]*)\/?/;
	var matches = regex.exec(str);
	return matches && matches[1];
}

/**
 * Get the Youtube Video id.
 * @param {string} str - the url from which you want to extract the id
 * @returns {string|undefined}
 */
function youtube(str) {
	// shortcode
	var shortcode = /youtube:\/\/|https?:\/\/youtu\.be\/|http:\/\/y2u\.be\//g;

	if (shortcode.test(str)) {
		var shortcodeid = str.split(shortcode)[1];
		return stripParameters(shortcodeid);
	}

	// /v/ or /vi/
	var inlinev = /\/v\/|\/vi\//g;

	if (inlinev.test(str)) {
		var inlineid = str.split(inlinev)[1];
		return stripParameters(inlineid);
	}

	// v= or vi=
	var parameterv = /v=|vi=/g;

	if (parameterv.test(str)) {
		var arr = str.split(parameterv);
		return arr[1].split('&')[0];
	}

	// v= or vi=
	var parameterwebp = /\/an_webp\//g;

	if (parameterwebp.test(str)) {
		var webp = str.split(parameterwebp)[1];
		return stripParameters(webp);
	}

	// embed
	var embedreg = /\/embed\//g;

	if (embedreg.test(str)) {
		var embedid = str.split(embedreg)[1];
		return stripParameters(embedid);
	}

	// ignore /user/username pattern
	var usernamereg = /\/user\/([a-zA-Z0-9]*)$/g;

	if (usernamereg.test(str)) {
		return undefined;
	}

	// user
	var userreg = /\/user\/(?!.*videos)/g;

	if (userreg.test(str)) {
		var elements = str.split('/');
		return stripParameters(elements.pop());
	}

	// attribution_link
	var attrreg = /\/attribution_link\?.*v%3D([^%&]*)(%26|&|$)/;

	if (attrreg.test(str)) {
		return str.match(attrreg)[1];
	}
}

/**
 * Get the VideoPress id.
 * @param {string} str - the url from which you want to extract the id
 * @returns {string|undefined}
 */
function videopress(str) {
	var idRegex;
	if (str.indexOf('embed') > -1) {
		idRegex = /embed\/(\w{8})/;
		return str.match(idRegex)[1];
	}

	idRegex = /\/v\/(\w{8})/;

	var match = str.match(idRegex);

	if (match && match.length > 0) {
		return str.match(idRegex)[1];
	}
	return undefined;
}

/**
 * Strip away any parameters following `?` or `/`
 * @param str
 * @returns {*}
 */
function stripParameters(str) {
	// Split parameters or split folder separator
	if (str.indexOf('?') > -1) {
		return str.split('?')[0];
	} else if (str.indexOf('/') > -1) {
		return str.split('/')[0];
	}
	return str;
}


/***/ }),

/***/ 54632:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/* global Blob File */

/*
 * Module requirements.
 */

var isArray = __webpack_require__(28992);

var toString = Object.prototype.toString;
var withNativeBlob = typeof Blob === 'function' ||
                        typeof Blob !== 'undefined' && toString.call(Blob) === '[object BlobConstructor]';
var withNativeFile = typeof File === 'function' ||
                        typeof File !== 'undefined' && toString.call(File) === '[object FileConstructor]';

/**
 * Module exports.
 */

module.exports = hasBinary;

/**
 * Checks for binary data.
 *
 * Supports Buffer, ArrayBuffer, Blob and File.
 *
 * @param {Object} anything
 * @api public
 */

function hasBinary (obj) {
  if (!obj || typeof obj !== 'object') {
    return false;
  }

  if (isArray(obj)) {
    for (var i = 0, l = obj.length; i < l; i++) {
      if (hasBinary(obj[i])) {
        return true;
      }
    }
    return false;
  }

  if ((typeof Buffer === 'function' && Buffer.isBuffer && Buffer.isBuffer(obj)) ||
    (typeof ArrayBuffer === 'function' && obj instanceof ArrayBuffer) ||
    (withNativeBlob && obj instanceof Blob) ||
    (withNativeFile && obj instanceof File)
  ) {
    return true;
  }

  // see: https://github.com/Automattic/has-binary/pull/4
  if (obj.toJSON && typeof obj.toJSON === 'function' && arguments.length === 1) {
    return hasBinary(obj.toJSON(), true);
  }

  for (var key in obj) {
    if (Object.prototype.hasOwnProperty.call(obj, key) && hasBinary(obj[key])) {
      return true;
    }
  }

  return false;
}


/***/ }),

/***/ 28992:
/***/ (function(module) {

var toString = {}.toString;

module.exports = Array.isArray || function (arr) {
  return toString.call(arr) == '[object Array]';
};


/***/ }),

/***/ 95460:
/***/ (function(module) {


/**
 * Module exports.
 *
 * Logic borrowed from Modernizr:
 *
 *   - https://github.com/Modernizr/Modernizr/blob/master/feature-detects/cors.js
 */

try {
  module.exports = typeof XMLHttpRequest !== 'undefined' &&
    'withCredentials' in new XMLHttpRequest();
} catch (err) {
  // if XMLHttp support is disabled in IE then it will throw
  // when trying to create
  module.exports = false;
}


/***/ }),

/***/ 32636:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var origSymbol = typeof Symbol !== 'undefined' && Symbol;
var hasSymbolSham = __webpack_require__(66679);

module.exports = function hasNativeSymbols() {
	if (typeof origSymbol !== 'function') { return false; }
	if (typeof Symbol !== 'function') { return false; }
	if (typeof origSymbol('foo') !== 'symbol') { return false; }
	if (typeof Symbol('bar') !== 'symbol') { return false; }

	return hasSymbolSham();
};


/***/ }),

/***/ 66679:
/***/ (function(module) {

"use strict";


/* eslint complexity: [2, 18], max-statements: [2, 33] */
module.exports = function hasSymbols() {
	if (typeof Symbol !== 'function' || typeof Object.getOwnPropertySymbols !== 'function') { return false; }
	if (typeof Symbol.iterator === 'symbol') { return true; }

	var obj = {};
	var sym = Symbol('test');
	var symObj = Object(sym);
	if (typeof sym === 'string') { return false; }

	if (Object.prototype.toString.call(sym) !== '[object Symbol]') { return false; }
	if (Object.prototype.toString.call(symObj) !== '[object Symbol]') { return false; }

	// temp disabled per https://github.com/ljharb/object.assign/issues/17
	// if (sym instanceof Symbol) { return false; }
	// temp disabled per https://github.com/WebReflection/get-own-property-symbols/issues/4
	// if (!(symObj instanceof Symbol)) { return false; }

	// if (typeof Symbol.prototype.toString !== 'function') { return false; }
	// if (String(sym) !== Symbol.prototype.toString.call(sym)) { return false; }

	var symVal = 42;
	obj[sym] = symVal;
	for (sym in obj) { return false; } // eslint-disable-line no-restricted-syntax, no-unreachable-loop
	if (typeof Object.keys === 'function' && Object.keys(obj).length !== 0) { return false; }

	if (typeof Object.getOwnPropertyNames === 'function' && Object.getOwnPropertyNames(obj).length !== 0) { return false; }

	var syms = Object.getOwnPropertySymbols(obj);
	if (syms.length !== 1 || syms[0] !== sym) { return false; }

	if (!Object.prototype.propertyIsEnumerable.call(obj, sym)) { return false; }

	if (typeof Object.getOwnPropertyDescriptor === 'function') {
		var descriptor = Object.getOwnPropertyDescriptor(obj, sym);
		if (descriptor.value !== symVal || descriptor.enumerable !== true) { return false; }
	}

	return true;
};


/***/ }),

/***/ 23198:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var bind = __webpack_require__(4090);

module.exports = bind.call(Function.call, Object.prototype.hasOwnProperty);


/***/ }),

/***/ 74495:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

"use strict";


var utils = __webpack_require__(50212);
var assert = __webpack_require__(79561);

function BlockHash() {
  this.pending = null;
  this.pendingTotal = 0;
  this.blockSize = this.constructor.blockSize;
  this.outSize = this.constructor.outSize;
  this.hmacStrength = this.constructor.hmacStrength;
  this.padLength = this.constructor.padLength / 8;
  this.endian = 'big';

  this._delta8 = this.blockSize / 8;
  this._delta32 = this.blockSize / 32;
}
exports.BlockHash = BlockHash;

BlockHash.prototype.update = function update(msg, enc) {
  // Convert message to array, pad it, and join into 32bit blocks
  msg = utils.toArray(msg, enc);
  if (!this.pending)
    this.pending = msg;
  else
    this.pending = this.pending.concat(msg);
  this.pendingTotal += msg.length;

  // Enough data, try updating
  if (this.pending.length >= this._delta8) {
    msg = this.pending;

    // Process pending data in blocks
    var r = msg.length % this._delta8;
    this.pending = msg.slice(msg.length - r, msg.length);
    if (this.pending.length === 0)
      this.pending = null;

    msg = utils.join32(msg, 0, msg.length - r, this.endian);
    for (var i = 0; i < msg.length; i += this._delta32)
      this._update(msg, i, i + this._delta32);
  }

  return this;
};

BlockHash.prototype.digest = function digest(enc) {
  this.update(this._pad());
  assert(this.pending === null);

  return this._digest(enc);
};

BlockHash.prototype._pad = function pad() {
  var len = this.pendingTotal;
  var bytes = this._delta8;
  var k = bytes - ((len + this.padLength) % bytes);
  var res = new Array(k + this.padLength);
  res[0] = 0x80;
  for (var i = 1; i < k; i++)
    res[i] = 0;

  // Append length
  len <<= 3;
  if (this.endian === 'big') {
    for (var t = 8; t < this.padLength; t++)
      res[i++] = 0;

    res[i++] = 0;
    res[i++] = 0;
    res[i++] = 0;
    res[i++] = 0;
    res[i++] = (len >>> 24) & 0xff;
    res[i++] = (len >>> 16) & 0xff;
    res[i++] = (len >>> 8) & 0xff;
    res[i++] = len & 0xff;
  } else {
    res[i++] = len & 0xff;
    res[i++] = (len >>> 8) & 0xff;
    res[i++] = (len >>> 16) & 0xff;
    res[i++] = (len >>> 24) & 0xff;
    res[i++] = 0;
    res[i++] = 0;
    res[i++] = 0;
    res[i++] = 0;

    for (t = 8; t < this.padLength; t++)
      res[i++] = 0;
  }

  return res;
};


/***/ }),

/***/ 35079:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var utils = __webpack_require__(50212);
var common = __webpack_require__(74495);
var shaCommon = __webpack_require__(40713);

var rotl32 = utils.rotl32;
var sum32 = utils.sum32;
var sum32_5 = utils.sum32_5;
var ft_1 = shaCommon.ft_1;
var BlockHash = common.BlockHash;

var sha1_K = [
  0x5A827999, 0x6ED9EBA1,
  0x8F1BBCDC, 0xCA62C1D6
];

function SHA1() {
  if (!(this instanceof SHA1))
    return new SHA1();

  BlockHash.call(this);
  this.h = [
    0x67452301, 0xefcdab89, 0x98badcfe,
    0x10325476, 0xc3d2e1f0 ];
  this.W = new Array(80);
}

utils.inherits(SHA1, BlockHash);
module.exports = SHA1;

SHA1.blockSize = 512;
SHA1.outSize = 160;
SHA1.hmacStrength = 80;
SHA1.padLength = 64;

SHA1.prototype._update = function _update(msg, start) {
  var W = this.W;

  for (var i = 0; i < 16; i++)
    W[i] = msg[start + i];

  for(; i < W.length; i++)
    W[i] = rotl32(W[i - 3] ^ W[i - 8] ^ W[i - 14] ^ W[i - 16], 1);

  var a = this.h[0];
  var b = this.h[1];
  var c = this.h[2];
  var d = this.h[3];
  var e = this.h[4];

  for (i = 0; i < W.length; i++) {
    var s = ~~(i / 20);
    var t = sum32_5(rotl32(a, 5), ft_1(s, b, c, d), e, W[i], sha1_K[s]);
    e = d;
    d = c;
    c = rotl32(b, 30);
    b = a;
    a = t;
  }

  this.h[0] = sum32(this.h[0], a);
  this.h[1] = sum32(this.h[1], b);
  this.h[2] = sum32(this.h[2], c);
  this.h[3] = sum32(this.h[3], d);
  this.h[4] = sum32(this.h[4], e);
};

SHA1.prototype._digest = function digest(enc) {
  if (enc === 'hex')
    return utils.toHex32(this.h, 'big');
  else
    return utils.split32(this.h, 'big');
};


/***/ }),

/***/ 68032:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var utils = __webpack_require__(50212);
var common = __webpack_require__(74495);
var shaCommon = __webpack_require__(40713);
var assert = __webpack_require__(79561);

var sum32 = utils.sum32;
var sum32_4 = utils.sum32_4;
var sum32_5 = utils.sum32_5;
var ch32 = shaCommon.ch32;
var maj32 = shaCommon.maj32;
var s0_256 = shaCommon.s0_256;
var s1_256 = shaCommon.s1_256;
var g0_256 = shaCommon.g0_256;
var g1_256 = shaCommon.g1_256;

var BlockHash = common.BlockHash;

var sha256_K = [
  0x428a2f98, 0x71374491, 0xb5c0fbcf, 0xe9b5dba5,
  0x3956c25b, 0x59f111f1, 0x923f82a4, 0xab1c5ed5,
  0xd807aa98, 0x12835b01, 0x243185be, 0x550c7dc3,
  0x72be5d74, 0x80deb1fe, 0x9bdc06a7, 0xc19bf174,
  0xe49b69c1, 0xefbe4786, 0x0fc19dc6, 0x240ca1cc,
  0x2de92c6f, 0x4a7484aa, 0x5cb0a9dc, 0x76f988da,
  0x983e5152, 0xa831c66d, 0xb00327c8, 0xbf597fc7,
  0xc6e00bf3, 0xd5a79147, 0x06ca6351, 0x14292967,
  0x27b70a85, 0x2e1b2138, 0x4d2c6dfc, 0x53380d13,
  0x650a7354, 0x766a0abb, 0x81c2c92e, 0x92722c85,
  0xa2bfe8a1, 0xa81a664b, 0xc24b8b70, 0xc76c51a3,
  0xd192e819, 0xd6990624, 0xf40e3585, 0x106aa070,
  0x19a4c116, 0x1e376c08, 0x2748774c, 0x34b0bcb5,
  0x391c0cb3, 0x4ed8aa4a, 0x5b9cca4f, 0x682e6ff3,
  0x748f82ee, 0x78a5636f, 0x84c87814, 0x8cc70208,
  0x90befffa, 0xa4506ceb, 0xbef9a3f7, 0xc67178f2
];

function SHA256() {
  if (!(this instanceof SHA256))
    return new SHA256();

  BlockHash.call(this);
  this.h = [
    0x6a09e667, 0xbb67ae85, 0x3c6ef372, 0xa54ff53a,
    0x510e527f, 0x9b05688c, 0x1f83d9ab, 0x5be0cd19
  ];
  this.k = sha256_K;
  this.W = new Array(64);
}
utils.inherits(SHA256, BlockHash);
module.exports = SHA256;

SHA256.blockSize = 512;
SHA256.outSize = 256;
SHA256.hmacStrength = 192;
SHA256.padLength = 64;

SHA256.prototype._update = function _update(msg, start) {
  var W = this.W;

  for (var i = 0; i < 16; i++)
    W[i] = msg[start + i];
  for (; i < W.length; i++)
    W[i] = sum32_4(g1_256(W[i - 2]), W[i - 7], g0_256(W[i - 15]), W[i - 16]);

  var a = this.h[0];
  var b = this.h[1];
  var c = this.h[2];
  var d = this.h[3];
  var e = this.h[4];
  var f = this.h[5];
  var g = this.h[6];
  var h = this.h[7];

  assert(this.k.length === W.length);
  for (i = 0; i < W.length; i++) {
    var T1 = sum32_5(h, s1_256(e), ch32(e, f, g), this.k[i], W[i]);
    var T2 = sum32(s0_256(a), maj32(a, b, c));
    h = g;
    g = f;
    f = e;
    e = sum32(d, T1);
    d = c;
    c = b;
    b = a;
    a = sum32(T1, T2);
  }

  this.h[0] = sum32(this.h[0], a);
  this.h[1] = sum32(this.h[1], b);
  this.h[2] = sum32(this.h[2], c);
  this.h[3] = sum32(this.h[3], d);
  this.h[4] = sum32(this.h[4], e);
  this.h[5] = sum32(this.h[5], f);
  this.h[6] = sum32(this.h[6], g);
  this.h[7] = sum32(this.h[7], h);
};

SHA256.prototype._digest = function digest(enc) {
  if (enc === 'hex')
    return utils.toHex32(this.h, 'big');
  else
    return utils.split32(this.h, 'big');
};


/***/ }),

/***/ 40713:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

"use strict";


var utils = __webpack_require__(50212);
var rotr32 = utils.rotr32;

function ft_1(s, x, y, z) {
  if (s === 0)
    return ch32(x, y, z);
  if (s === 1 || s === 3)
    return p32(x, y, z);
  if (s === 2)
    return maj32(x, y, z);
}
exports.ft_1 = ft_1;

function ch32(x, y, z) {
  return (x & y) ^ ((~x) & z);
}
exports.ch32 = ch32;

function maj32(x, y, z) {
  return (x & y) ^ (x & z) ^ (y & z);
}
exports.maj32 = maj32;

function p32(x, y, z) {
  return x ^ y ^ z;
}
exports.p32 = p32;

function s0_256(x) {
  return rotr32(x, 2) ^ rotr32(x, 13) ^ rotr32(x, 22);
}
exports.s0_256 = s0_256;

function s1_256(x) {
  return rotr32(x, 6) ^ rotr32(x, 11) ^ rotr32(x, 25);
}
exports.s1_256 = s1_256;

function g0_256(x) {
  return rotr32(x, 7) ^ rotr32(x, 18) ^ (x >>> 3);
}
exports.g0_256 = g0_256;

function g1_256(x) {
  return rotr32(x, 17) ^ rotr32(x, 19) ^ (x >>> 10);
}
exports.g1_256 = g1_256;


/***/ }),

/***/ 50212:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

"use strict";


var assert = __webpack_require__(79561);
var inherits = __webpack_require__(91285);

exports.inherits = inherits;

function isSurrogatePair(msg, i) {
  if ((msg.charCodeAt(i) & 0xFC00) !== 0xD800) {
    return false;
  }
  if (i < 0 || i + 1 >= msg.length) {
    return false;
  }
  return (msg.charCodeAt(i + 1) & 0xFC00) === 0xDC00;
}

function toArray(msg, enc) {
  if (Array.isArray(msg))
    return msg.slice();
  if (!msg)
    return [];
  var res = [];
  if (typeof msg === 'string') {
    if (!enc) {
      // Inspired by stringToUtf8ByteArray() in closure-library by Google
      // https://github.com/google/closure-library/blob/8598d87242af59aac233270742c8984e2b2bdbe0/closure/goog/crypt/crypt.js#L117-L143
      // Apache License 2.0
      // https://github.com/google/closure-library/blob/master/LICENSE
      var p = 0;
      for (var i = 0; i < msg.length; i++) {
        var c = msg.charCodeAt(i);
        if (c < 128) {
          res[p++] = c;
        } else if (c < 2048) {
          res[p++] = (c >> 6) | 192;
          res[p++] = (c & 63) | 128;
        } else if (isSurrogatePair(msg, i)) {
          c = 0x10000 + ((c & 0x03FF) << 10) + (msg.charCodeAt(++i) & 0x03FF);
          res[p++] = (c >> 18) | 240;
          res[p++] = ((c >> 12) & 63) | 128;
          res[p++] = ((c >> 6) & 63) | 128;
          res[p++] = (c & 63) | 128;
        } else {
          res[p++] = (c >> 12) | 224;
          res[p++] = ((c >> 6) & 63) | 128;
          res[p++] = (c & 63) | 128;
        }
      }
    } else if (enc === 'hex') {
      msg = msg.replace(/[^a-z0-9]+/ig, '');
      if (msg.length % 2 !== 0)
        msg = '0' + msg;
      for (i = 0; i < msg.length; i += 2)
        res.push(parseInt(msg[i] + msg[i + 1], 16));
    }
  } else {
    for (i = 0; i < msg.length; i++)
      res[i] = msg[i] | 0;
  }
  return res;
}
exports.toArray = toArray;

function toHex(msg) {
  var res = '';
  for (var i = 0; i < msg.length; i++)
    res += zero2(msg[i].toString(16));
  return res;
}
exports.toHex = toHex;

function htonl(w) {
  var res = (w >>> 24) |
            ((w >>> 8) & 0xff00) |
            ((w << 8) & 0xff0000) |
            ((w & 0xff) << 24);
  return res >>> 0;
}
exports.htonl = htonl;

function toHex32(msg, endian) {
  var res = '';
  for (var i = 0; i < msg.length; i++) {
    var w = msg[i];
    if (endian === 'little')
      w = htonl(w);
    res += zero8(w.toString(16));
  }
  return res;
}
exports.toHex32 = toHex32;

function zero2(word) {
  if (word.length === 1)
    return '0' + word;
  else
    return word;
}
exports.zero2 = zero2;

function zero8(word) {
  if (word.length === 7)
    return '0' + word;
  else if (word.length === 6)
    return '00' + word;
  else if (word.length === 5)
    return '000' + word;
  else if (word.length === 4)
    return '0000' + word;
  else if (word.length === 3)
    return '00000' + word;
  else if (word.length === 2)
    return '000000' + word;
  else if (word.length === 1)
    return '0000000' + word;
  else
    return word;
}
exports.zero8 = zero8;

function join32(msg, start, end, endian) {
  var len = end - start;
  assert(len % 4 === 0);
  var res = new Array(len / 4);
  for (var i = 0, k = start; i < res.length; i++, k += 4) {
    var w;
    if (endian === 'big')
      w = (msg[k] << 24) | (msg[k + 1] << 16) | (msg[k + 2] << 8) | msg[k + 3];
    else
      w = (msg[k + 3] << 24) | (msg[k + 2] << 16) | (msg[k + 1] << 8) | msg[k];
    res[i] = w >>> 0;
  }
  return res;
}
exports.join32 = join32;

function split32(msg, endian) {
  var res = new Array(msg.length * 4);
  for (var i = 0, k = 0; i < msg.length; i++, k += 4) {
    var m = msg[i];
    if (endian === 'big') {
      res[k] = m >>> 24;
      res[k + 1] = (m >>> 16) & 0xff;
      res[k + 2] = (m >>> 8) & 0xff;
      res[k + 3] = m & 0xff;
    } else {
      res[k + 3] = m >>> 24;
      res[k + 2] = (m >>> 16) & 0xff;
      res[k + 1] = (m >>> 8) & 0xff;
      res[k] = m & 0xff;
    }
  }
  return res;
}
exports.split32 = split32;

function rotr32(w, b) {
  return (w >>> b) | (w << (32 - b));
}
exports.rotr32 = rotr32;

function rotl32(w, b) {
  return (w << b) | (w >>> (32 - b));
}
exports.rotl32 = rotl32;

function sum32(a, b) {
  return (a + b) >>> 0;
}
exports.sum32 = sum32;

function sum32_3(a, b, c) {
  return (a + b + c) >>> 0;
}
exports.sum32_3 = sum32_3;

function sum32_4(a, b, c, d) {
  return (a + b + c + d) >>> 0;
}
exports.sum32_4 = sum32_4;

function sum32_5(a, b, c, d, e) {
  return (a + b + c + d + e) >>> 0;
}
exports.sum32_5 = sum32_5;

function sum64(buf, pos, ah, al) {
  var bh = buf[pos];
  var bl = buf[pos + 1];

  var lo = (al + bl) >>> 0;
  var hi = (lo < al ? 1 : 0) + ah + bh;
  buf[pos] = hi >>> 0;
  buf[pos + 1] = lo;
}
exports.sum64 = sum64;

function sum64_hi(ah, al, bh, bl) {
  var lo = (al + bl) >>> 0;
  var hi = (lo < al ? 1 : 0) + ah + bh;
  return hi >>> 0;
}
exports.sum64_hi = sum64_hi;

function sum64_lo(ah, al, bh, bl) {
  var lo = al + bl;
  return lo >>> 0;
}
exports.sum64_lo = sum64_lo;

function sum64_4_hi(ah, al, bh, bl, ch, cl, dh, dl) {
  var carry = 0;
  var lo = al;
  lo = (lo + bl) >>> 0;
  carry += lo < al ? 1 : 0;
  lo = (lo + cl) >>> 0;
  carry += lo < cl ? 1 : 0;
  lo = (lo + dl) >>> 0;
  carry += lo < dl ? 1 : 0;

  var hi = ah + bh + ch + dh + carry;
  return hi >>> 0;
}
exports.sum64_4_hi = sum64_4_hi;

function sum64_4_lo(ah, al, bh, bl, ch, cl, dh, dl) {
  var lo = al + bl + cl + dl;
  return lo >>> 0;
}
exports.sum64_4_lo = sum64_4_lo;

function sum64_5_hi(ah, al, bh, bl, ch, cl, dh, dl, eh, el) {
  var carry = 0;
  var lo = al;
  lo = (lo + bl) >>> 0;
  carry += lo < al ? 1 : 0;
  lo = (lo + cl) >>> 0;
  carry += lo < cl ? 1 : 0;
  lo = (lo + dl) >>> 0;
  carry += lo < dl ? 1 : 0;
  lo = (lo + el) >>> 0;
  carry += lo < el ? 1 : 0;

  var hi = ah + bh + ch + dh + eh + carry;
  return hi >>> 0;
}
exports.sum64_5_hi = sum64_5_hi;

function sum64_5_lo(ah, al, bh, bl, ch, cl, dh, dl, eh, el) {
  var lo = al + bl + cl + dl + el;

  return lo >>> 0;
}
exports.sum64_5_lo = sum64_5_lo;

function rotr64_hi(ah, al, num) {
  var r = (al << (32 - num)) | (ah >>> num);
  return r >>> 0;
}
exports.rotr64_hi = rotr64_hi;

function rotr64_lo(ah, al, num) {
  var r = (ah << (32 - num)) | (al >>> num);
  return r >>> 0;
}
exports.rotr64_lo = rotr64_lo;

function shr64_hi(ah, al, num) {
  return ah >>> num;
}
exports.shr64_hi = shr64_hi;

function shr64_lo(ah, al, num) {
  var r = (ah << (32 - num)) | (al >>> num);
  return r >>> 0;
}
exports.shr64_lo = shr64_lo;


/***/ }),

/***/ 73463:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var reactIs = __webpack_require__(73887);

/**
 * Copyright 2015, Yahoo! Inc.
 * Copyrights licensed under the New BSD License. See the accompanying LICENSE file for terms.
 */
var REACT_STATICS = {
  childContextTypes: true,
  contextType: true,
  contextTypes: true,
  defaultProps: true,
  displayName: true,
  getDefaultProps: true,
  getDerivedStateFromError: true,
  getDerivedStateFromProps: true,
  mixins: true,
  propTypes: true,
  type: true
};
var KNOWN_STATICS = {
  name: true,
  length: true,
  prototype: true,
  caller: true,
  callee: true,
  arguments: true,
  arity: true
};
var FORWARD_REF_STATICS = {
  '$$typeof': true,
  render: true,
  defaultProps: true,
  displayName: true,
  propTypes: true
};
var MEMO_STATICS = {
  '$$typeof': true,
  compare: true,
  defaultProps: true,
  displayName: true,
  propTypes: true,
  type: true
};
var TYPE_STATICS = {};
TYPE_STATICS[reactIs.ForwardRef] = FORWARD_REF_STATICS;
TYPE_STATICS[reactIs.Memo] = MEMO_STATICS;

function getStatics(component) {
  // React v16.11 and below
  if (reactIs.isMemo(component)) {
    return MEMO_STATICS;
  } // React v16.12 and above


  return TYPE_STATICS[component['$$typeof']] || REACT_STATICS;
}

var defineProperty = Object.defineProperty;
var getOwnPropertyNames = Object.getOwnPropertyNames;
var getOwnPropertySymbols = Object.getOwnPropertySymbols;
var getOwnPropertyDescriptor = Object.getOwnPropertyDescriptor;
var getPrototypeOf = Object.getPrototypeOf;
var objectPrototype = Object.prototype;
function hoistNonReactStatics(targetComponent, sourceComponent, blacklist) {
  if (typeof sourceComponent !== 'string') {
    // don't hoist over string (html) components
    if (objectPrototype) {
      var inheritedComponent = getPrototypeOf(sourceComponent);

      if (inheritedComponent && inheritedComponent !== objectPrototype) {
        hoistNonReactStatics(targetComponent, inheritedComponent, blacklist);
      }
    }

    var keys = getOwnPropertyNames(sourceComponent);

    if (getOwnPropertySymbols) {
      keys = keys.concat(getOwnPropertySymbols(sourceComponent));
    }

    var targetStatics = getStatics(targetComponent);
    var sourceStatics = getStatics(sourceComponent);

    for (var i = 0; i < keys.length; ++i) {
      var key = keys[i];

      if (!KNOWN_STATICS[key] && !(blacklist && blacklist[key]) && !(sourceStatics && sourceStatics[key]) && !(targetStatics && targetStatics[key])) {
        var descriptor = getOwnPropertyDescriptor(sourceComponent, key);

        try {
          // Avoid failures from read-only properties
          defineProperty(targetComponent, key, descriptor);
        } catch (e) {}
      }
    }
  }

  return targetComponent;
}

module.exports = hoistNonReactStatics;


/***/ }),

/***/ 43459:
/***/ (function(__unused_webpack_module, exports) {

"use strict";
/** @license React v16.13.1
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var b="function"===typeof Symbol&&Symbol.for,c=b?Symbol.for("react.element"):60103,d=b?Symbol.for("react.portal"):60106,e=b?Symbol.for("react.fragment"):60107,f=b?Symbol.for("react.strict_mode"):60108,g=b?Symbol.for("react.profiler"):60114,h=b?Symbol.for("react.provider"):60109,k=b?Symbol.for("react.context"):60110,l=b?Symbol.for("react.async_mode"):60111,m=b?Symbol.for("react.concurrent_mode"):60111,n=b?Symbol.for("react.forward_ref"):60112,p=b?Symbol.for("react.suspense"):60113,q=b?
Symbol.for("react.suspense_list"):60120,r=b?Symbol.for("react.memo"):60115,t=b?Symbol.for("react.lazy"):60116,v=b?Symbol.for("react.block"):60121,w=b?Symbol.for("react.fundamental"):60117,x=b?Symbol.for("react.responder"):60118,y=b?Symbol.for("react.scope"):60119;
function z(a){if("object"===typeof a&&null!==a){var u=a.$$typeof;switch(u){case c:switch(a=a.type,a){case l:case m:case e:case g:case f:case p:return a;default:switch(a=a&&a.$$typeof,a){case k:case n:case t:case r:case h:return a;default:return u}}case d:return u}}}function A(a){return z(a)===m}exports.AsyncMode=l;exports.ConcurrentMode=m;exports.ContextConsumer=k;exports.ContextProvider=h;exports.Element=c;exports.ForwardRef=n;exports.Fragment=e;exports.Lazy=t;exports.Memo=r;exports.Portal=d;
exports.Profiler=g;exports.StrictMode=f;exports.Suspense=p;exports.isAsyncMode=function(a){return A(a)||z(a)===l};exports.isConcurrentMode=A;exports.isContextConsumer=function(a){return z(a)===k};exports.isContextProvider=function(a){return z(a)===h};exports.isElement=function(a){return"object"===typeof a&&null!==a&&a.$$typeof===c};exports.isForwardRef=function(a){return z(a)===n};exports.isFragment=function(a){return z(a)===e};exports.isLazy=function(a){return z(a)===t};
exports.isMemo=function(a){return z(a)===r};exports.isPortal=function(a){return z(a)===d};exports.isProfiler=function(a){return z(a)===g};exports.isStrictMode=function(a){return z(a)===f};exports.isSuspense=function(a){return z(a)===p};
exports.isValidElementType=function(a){return"string"===typeof a||"function"===typeof a||a===e||a===m||a===g||a===f||a===p||a===q||"object"===typeof a&&null!==a&&(a.$$typeof===t||a.$$typeof===r||a.$$typeof===h||a.$$typeof===k||a.$$typeof===n||a.$$typeof===w||a.$$typeof===x||a.$$typeof===y||a.$$typeof===v)};exports.typeOf=z;


/***/ }),

/***/ 73887:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


if (true) {
  module.exports = __webpack_require__(43459);
} else {}


/***/ }),

/***/ 92543:
/***/ (function(module) {


var indexOf = [].indexOf;

module.exports = function(arr, obj){
  if (indexOf) return arr.indexOf(obj);
  for (var i = 0; i < arr.length; ++i) {
    if (arr[i] === obj) return i;
  }
  return -1;
};

/***/ }),

/***/ 91285:
/***/ (function(module) {

if (typeof Object.create === 'function') {
  // implementation from standard node.js 'util' module
  module.exports = function inherits(ctor, superCtor) {
    if (superCtor) {
      ctor.super_ = superCtor
      ctor.prototype = Object.create(superCtor.prototype, {
        constructor: {
          value: ctor,
          enumerable: false,
          writable: true,
          configurable: true
        }
      })
    }
  };
} else {
  // old school shim for old browsers
  module.exports = function inherits(ctor, superCtor) {
    if (superCtor) {
      ctor.super_ = superCtor
      var TempCtor = function () {}
      TempCtor.prototype = superCtor.prototype
      ctor.prototype = new TempCtor()
      ctor.prototype.constructor = ctor
    }
  }
}


/***/ }),

/***/ 52635:
/***/ (function(module) {

"use strict";


var hasToStringTag = typeof Symbol === 'function' && typeof Symbol.toStringTag === 'symbol';
var toStr = Object.prototype.toString;

var isStandardArguments = function isArguments(value) {
	if (hasToStringTag && value && typeof value === 'object' && Symbol.toStringTag in value) {
		return false;
	}
	return toStr.call(value) === '[object Arguments]';
};

var isLegacyArguments = function isArguments(value) {
	if (isStandardArguments(value)) {
		return true;
	}
	return value !== null &&
		typeof value === 'object' &&
		typeof value.length === 'number' &&
		value.length >= 0 &&
		toStr.call(value) !== '[object Array]' &&
		toStr.call(value.callee) === '[object Function]';
};

var supportsStandardArguments = (function () {
	return isStandardArguments(arguments);
}());

isStandardArguments.isLegacyArguments = isLegacyArguments; // for tests

module.exports = supportsStandardArguments ? isStandardArguments : isLegacyArguments;


/***/ }),

/***/ 43138:
/***/ (function(module) {

"use strict";


var toStr = Object.prototype.toString;
var fnToStr = Function.prototype.toString;
var isFnRegex = /^\s*(?:function)?\*/;
var hasToStringTag = typeof Symbol === 'function' && typeof Symbol.toStringTag === 'symbol';
var getProto = Object.getPrototypeOf;
var getGeneratorFunc = function () { // eslint-disable-line consistent-return
	if (!hasToStringTag) {
		return false;
	}
	try {
		return Function('return function*() {}')();
	} catch (e) {
	}
};
var generatorFunc = getGeneratorFunc();
var GeneratorFunction = getProto && generatorFunc ? getProto(generatorFunc) : false;

module.exports = function isGeneratorFunction(fn) {
	if (typeof fn !== 'function') {
		return false;
	}
	if (isFnRegex.test(fnToStr.call(fn))) {
		return true;
	}
	if (!hasToStringTag) {
		var str = toStr.call(fn);
		return str === '[object GeneratorFunction]';
	}
	return getProto && getProto(fn) === GeneratorFunction;
};


/***/ }),

/***/ 12653:
/***/ (function(module) {

var reIpv4FirstPass = /^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$/

var reSubnetString = /\/\d{1,3}(?=%|$)/
var reForwardSlash = /\//
var reZone = /%.*$/
var reBadCharacters = /([^0-9a-f:/%])/i
var reBadAddress = /([0-9a-f]{5,}|:{3,}|[^:]:$|^:[^:]|\/$)/i

function validate4 (input) {
  if (!(reIpv4FirstPass.test(input))) return false

  var parts = input.split('.')

  if (parts.length !== 4) return false

  if (parts[0][0] === '0' && parts[0].length > 1) return false
  if (parts[1][0] === '0' && parts[1].length > 1) return false
  if (parts[2][0] === '0' && parts[2].length > 1) return false
  if (parts[3][0] === '0' && parts[3].length > 1) return false

  var n0 = Number(parts[0])
  var n1 = Number(parts[1])
  var n2 = Number(parts[2])
  var n3 = Number(parts[3])

  return (n0 >= 0 && n0 < 256 && n1 >= 0 && n1 < 256 && n2 >= 0 && n2 < 256 && n3 >= 0 && n3 < 256)
}

function validate6 (input) {
  var withoutSubnet = input.replace(reSubnetString, '')
  var hasSubnet = (input.length !== withoutSubnet.length)

  // FIXME: this should probably be an option in the future
  if (hasSubnet) return false

  if (!hasSubnet) {
    if (reForwardSlash.test(input)) return false
  }

  var withoutZone = withoutSubnet.replace(reZone, '')
  var lastPartSeparator = withoutZone.lastIndexOf(':')

  if (lastPartSeparator === -1) return false

  var lastPart = withoutZone.substring(lastPartSeparator + 1)
  var hasV4Part = validate4(lastPart)
  var address = (hasV4Part ? withoutZone.substring(0, lastPartSeparator + 1) + '1234:5678' : withoutZone)

  if (reBadCharacters.test(address)) return false
  if (reBadAddress.test(address)) return false

  var halves = address.split('::')

  if (halves.length > 2) return false

  if (halves.length === 2) {
    var first = (halves[0] === '' ? [] : halves[0].split(':'))
    var last = (halves[1] === '' ? [] : halves[1].split(':'))
    var remainingLength = 8 - (first.length + last.length)

    if (remainingLength <= 0) return false
  } else {
    if (address.split(':').length !== 8) return false
  }

  return true
}

function validate (input) {
  return validate4(input) || validate6(input)
}

module.exports = function validator (options) {
  if (!options) options = {}

  if (options.version === 4) return validate4
  if (options.version === 6) return validate6
  if (options.version == null) return validate

  throw new Error('Unknown version: ' + options.version)
}

module.exports.__all_regexes__ = [
  reIpv4FirstPass,
  reSubnetString,
  reForwardSlash,
  reZone,
  reBadCharacters,
  reBadAddress
]


/***/ }),

/***/ 77465:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

var createIpValidator = __webpack_require__(12653)

var reEmailWhitespace = /\s/
var reHostnameFirstPass = /^[a-zA-Z0-9.-]+$/
var reHostnamePart = /^([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9-]{0,61}[a-zA-Z0-9])$/
var rePhoneFirstPass = /^\+[0-9][0-9 ]{5,27}[0-9]$/
var rePhoneDoubleSpace = / {2}/
var rePhoneGlobalSpace = / /g

exports["date-time"] = /^\d{4}-(?:0[0-9]{1}|1[0-2]{1})-[0-9]{2}[tT ]\d{2}:\d{2}:\d{2}(?:\.\d+|)([zZ]|[+-]\d{2}:\d{2})$/
exports.date = /^\d{4}-(?:0[0-9]{1}|1[0-2]{1})-[0-9]{2}$/
exports.time = /^\d{2}:\d{2}:\d{2}$/
exports.email = function (input) { return (input.indexOf('@') !== -1) && (!reEmailWhitespace.test(input)) }
exports["ip-address"] = exports.ipv4 = createIpValidator({ version: 4 })
exports.ipv6 = createIpValidator({ version: 6 })
exports.uri = /^[a-zA-Z][a-zA-Z0-9+\-.]*:[^\s]*$/
exports.color = /(#?([0-9A-Fa-f]{3,6})\b)|(aqua)|(black)|(blue)|(fuchsia)|(gray)|(green)|(lime)|(maroon)|(navy)|(olive)|(orange)|(purple)|(red)|(silver)|(teal)|(white)|(yellow)|(rgb\(\s*\b([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\b\s*,\s*\b([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\b\s*,\s*\b([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\b\s*\))|(rgb\(\s*(\d?\d%|100%)+\s*,\s*(\d?\d%|100%)+\s*,\s*(\d?\d%|100%)+\s*\))/
exports.hostname = function (input) {
  if (!(reHostnameFirstPass.test(input))) return false

  var parts = input.split('.')

  for (var i = 0; i < parts.length; i++) {
    if (!(reHostnamePart.test(parts[i]))) return false
  }

  return true
}
exports.alpha = /^[a-zA-Z]+$/
exports.alphanumeric = /^[a-zA-Z0-9]+$/
exports.style = /.:\s*[^;]/g
exports.phone = function (input) {
  if (!(rePhoneFirstPass.test(input))) return false
  if (rePhoneDoubleSpace.test(input)) return false

  var digits = input.substring(1).replace(rePhoneGlobalSpace, '').length

  return (digits >= 7 && digits <= 15)
}
exports["utc-millisec"] = /^[0-9]{1,15}\.?[0-9]{0,15}$/


/***/ }),

/***/ 60772:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var genobj = __webpack_require__(6000)
var genfun = __webpack_require__(88616)
var jsonpointer = __webpack_require__(404)
var xtend = __webpack_require__(51960)
var formats = __webpack_require__(77465)

var get = function(obj, additionalSchemas, ptr) {

  var visit = function(sub) {
    if (sub && sub.id === ptr) return sub
    if (typeof sub !== 'object' || !sub) return null
    return Object.keys(sub).reduce(function(res, k) {
      return res || visit(sub[k])
    }, null)
  }

  var res = visit(obj)
  if (res) return res

  ptr = ptr.replace(/^#/, '')
  ptr = ptr.replace(/\/$/, '')

  try {
    return jsonpointer.get(obj, decodeURI(ptr))
  } catch (err) {
    var end = ptr.indexOf('#')
    var other
    // external reference
    if (end !== 0) {
      // fragment doesn't exist.
      if (end === -1) {
        other = additionalSchemas[ptr]
      } else {
        var ext = ptr.slice(0, end)
        other = additionalSchemas[ext]
        var fragment = ptr.slice(end).replace(/^#/, '')
        try {
          return jsonpointer.get(other, fragment)
        } catch (err) {}
      }
    } else {
      other = additionalSchemas[ptr]
    }
    return other || null
  }
}

var types = {}

types.any = function() {
  return 'true'
}

types.null = function(name) {
  return name+' === null'
}

types.boolean = function(name) {
  return 'typeof '+name+' === "boolean"'
}

types.array = function(name) {
  return 'Array.isArray('+name+')'
}

types.object = function(name) {
  return 'typeof '+name+' === "object" && '+name+' && !Array.isArray('+name+')'
}

types.number = function(name) {
  return 'typeof '+name+' === "number" && isFinite('+name+')'
}

types.integer = function(name) {
  return 'typeof '+name+' === "number" && (Math.floor('+name+') === '+name+' || '+name+' > 9007199254740992 || '+name+' < -9007199254740992)'
}

types.string = function(name) {
  return 'typeof '+name+' === "string"'
}

var unique = function(array, len) {
  len = Math.min(len === -1 ? array.length : len, array.length)
  var list = []
  for (var i = 0; i < len; i++) {
    list.push(typeof array[i] === 'object' ? JSON.stringify(array[i]) : array[i])
  }
  for (var i = 1; i < list.length; i++) {
    if (list.indexOf(list[i]) !== i) return false
  }
  return true
}

var isMultipleOf = function(name, multipleOf) {
  var res;
  var factor = ((multipleOf | 0) !== multipleOf) ? Math.pow(10, multipleOf.toString().split('.').pop().length) : 1
  if (factor > 1) {
    var factorName = ((name | 0) !== name) ? Math.pow(10, name.toString().split('.').pop().length) : 1
    if (factorName > factor) res = true
    else res = Math.round(factor * name) % (factor * multipleOf)
  }
  else res = name % multipleOf;
  return !res;
}

var testLimitedRegex = function (r, s, maxLength) {
  if (maxLength > -1 && s.length > maxLength) return true
  return r.test(s)
}

var compile = function(schema, cache, root, reporter, opts) {
  var fmts = opts ? xtend(formats, opts.formats) : formats
  var scope = {unique:unique, formats:fmts, isMultipleOf:isMultipleOf, testLimitedRegex:testLimitedRegex}
  var verbose = opts ? !!opts.verbose : false;
  var greedy = opts && opts.greedy !== undefined ?
    opts.greedy : false;

  var syms = {}
  var allocated = []
  var gensym = function(name) {
    var res = name+(syms[name] = (syms[name] || 0)+1)
    allocated.push(res)
    return res
  }

  var formatName = function(field) {
    var s = JSON.stringify(field)
    try {
      var pattern = /\[([^\[\]"]+)\]/
      while (pattern.test(s)) s = s.replace(pattern, replacer)
      return s
    } catch (_) {
      return JSON.stringify(field)
    }

    function replacer (match, v) {
      if (allocated.indexOf(v) === -1) throw new Error('Unreplaceable')
      return '." + ' + v + ' + "'
    }
  }

  var reversePatterns = {}
  var patterns = function(p) {
    if (reversePatterns[p]) return reversePatterns[p]
    var n = gensym('pattern')
    scope[n] = new RegExp(p)
    reversePatterns[p] = n
    return n
  }

  var vars = ['i','j','k','l','m','n','o','p','q','r','s','t','u','v','x','y','z']
  var genloop = function() {
    var v = vars.shift()
    vars.push(v+v[0])
    allocated.push(v)
    return v
  }

  var visit = function(name, node, reporter, filter, schemaPath) {
    var properties = node.properties
    var type = node.type
    var tuple = false

    if (Array.isArray(node.items)) { // tuple type
      properties = {}
      node.items.forEach(function(item, i) {
        properties[i] = item
      })
      type = 'array'
      tuple = true
    }

    var indent = 0
    var error = function(msg, prop, value) {
      validate('errors++')
      if (reporter === true) {
        validate('if (validate.errors === null) validate.errors = []')
        if (verbose) {
          validate(
            'validate.errors.push({field:%s,message:%s,value:%s,type:%s,schemaPath:%s})',
            formatName(prop || name),
            JSON.stringify(msg),
            value || name,
            JSON.stringify(type),
            JSON.stringify(schemaPath)
          )
        } else {
          validate('validate.errors.push({field:%s,message:%s})', formatName(prop || name), JSON.stringify(msg))
        }
      }
    }

    if (node.required === true) {
      indent++
      validate('if (%s === undefined) {', name)
      error('is required')
      validate('} else {')
    } else {
      indent++
      validate('if (%s !== undefined) {', name)
    }

    var valid = [].concat(type)
      .map(function(t) {
        if (t && !types.hasOwnProperty(t)) {
          throw new Error('Unknown type: ' + t)
        }

        return types[t || 'any'](name)
      })
      .join(' || ') || 'true'

    if (valid !== 'true') {
      indent++
      validate('if (!(%s)) {', valid)
      error('is the wrong type')
      validate('} else {')
    }

    if (tuple) {
      if (node.additionalItems === false) {
        validate('if (%s.length > %d) {', name, node.items.length)
        error('has additional items')
        validate('}')
      } else if (node.additionalItems) {
        var i = genloop()
        validate('for (var %s = %d; %s < %s.length; %s++) {', i, node.items.length, i, name, i)
        visit(name+'['+i+']', node.additionalItems, reporter, filter, schemaPath.concat('additionalItems'))
        validate('}')
      }
    }

    if (node.format && fmts[node.format]) {
      if (type !== 'string' && formats[node.format]) validate('if (%s) {', types.string(name))
      var n = gensym('format')
      scope[n] = fmts[node.format]

      if (typeof scope[n] === 'function') validate('if (!%s(%s)) {', n, name)
      else validate('if (!testLimitedRegex(%s, %s, %d)) {', n, name, typeof node.maxLength === 'undefined' ? -1 : node.maxLength)
      error('must be '+node.format+' format')
      validate('}')
      if (type !== 'string' && formats[node.format]) validate('}')
    }

    if (Array.isArray(node.required)) {
      var n = gensym('missing')
      validate('var %s = 0', n)
      var checkRequired = function (req) {
        var prop = genobj(name, req);
        validate('if (%s === undefined) {', prop)
        error('is required', prop)
        validate('%s++', n)
        validate('}')
      }
      validate('if ((%s)) {', type !== 'object' ? types.object(name) : 'true')
      node.required.map(checkRequired)
      validate('}');
      if (!greedy) {
        validate('if (%s === 0) {', n)
        indent++
      }
    }

    if (node.uniqueItems) {
      if (type !== 'array') validate('if (%s) {', types.array(name))
      validate('if (!(unique(%s, %d))) {', name, node.maxItems || -1)
      error('must be unique')
      validate('}')
      if (type !== 'array') validate('}')
    }

    if (node.enum) {
      var complex = node.enum.some(function(e) {
        return typeof e === 'object'
      })

      var compare = complex ?
        function(e) {
          return 'JSON.stringify('+name+')'+' !== JSON.stringify('+JSON.stringify(e)+')'
        } :
        function(e) {
          return name+' !== '+JSON.stringify(e)
        }

      validate('if (%s) {', node.enum.map(compare).join(' && ') || 'false')
      error('must be an enum value')
      validate('}')
    }

    if (node.dependencies) {
      if (type !== 'object') validate('if (%s) {', types.object(name))

      Object.keys(node.dependencies).forEach(function(key) {
        var deps = node.dependencies[key]
        if (typeof deps === 'string') deps = [deps]

        var exists = function(k) {
          return genobj(name, k) + ' !== undefined'
        }

        if (Array.isArray(deps)) {
          validate('if (%s !== undefined && !(%s)) {', genobj(name, key), deps.map(exists).join(' && ') || 'true')
          error('dependencies not set')
          validate('}')
        }
        if (typeof deps === 'object') {
          validate('if (%s !== undefined) {', genobj(name, key))
          visit(name, deps, reporter, filter, schemaPath.concat(['dependencies', key]))
          validate('}')
        }
      })

      if (type !== 'object') validate('}')
    }

    if (node.additionalProperties || node.additionalProperties === false) {
      if (type !== 'object') validate('if (%s) {', types.object(name))

      var i = genloop()
      var keys = gensym('keys')

      var toCompare = function(p) {
        return keys+'['+i+'] !== '+JSON.stringify(p)
      }

      var toTest = function(p) {
        return '!'+patterns(p)+'.test('+keys+'['+i+'])'
      }

      var additionalProp = Object.keys(properties || {}).map(toCompare)
        .concat(Object.keys(node.patternProperties || {}).map(toTest))
        .join(' && ') || 'true'

      validate('var %s = Object.keys(%s)', keys, name)
        ('for (var %s = 0; %s < %s.length; %s++) {', i, i, keys, i)
          ('if (%s) {', additionalProp)

      if (node.additionalProperties === false) {
        if (filter) validate('delete %s', name+'['+keys+'['+i+']]')
        error('has additional properties', null, JSON.stringify(name+'.') + ' + ' + keys + '['+i+']')
      } else {
        visit(name+'['+keys+'['+i+']]', node.additionalProperties, reporter, filter, schemaPath.concat(['additionalProperties']))
      }

      validate
          ('}')
        ('}')

      if (type !== 'object') validate('}')
    }

    if (node.$ref) {
      var sub = get(root, opts && opts.schemas || {}, node.$ref)
      if (sub) {
        var fn = cache[node.$ref]
        if (!fn) {
          cache[node.$ref] = function proxy(data) {
            return fn(data)
          }
          fn = compile(sub, cache, root, false, opts)
        }
        var n = gensym('ref')
        scope[n] = fn
        validate('if (!(%s(%s))) {', n, name)
        error('referenced schema does not match')
        validate('}')
      }
    }

    if (node.not) {
      var prev = gensym('prev')
      validate('var %s = errors', prev)
      visit(name, node.not, false, filter, schemaPath.concat('not'))
      validate('if (%s === errors) {', prev)
      error('negative schema matches')
      validate('} else {')
        ('errors = %s', prev)
      ('}')
    }

    if (node.items && !tuple) {
      if (type !== 'array') validate('if (%s) {', types.array(name))

      var i = genloop()
      validate('for (var %s = 0; %s < %s.length; %s++) {', i, i, name, i)
      visit(name+'['+i+']', node.items, reporter, filter, schemaPath.concat('items'))
      validate('}')

      if (type !== 'array') validate('}')
    }

    if (node.patternProperties) {
      if (type !== 'object') validate('if (%s) {', types.object(name))
      var keys = gensym('keys')
      var i = genloop()
      validate
        ('var %s = Object.keys(%s)', keys, name)
        ('for (var %s = 0; %s < %s.length; %s++) {', i, i, keys, i)

      Object.keys(node.patternProperties).forEach(function(key) {
        var p = patterns(key)
        validate('if (%s.test(%s)) {', p, keys+'['+i+']')
        visit(name+'['+keys+'['+i+']]', node.patternProperties[key], reporter, filter, schemaPath.concat(['patternProperties', key]))
        validate('}')
      })

      validate('}')
      if (type !== 'object') validate('}')
    }

    if (node.pattern) {
      var p = patterns(node.pattern)
      if (type !== 'string') validate('if (%s) {', types.string(name))
      validate('if (!(testLimitedRegex(%s, %s, %d))) {', p, name, typeof node.maxLength === 'undefined' ? -1 : node.maxLength)
      error('pattern mismatch')
      validate('}')
      if (type !== 'string') validate('}')
    }

    if (node.allOf) {
      node.allOf.forEach(function(sch, key) {
        visit(name, sch, reporter, filter, schemaPath.concat(['allOf', key]))
      })
    }

    if (node.anyOf && node.anyOf.length) {
      var prev = gensym('prev')

      node.anyOf.forEach(function(sch, i) {
        if (i === 0) {
          validate('var %s = errors', prev)
        } else {
          validate('if (errors !== %s) {', prev)
            ('errors = %s', prev)
        }
        visit(name, sch, false, false, schemaPath)
      })
      node.anyOf.forEach(function(sch, i) {
        if (i) validate('}')
      })
      validate('if (%s !== errors) {', prev)
      error('no schemas match')
      validate('}')
    }

    if (node.oneOf && node.oneOf.length) {
      var prev = gensym('prev')
      var passes = gensym('passes')

      validate
        ('var %s = errors', prev)
        ('var %s = 0', passes)

      node.oneOf.forEach(function(sch, i) {
        visit(name, sch, false, false, schemaPath)
        validate('if (%s === errors) {', prev)
          ('%s++', passes)
        ('} else {')
          ('errors = %s', prev)
        ('}')
      })

      validate('if (%s !== 1) {', passes)
      error('no (or more than one) schemas match')
      validate('}')
    }

    if (node.multipleOf !== undefined) {
      if (type !== 'number' && type !== 'integer') validate('if (%s) {', types.number(name))

      validate('if (!isMultipleOf(%s, %d)) {', name, node.multipleOf)

      error('has a remainder')
      validate('}')

      if (type !== 'number' && type !== 'integer') validate('}')
    }

    if (node.maxProperties !== undefined) {
      if (type !== 'object') validate('if (%s) {', types.object(name))

      validate('if (Object.keys(%s).length > %d) {', name, node.maxProperties)
      error('has more properties than allowed')
      validate('}')

      if (type !== 'object') validate('}')
    }

    if (node.minProperties !== undefined) {
      if (type !== 'object') validate('if (%s) {', types.object(name))

      validate('if (Object.keys(%s).length < %d) {', name, node.minProperties)
      error('has less properties than allowed')
      validate('}')

      if (type !== 'object') validate('}')
    }

    if (node.maxItems !== undefined) {
      if (type !== 'array') validate('if (%s) {', types.array(name))

      validate('if (%s.length > %d) {', name, node.maxItems)
      error('has more items than allowed')
      validate('}')

      if (type !== 'array') validate('}')
    }

    if (node.minItems !== undefined) {
      if (type !== 'array') validate('if (%s) {', types.array(name))

      validate('if (%s.length < %d) {', name, node.minItems)
      error('has less items than allowed')
      validate('}')

      if (type !== 'array') validate('}')
    }

    if (node.maxLength !== undefined) {
      if (type !== 'string') validate('if (%s) {', types.string(name))

      validate('if (%s.length > %d) {', name, node.maxLength)
      error('has longer length than allowed')
      validate('}')

      if (type !== 'string') validate('}')
    }

    if (node.minLength !== undefined) {
      if (type !== 'string') validate('if (%s) {', types.string(name))

      validate('if (%s.length < %d) {', name, node.minLength)
      error('has less length than allowed')
      validate('}')

      if (type !== 'string') validate('}')
    }

    if (node.minimum !== undefined) {
      if (type !== 'number' && type !== 'integer') validate('if (%s) {', types.number(name))

      validate('if (%s %s %d) {', name, node.exclusiveMinimum ? '<=' : '<', node.minimum)
      error('is less than minimum')
      validate('}')

      if (type !== 'number' && type !== 'integer') validate('}')
    }

    if (node.maximum !== undefined) {
      if (type !== 'number' && type !== 'integer') validate('if (%s) {', types.number(name))

      validate('if (%s %s %d) {', name, node.exclusiveMaximum ? '>=' : '>', node.maximum)
      error('is more than maximum')
      validate('}')

      if (type !== 'number' && type !== 'integer') validate('}')
    }

    if (properties) {
      Object.keys(properties).forEach(function(p) {
        if (Array.isArray(type) && type.indexOf('null') !== -1) validate('if (%s !== null) {', name)

        visit(
          genobj(name, p),
          properties[p],
          reporter,
          filter,
          schemaPath.concat(tuple ? p : ['properties', p])
        )

        if (Array.isArray(type) && type.indexOf('null') !== -1) validate('}')
      })
    }

    while (indent--) validate('}')
  }

  var validate = genfun
    ('function validate(data) {')
      // Since undefined is not a valid JSON value, we coerce to null and other checks will catch this
      ('if (data === undefined) data = null')
      ('validate.errors = null')
      ('var errors = 0')

  visit('data', schema, reporter, opts && opts.filter, [])

  validate
      ('return errors === 0')
    ('}')

  validate = validate.toFunction(scope)
  validate.errors = null

  if (Object.defineProperty) {
    Object.defineProperty(validate, 'error', {
      get: function() {
        if (!validate.errors) return ''
        return validate.errors.map(function(err) {
          return err.field + ' ' + err.message;
        }).join('\n')
      }
    })
  }

  validate.toJSON = function() {
    return schema
  }

  return validate
}

module.exports = function(schema, opts) {
  if (typeof schema === 'string') schema = JSON.parse(schema)
  return compile(schema, {}, schema, true, opts)
}

module.exports.filter = function(schema, opts) {
  var validate = module.exports(schema, xtend(opts, {filter: true}))
  return function(sch) {
    validate(sch)
    return sch
  }
}


/***/ }),

/***/ 30892:
/***/ (function(module) {

"use strict";

function isProperty(str) {
  return /^[$A-Z\_a-z\xaa\xb5\xba\xc0-\xd6\xd8-\xf6\xf8-\u02c1\u02c6-\u02d1\u02e0-\u02e4\u02ec\u02ee\u0370-\u0374\u0376\u0377\u037a-\u037d\u0386\u0388-\u038a\u038c\u038e-\u03a1\u03a3-\u03f5\u03f7-\u0481\u048a-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05d0-\u05ea\u05f0-\u05f2\u0620-\u064a\u066e\u066f\u0671-\u06d3\u06d5\u06e5\u06e6\u06ee\u06ef\u06fa-\u06fc\u06ff\u0710\u0712-\u072f\u074d-\u07a5\u07b1\u07ca-\u07ea\u07f4\u07f5\u07fa\u0800-\u0815\u081a\u0824\u0828\u0840-\u0858\u08a0\u08a2-\u08ac\u0904-\u0939\u093d\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097f\u0985-\u098c\u098f\u0990\u0993-\u09a8\u09aa-\u09b0\u09b2\u09b6-\u09b9\u09bd\u09ce\u09dc\u09dd\u09df-\u09e1\u09f0\u09f1\u0a05-\u0a0a\u0a0f\u0a10\u0a13-\u0a28\u0a2a-\u0a30\u0a32\u0a33\u0a35\u0a36\u0a38\u0a39\u0a59-\u0a5c\u0a5e\u0a72-\u0a74\u0a85-\u0a8d\u0a8f-\u0a91\u0a93-\u0aa8\u0aaa-\u0ab0\u0ab2\u0ab3\u0ab5-\u0ab9\u0abd\u0ad0\u0ae0\u0ae1\u0b05-\u0b0c\u0b0f\u0b10\u0b13-\u0b28\u0b2a-\u0b30\u0b32\u0b33\u0b35-\u0b39\u0b3d\u0b5c\u0b5d\u0b5f-\u0b61\u0b71\u0b83\u0b85-\u0b8a\u0b8e-\u0b90\u0b92-\u0b95\u0b99\u0b9a\u0b9c\u0b9e\u0b9f\u0ba3\u0ba4\u0ba8-\u0baa\u0bae-\u0bb9\u0bd0\u0c05-\u0c0c\u0c0e-\u0c10\u0c12-\u0c28\u0c2a-\u0c33\u0c35-\u0c39\u0c3d\u0c58\u0c59\u0c60\u0c61\u0c85-\u0c8c\u0c8e-\u0c90\u0c92-\u0ca8\u0caa-\u0cb3\u0cb5-\u0cb9\u0cbd\u0cde\u0ce0\u0ce1\u0cf1\u0cf2\u0d05-\u0d0c\u0d0e-\u0d10\u0d12-\u0d3a\u0d3d\u0d4e\u0d60\u0d61\u0d7a-\u0d7f\u0d85-\u0d96\u0d9a-\u0db1\u0db3-\u0dbb\u0dbd\u0dc0-\u0dc6\u0e01-\u0e30\u0e32\u0e33\u0e40-\u0e46\u0e81\u0e82\u0e84\u0e87\u0e88\u0e8a\u0e8d\u0e94-\u0e97\u0e99-\u0e9f\u0ea1-\u0ea3\u0ea5\u0ea7\u0eaa\u0eab\u0ead-\u0eb0\u0eb2\u0eb3\u0ebd\u0ec0-\u0ec4\u0ec6\u0edc-\u0edf\u0f00\u0f40-\u0f47\u0f49-\u0f6c\u0f88-\u0f8c\u1000-\u102a\u103f\u1050-\u1055\u105a-\u105d\u1061\u1065\u1066\u106e-\u1070\u1075-\u1081\u108e\u10a0-\u10c5\u10c7\u10cd\u10d0-\u10fa\u10fc-\u1248\u124a-\u124d\u1250-\u1256\u1258\u125a-\u125d\u1260-\u1288\u128a-\u128d\u1290-\u12b0\u12b2-\u12b5\u12b8-\u12be\u12c0\u12c2-\u12c5\u12c8-\u12d6\u12d8-\u1310\u1312-\u1315\u1318-\u135a\u1380-\u138f\u13a0-\u13f4\u1401-\u166c\u166f-\u167f\u1681-\u169a\u16a0-\u16ea\u16ee-\u16f0\u1700-\u170c\u170e-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176c\u176e-\u1770\u1780-\u17b3\u17d7\u17dc\u1820-\u1877\u1880-\u18a8\u18aa\u18b0-\u18f5\u1900-\u191c\u1950-\u196d\u1970-\u1974\u1980-\u19ab\u19c1-\u19c7\u1a00-\u1a16\u1a20-\u1a54\u1aa7\u1b05-\u1b33\u1b45-\u1b4b\u1b83-\u1ba0\u1bae\u1baf\u1bba-\u1be5\u1c00-\u1c23\u1c4d-\u1c4f\u1c5a-\u1c7d\u1ce9-\u1cec\u1cee-\u1cf1\u1cf5\u1cf6\u1d00-\u1dbf\u1e00-\u1f15\u1f18-\u1f1d\u1f20-\u1f45\u1f48-\u1f4d\u1f50-\u1f57\u1f59\u1f5b\u1f5d\u1f5f-\u1f7d\u1f80-\u1fb4\u1fb6-\u1fbc\u1fbe\u1fc2-\u1fc4\u1fc6-\u1fcc\u1fd0-\u1fd3\u1fd6-\u1fdb\u1fe0-\u1fec\u1ff2-\u1ff4\u1ff6-\u1ffc\u2071\u207f\u2090-\u209c\u2102\u2107\u210a-\u2113\u2115\u2119-\u211d\u2124\u2126\u2128\u212a-\u212d\u212f-\u2139\u213c-\u213f\u2145-\u2149\u214e\u2160-\u2188\u2c00-\u2c2e\u2c30-\u2c5e\u2c60-\u2ce4\u2ceb-\u2cee\u2cf2\u2cf3\u2d00-\u2d25\u2d27\u2d2d\u2d30-\u2d67\u2d6f\u2d80-\u2d96\u2da0-\u2da6\u2da8-\u2dae\u2db0-\u2db6\u2db8-\u2dbe\u2dc0-\u2dc6\u2dc8-\u2dce\u2dd0-\u2dd6\u2dd8-\u2dde\u2e2f\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303c\u3041-\u3096\u309d-\u309f\u30a1-\u30fa\u30fc-\u30ff\u3105-\u312d\u3131-\u318e\u31a0-\u31ba\u31f0-\u31ff\u3400-\u4db5\u4e00-\u9fcc\ua000-\ua48c\ua4d0-\ua4fd\ua500-\ua60c\ua610-\ua61f\ua62a\ua62b\ua640-\ua66e\ua67f-\ua697\ua6a0-\ua6ef\ua717-\ua71f\ua722-\ua788\ua78b-\ua78e\ua790-\ua793\ua7a0-\ua7aa\ua7f8-\ua801\ua803-\ua805\ua807-\ua80a\ua80c-\ua822\ua840-\ua873\ua882-\ua8b3\ua8f2-\ua8f7\ua8fb\ua90a-\ua925\ua930-\ua946\ua960-\ua97c\ua984-\ua9b2\ua9cf\uaa00-\uaa28\uaa40-\uaa42\uaa44-\uaa4b\uaa60-\uaa76\uaa7a\uaa80-\uaaaf\uaab1\uaab5\uaab6\uaab9-\uaabd\uaac0\uaac2\uaadb-\uaadd\uaae0-\uaaea\uaaf2-\uaaf4\uab01-\uab06\uab09-\uab0e\uab11-\uab16\uab20-\uab26\uab28-\uab2e\uabc0-\uabe2\uac00-\ud7a3\ud7b0-\ud7c6\ud7cb-\ud7fb\uf900-\ufa6d\ufa70-\ufad9\ufb00-\ufb06\ufb13-\ufb17\ufb1d\ufb1f-\ufb28\ufb2a-\ufb36\ufb38-\ufb3c\ufb3e\ufb40\ufb41\ufb43\ufb44\ufb46-\ufbb1\ufbd3-\ufd3d\ufd50-\ufd8f\ufd92-\ufdc7\ufdf0-\ufdfb\ufe70-\ufe74\ufe76-\ufefc\uff21-\uff3a\uff41-\uff5a\uff66-\uffbe\uffc2-\uffc7\uffca-\uffcf\uffd2-\uffd7\uffda-\uffdc][$A-Z\_a-z\xaa\xb5\xba\xc0-\xd6\xd8-\xf6\xf8-\u02c1\u02c6-\u02d1\u02e0-\u02e4\u02ec\u02ee\u0370-\u0374\u0376\u0377\u037a-\u037d\u0386\u0388-\u038a\u038c\u038e-\u03a1\u03a3-\u03f5\u03f7-\u0481\u048a-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05d0-\u05ea\u05f0-\u05f2\u0620-\u064a\u066e\u066f\u0671-\u06d3\u06d5\u06e5\u06e6\u06ee\u06ef\u06fa-\u06fc\u06ff\u0710\u0712-\u072f\u074d-\u07a5\u07b1\u07ca-\u07ea\u07f4\u07f5\u07fa\u0800-\u0815\u081a\u0824\u0828\u0840-\u0858\u08a0\u08a2-\u08ac\u0904-\u0939\u093d\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097f\u0985-\u098c\u098f\u0990\u0993-\u09a8\u09aa-\u09b0\u09b2\u09b6-\u09b9\u09bd\u09ce\u09dc\u09dd\u09df-\u09e1\u09f0\u09f1\u0a05-\u0a0a\u0a0f\u0a10\u0a13-\u0a28\u0a2a-\u0a30\u0a32\u0a33\u0a35\u0a36\u0a38\u0a39\u0a59-\u0a5c\u0a5e\u0a72-\u0a74\u0a85-\u0a8d\u0a8f-\u0a91\u0a93-\u0aa8\u0aaa-\u0ab0\u0ab2\u0ab3\u0ab5-\u0ab9\u0abd\u0ad0\u0ae0\u0ae1\u0b05-\u0b0c\u0b0f\u0b10\u0b13-\u0b28\u0b2a-\u0b30\u0b32\u0b33\u0b35-\u0b39\u0b3d\u0b5c\u0b5d\u0b5f-\u0b61\u0b71\u0b83\u0b85-\u0b8a\u0b8e-\u0b90\u0b92-\u0b95\u0b99\u0b9a\u0b9c\u0b9e\u0b9f\u0ba3\u0ba4\u0ba8-\u0baa\u0bae-\u0bb9\u0bd0\u0c05-\u0c0c\u0c0e-\u0c10\u0c12-\u0c28\u0c2a-\u0c33\u0c35-\u0c39\u0c3d\u0c58\u0c59\u0c60\u0c61\u0c85-\u0c8c\u0c8e-\u0c90\u0c92-\u0ca8\u0caa-\u0cb3\u0cb5-\u0cb9\u0cbd\u0cde\u0ce0\u0ce1\u0cf1\u0cf2\u0d05-\u0d0c\u0d0e-\u0d10\u0d12-\u0d3a\u0d3d\u0d4e\u0d60\u0d61\u0d7a-\u0d7f\u0d85-\u0d96\u0d9a-\u0db1\u0db3-\u0dbb\u0dbd\u0dc0-\u0dc6\u0e01-\u0e30\u0e32\u0e33\u0e40-\u0e46\u0e81\u0e82\u0e84\u0e87\u0e88\u0e8a\u0e8d\u0e94-\u0e97\u0e99-\u0e9f\u0ea1-\u0ea3\u0ea5\u0ea7\u0eaa\u0eab\u0ead-\u0eb0\u0eb2\u0eb3\u0ebd\u0ec0-\u0ec4\u0ec6\u0edc-\u0edf\u0f00\u0f40-\u0f47\u0f49-\u0f6c\u0f88-\u0f8c\u1000-\u102a\u103f\u1050-\u1055\u105a-\u105d\u1061\u1065\u1066\u106e-\u1070\u1075-\u1081\u108e\u10a0-\u10c5\u10c7\u10cd\u10d0-\u10fa\u10fc-\u1248\u124a-\u124d\u1250-\u1256\u1258\u125a-\u125d\u1260-\u1288\u128a-\u128d\u1290-\u12b0\u12b2-\u12b5\u12b8-\u12be\u12c0\u12c2-\u12c5\u12c8-\u12d6\u12d8-\u1310\u1312-\u1315\u1318-\u135a\u1380-\u138f\u13a0-\u13f4\u1401-\u166c\u166f-\u167f\u1681-\u169a\u16a0-\u16ea\u16ee-\u16f0\u1700-\u170c\u170e-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176c\u176e-\u1770\u1780-\u17b3\u17d7\u17dc\u1820-\u1877\u1880-\u18a8\u18aa\u18b0-\u18f5\u1900-\u191c\u1950-\u196d\u1970-\u1974\u1980-\u19ab\u19c1-\u19c7\u1a00-\u1a16\u1a20-\u1a54\u1aa7\u1b05-\u1b33\u1b45-\u1b4b\u1b83-\u1ba0\u1bae\u1baf\u1bba-\u1be5\u1c00-\u1c23\u1c4d-\u1c4f\u1c5a-\u1c7d\u1ce9-\u1cec\u1cee-\u1cf1\u1cf5\u1cf6\u1d00-\u1dbf\u1e00-\u1f15\u1f18-\u1f1d\u1f20-\u1f45\u1f48-\u1f4d\u1f50-\u1f57\u1f59\u1f5b\u1f5d\u1f5f-\u1f7d\u1f80-\u1fb4\u1fb6-\u1fbc\u1fbe\u1fc2-\u1fc4\u1fc6-\u1fcc\u1fd0-\u1fd3\u1fd6-\u1fdb\u1fe0-\u1fec\u1ff2-\u1ff4\u1ff6-\u1ffc\u2071\u207f\u2090-\u209c\u2102\u2107\u210a-\u2113\u2115\u2119-\u211d\u2124\u2126\u2128\u212a-\u212d\u212f-\u2139\u213c-\u213f\u2145-\u2149\u214e\u2160-\u2188\u2c00-\u2c2e\u2c30-\u2c5e\u2c60-\u2ce4\u2ceb-\u2cee\u2cf2\u2cf3\u2d00-\u2d25\u2d27\u2d2d\u2d30-\u2d67\u2d6f\u2d80-\u2d96\u2da0-\u2da6\u2da8-\u2dae\u2db0-\u2db6\u2db8-\u2dbe\u2dc0-\u2dc6\u2dc8-\u2dce\u2dd0-\u2dd6\u2dd8-\u2dde\u2e2f\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303c\u3041-\u3096\u309d-\u309f\u30a1-\u30fa\u30fc-\u30ff\u3105-\u312d\u3131-\u318e\u31a0-\u31ba\u31f0-\u31ff\u3400-\u4db5\u4e00-\u9fcc\ua000-\ua48c\ua4d0-\ua4fd\ua500-\ua60c\ua610-\ua61f\ua62a\ua62b\ua640-\ua66e\ua67f-\ua697\ua6a0-\ua6ef\ua717-\ua71f\ua722-\ua788\ua78b-\ua78e\ua790-\ua793\ua7a0-\ua7aa\ua7f8-\ua801\ua803-\ua805\ua807-\ua80a\ua80c-\ua822\ua840-\ua873\ua882-\ua8b3\ua8f2-\ua8f7\ua8fb\ua90a-\ua925\ua930-\ua946\ua960-\ua97c\ua984-\ua9b2\ua9cf\uaa00-\uaa28\uaa40-\uaa42\uaa44-\uaa4b\uaa60-\uaa76\uaa7a\uaa80-\uaaaf\uaab1\uaab5\uaab6\uaab9-\uaabd\uaac0\uaac2\uaadb-\uaadd\uaae0-\uaaea\uaaf2-\uaaf4\uab01-\uab06\uab09-\uab0e\uab11-\uab16\uab20-\uab26\uab28-\uab2e\uabc0-\uabe2\uac00-\ud7a3\ud7b0-\ud7c6\ud7cb-\ud7fb\uf900-\ufa6d\ufa70-\ufad9\ufb00-\ufb06\ufb13-\ufb17\ufb1d\ufb1f-\ufb28\ufb2a-\ufb36\ufb38-\ufb3c\ufb3e\ufb40\ufb41\ufb43\ufb44\ufb46-\ufbb1\ufbd3-\ufd3d\ufd50-\ufd8f\ufd92-\ufdc7\ufdf0-\ufdfb\ufe70-\ufe74\ufe76-\ufefc\uff21-\uff3a\uff41-\uff5a\uff66-\uffbe\uffc2-\uffc7\uffca-\uffcf\uffd2-\uffd7\uffda-\uffdc0-9\u0300-\u036f\u0483-\u0487\u0591-\u05bd\u05bf\u05c1\u05c2\u05c4\u05c5\u05c7\u0610-\u061a\u064b-\u0669\u0670\u06d6-\u06dc\u06df-\u06e4\u06e7\u06e8\u06ea-\u06ed\u06f0-\u06f9\u0711\u0730-\u074a\u07a6-\u07b0\u07c0-\u07c9\u07eb-\u07f3\u0816-\u0819\u081b-\u0823\u0825-\u0827\u0829-\u082d\u0859-\u085b\u08e4-\u08fe\u0900-\u0903\u093a-\u093c\u093e-\u094f\u0951-\u0957\u0962\u0963\u0966-\u096f\u0981-\u0983\u09bc\u09be-\u09c4\u09c7\u09c8\u09cb-\u09cd\u09d7\u09e2\u09e3\u09e6-\u09ef\u0a01-\u0a03\u0a3c\u0a3e-\u0a42\u0a47\u0a48\u0a4b-\u0a4d\u0a51\u0a66-\u0a71\u0a75\u0a81-\u0a83\u0abc\u0abe-\u0ac5\u0ac7-\u0ac9\u0acb-\u0acd\u0ae2\u0ae3\u0ae6-\u0aef\u0b01-\u0b03\u0b3c\u0b3e-\u0b44\u0b47\u0b48\u0b4b-\u0b4d\u0b56\u0b57\u0b62\u0b63\u0b66-\u0b6f\u0b82\u0bbe-\u0bc2\u0bc6-\u0bc8\u0bca-\u0bcd\u0bd7\u0be6-\u0bef\u0c01-\u0c03\u0c3e-\u0c44\u0c46-\u0c48\u0c4a-\u0c4d\u0c55\u0c56\u0c62\u0c63\u0c66-\u0c6f\u0c82\u0c83\u0cbc\u0cbe-\u0cc4\u0cc6-\u0cc8\u0cca-\u0ccd\u0cd5\u0cd6\u0ce2\u0ce3\u0ce6-\u0cef\u0d02\u0d03\u0d3e-\u0d44\u0d46-\u0d48\u0d4a-\u0d4d\u0d57\u0d62\u0d63\u0d66-\u0d6f\u0d82\u0d83\u0dca\u0dcf-\u0dd4\u0dd6\u0dd8-\u0ddf\u0df2\u0df3\u0e31\u0e34-\u0e3a\u0e47-\u0e4e\u0e50-\u0e59\u0eb1\u0eb4-\u0eb9\u0ebb\u0ebc\u0ec8-\u0ecd\u0ed0-\u0ed9\u0f18\u0f19\u0f20-\u0f29\u0f35\u0f37\u0f39\u0f3e\u0f3f\u0f71-\u0f84\u0f86\u0f87\u0f8d-\u0f97\u0f99-\u0fbc\u0fc6\u102b-\u103e\u1040-\u1049\u1056-\u1059\u105e-\u1060\u1062-\u1064\u1067-\u106d\u1071-\u1074\u1082-\u108d\u108f-\u109d\u135d-\u135f\u1712-\u1714\u1732-\u1734\u1752\u1753\u1772\u1773\u17b4-\u17d3\u17dd\u17e0-\u17e9\u180b-\u180d\u1810-\u1819\u18a9\u1920-\u192b\u1930-\u193b\u1946-\u194f\u19b0-\u19c0\u19c8\u19c9\u19d0-\u19d9\u1a17-\u1a1b\u1a55-\u1a5e\u1a60-\u1a7c\u1a7f-\u1a89\u1a90-\u1a99\u1b00-\u1b04\u1b34-\u1b44\u1b50-\u1b59\u1b6b-\u1b73\u1b80-\u1b82\u1ba1-\u1bad\u1bb0-\u1bb9\u1be6-\u1bf3\u1c24-\u1c37\u1c40-\u1c49\u1c50-\u1c59\u1cd0-\u1cd2\u1cd4-\u1ce8\u1ced\u1cf2-\u1cf4\u1dc0-\u1de6\u1dfc-\u1dff\u200c\u200d\u203f\u2040\u2054\u20d0-\u20dc\u20e1\u20e5-\u20f0\u2cef-\u2cf1\u2d7f\u2de0-\u2dff\u302a-\u302f\u3099\u309a\ua620-\ua629\ua66f\ua674-\ua67d\ua69f\ua6f0\ua6f1\ua802\ua806\ua80b\ua823-\ua827\ua880\ua881\ua8b4-\ua8c4\ua8d0-\ua8d9\ua8e0-\ua8f1\ua900-\ua909\ua926-\ua92d\ua947-\ua953\ua980-\ua983\ua9b3-\ua9c0\ua9d0-\ua9d9\uaa29-\uaa36\uaa43\uaa4c\uaa4d\uaa50-\uaa59\uaa7b\uaab0\uaab2-\uaab4\uaab7\uaab8\uaabe\uaabf\uaac1\uaaeb-\uaaef\uaaf5\uaaf6\uabe3-\uabea\uabec\uabed\uabf0-\uabf9\ufb1e\ufe00-\ufe0f\ufe20-\ufe26\ufe33\ufe34\ufe4d-\ufe4f\uff10-\uff19\uff3f]*$/.test(str)
}
module.exports = isProperty

/***/ }),

/***/ 50198:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var forEach = __webpack_require__(46388);
var availableTypedArrays = __webpack_require__(62191);
var callBound = __webpack_require__(62680);

var $toString = callBound('Object.prototype.toString');
var hasSymbols = __webpack_require__(32636)();
var hasToStringTag = hasSymbols && typeof Symbol.toStringTag === 'symbol';

var typedArrays = availableTypedArrays();

var $indexOf = callBound('Array.prototype.indexOf', true) || function indexOf(array, value) {
	for (var i = 0; i < array.length; i += 1) {
		if (array[i] === value) {
			return i;
		}
	}
	return -1;
};
var $slice = callBound('String.prototype.slice');
var toStrTags = {};
var gOPD = __webpack_require__(29765);
var getPrototypeOf = Object.getPrototypeOf; // require('getprototypeof');
if (hasToStringTag && gOPD && getPrototypeOf) {
	forEach(typedArrays, function (typedArray) {
		var arr = new window[typedArray]();
		if (!(Symbol.toStringTag in arr)) {
			throw new EvalError('this engine has support for Symbol.toStringTag, but ' + typedArray + ' does not have the property! Please report this.');
		}
		var proto = getPrototypeOf(arr);
		var descriptor = gOPD(proto, Symbol.toStringTag);
		if (!descriptor) {
			var superProto = getPrototypeOf(proto);
			descriptor = gOPD(superProto, Symbol.toStringTag);
		}
		toStrTags[typedArray] = descriptor.get;
	});
}

var tryTypedArrays = function tryAllTypedArrays(value) {
	var anyTrue = false;
	forEach(toStrTags, function (getter, typedArray) {
		if (!anyTrue) {
			try {
				anyTrue = getter.call(value) === typedArray;
			} catch (e) { /**/ }
		}
	});
	return anyTrue;
};

module.exports = function isTypedArray(value) {
	if (!value || typeof value !== 'object') { return false; }
	if (!hasToStringTag) {
		var tag = $slice($toString(value), 8, -1);
		return $indexOf(typedArrays, tag) > -1;
	}
	if (!gOPD) { return false; }
	return tryTypedArrays(value);
};


/***/ }),

/***/ 95978:
/***/ (function(module, exports) {

var __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/*
 *  base64.js
 *
 *  Licensed under the BSD 3-Clause License.
 *    http://opensource.org/licenses/BSD-3-Clause
 *
 *  References:
 *    http://en.wikipedia.org/wiki/Base64
 */
;(function (global, factory) {
     true
        ? module.exports = factory(global)
        : 0
}((
    typeof self !== 'undefined' ? self
        : typeof window !== 'undefined' ? window
        : typeof window !== 'undefined' ? window
: this
), function(global) {
    'use strict';
    // existing version for noConflict()
    global = global || {};
    var _Base64 = global.Base64;
    var version = "2.6.4";
    // constants
    var b64chars
        = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
    var b64tab = function(bin) {
        var t = {};
        for (var i = 0, l = bin.length; i < l; i++) t[bin.charAt(i)] = i;
        return t;
    }(b64chars);
    var fromCharCode = String.fromCharCode;
    // encoder stuff
    var cb_utob = function(c) {
        if (c.length < 2) {
            var cc = c.charCodeAt(0);
            return cc < 0x80 ? c
                : cc < 0x800 ? (fromCharCode(0xc0 | (cc >>> 6))
                                + fromCharCode(0x80 | (cc & 0x3f)))
                : (fromCharCode(0xe0 | ((cc >>> 12) & 0x0f))
                    + fromCharCode(0x80 | ((cc >>>  6) & 0x3f))
                    + fromCharCode(0x80 | ( cc         & 0x3f)));
        } else {
            var cc = 0x10000
                + (c.charCodeAt(0) - 0xD800) * 0x400
                + (c.charCodeAt(1) - 0xDC00);
            return (fromCharCode(0xf0 | ((cc >>> 18) & 0x07))
                    + fromCharCode(0x80 | ((cc >>> 12) & 0x3f))
                    + fromCharCode(0x80 | ((cc >>>  6) & 0x3f))
                    + fromCharCode(0x80 | ( cc         & 0x3f)));
        }
    };
    var re_utob = /[\uD800-\uDBFF][\uDC00-\uDFFFF]|[^\x00-\x7F]/g;
    var utob = function(u) {
        return u.replace(re_utob, cb_utob);
    };
    var cb_encode = function(ccc) {
        var padlen = [0, 2, 1][ccc.length % 3],
        ord = ccc.charCodeAt(0) << 16
            | ((ccc.length > 1 ? ccc.charCodeAt(1) : 0) << 8)
            | ((ccc.length > 2 ? ccc.charCodeAt(2) : 0)),
        chars = [
            b64chars.charAt( ord >>> 18),
            b64chars.charAt((ord >>> 12) & 63),
            padlen >= 2 ? '=' : b64chars.charAt((ord >>> 6) & 63),
            padlen >= 1 ? '=' : b64chars.charAt(ord & 63)
        ];
        return chars.join('');
    };
    var btoa = global.btoa && typeof global.btoa == 'function'
        ? function(b){ return global.btoa(b) } : function(b) {
        if (b.match(/[^\x00-\xFF]/)) throw new RangeError(
            'The string contains invalid characters.'
        );
        return b.replace(/[\s\S]{1,3}/g, cb_encode);
    };
    var _encode = function(u) {
        return btoa(utob(String(u)));
    };
    var mkUriSafe = function (b64) {
        return b64.replace(/[+\/]/g, function(m0) {
            return m0 == '+' ? '-' : '_';
        }).replace(/=/g, '');
    };
    var encode = function(u, urisafe) {
        return urisafe ? mkUriSafe(_encode(u)) : _encode(u);
    };
    var encodeURI = function(u) { return encode(u, true) };
    var fromUint8Array;
    if (global.Uint8Array) fromUint8Array = function(a, urisafe) {
        // return btoa(fromCharCode.apply(null, a));
        var b64 = '';
        for (var i = 0, l = a.length; i < l; i += 3) {
            var a0 = a[i], a1 = a[i+1], a2 = a[i+2];
            var ord = a0 << 16 | a1 << 8 | a2;
            b64 +=    b64chars.charAt( ord >>> 18)
                +     b64chars.charAt((ord >>> 12) & 63)
                + ( typeof a1 != 'undefined'
                    ? b64chars.charAt((ord >>>  6) & 63) : '=')
                + ( typeof a2 != 'undefined'
                    ? b64chars.charAt( ord         & 63) : '=');
        }
        return urisafe ? mkUriSafe(b64) : b64;
    };
    // decoder stuff
    var re_btou = /[\xC0-\xDF][\x80-\xBF]|[\xE0-\xEF][\x80-\xBF]{2}|[\xF0-\xF7][\x80-\xBF]{3}/g;
    var cb_btou = function(cccc) {
        switch(cccc.length) {
        case 4:
            var cp = ((0x07 & cccc.charCodeAt(0)) << 18)
                |    ((0x3f & cccc.charCodeAt(1)) << 12)
                |    ((0x3f & cccc.charCodeAt(2)) <<  6)
                |     (0x3f & cccc.charCodeAt(3)),
            offset = cp - 0x10000;
            return (fromCharCode((offset  >>> 10) + 0xD800)
                    + fromCharCode((offset & 0x3FF) + 0xDC00));
        case 3:
            return fromCharCode(
                ((0x0f & cccc.charCodeAt(0)) << 12)
                    | ((0x3f & cccc.charCodeAt(1)) << 6)
                    |  (0x3f & cccc.charCodeAt(2))
            );
        default:
            return  fromCharCode(
                ((0x1f & cccc.charCodeAt(0)) << 6)
                    |  (0x3f & cccc.charCodeAt(1))
            );
        }
    };
    var btou = function(b) {
        return b.replace(re_btou, cb_btou);
    };
    var cb_decode = function(cccc) {
        var len = cccc.length,
        padlen = len % 4,
        n = (len > 0 ? b64tab[cccc.charAt(0)] << 18 : 0)
            | (len > 1 ? b64tab[cccc.charAt(1)] << 12 : 0)
            | (len > 2 ? b64tab[cccc.charAt(2)] <<  6 : 0)
            | (len > 3 ? b64tab[cccc.charAt(3)]       : 0),
        chars = [
            fromCharCode( n >>> 16),
            fromCharCode((n >>>  8) & 0xff),
            fromCharCode( n         & 0xff)
        ];
        chars.length -= [0, 0, 2, 1][padlen];
        return chars.join('');
    };
    var _atob = global.atob && typeof global.atob == 'function'
        ? function(a){ return global.atob(a) } : function(a){
        return a.replace(/\S{1,4}/g, cb_decode);
    };
    var atob = function(a) {
        return _atob(String(a).replace(/[^A-Za-z0-9\+\/]/g, ''));
    };
    var _decode = function(a) { return btou(_atob(a)) };
    var _fromURI = function(a) {
        return String(a).replace(/[-_]/g, function(m0) {
            return m0 == '-' ? '+' : '/'
        }).replace(/[^A-Za-z0-9\+\/]/g, '');
    };
    var decode = function(a){
        return _decode(_fromURI(a));
    };
    var toUint8Array;
    if (global.Uint8Array) toUint8Array = function(a) {
        return Uint8Array.from(atob(_fromURI(a)), function(c) {
            return c.charCodeAt(0);
        });
    };
    var noConflict = function() {
        var Base64 = global.Base64;
        global.Base64 = _Base64;
        return Base64;
    };
    // export Base64
    global.Base64 = {
        VERSION: version,
        atob: atob,
        btoa: btoa,
        fromBase64: decode,
        toBase64: encode,
        utob: utob,
        encode: encode,
        encodeURI: encodeURI,
        btou: btou,
        decode: decode,
        noConflict: noConflict,
        fromUint8Array: fromUint8Array,
        toUint8Array: toUint8Array
    };
    // if ES5 is available, make Base64.extendString() available
    if (typeof Object.defineProperty === 'function') {
        var noEnum = function(v){
            return {value:v,enumerable:false,writable:true,configurable:true};
        };
        global.Base64.extendString = function () {
            Object.defineProperty(
                String.prototype, 'fromBase64', noEnum(function () {
                    return decode(this)
                }));
            Object.defineProperty(
                String.prototype, 'toBase64', noEnum(function (urisafe) {
                    return encode(this, urisafe)
                }));
            Object.defineProperty(
                String.prototype, 'toBase64URI', noEnum(function () {
                    return encode(this, true)
                }));
        };
    }
    //
    // export Base64 to the namespace
    //
    if (global['Meteor']) { // Meteor.js
        Base64 = global.Base64;
    }
    // module.exports and AMD are mutually exclusive.
    // module.exports has precedence.
    if ( true && module.exports) {
        module.exports.Base64 = global.Base64;
    }
    else if (true) {
        // AMD. Register as an anonymous module.
        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [], __WEBPACK_AMD_DEFINE_RESULT__ = (function(){ return global.Base64 }).apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
    }
    // that's it!
    return {Base64: global.Base64}
}));


/***/ }),

/***/ 404:
/***/ (function(__unused_webpack_module, exports) {

var hasExcape = /~/
var escapeMatcher = /~[01]/g
function escapeReplacer (m) {
  switch (m) {
    case '~1': return '/'
    case '~0': return '~'
  }
  throw new Error('Invalid tilde escape: ' + m)
}

function untilde (str) {
  if (!hasExcape.test(str)) return str
  return str.replace(escapeMatcher, escapeReplacer)
}

function setter (obj, pointer, value) {
  var part
  var hasNextPart

  for (var p = 1, len = pointer.length; p < len;) {
    part = untilde(pointer[p++])
    hasNextPart = len > p

    if (typeof obj[part] === 'undefined') {
      // support setting of /-
      if (Array.isArray(obj) && part === '-') {
        part = obj.length
      }

      // support nested objects/array when setting values
      if (hasNextPart) {
        if ((pointer[p] !== '' && pointer[p] < Infinity) || pointer[p] === '-') obj[part] = []
        else obj[part] = {}
      }
    }

    if (!hasNextPart) break
    obj = obj[part]
  }

  var oldValue = obj[part]
  if (value === undefined) delete obj[part]
  else obj[part] = value
  return oldValue
}

function compilePointer (pointer) {
  if (typeof pointer === 'string') {
    pointer = pointer.split('/')
    if (pointer[0] === '') return pointer
    throw new Error('Invalid JSON pointer.')
  } else if (Array.isArray(pointer)) {
    return pointer
  }

  throw new Error('Invalid JSON pointer.')
}

function get (obj, pointer) {
  if (typeof obj !== 'object') throw new Error('Invalid input object.')
  pointer = compilePointer(pointer)
  var len = pointer.length
  if (len === 1) return obj

  for (var p = 1; p < len;) {
    obj = obj[untilde(pointer[p++])]
    if (len === p) return obj
    if (typeof obj !== 'object') return undefined
  }
}

function set (obj, pointer, value) {
  if (typeof obj !== 'object') throw new Error('Invalid input object.')
  pointer = compilePointer(pointer)
  if (pointer.length === 0) throw new Error('Invalid JSON pointer for set.')
  return setter(obj, pointer, value)
}

function compile (pointer) {
  var compiled = compilePointer(pointer)
  return {
    get: function (object) {
      return get(object, compiled)
    },
    set: function (object, value) {
      return set(object, compiled, value)
    }
  }
}

exports.get = get
exports.set = set
exports.compile = compile


/***/ }),

/***/ 7839:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var events = __webpack_require__(22699)
var inherits = __webpack_require__(91285)

module.exports = LRU

function LRU (opts) {
  if (!(this instanceof LRU)) return new LRU(opts)
  if (typeof opts === 'number') opts = {max: opts}
  if (!opts) opts = {}
  events.EventEmitter.call(this)
  this.cache = {}
  this.head = this.tail = null
  this.length = 0
  this.max = opts.max || 1000
  this.maxAge = opts.maxAge || 0
}

inherits(LRU, events.EventEmitter)

Object.defineProperty(LRU.prototype, 'keys', {
  get: function () { return Object.keys(this.cache) }
})

LRU.prototype.clear = function () {
  this.cache = {}
  this.head = this.tail = null
  this.length = 0
}

LRU.prototype.remove = function (key) {
  if (typeof key !== 'string') key = '' + key
  if (!this.cache.hasOwnProperty(key)) return

  var element = this.cache[key]
  delete this.cache[key]
  this._unlink(key, element.prev, element.next)
  return element.value
}

LRU.prototype._unlink = function (key, prev, next) {
  this.length--

  if (this.length === 0) {
    this.head = this.tail = null
  } else {
    if (this.head === key) {
      this.head = prev
      this.cache[this.head].next = null
    } else if (this.tail === key) {
      this.tail = next
      this.cache[this.tail].prev = null
    } else {
      this.cache[prev].next = next
      this.cache[next].prev = prev
    }
  }
}

LRU.prototype.peek = function (key) {
  if (!this.cache.hasOwnProperty(key)) return

  var element = this.cache[key]

  if (!this._checkAge(key, element)) return
  return element.value
}

LRU.prototype.set = function (key, value) {
  if (typeof key !== 'string') key = '' + key

  var element

  if (this.cache.hasOwnProperty(key)) {
    element = this.cache[key]
    element.value = value
    if (this.maxAge) element.modified = Date.now()

    // If it's already the head, there's nothing more to do:
    if (key === this.head) return value
    this._unlink(key, element.prev, element.next)
  } else {
    element = {value: value, modified: 0, next: null, prev: null}
    if (this.maxAge) element.modified = Date.now()
    this.cache[key] = element

    // Eviction is only possible if the key didn't already exist:
    if (this.length === this.max) this.evict()
  }

  this.length++
  element.next = null
  element.prev = this.head

  if (this.head) this.cache[this.head].next = key
  this.head = key

  if (!this.tail) this.tail = key
  return value
}

LRU.prototype._checkAge = function (key, element) {
  if (this.maxAge && (Date.now() - element.modified) > this.maxAge) {
    this.remove(key)
    this.emit('evict', {key: key, value: element.value})
    return false
  }
  return true
}

LRU.prototype.get = function (key) {
  if (typeof key !== 'string') key = '' + key
  if (!this.cache.hasOwnProperty(key)) return

  var element = this.cache[key]

  if (!this._checkAge(key, element)) return

  if (this.head !== key) {
    if (key === this.tail) {
      this.tail = element.next
      this.cache[this.tail].prev = null
    } else {
      // Set prev.next -> element.next:
      this.cache[element.prev].next = element.next
    }

    // Set element.next.prev -> element.prev:
    this.cache[element.next].prev = element.prev

    // Element is the new head
    this.cache[this.head].next = key
    element.prev = this.head
    element.next = null
    this.head = key
  }

  return element.value
}

LRU.prototype.evict = function () {
  if (!this.tail) return
  var key = this.tail
  var value = this.remove(this.tail)
  this.emit('evict', {key: key, value: value})
}


/***/ }),

/***/ 81549:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(81665);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(13980);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_2__);





var MAX_SIGNED_31_BIT_INT = 1073741823;
var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof window !== 'undefined' ? window : {};

function getUniqueId() {
  var key = '__global_unique_id__';
  return commonjsGlobal[key] = (commonjsGlobal[key] || 0) + 1;
}

function objectIs(x, y) {
  if (x === y) {
    return x !== 0 || 1 / x === 1 / y;
  } else {
    return x !== x && y !== y;
  }
}

function createEventEmitter(value) {
  var handlers = [];
  return {
    on: function on(handler) {
      handlers.push(handler);
    },
    off: function off(handler) {
      handlers = handlers.filter(function (h) {
        return h !== handler;
      });
    },
    get: function get() {
      return value;
    },
    set: function set(newValue, changedBits) {
      value = newValue;
      handlers.forEach(function (handler) {
        return handler(value, changedBits);
      });
    }
  };
}

function onlyChild(children) {
  return Array.isArray(children) ? children[0] : children;
}

function createReactContext(defaultValue, calculateChangedBits) {
  var _Provider$childContex, _Consumer$contextType;

  var contextProp = '__create-react-context-' + getUniqueId() + '__';

  var Provider = /*#__PURE__*/function (_Component) {
    (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(Provider, _Component);

    function Provider() {
      var _this;

      _this = _Component.apply(this, arguments) || this;
      _this.emitter = createEventEmitter(_this.props.value);
      return _this;
    }

    var _proto = Provider.prototype;

    _proto.getChildContext = function getChildContext() {
      var _ref;

      return _ref = {}, _ref[contextProp] = this.emitter, _ref;
    };

    _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
      if (this.props.value !== nextProps.value) {
        var oldValue = this.props.value;
        var newValue = nextProps.value;
        var changedBits;

        if (objectIs(oldValue, newValue)) {
          changedBits = 0;
        } else {
          changedBits = typeof calculateChangedBits === 'function' ? calculateChangedBits(oldValue, newValue) : MAX_SIGNED_31_BIT_INT;

          if (false) {}

          changedBits |= 0;

          if (changedBits !== 0) {
            this.emitter.set(nextProps.value, changedBits);
          }
        }
      }
    };

    _proto.render = function render() {
      return this.props.children;
    };

    return Provider;
  }(react__WEBPACK_IMPORTED_MODULE_0__.Component);

  Provider.childContextTypes = (_Provider$childContex = {}, _Provider$childContex[contextProp] = (prop_types__WEBPACK_IMPORTED_MODULE_2___default().object.isRequired), _Provider$childContex);

  var Consumer = /*#__PURE__*/function (_Component2) {
    (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(Consumer, _Component2);

    function Consumer() {
      var _this2;

      _this2 = _Component2.apply(this, arguments) || this;
      _this2.state = {
        value: _this2.getValue()
      };

      _this2.onUpdate = function (newValue, changedBits) {
        var observedBits = _this2.observedBits | 0;

        if ((observedBits & changedBits) !== 0) {
          _this2.setState({
            value: _this2.getValue()
          });
        }
      };

      return _this2;
    }

    var _proto2 = Consumer.prototype;

    _proto2.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
      var observedBits = nextProps.observedBits;
      this.observedBits = observedBits === undefined || observedBits === null ? MAX_SIGNED_31_BIT_INT : observedBits;
    };

    _proto2.componentDidMount = function componentDidMount() {
      if (this.context[contextProp]) {
        this.context[contextProp].on(this.onUpdate);
      }

      var observedBits = this.props.observedBits;
      this.observedBits = observedBits === undefined || observedBits === null ? MAX_SIGNED_31_BIT_INT : observedBits;
    };

    _proto2.componentWillUnmount = function componentWillUnmount() {
      if (this.context[contextProp]) {
        this.context[contextProp].off(this.onUpdate);
      }
    };

    _proto2.getValue = function getValue() {
      if (this.context[contextProp]) {
        return this.context[contextProp].get();
      } else {
        return defaultValue;
      }
    };

    _proto2.render = function render() {
      return onlyChild(this.props.children)(this.state.value);
    };

    return Consumer;
  }(react__WEBPACK_IMPORTED_MODULE_0__.Component);

  Consumer.contextTypes = (_Consumer$contextType = {}, _Consumer$contextType[contextProp] = (prop_types__WEBPACK_IMPORTED_MODULE_2___default().object), _Consumer$contextType);
  return {
    Provider: Provider,
    Consumer: Consumer
  };
}

var index = (react__WEBPACK_IMPORTED_MODULE_0___default().createContext) || createReactContext;

/* harmony default export */ __webpack_exports__["Z"] = (index);


/***/ }),

/***/ 39142:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 43261:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 53616:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 81712:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 32014:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 17228:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 9723:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 80418:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 50436:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 21586:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 27427:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 96459:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 6128:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 25827:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 23980:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 62829:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 19201:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 46590:
/***/ (function() {

"use strict";
// extracted by mini-css-extract-plugin


/***/ }),

/***/ 79561:
/***/ (function(module) {

module.exports = assert;

function assert(val, msg) {
  if (!val)
    throw new Error(msg || 'Assertion failed');
}

assert.equal = function assertEqual(l, r, msg) {
  if (l != r)
    throw new Error(msg || ('Assertion failed: ' + l + ' != ' + r));
};


/***/ }),

/***/ 11378:
/***/ (function(module) {

/**
 * Helpers.
 */

var s = 1000;
var m = s * 60;
var h = m * 60;
var d = h * 24;
var w = d * 7;
var y = d * 365.25;

/**
 * Parse or format the given `val`.
 *
 * Options:
 *
 *  - `long` verbose formatting [false]
 *
 * @param {String|Number} val
 * @param {Object} [options]
 * @throws {Error} throw an error if val is not a non-empty string or a number
 * @return {String|Number}
 * @api public
 */

module.exports = function (val, options) {
  options = options || {};
  var type = typeof val;
  if (type === 'string' && val.length > 0) {
    return parse(val);
  } else if (type === 'number' && isFinite(val)) {
    return options.long ? fmtLong(val) : fmtShort(val);
  }
  throw new Error(
    'val is not a non-empty string or a valid number. val=' +
      JSON.stringify(val)
  );
};

/**
 * Parse the given `str` and return milliseconds.
 *
 * @param {String} str
 * @return {Number}
 * @api private
 */

function parse(str) {
  str = String(str);
  if (str.length > 100) {
    return;
  }
  var match = /^(-?(?:\d+)?\.?\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|weeks?|w|years?|yrs?|y)?$/i.exec(
    str
  );
  if (!match) {
    return;
  }
  var n = parseFloat(match[1]);
  var type = (match[2] || 'ms').toLowerCase();
  switch (type) {
    case 'years':
    case 'year':
    case 'yrs':
    case 'yr':
    case 'y':
      return n * y;
    case 'weeks':
    case 'week':
    case 'w':
      return n * w;
    case 'days':
    case 'day':
    case 'd':
      return n * d;
    case 'hours':
    case 'hour':
    case 'hrs':
    case 'hr':
    case 'h':
      return n * h;
    case 'minutes':
    case 'minute':
    case 'mins':
    case 'min':
    case 'm':
      return n * m;
    case 'seconds':
    case 'second':
    case 'secs':
    case 'sec':
    case 's':
      return n * s;
    case 'milliseconds':
    case 'millisecond':
    case 'msecs':
    case 'msec':
    case 'ms':
      return n;
    default:
      return undefined;
  }
}

/**
 * Short format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function fmtShort(ms) {
  var msAbs = Math.abs(ms);
  if (msAbs >= d) {
    return Math.round(ms / d) + 'd';
  }
  if (msAbs >= h) {
    return Math.round(ms / h) + 'h';
  }
  if (msAbs >= m) {
    return Math.round(ms / m) + 'm';
  }
  if (msAbs >= s) {
    return Math.round(ms / s) + 's';
  }
  return ms + 'ms';
}

/**
 * Long format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function fmtLong(ms) {
  var msAbs = Math.abs(ms);
  if (msAbs >= d) {
    return plural(ms, msAbs, d, 'day');
  }
  if (msAbs >= h) {
    return plural(ms, msAbs, h, 'hour');
  }
  if (msAbs >= m) {
    return plural(ms, msAbs, m, 'minute');
  }
  if (msAbs >= s) {
    return plural(ms, msAbs, s, 'second');
  }
  return ms + ' ms';
}

/**
 * Pluralization helper.
 */

function plural(ms, msAbs, n, name) {
  var isPlural = msAbs >= n * 1.5;
  return Math.round(ms / n) + ' ' + name + (isPlural ? 's' : '');
}


/***/ }),

/***/ 37320:
/***/ (function(module) {

"use strict";
/*
object-assign
(c) Sindre Sorhus
@license MIT
*/


/* eslint-disable no-unused-vars */
var getOwnPropertySymbols = Object.getOwnPropertySymbols;
var hasOwnProperty = Object.prototype.hasOwnProperty;
var propIsEnumerable = Object.prototype.propertyIsEnumerable;

function toObject(val) {
	if (val === null || val === undefined) {
		throw new TypeError('Object.assign cannot be called with null or undefined');
	}

	return Object(val);
}

function shouldUseNative() {
	try {
		if (!Object.assign) {
			return false;
		}

		// Detect buggy property enumeration order in older V8 versions.

		// https://bugs.chromium.org/p/v8/issues/detail?id=4118
		var test1 = new String('abc');  // eslint-disable-line no-new-wrappers
		test1[5] = 'de';
		if (Object.getOwnPropertyNames(test1)[0] === '5') {
			return false;
		}

		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
		var test2 = {};
		for (var i = 0; i < 10; i++) {
			test2['_' + String.fromCharCode(i)] = i;
		}
		var order2 = Object.getOwnPropertyNames(test2).map(function (n) {
			return test2[n];
		});
		if (order2.join('') !== '0123456789') {
			return false;
		}

		// https://bugs.chromium.org/p/v8/issues/detail?id=3056
		var test3 = {};
		'abcdefghijklmnopqrst'.split('').forEach(function (letter) {
			test3[letter] = letter;
		});
		if (Object.keys(Object.assign({}, test3)).join('') !==
				'abcdefghijklmnopqrst') {
			return false;
		}

		return true;
	} catch (err) {
		// We don't expect any of the above to throw, but better to be safe.
		return false;
	}
}

module.exports = shouldUseNative() ? Object.assign : function (target, source) {
	var from;
	var to = toObject(target);
	var symbols;

	for (var s = 1; s < arguments.length; s++) {
		from = Object(arguments[s]);

		for (var key in from) {
			if (hasOwnProperty.call(from, key)) {
				to[key] = from[key];
			}
		}

		if (getOwnPropertySymbols) {
			symbols = getOwnPropertySymbols(from);
			for (var i = 0; i < symbols.length; i++) {
				if (propIsEnumerable.call(from, symbols[i])) {
					to[symbols[i]] = from[symbols[i]];
				}
			}
		}
	}

	return to;
};


/***/ }),

/***/ 99500:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var hasMap = typeof Map === 'function' && Map.prototype;
var mapSizeDescriptor = Object.getOwnPropertyDescriptor && hasMap ? Object.getOwnPropertyDescriptor(Map.prototype, 'size') : null;
var mapSize = hasMap && mapSizeDescriptor && typeof mapSizeDescriptor.get === 'function' ? mapSizeDescriptor.get : null;
var mapForEach = hasMap && Map.prototype.forEach;
var hasSet = typeof Set === 'function' && Set.prototype;
var setSizeDescriptor = Object.getOwnPropertyDescriptor && hasSet ? Object.getOwnPropertyDescriptor(Set.prototype, 'size') : null;
var setSize = hasSet && setSizeDescriptor && typeof setSizeDescriptor.get === 'function' ? setSizeDescriptor.get : null;
var setForEach = hasSet && Set.prototype.forEach;
var hasWeakMap = typeof WeakMap === 'function' && WeakMap.prototype;
var weakMapHas = hasWeakMap ? WeakMap.prototype.has : null;
var hasWeakSet = typeof WeakSet === 'function' && WeakSet.prototype;
var weakSetHas = hasWeakSet ? WeakSet.prototype.has : null;
var hasWeakRef = typeof WeakRef === 'function' && WeakRef.prototype;
var weakRefDeref = hasWeakRef ? WeakRef.prototype.deref : null;
var booleanValueOf = Boolean.prototype.valueOf;
var objectToString = Object.prototype.toString;
var functionToString = Function.prototype.toString;
var match = String.prototype.match;
var bigIntValueOf = typeof BigInt === 'function' ? BigInt.prototype.valueOf : null;
var gOPS = Object.getOwnPropertySymbols;
var symToString = typeof Symbol === 'function' && typeof Symbol.iterator === 'symbol' ? Symbol.prototype.toString : null;
var hasShammedSymbols = typeof Symbol === 'function' && typeof Symbol.iterator === 'object';
var isEnumerable = Object.prototype.propertyIsEnumerable;

var gPO = (typeof Reflect === 'function' ? Reflect.getPrototypeOf : Object.getPrototypeOf) || (
    [].__proto__ === Array.prototype // eslint-disable-line no-proto
        ? function (O) {
            return O.__proto__; // eslint-disable-line no-proto
        }
        : null
);

var inspectCustom = (__webpack_require__(53260).custom);
var inspectSymbol = inspectCustom && isSymbol(inspectCustom) ? inspectCustom : null;
var toStringTag = typeof Symbol === 'function' && typeof Symbol.toStringTag !== 'undefined' ? Symbol.toStringTag : null;

module.exports = function inspect_(obj, options, depth, seen) {
    var opts = options || {};

    if (has(opts, 'quoteStyle') && (opts.quoteStyle !== 'single' && opts.quoteStyle !== 'double')) {
        throw new TypeError('option "quoteStyle" must be "single" or "double"');
    }
    if (
        has(opts, 'maxStringLength') && (typeof opts.maxStringLength === 'number'
            ? opts.maxStringLength < 0 && opts.maxStringLength !== Infinity
            : opts.maxStringLength !== null
        )
    ) {
        throw new TypeError('option "maxStringLength", if provided, must be a positive integer, Infinity, or `null`');
    }
    var customInspect = has(opts, 'customInspect') ? opts.customInspect : true;
    if (typeof customInspect !== 'boolean' && customInspect !== 'symbol') {
        throw new TypeError('option "customInspect", if provided, must be `true`, `false`, or `\'symbol\'`');
    }

    if (
        has(opts, 'indent')
        && opts.indent !== null
        && opts.indent !== '\t'
        && !(parseInt(opts.indent, 10) === opts.indent && opts.indent > 0)
    ) {
        throw new TypeError('options "indent" must be "\\t", an integer > 0, or `null`');
    }

    if (typeof obj === 'undefined') {
        return 'undefined';
    }
    if (obj === null) {
        return 'null';
    }
    if (typeof obj === 'boolean') {
        return obj ? 'true' : 'false';
    }

    if (typeof obj === 'string') {
        return inspectString(obj, opts);
    }
    if (typeof obj === 'number') {
        if (obj === 0) {
            return Infinity / obj > 0 ? '0' : '-0';
        }
        return String(obj);
    }
    if (typeof obj === 'bigint') {
        return String(obj) + 'n';
    }

    var maxDepth = typeof opts.depth === 'undefined' ? 5 : opts.depth;
    if (typeof depth === 'undefined') { depth = 0; }
    if (depth >= maxDepth && maxDepth > 0 && typeof obj === 'object') {
        return isArray(obj) ? '[Array]' : '[Object]';
    }

    var indent = getIndent(opts, depth);

    if (typeof seen === 'undefined') {
        seen = [];
    } else if (indexOf(seen, obj) >= 0) {
        return '[Circular]';
    }

    function inspect(value, from, noIndent) {
        if (from) {
            seen = seen.slice();
            seen.push(from);
        }
        if (noIndent) {
            var newOpts = {
                depth: opts.depth
            };
            if (has(opts, 'quoteStyle')) {
                newOpts.quoteStyle = opts.quoteStyle;
            }
            return inspect_(value, newOpts, depth + 1, seen);
        }
        return inspect_(value, opts, depth + 1, seen);
    }

    if (typeof obj === 'function') {
        var name = nameOf(obj);
        var keys = arrObjKeys(obj, inspect);
        return '[Function' + (name ? ': ' + name : ' (anonymous)') + ']' + (keys.length > 0 ? ' { ' + keys.join(', ') + ' }' : '');
    }
    if (isSymbol(obj)) {
        var symString = hasShammedSymbols ? String(obj).replace(/^(Symbol\(.*\))_[^)]*$/, '$1') : symToString.call(obj);
        return typeof obj === 'object' && !hasShammedSymbols ? markBoxed(symString) : symString;
    }
    if (isElement(obj)) {
        var s = '<' + String(obj.nodeName).toLowerCase();
        var attrs = obj.attributes || [];
        for (var i = 0; i < attrs.length; i++) {
            s += ' ' + attrs[i].name + '=' + wrapQuotes(quote(attrs[i].value), 'double', opts);
        }
        s += '>';
        if (obj.childNodes && obj.childNodes.length) { s += '...'; }
        s += '</' + String(obj.nodeName).toLowerCase() + '>';
        return s;
    }
    if (isArray(obj)) {
        if (obj.length === 0) { return '[]'; }
        var xs = arrObjKeys(obj, inspect);
        if (indent && !singleLineValues(xs)) {
            return '[' + indentedJoin(xs, indent) + ']';
        }
        return '[ ' + xs.join(', ') + ' ]';
    }
    if (isError(obj)) {
        var parts = arrObjKeys(obj, inspect);
        if (parts.length === 0) { return '[' + String(obj) + ']'; }
        return '{ [' + String(obj) + '] ' + parts.join(', ') + ' }';
    }
    if (typeof obj === 'object' && customInspect) {
        if (inspectSymbol && typeof obj[inspectSymbol] === 'function') {
            return obj[inspectSymbol]();
        } else if (customInspect !== 'symbol' && typeof obj.inspect === 'function') {
            return obj.inspect();
        }
    }
    if (isMap(obj)) {
        var mapParts = [];
        mapForEach.call(obj, function (value, key) {
            mapParts.push(inspect(key, obj, true) + ' => ' + inspect(value, obj));
        });
        return collectionOf('Map', mapSize.call(obj), mapParts, indent);
    }
    if (isSet(obj)) {
        var setParts = [];
        setForEach.call(obj, function (value) {
            setParts.push(inspect(value, obj));
        });
        return collectionOf('Set', setSize.call(obj), setParts, indent);
    }
    if (isWeakMap(obj)) {
        return weakCollectionOf('WeakMap');
    }
    if (isWeakSet(obj)) {
        return weakCollectionOf('WeakSet');
    }
    if (isWeakRef(obj)) {
        return weakCollectionOf('WeakRef');
    }
    if (isNumber(obj)) {
        return markBoxed(inspect(Number(obj)));
    }
    if (isBigInt(obj)) {
        return markBoxed(inspect(bigIntValueOf.call(obj)));
    }
    if (isBoolean(obj)) {
        return markBoxed(booleanValueOf.call(obj));
    }
    if (isString(obj)) {
        return markBoxed(inspect(String(obj)));
    }
    if (!isDate(obj) && !isRegExp(obj)) {
        var ys = arrObjKeys(obj, inspect);
        var isPlainObject = gPO ? gPO(obj) === Object.prototype : obj instanceof Object || obj.constructor === Object;
        var protoTag = obj instanceof Object ? '' : 'null prototype';
        var stringTag = !isPlainObject && toStringTag && Object(obj) === obj && toStringTag in obj ? toStr(obj).slice(8, -1) : protoTag ? 'Object' : '';
        var constructorTag = isPlainObject || typeof obj.constructor !== 'function' ? '' : obj.constructor.name ? obj.constructor.name + ' ' : '';
        var tag = constructorTag + (stringTag || protoTag ? '[' + [].concat(stringTag || [], protoTag || []).join(': ') + '] ' : '');
        if (ys.length === 0) { return tag + '{}'; }
        if (indent) {
            return tag + '{' + indentedJoin(ys, indent) + '}';
        }
        return tag + '{ ' + ys.join(', ') + ' }';
    }
    return String(obj);
};

function wrapQuotes(s, defaultStyle, opts) {
    var quoteChar = (opts.quoteStyle || defaultStyle) === 'double' ? '"' : "'";
    return quoteChar + s + quoteChar;
}

function quote(s) {
    return String(s).replace(/"/g, '&quot;');
}

function isArray(obj) { return toStr(obj) === '[object Array]' && (!toStringTag || !(typeof obj === 'object' && toStringTag in obj)); }
function isDate(obj) { return toStr(obj) === '[object Date]' && (!toStringTag || !(typeof obj === 'object' && toStringTag in obj)); }
function isRegExp(obj) { return toStr(obj) === '[object RegExp]' && (!toStringTag || !(typeof obj === 'object' && toStringTag in obj)); }
function isError(obj) { return toStr(obj) === '[object Error]' && (!toStringTag || !(typeof obj === 'object' && toStringTag in obj)); }
function isString(obj) { return toStr(obj) === '[object String]' && (!toStringTag || !(typeof obj === 'object' && toStringTag in obj)); }
function isNumber(obj) { return toStr(obj) === '[object Number]' && (!toStringTag || !(typeof obj === 'object' && toStringTag in obj)); }
function isBoolean(obj) { return toStr(obj) === '[object Boolean]' && (!toStringTag || !(typeof obj === 'object' && toStringTag in obj)); }

// Symbol and BigInt do have Symbol.toStringTag by spec, so that can't be used to eliminate false positives
function isSymbol(obj) {
    if (hasShammedSymbols) {
        return obj && typeof obj === 'object' && obj instanceof Symbol;
    }
    if (typeof obj === 'symbol') {
        return true;
    }
    if (!obj || typeof obj !== 'object' || !symToString) {
        return false;
    }
    try {
        symToString.call(obj);
        return true;
    } catch (e) {}
    return false;
}

function isBigInt(obj) {
    if (!obj || typeof obj !== 'object' || !bigIntValueOf) {
        return false;
    }
    try {
        bigIntValueOf.call(obj);
        return true;
    } catch (e) {}
    return false;
}

var hasOwn = Object.prototype.hasOwnProperty || function (key) { return key in this; };
function has(obj, key) {
    return hasOwn.call(obj, key);
}

function toStr(obj) {
    return objectToString.call(obj);
}

function nameOf(f) {
    if (f.name) { return f.name; }
    var m = match.call(functionToString.call(f), /^function\s*([\w$]+)/);
    if (m) { return m[1]; }
    return null;
}

function indexOf(xs, x) {
    if (xs.indexOf) { return xs.indexOf(x); }
    for (var i = 0, l = xs.length; i < l; i++) {
        if (xs[i] === x) { return i; }
    }
    return -1;
}

function isMap(x) {
    if (!mapSize || !x || typeof x !== 'object') {
        return false;
    }
    try {
        mapSize.call(x);
        try {
            setSize.call(x);
        } catch (s) {
            return true;
        }
        return x instanceof Map; // core-js workaround, pre-v2.5.0
    } catch (e) {}
    return false;
}

function isWeakMap(x) {
    if (!weakMapHas || !x || typeof x !== 'object') {
        return false;
    }
    try {
        weakMapHas.call(x, weakMapHas);
        try {
            weakSetHas.call(x, weakSetHas);
        } catch (s) {
            return true;
        }
        return x instanceof WeakMap; // core-js workaround, pre-v2.5.0
    } catch (e) {}
    return false;
}

function isWeakRef(x) {
    if (!weakRefDeref || !x || typeof x !== 'object') {
        return false;
    }
    try {
        weakRefDeref.call(x);
        return true;
    } catch (e) {}
    return false;
}

function isSet(x) {
    if (!setSize || !x || typeof x !== 'object') {
        return false;
    }
    try {
        setSize.call(x);
        try {
            mapSize.call(x);
        } catch (m) {
            return true;
        }
        return x instanceof Set; // core-js workaround, pre-v2.5.0
    } catch (e) {}
    return false;
}

function isWeakSet(x) {
    if (!weakSetHas || !x || typeof x !== 'object') {
        return false;
    }
    try {
        weakSetHas.call(x, weakSetHas);
        try {
            weakMapHas.call(x, weakMapHas);
        } catch (s) {
            return true;
        }
        return x instanceof WeakSet; // core-js workaround, pre-v2.5.0
    } catch (e) {}
    return false;
}

function isElement(x) {
    if (!x || typeof x !== 'object') { return false; }
    if (typeof HTMLElement !== 'undefined' && x instanceof HTMLElement) {
        return true;
    }
    return typeof x.nodeName === 'string' && typeof x.getAttribute === 'function';
}

function inspectString(str, opts) {
    if (str.length > opts.maxStringLength) {
        var remaining = str.length - opts.maxStringLength;
        var trailer = '... ' + remaining + ' more character' + (remaining > 1 ? 's' : '');
        return inspectString(str.slice(0, opts.maxStringLength), opts) + trailer;
    }
    // eslint-disable-next-line no-control-regex
    var s = str.replace(/(['\\])/g, '\\$1').replace(/[\x00-\x1f]/g, lowbyte);
    return wrapQuotes(s, 'single', opts);
}

function lowbyte(c) {
    var n = c.charCodeAt(0);
    var x = {
        8: 'b',
        9: 't',
        10: 'n',
        12: 'f',
        13: 'r'
    }[n];
    if (x) { return '\\' + x; }
    return '\\x' + (n < 0x10 ? '0' : '') + n.toString(16).toUpperCase();
}

function markBoxed(str) {
    return 'Object(' + str + ')';
}

function weakCollectionOf(type) {
    return type + ' { ? }';
}

function collectionOf(type, size, entries, indent) {
    var joinedEntries = indent ? indentedJoin(entries, indent) : entries.join(', ');
    return type + ' (' + size + ') {' + joinedEntries + '}';
}

function singleLineValues(xs) {
    for (var i = 0; i < xs.length; i++) {
        if (indexOf(xs[i], '\n') >= 0) {
            return false;
        }
    }
    return true;
}

function getIndent(opts, depth) {
    var baseIndent;
    if (opts.indent === '\t') {
        baseIndent = '\t';
    } else if (typeof opts.indent === 'number' && opts.indent > 0) {
        baseIndent = Array(opts.indent + 1).join(' ');
    } else {
        return null;
    }
    return {
        base: baseIndent,
        prev: Array(depth + 1).join(baseIndent)
    };
}

function indentedJoin(xs, indent) {
    if (xs.length === 0) { return ''; }
    var lineJoiner = '\n' + indent.prev + indent.base;
    return lineJoiner + xs.join(',' + lineJoiner) + '\n' + indent.prev;
}

function arrObjKeys(obj, inspect) {
    var isArr = isArray(obj);
    var xs = [];
    if (isArr) {
        xs.length = obj.length;
        for (var i = 0; i < obj.length; i++) {
            xs[i] = has(obj, i) ? inspect(obj[i], obj) : '';
        }
    }
    var syms = typeof gOPS === 'function' ? gOPS(obj) : [];
    var symMap;
    if (hasShammedSymbols) {
        symMap = {};
        for (var k = 0; k < syms.length; k++) {
            symMap['$' + syms[k]] = syms[k];
        }
    }

    for (var key in obj) { // eslint-disable-line no-restricted-syntax
        if (!has(obj, key)) { continue; } // eslint-disable-line no-restricted-syntax, no-continue
        if (isArr && String(Number(key)) === key && key < obj.length) { continue; } // eslint-disable-line no-restricted-syntax, no-continue
        if (hasShammedSymbols && symMap['$' + key] instanceof Symbol) {
            // this is to prevent shammed Symbols, which are stored as strings, from being included in the string key section
            continue; // eslint-disable-line no-restricted-syntax, no-continue
        } else if ((/[^\w$]/).test(key)) {
            xs.push(inspect(key, obj) + ': ' + inspect(obj[key], obj));
        } else {
            xs.push(key + ': ' + inspect(obj[key], obj));
        }
    }
    if (typeof gOPS === 'function') {
        for (var j = 0; j < syms.length; j++) {
            if (isEnumerable.call(obj, syms[j])) {
                xs.push('[' + inspect(syms[j]) + ']: ' + inspect(obj[syms[j]], obj));
            }
        }
    }
    return xs;
}


/***/ }),

/***/ 78319:
/***/ (function(module) {

(function (global, factory) {
	 true ? module.exports = factory() :
	0;
}(this, (function () { 'use strict';

var isarray = Array.isArray || function (arr) {
  return Object.prototype.toString.call(arr) == '[object Array]';
};

/**
 * Expose `pathToRegexp`.
 */
var pathToRegexp_1 = pathToRegexp;
var parse_1 = parse;
var compile_1 = compile;
var tokensToFunction_1 = tokensToFunction;
var tokensToRegExp_1 = tokensToRegExp;

/**
 * The main path matching regexp utility.
 *
 * @type {RegExp}
 */
var PATH_REGEXP = new RegExp([
  // Match escaped characters that would otherwise appear in future matches.
  // This allows the user to escape special characters that won't transform.
  '(\\\\.)',
  // Match Express-style parameters and un-named parameters with a prefix
  // and optional suffixes. Matches appear as:
  //
  // "/:test(\\d+)?" => ["/", "test", "\d+", undefined, "?", undefined]
  // "/route(\\d+)"  => [undefined, undefined, undefined, "\d+", undefined, undefined]
  // "/*"            => ["/", undefined, undefined, undefined, undefined, "*"]
  '([\\/.])?(?:(?:\\:(\\w+)(?:\\(((?:\\\\.|[^()])+)\\))?|\\(((?:\\\\.|[^()])+)\\))([+*?])?|(\\*))'
].join('|'), 'g');

/**
 * Parse a string for the raw tokens.
 *
 * @param  {String} str
 * @return {Array}
 */
function parse (str) {
  var tokens = [];
  var key = 0;
  var index = 0;
  var path = '';
  var res;

  while ((res = PATH_REGEXP.exec(str)) != null) {
    var m = res[0];
    var escaped = res[1];
    var offset = res.index;
    path += str.slice(index, offset);
    index = offset + m.length;

    // Ignore already escaped sequences.
    if (escaped) {
      path += escaped[1];
      continue
    }

    // Push the current path onto the tokens.
    if (path) {
      tokens.push(path);
      path = '';
    }

    var prefix = res[2];
    var name = res[3];
    var capture = res[4];
    var group = res[5];
    var suffix = res[6];
    var asterisk = res[7];

    var repeat = suffix === '+' || suffix === '*';
    var optional = suffix === '?' || suffix === '*';
    var delimiter = prefix || '/';
    var pattern = capture || group || (asterisk ? '.*' : '[^' + delimiter + ']+?');

    tokens.push({
      name: name || key++,
      prefix: prefix || '',
      delimiter: delimiter,
      optional: optional,
      repeat: repeat,
      pattern: escapeGroup(pattern)
    });
  }

  // Match any characters still remaining.
  if (index < str.length) {
    path += str.substr(index);
  }

  // If the path exists, push it onto the end.
  if (path) {
    tokens.push(path);
  }

  return tokens
}

/**
 * Compile a string to a template function for the path.
 *
 * @param  {String}   str
 * @return {Function}
 */
function compile (str) {
  return tokensToFunction(parse(str))
}

/**
 * Expose a method for transforming tokens into the path function.
 */
function tokensToFunction (tokens) {
  // Compile all the tokens into regexps.
  var matches = new Array(tokens.length);

  // Compile all the patterns before compilation.
  for (var i = 0; i < tokens.length; i++) {
    if (typeof tokens[i] === 'object') {
      matches[i] = new RegExp('^' + tokens[i].pattern + '$');
    }
  }

  return function (obj) {
    var path = '';
    var data = obj || {};

    for (var i = 0; i < tokens.length; i++) {
      var token = tokens[i];

      if (typeof token === 'string') {
        path += token;

        continue
      }

      var value = data[token.name];
      var segment;

      if (value == null) {
        if (token.optional) {
          continue
        } else {
          throw new TypeError('Expected "' + token.name + '" to be defined')
        }
      }

      if (isarray(value)) {
        if (!token.repeat) {
          throw new TypeError('Expected "' + token.name + '" to not repeat, but received "' + value + '"')
        }

        if (value.length === 0) {
          if (token.optional) {
            continue
          } else {
            throw new TypeError('Expected "' + token.name + '" to not be empty')
          }
        }

        for (var j = 0; j < value.length; j++) {
          segment = encodeURIComponent(value[j]);

          if (!matches[i].test(segment)) {
            throw new TypeError('Expected all "' + token.name + '" to match "' + token.pattern + '", but received "' + segment + '"')
          }

          path += (j === 0 ? token.prefix : token.delimiter) + segment;
        }

        continue
      }

      segment = encodeURIComponent(value);

      if (!matches[i].test(segment)) {
        throw new TypeError('Expected "' + token.name + '" to match "' + token.pattern + '", but received "' + segment + '"')
      }

      path += token.prefix + segment;
    }

    return path
  }
}

/**
 * Escape a regular expression string.
 *
 * @param  {String} str
 * @return {String}
 */
function escapeString (str) {
  return str.replace(/([.+*?=^!:${}()[\]|\/])/g, '\\$1')
}

/**
 * Escape the capturing group by escaping special characters and meaning.
 *
 * @param  {String} group
 * @return {String}
 */
function escapeGroup (group) {
  return group.replace(/([=!:$\/()])/g, '\\$1')
}

/**
 * Attach the keys as a property of the regexp.
 *
 * @param  {RegExp} re
 * @param  {Array}  keys
 * @return {RegExp}
 */
function attachKeys (re, keys) {
  re.keys = keys;
  return re
}

/**
 * Get the flags for a regexp from the options.
 *
 * @param  {Object} options
 * @return {String}
 */
function flags (options) {
  return options.sensitive ? '' : 'i'
}

/**
 * Pull out keys from a regexp.
 *
 * @param  {RegExp} path
 * @param  {Array}  keys
 * @return {RegExp}
 */
function regexpToRegexp (path, keys) {
  // Use a negative lookahead to match only capturing groups.
  var groups = path.source.match(/\((?!\?)/g);

  if (groups) {
    for (var i = 0; i < groups.length; i++) {
      keys.push({
        name: i,
        prefix: null,
        delimiter: null,
        optional: false,
        repeat: false,
        pattern: null
      });
    }
  }

  return attachKeys(path, keys)
}

/**
 * Transform an array into a regexp.
 *
 * @param  {Array}  path
 * @param  {Array}  keys
 * @param  {Object} options
 * @return {RegExp}
 */
function arrayToRegexp (path, keys, options) {
  var parts = [];

  for (var i = 0; i < path.length; i++) {
    parts.push(pathToRegexp(path[i], keys, options).source);
  }

  var regexp = new RegExp('(?:' + parts.join('|') + ')', flags(options));

  return attachKeys(regexp, keys)
}

/**
 * Create a path regexp from string input.
 *
 * @param  {String} path
 * @param  {Array}  keys
 * @param  {Object} options
 * @return {RegExp}
 */
function stringToRegexp (path, keys, options) {
  var tokens = parse(path);
  var re = tokensToRegExp(tokens, options);

  // Attach keys back to the regexp.
  for (var i = 0; i < tokens.length; i++) {
    if (typeof tokens[i] !== 'string') {
      keys.push(tokens[i]);
    }
  }

  return attachKeys(re, keys)
}

/**
 * Expose a function for taking tokens and returning a RegExp.
 *
 * @param  {Array}  tokens
 * @param  {Array}  keys
 * @param  {Object} options
 * @return {RegExp}
 */
function tokensToRegExp (tokens, options) {
  options = options || {};

  var strict = options.strict;
  var end = options.end !== false;
  var route = '';
  var lastToken = tokens[tokens.length - 1];
  var endsWithSlash = typeof lastToken === 'string' && /\/$/.test(lastToken);

  // Iterate over the tokens and create our regexp string.
  for (var i = 0; i < tokens.length; i++) {
    var token = tokens[i];

    if (typeof token === 'string') {
      route += escapeString(token);
    } else {
      var prefix = escapeString(token.prefix);
      var capture = token.pattern;

      if (token.repeat) {
        capture += '(?:' + prefix + capture + ')*';
      }

      if (token.optional) {
        if (prefix) {
          capture = '(?:' + prefix + '(' + capture + '))?';
        } else {
          capture = '(' + capture + ')?';
        }
      } else {
        capture = prefix + '(' + capture + ')';
      }

      route += capture;
    }
  }

  // In non-strict mode we allow a slash at the end of match. If the path to
  // match already ends with a slash, we remove it for consistency. The slash
  // is valid at the end of a path match, not in the middle. This is important
  // in non-ending mode, where "/test/" shouldn't match "/test//route".
  if (!strict) {
    route = (endsWithSlash ? route.slice(0, -2) : route) + '(?:\\/(?=$))?';
  }

  if (end) {
    route += '$';
  } else {
    // In non-ending mode, we need the capturing groups to match as much as
    // possible by using a positive lookahead to the end or next path segment.
    route += strict && endsWithSlash ? '' : '(?=\\/|$)';
  }

  return new RegExp('^' + route, flags(options))
}

/**
 * Normalize the given path string, returning a regular expression.
 *
 * An empty array can be passed in for the keys, which will hold the
 * placeholder key descriptions. For example, using `/user/:id`, `keys` will
 * contain `[{ name: 'id', delimiter: '/', optional: false, repeat: false }]`.
 *
 * @param  {(String|RegExp|Array)} path
 * @param  {Array}                 [keys]
 * @param  {Object}                [options]
 * @return {RegExp}
 */
function pathToRegexp (path, keys, options) {
  keys = keys || [];

  if (!isarray(keys)) {
    options = keys;
    keys = [];
  } else if (!options) {
    options = {};
  }

  if (path instanceof RegExp) {
    return regexpToRegexp(path, keys, options)
  }

  if (isarray(path)) {
    return arrayToRegexp(path, keys, options)
  }

  return stringToRegexp(path, keys, options)
}

pathToRegexp_1.parse = parse_1;
pathToRegexp_1.compile = compile_1;
pathToRegexp_1.tokensToFunction = tokensToFunction_1;
pathToRegexp_1.tokensToRegExp = tokensToRegExp_1;

/**
   * Module dependencies.
   */



  /**
   * Short-cuts for global-object checks
   */

  var hasDocument = ('undefined' !== typeof document);
  var hasWindow = ('undefined' !== typeof window);
  var hasHistory = ('undefined' !== typeof history);
  var hasProcess = typeof process !== 'undefined';

  /**
   * Detect click event
   */
  var clickEvent = hasDocument && document.ontouchstart ? 'touchstart' : 'click';

  /**
   * To work properly with the URL
   * history.location generated polyfill in https://github.com/devote/HTML5-History-API
   */

  var isLocation = hasWindow && !!(window.history.location || window.location);

  /**
   * The page instance
   * @api private
   */
  function Page() {
    // public things
    this.callbacks = [];
    this.exits = [];
    this.current = '';
    this.len = 0;

    // private things
    this._decodeURLComponents = true;
    this._base = '';
    this._strict = false;
    this._running = false;
    this._hashbang = false;

    // bound functions
    this.clickHandler = this.clickHandler.bind(this);
    this._onpopstate = this._onpopstate.bind(this);
  }

  /**
   * Configure the instance of page. This can be called multiple times.
   *
   * @param {Object} options
   * @api public
   */

  Page.prototype.configure = function(options) {
    var opts = options || {};

    this._window = opts.window || (hasWindow && window);
    this._decodeURLComponents = opts.decodeURLComponents !== false;
    this._popstate = opts.popstate !== false && hasWindow;
    this._click = opts.click !== false && hasDocument;
    this._hashbang = !!opts.hashbang;

    var _window = this._window;
    if(this._popstate) {
      _window.addEventListener('popstate', this._onpopstate, false);
    } else if(hasWindow) {
      _window.removeEventListener('popstate', this._onpopstate, false);
    }

    if (this._click) {
      _window.document.addEventListener(clickEvent, this.clickHandler, false);
    } else if(hasDocument) {
      _window.document.removeEventListener(clickEvent, this.clickHandler, false);
    }

    if(this._hashbang && hasWindow && !hasHistory) {
      _window.addEventListener('hashchange', this._onpopstate, false);
    } else if(hasWindow) {
      _window.removeEventListener('hashchange', this._onpopstate, false);
    }
  };

  /**
   * Get or set basepath to `path`.
   *
   * @param {string} path
   * @api public
   */

  Page.prototype.base = function(path) {
    if (0 === arguments.length) return this._base;
    this._base = path;
  };

  /**
   * Gets the `base`, which depends on whether we are using History or
   * hashbang routing.

   * @api private
   */
  Page.prototype._getBase = function() {
    var base = this._base;
    if(!!base) return base;
    var loc = hasWindow && this._window && this._window.location;

    if(hasWindow && this._hashbang && loc && loc.protocol === 'file:') {
      base = loc.pathname;
    }

    return base;
  };

  /**
   * Get or set strict path matching to `enable`
   *
   * @param {boolean} enable
   * @api public
   */

  Page.prototype.strict = function(enable) {
    if (0 === arguments.length) return this._strict;
    this._strict = enable;
  };


  /**
   * Bind with the given `options`.
   *
   * Options:
   *
   *    - `click` bind to click events [true]
   *    - `popstate` bind to popstate [true]
   *    - `dispatch` perform initial dispatch [true]
   *
   * @param {Object} options
   * @api public
   */

  Page.prototype.start = function(options) {
    var opts = options || {};
    this.configure(opts);

    if (false === opts.dispatch) return;
    this._running = true;

    var url;
    if(isLocation) {
      var window = this._window;
      var loc = window.location;

      if(this._hashbang && ~loc.hash.indexOf('#!')) {
        url = loc.hash.substr(2) + loc.search;
      } else if (this._hashbang) {
        url = loc.search + loc.hash;
      } else {
        url = loc.pathname + loc.search + loc.hash;
      }
    }

    this.replace(url, null, true, opts.dispatch);
  };

  /**
   * Unbind click and popstate event handlers.
   *
   * @api public
   */

  Page.prototype.stop = function() {
    if (!this._running) return;
    this.current = '';
    this.len = 0;
    this._running = false;

    var window = this._window;
    this._click && window.document.removeEventListener(clickEvent, this.clickHandler, false);
    hasWindow && window.removeEventListener('popstate', this._onpopstate, false);
    hasWindow && window.removeEventListener('hashchange', this._onpopstate, false);
  };

  /**
   * Show `path` with optional `state` object.
   *
   * @param {string} path
   * @param {Object=} state
   * @param {boolean=} dispatch
   * @param {boolean=} push
   * @return {!Context}
   * @api public
   */

  Page.prototype.show = function(path, state, dispatch, push) {
    var ctx = new Context(path, state, this),
      prev = this.prevContext;
    this.prevContext = ctx;
    this.current = ctx.path;
    if (false !== dispatch) this.dispatch(ctx, prev);
    if (false !== ctx.handled && false !== push) ctx.pushState();
    return ctx;
  };

  /**
   * Goes back in the history
   * Back should always let the current route push state and then go back.
   *
   * @param {string} path - fallback path to go back if no more history exists, if undefined defaults to page.base
   * @param {Object=} state
   * @api public
   */

  Page.prototype.back = function(path, state) {
    var page = this;
    if (this.len > 0) {
      var window = this._window;
      // this may need more testing to see if all browsers
      // wait for the next tick to go back in history
      hasHistory && window.history.back();
      this.len--;
    } else if (path) {
      setTimeout(function() {
        page.show(path, state);
      });
    } else {
      setTimeout(function() {
        page.show(page._getBase(), state);
      });
    }
  };

  /**
   * Register route to redirect from one path to other
   * or just redirect to another route
   *
   * @param {string} from - if param 'to' is undefined redirects to 'from'
   * @param {string=} to
   * @api public
   */
  Page.prototype.redirect = function(from, to) {
    var inst = this;

    // Define route from a path to another
    if ('string' === typeof from && 'string' === typeof to) {
      page.call(this, from, function(e) {
        setTimeout(function() {
          inst.replace(/** @type {!string} */ (to));
        }, 0);
      });
    }

    // Wait for the push state and replace it with another
    if ('string' === typeof from && 'undefined' === typeof to) {
      setTimeout(function() {
        inst.replace(from);
      }, 0);
    }
  };

  /**
   * Replace `path` with optional `state` object.
   *
   * @param {string} path
   * @param {Object=} state
   * @param {boolean=} init
   * @param {boolean=} dispatch
   * @return {!Context}
   * @api public
   */


  Page.prototype.replace = function(path, state, init, dispatch) {
    var ctx = new Context(path, state, this),
      prev = this.prevContext;
    this.prevContext = ctx;
    this.current = ctx.path;
    ctx.init = init;
    ctx.save(); // save before dispatching, which may redirect
    if (false !== dispatch) this.dispatch(ctx, prev);
    return ctx;
  };

  /**
   * Dispatch the given `ctx`.
   *
   * @param {Context} ctx
   * @api private
   */

  Page.prototype.dispatch = function(ctx, prev) {
    var i = 0, j = 0, page = this;

    function nextExit() {
      var fn = page.exits[j++];
      if (!fn) return nextEnter();
      fn(prev, nextExit);
    }

    function nextEnter() {
      var fn = page.callbacks[i++];

      if (ctx.path !== page.current) {
        ctx.handled = false;
        return;
      }
      if (!fn) return unhandled.call(page, ctx);
      fn(ctx, nextEnter);
    }

    if (prev) {
      nextExit();
    } else {
      nextEnter();
    }
  };

  /**
   * Register an exit route on `path` with
   * callback `fn()`, which will be called
   * on the previous context when a new
   * page is visited.
   */
  Page.prototype.exit = function(path, fn) {
    if (typeof path === 'function') {
      return this.exit('*', path);
    }

    var route = new Route(path, null, this);
    for (var i = 1; i < arguments.length; ++i) {
      this.exits.push(route.middleware(arguments[i]));
    }
  };

  /**
   * Handle "click" events.
   */

  /* jshint +W054 */
  Page.prototype.clickHandler = function(e) {
    if (1 !== this._which(e)) return;

    if (e.metaKey || e.ctrlKey || e.shiftKey) return;
    if (e.defaultPrevented) return;

    // ensure link
    // use shadow dom when available if not, fall back to composedPath()
    // for browsers that only have shady
    var el = e.target;
    var eventPath = e.path || (e.composedPath ? e.composedPath() : null);

    if(eventPath) {
      for (var i = 0; i < eventPath.length; i++) {
        if (!eventPath[i].nodeName) continue;
        if (eventPath[i].nodeName.toUpperCase() !== 'A') continue;
        if (!eventPath[i].href) continue;

        el = eventPath[i];
        break;
      }
    }

    // continue ensure link
    // el.nodeName for svg links are 'a' instead of 'A'
    while (el && 'A' !== el.nodeName.toUpperCase()) el = el.parentNode;
    if (!el || 'A' !== el.nodeName.toUpperCase()) return;

    // check if link is inside an svg
    // in this case, both href and target are always inside an object
    var svg = (typeof el.href === 'object') && el.href.constructor.name === 'SVGAnimatedString';

    // Ignore if tag has
    // 1. "download" attribute
    // 2. rel="external" attribute
    if (el.hasAttribute('download') || el.getAttribute('rel') === 'external') return;

    // ensure non-hash for the same path
    var link = el.getAttribute('href');
    if(!this._hashbang && this._samePath(el) && (el.hash || '#' === link)) return;

    // Check for mailto: in the href
    if (link && link.indexOf('mailto:') > -1) return;

    // check target
    // svg target is an object and its desired value is in .baseVal property
    if (svg ? el.target.baseVal : el.target) return;

    // x-origin
    // note: svg links that are not relative don't call click events (and skip page.js)
    // consequently, all svg links tested inside page.js are relative and in the same origin
    if (!svg && !this.sameOrigin(el.href)) return;

    // rebuild path
    // There aren't .pathname and .search properties in svg links, so we use href
    // Also, svg href is an object and its desired value is in .baseVal property
    var path = svg ? el.href.baseVal : (el.pathname + el.search + (el.hash || ''));

    path = path[0] !== '/' ? '/' + path : path;

    // strip leading "/[drive letter]:" on NW.js on Windows
    if (hasProcess && path.match(/^\/[a-zA-Z]:\//)) {
      path = path.replace(/^\/[a-zA-Z]:\//, '/');
    }

    // same page
    var orig = path;
    var pageBase = this._getBase();

    if (path.indexOf(pageBase) === 0) {
      path = path.substr(pageBase.length);
    }

    if (this._hashbang) path = path.replace('#!', '');

    if (pageBase && orig === path && (!isLocation || this._window.location.protocol !== 'file:')) {
      return;
    }

    e.preventDefault();
    this.show(orig);
  };

  /**
   * Handle "populate" events.
   * @api private
   */

  Page.prototype._onpopstate = (function () {
    var loaded = false;
    if ( ! hasWindow ) {
      return function () {};
    }
    if (hasDocument && document.readyState === 'complete') {
      loaded = true;
    } else {
      window.addEventListener('load', function() {
        setTimeout(function() {
          loaded = true;
        }, 0);
      });
    }
    return function onpopstate(e) {
      if (!loaded) return;
      var page = this;
      if (e.state) {
        var path = e.state.path;
        page.replace(path, e.state);
      } else if (isLocation) {
        var loc = page._window.location;
        page.show(loc.pathname + loc.search + loc.hash, undefined, undefined, false);
      }
    };
  })();

  /**
   * Event button.
   */
  Page.prototype._which = function(e) {
    e = e || (hasWindow && this._window.event);
    return null == e.which ? e.button : e.which;
  };

  /**
   * Convert to a URL object
   * @api private
   */
  Page.prototype._toURL = function(href) {
    var window = this._window;
    if(typeof URL === 'function' && isLocation) {
      return new URL(href, window.location.toString());
    } else if (hasDocument) {
      var anc = window.document.createElement('a');
      anc.href = href;
      return anc;
    }
  };

  /**
   * Check if `href` is the same origin.
   * @param {string} href
   * @api public
   */

  Page.prototype.sameOrigin = function(href) {
    if(!href || !isLocation) return false;

    var url = this._toURL(href);
    var window = this._window;

    var loc = window.location;

    /*
       when the port is the default http port 80, internet explorer 11
       returns an empty string for loc.port, so we need to compare loc.port
       with an empty string if url.port is the default port 80.
    */
    return loc.protocol === url.protocol &&
      loc.hostname === url.hostname &&
      (loc.port === url.port || loc.port === '' && url.port === 80);
  };

  /**
   * @api private
   */
  Page.prototype._samePath = function(url) {
    if(!isLocation) return false;
    var window = this._window;
    var loc = window.location;
    return url.pathname === loc.pathname &&
      url.search === loc.search;
  };

  /**
   * Remove URL encoding from the given `str`.
   * Accommodates whitespace in both x-www-form-urlencoded
   * and regular percent-encoded form.
   *
   * @param {string} val - URL component to decode
   * @api private
   */
  Page.prototype._decodeURLEncodedURIComponent = function(val) {
    if (typeof val !== 'string') { return val; }
    return this._decodeURLComponents ? decodeURIComponent(val.replace(/\+/g, ' ')) : val;
  };

  /**
   * Create a new `page` instance and function
   */
  function createPage() {
    var pageInstance = new Page();

    function pageFn(/* args */) {
      return page.apply(pageInstance, arguments);
    }

    // Copy all of the things over. In 2.0 maybe we use setPrototypeOf
    pageFn.callbacks = pageInstance.callbacks;
    pageFn.exits = pageInstance.exits;
    pageFn.base = pageInstance.base.bind(pageInstance);
    pageFn.strict = pageInstance.strict.bind(pageInstance);
    pageFn.start = pageInstance.start.bind(pageInstance);
    pageFn.stop = pageInstance.stop.bind(pageInstance);
    pageFn.show = pageInstance.show.bind(pageInstance);
    pageFn.back = pageInstance.back.bind(pageInstance);
    pageFn.redirect = pageInstance.redirect.bind(pageInstance);
    pageFn.replace = pageInstance.replace.bind(pageInstance);
    pageFn.dispatch = pageInstance.dispatch.bind(pageInstance);
    pageFn.exit = pageInstance.exit.bind(pageInstance);
    pageFn.configure = pageInstance.configure.bind(pageInstance);
    pageFn.sameOrigin = pageInstance.sameOrigin.bind(pageInstance);
    pageFn.clickHandler = pageInstance.clickHandler.bind(pageInstance);

    pageFn.create = createPage;

    Object.defineProperty(pageFn, 'len', {
      get: function(){
        return pageInstance.len;
      },
      set: function(val) {
        pageInstance.len = val;
      }
    });

    Object.defineProperty(pageFn, 'current', {
      get: function(){
        return pageInstance.current;
      },
      set: function(val) {
        pageInstance.current = val;
      }
    });

    // In 2.0 these can be named exports
    pageFn.Context = Context;
    pageFn.Route = Route;

    return pageFn;
  }

  /**
   * Register `path` with callback `fn()`,
   * or route `path`, or redirection,
   * or `page.start()`.
   *
   *   page(fn);
   *   page('*', fn);
   *   page('/user/:id', load, user);
   *   page('/user/' + user.id, { some: 'thing' });
   *   page('/user/' + user.id);
   *   page('/from', '/to')
   *   page();
   *
   * @param {string|!Function|!Object} path
   * @param {Function=} fn
   * @api public
   */

  function page(path, fn) {
    // <callback>
    if ('function' === typeof path) {
      return page.call(this, '*', path);
    }

    // route <path> to <callback ...>
    if ('function' === typeof fn) {
      var route = new Route(/** @type {string} */ (path), null, this);
      for (var i = 1; i < arguments.length; ++i) {
        this.callbacks.push(route.middleware(arguments[i]));
      }
      // show <path> with [state]
    } else if ('string' === typeof path) {
      this['string' === typeof fn ? 'redirect' : 'show'](path, fn);
      // start [options]
    } else {
      this.start(path);
    }
  }

  /**
   * Unhandled `ctx`. When it's not the initial
   * popstate then redirect. If you wish to handle
   * 404s on your own use `page('*', callback)`.
   *
   * @param {Context} ctx
   * @api private
   */
  function unhandled(ctx) {
    if (ctx.handled) return;
    var current;
    var page = this;
    var window = page._window;

    if (page._hashbang) {
      current = isLocation && this._getBase() + window.location.hash.replace('#!', '');
    } else {
      current = isLocation && window.location.pathname + window.location.search;
    }

    if (current === ctx.canonicalPath) return;
    page.stop();
    ctx.handled = false;
    isLocation && (window.location.href = ctx.canonicalPath);
  }

  /**
   * Escapes RegExp characters in the given string.
   *
   * @param {string} s
   * @api private
   */
  function escapeRegExp(s) {
    return s.replace(/([.+*?=^!:${}()[\]|/\\])/g, '\\$1');
  }

  /**
   * Initialize a new "request" `Context`
   * with the given `path` and optional initial `state`.
   *
   * @constructor
   * @param {string} path
   * @param {Object=} state
   * @api public
   */

  function Context(path, state, pageInstance) {
    var _page = this.page = pageInstance || page;
    var window = _page._window;
    var hashbang = _page._hashbang;

    var pageBase = _page._getBase();
    if ('/' === path[0] && 0 !== path.indexOf(pageBase)) path = pageBase + (hashbang ? '#!' : '') + path;
    var i = path.indexOf('?');

    this.canonicalPath = path;
    var re = new RegExp('^' + escapeRegExp(pageBase));
    this.path = path.replace(re, '') || '/';
    if (hashbang) this.path = this.path.replace('#!', '') || '/';

    this.title = (hasDocument && window.document.title);
    this.state = state || {};
    this.state.path = path;
    this.querystring = ~i ? _page._decodeURLEncodedURIComponent(path.slice(i + 1)) : '';
    this.pathname = _page._decodeURLEncodedURIComponent(~i ? path.slice(0, i) : path);
    this.params = {};

    // fragment
    this.hash = '';
    if (!hashbang) {
      if (!~this.path.indexOf('#')) return;
      var parts = this.path.split('#');
      this.path = this.pathname = parts[0];
      this.hash = _page._decodeURLEncodedURIComponent(parts[1]) || '';
      this.querystring = this.querystring.split('#')[0];
    }
  }

  /**
   * Push state.
   *
   * @api private
   */

  Context.prototype.pushState = function() {
    var page = this.page;
    var window = page._window;
    var hashbang = page._hashbang;

    page.len++;
    if (hasHistory) {
        window.history.pushState(this.state, this.title,
          hashbang && this.path !== '/' ? '#!' + this.path : this.canonicalPath);
    }
  };

  /**
   * Save the context state.
   *
   * @api public
   */

  Context.prototype.save = function() {
    var page = this.page;
    if (hasHistory) {
        page._window.history.replaceState(this.state, this.title,
          page._hashbang && this.path !== '/' ? '#!' + this.path : this.canonicalPath);
    }
  };

  /**
   * Initialize `Route` with the given HTTP `path`,
   * and an array of `callbacks` and `options`.
   *
   * Options:
   *
   *   - `sensitive`    enable case-sensitive routes
   *   - `strict`       enable strict matching for trailing slashes
   *
   * @constructor
   * @param {string} path
   * @param {Object=} options
   * @api private
   */

  function Route(path, options, page) {
    var _page = this.page = page || globalPage;
    var opts = options || {};
    opts.strict = opts.strict || page._strict;
    this.path = (path === '*') ? '(.*)' : path;
    this.method = 'GET';
    this.regexp = pathToRegexp_1(this.path, this.keys = [], opts);
  }

  /**
   * Return route middleware with
   * the given callback `fn()`.
   *
   * @param {Function} fn
   * @return {Function}
   * @api public
   */

  Route.prototype.middleware = function(fn) {
    var self = this;
    return function(ctx, next) {
      if (self.match(ctx.path, ctx.params)) return fn(ctx, next);
      next();
    };
  };

  /**
   * Check if this route matches `path`, if so
   * populate `params`.
   *
   * @param {string} path
   * @param {Object} params
   * @return {boolean}
   * @api private
   */

  Route.prototype.match = function(path, params) {
    var keys = this.keys,
      qsIndex = path.indexOf('?'),
      pathname = ~qsIndex ? path.slice(0, qsIndex) : path,
      m = this.regexp.exec(decodeURIComponent(pathname));

    if (!m) return false;
	  
    delete params[0]

    for (var i = 1, len = m.length; i < len; ++i) {
      var key = keys[i - 1];
      var val = this.page._decodeURLEncodedURIComponent(m[i]);
      if (val !== undefined || !(hasOwnProperty.call(params, key.name))) {
        params[key.name] = val;
      }
    }

    return true;
  };


  /**
   * Module exports.
   */

  var globalPage = createPage();
  var page_js = globalPage;
  var default_1 = globalPage;

page_js.default = default_1;

return page_js;

})));


/***/ }),

/***/ 54355:
/***/ (function(__unused_webpack_module, exports) {

/**
 * Compiles a querystring
 * Returns string representation of the object
 *
 * @param {Object}
 * @api private
 */

exports.encode = function (obj) {
  var str = '';

  for (var i in obj) {
    if (obj.hasOwnProperty(i)) {
      if (str.length) str += '&';
      str += encodeURIComponent(i) + '=' + encodeURIComponent(obj[i]);
    }
  }

  return str;
};

/**
 * Parses a simple querystring into an object
 *
 * @param {String} qs
 * @api private
 */

exports.decode = function(qs){
  var qry = {};
  var pairs = qs.split('&');
  for (var i = 0, l = pairs.length; i < l; i++) {
    var pair = pairs[i].split('=');
    qry[decodeURIComponent(pair[0])] = decodeURIComponent(pair[1]);
  }
  return qry;
};


/***/ }),

/***/ 14243:
/***/ (function(module) {

/**
 * Parses an URI
 *
 * @author Steven Levithan <stevenlevithan.com> (MIT license)
 * @api private
 */

var re = /^(?:(?![^:@]+:[^:@\/]*@)(http|https|ws|wss):\/\/)?((?:(([^:@]*)(?::([^:@]*))?)?@)?((?:[a-f0-9]{0,4}:){2,7}[a-f0-9]{0,4}|[^:\/?#]*)(?::(\d*))?)(((\/(?:[^?#](?![^?#\/]*\.[^?#\/.]+(?:[?#]|$)))*\/?)?([^?#\/]*))(?:\?([^#]*))?(?:#(.*))?)/;

var parts = [
    'source', 'protocol', 'authority', 'userInfo', 'user', 'password', 'host', 'port', 'relative', 'path', 'directory', 'file', 'query', 'anchor'
];

module.exports = function parseuri(str) {
    var src = str,
        b = str.indexOf('['),
        e = str.indexOf(']');

    if (b != -1 && e != -1) {
        str = str.substring(0, b) + str.substring(b, e).replace(/:/g, ';') + str.substring(e, str.length);
    }

    var m = re.exec(str || ''),
        uri = {},
        i = 14;

    while (i--) {
        uri[parts[i]] = m[i] || '';
    }

    if (b != -1 && e != -1) {
        uri.source = src;
        uri.host = uri.host.substring(1, uri.host.length - 1).replace(/;/g, ':');
        uri.authority = uri.authority.replace('[', '').replace(']', '').replace(/;/g, ':');
        uri.ipv6uri = true;
    }

    return uri;
};


/***/ }),

/***/ 20099:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var isarray = __webpack_require__(30243)

/**
 * Expose `pathToRegexp`.
 */
module.exports = pathToRegexp
module.exports.parse = parse
module.exports.compile = compile
module.exports.tokensToFunction = tokensToFunction
module.exports.tokensToRegExp = tokensToRegExp

/**
 * The main path matching regexp utility.
 *
 * @type {RegExp}
 */
var PATH_REGEXP = new RegExp([
  // Match escaped characters that would otherwise appear in future matches.
  // This allows the user to escape special characters that won't transform.
  '(\\\\.)',
  // Match Express-style parameters and un-named parameters with a prefix
  // and optional suffixes. Matches appear as:
  //
  // "/:test(\\d+)?" => ["/", "test", "\d+", undefined, "?", undefined]
  // "/route(\\d+)"  => [undefined, undefined, undefined, "\d+", undefined, undefined]
  // "/*"            => ["/", undefined, undefined, undefined, undefined, "*"]
  '([\\/.])?(?:(?:\\:(\\w+)(?:\\(((?:\\\\.|[^\\\\()])+)\\))?|\\(((?:\\\\.|[^\\\\()])+)\\))([+*?])?|(\\*))'
].join('|'), 'g')

/**
 * Parse a string for the raw tokens.
 *
 * @param  {string}  str
 * @param  {Object=} options
 * @return {!Array}
 */
function parse (str, options) {
  var tokens = []
  var key = 0
  var index = 0
  var path = ''
  var defaultDelimiter = options && options.delimiter || '/'
  var res

  while ((res = PATH_REGEXP.exec(str)) != null) {
    var m = res[0]
    var escaped = res[1]
    var offset = res.index
    path += str.slice(index, offset)
    index = offset + m.length

    // Ignore already escaped sequences.
    if (escaped) {
      path += escaped[1]
      continue
    }

    var next = str[index]
    var prefix = res[2]
    var name = res[3]
    var capture = res[4]
    var group = res[5]
    var modifier = res[6]
    var asterisk = res[7]

    // Push the current path onto the tokens.
    if (path) {
      tokens.push(path)
      path = ''
    }

    var partial = prefix != null && next != null && next !== prefix
    var repeat = modifier === '+' || modifier === '*'
    var optional = modifier === '?' || modifier === '*'
    var delimiter = res[2] || defaultDelimiter
    var pattern = capture || group

    tokens.push({
      name: name || key++,
      prefix: prefix || '',
      delimiter: delimiter,
      optional: optional,
      repeat: repeat,
      partial: partial,
      asterisk: !!asterisk,
      pattern: pattern ? escapeGroup(pattern) : (asterisk ? '.*' : '[^' + escapeString(delimiter) + ']+?')
    })
  }

  // Match any characters still remaining.
  if (index < str.length) {
    path += str.substr(index)
  }

  // If the path exists, push it onto the end.
  if (path) {
    tokens.push(path)
  }

  return tokens
}

/**
 * Compile a string to a template function for the path.
 *
 * @param  {string}             str
 * @param  {Object=}            options
 * @return {!function(Object=, Object=)}
 */
function compile (str, options) {
  return tokensToFunction(parse(str, options), options)
}

/**
 * Prettier encoding of URI path segments.
 *
 * @param  {string}
 * @return {string}
 */
function encodeURIComponentPretty (str) {
  return encodeURI(str).replace(/[\/?#]/g, function (c) {
    return '%' + c.charCodeAt(0).toString(16).toUpperCase()
  })
}

/**
 * Encode the asterisk parameter. Similar to `pretty`, but allows slashes.
 *
 * @param  {string}
 * @return {string}
 */
function encodeAsterisk (str) {
  return encodeURI(str).replace(/[?#]/g, function (c) {
    return '%' + c.charCodeAt(0).toString(16).toUpperCase()
  })
}

/**
 * Expose a method for transforming tokens into the path function.
 */
function tokensToFunction (tokens, options) {
  // Compile all the tokens into regexps.
  var matches = new Array(tokens.length)

  // Compile all the patterns before compilation.
  for (var i = 0; i < tokens.length; i++) {
    if (typeof tokens[i] === 'object') {
      matches[i] = new RegExp('^(?:' + tokens[i].pattern + ')$', flags(options))
    }
  }

  return function (obj, opts) {
    var path = ''
    var data = obj || {}
    var options = opts || {}
    var encode = options.pretty ? encodeURIComponentPretty : encodeURIComponent

    for (var i = 0; i < tokens.length; i++) {
      var token = tokens[i]

      if (typeof token === 'string') {
        path += token

        continue
      }

      var value = data[token.name]
      var segment

      if (value == null) {
        if (token.optional) {
          // Prepend partial segment prefixes.
          if (token.partial) {
            path += token.prefix
          }

          continue
        } else {
          throw new TypeError('Expected "' + token.name + '" to be defined')
        }
      }

      if (isarray(value)) {
        if (!token.repeat) {
          throw new TypeError('Expected "' + token.name + '" to not repeat, but received `' + JSON.stringify(value) + '`')
        }

        if (value.length === 0) {
          if (token.optional) {
            continue
          } else {
            throw new TypeError('Expected "' + token.name + '" to not be empty')
          }
        }

        for (var j = 0; j < value.length; j++) {
          segment = encode(value[j])

          if (!matches[i].test(segment)) {
            throw new TypeError('Expected all "' + token.name + '" to match "' + token.pattern + '", but received `' + JSON.stringify(segment) + '`')
          }

          path += (j === 0 ? token.prefix : token.delimiter) + segment
        }

        continue
      }

      segment = token.asterisk ? encodeAsterisk(value) : encode(value)

      if (!matches[i].test(segment)) {
        throw new TypeError('Expected "' + token.name + '" to match "' + token.pattern + '", but received "' + segment + '"')
      }

      path += token.prefix + segment
    }

    return path
  }
}

/**
 * Escape a regular expression string.
 *
 * @param  {string} str
 * @return {string}
 */
function escapeString (str) {
  return str.replace(/([.+*?=^!:${}()[\]|\/\\])/g, '\\$1')
}

/**
 * Escape the capturing group by escaping special characters and meaning.
 *
 * @param  {string} group
 * @return {string}
 */
function escapeGroup (group) {
  return group.replace(/([=!:$\/()])/g, '\\$1')
}

/**
 * Attach the keys as a property of the regexp.
 *
 * @param  {!RegExp} re
 * @param  {Array}   keys
 * @return {!RegExp}
 */
function attachKeys (re, keys) {
  re.keys = keys
  return re
}

/**
 * Get the flags for a regexp from the options.
 *
 * @param  {Object} options
 * @return {string}
 */
function flags (options) {
  return options && options.sensitive ? '' : 'i'
}

/**
 * Pull out keys from a regexp.
 *
 * @param  {!RegExp} path
 * @param  {!Array}  keys
 * @return {!RegExp}
 */
function regexpToRegexp (path, keys) {
  // Use a negative lookahead to match only capturing groups.
  var groups = path.source.match(/\((?!\?)/g)

  if (groups) {
    for (var i = 0; i < groups.length; i++) {
      keys.push({
        name: i,
        prefix: null,
        delimiter: null,
        optional: false,
        repeat: false,
        partial: false,
        asterisk: false,
        pattern: null
      })
    }
  }

  return attachKeys(path, keys)
}

/**
 * Transform an array into a regexp.
 *
 * @param  {!Array}  path
 * @param  {Array}   keys
 * @param  {!Object} options
 * @return {!RegExp}
 */
function arrayToRegexp (path, keys, options) {
  var parts = []

  for (var i = 0; i < path.length; i++) {
    parts.push(pathToRegexp(path[i], keys, options).source)
  }

  var regexp = new RegExp('(?:' + parts.join('|') + ')', flags(options))

  return attachKeys(regexp, keys)
}

/**
 * Create a path regexp from string input.
 *
 * @param  {string}  path
 * @param  {!Array}  keys
 * @param  {!Object} options
 * @return {!RegExp}
 */
function stringToRegexp (path, keys, options) {
  return tokensToRegExp(parse(path, options), keys, options)
}

/**
 * Expose a function for taking tokens and returning a RegExp.
 *
 * @param  {!Array}          tokens
 * @param  {(Array|Object)=} keys
 * @param  {Object=}         options
 * @return {!RegExp}
 */
function tokensToRegExp (tokens, keys, options) {
  if (!isarray(keys)) {
    options = /** @type {!Object} */ (keys || options)
    keys = []
  }

  options = options || {}

  var strict = options.strict
  var end = options.end !== false
  var route = ''

  // Iterate over the tokens and create our regexp string.
  for (var i = 0; i < tokens.length; i++) {
    var token = tokens[i]

    if (typeof token === 'string') {
      route += escapeString(token)
    } else {
      var prefix = escapeString(token.prefix)
      var capture = '(?:' + token.pattern + ')'

      keys.push(token)

      if (token.repeat) {
        capture += '(?:' + prefix + capture + ')*'
      }

      if (token.optional) {
        if (!token.partial) {
          capture = '(?:' + prefix + '(' + capture + '))?'
        } else {
          capture = prefix + '(' + capture + ')?'
        }
      } else {
        capture = prefix + '(' + capture + ')'
      }

      route += capture
    }
  }

  var delimiter = escapeString(options.delimiter || '/')
  var endsWithDelimiter = route.slice(-delimiter.length) === delimiter

  // In non-strict mode we allow a slash at the end of match. If the path to
  // match already ends with a slash, we remove it for consistency. The slash
  // is valid at the end of a path match, not in the middle. This is important
  // in non-ending mode, where "/test/" shouldn't match "/test//route".
  if (!strict) {
    route = (endsWithDelimiter ? route.slice(0, -delimiter.length) : route) + '(?:' + delimiter + '(?=$))?'
  }

  if (end) {
    route += '$'
  } else {
    // In non-ending mode, we need the capturing groups to match as much as
    // possible by using a positive lookahead to the end or next path segment.
    route += strict && endsWithDelimiter ? '' : '(?=' + delimiter + '|$)'
  }

  return attachKeys(new RegExp('^' + route, flags(options)), keys)
}

/**
 * Normalize the given path string, returning a regular expression.
 *
 * An empty array can be passed in for the keys, which will hold the
 * placeholder key descriptions. For example, using `/user/:id`, `keys` will
 * contain `[{ name: 'id', delimiter: '/', optional: false, repeat: false }]`.
 *
 * @param  {(string|RegExp|Array)} path
 * @param  {(Array|Object)=}       keys
 * @param  {Object=}               options
 * @return {!RegExp}
 */
function pathToRegexp (path, keys, options) {
  if (!isarray(keys)) {
    options = /** @type {!Object} */ (keys || options)
    keys = []
  }

  options = options || {}

  if (path instanceof RegExp) {
    return regexpToRegexp(path, /** @type {!Array} */ (keys))
  }

  if (isarray(path)) {
    return arrayToRegexp(/** @type {!Array} */ (path), /** @type {!Array} */ (keys), options)
  }

  return stringToRegexp(/** @type {string} */ (path), /** @type {!Array} */ (keys), options)
}


/***/ }),

/***/ 30243:
/***/ (function(module) {

module.exports = Array.isArray || function (arr) {
  return Object.prototype.toString.call(arr) == '[object Array]';
};


/***/ }),

/***/ 48650:
/***/ (function(module) {


var NativeProgressEvent = window.ProgressEvent;
var useNative = !!NativeProgressEvent;

try {
  (function () {
    var p = new NativeProgressEvent('loaded');
    useNative = 'loaded' === p.type;
    p = null;
  })();
} catch (e) {
  useNative = false;
}

/**
 * Cross-browser `ProgressEvent` constructor.
 *
 * https://developer.mozilla.org/en-US/docs/Web/API/ProgressEvent.ProgressEvent
 *
 * @public
 */

module.exports = useNative ? NativeProgressEvent :

// IE >= 9
'function' === typeof document.createEvent ? function ProgressEvent (type, props) {
  var e = document.createEvent('Event');
  e.initEvent(type, false, false);
  if (props) {
    e.lengthComputable = Boolean(props.lengthComputable);
    e.loaded = Number(props.loaded) || 0;
    e.total = Number(props.total) || 0;
  } else {
    e.lengthComputable = false;
    e.loaded = e.total = 0;
  }
  return e;
} :

// IE <= 8
function ProgressEvent (type, props) {
  var e = document.createEventObject();
  e.type = type;
  if (props) {
    e.lengthComputable = Boolean(props.lengthComputable);
    e.loaded = Number(props.loaded) || 0;
    e.total = Number(props.total) || 0;
  } else {
    e.lengthComputable = false;
    e.loaded = e.total = 0;
  }
  return e;
}


/***/ }),

/***/ 68262:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";
/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */



var ReactPropTypesSecret = __webpack_require__(23586);

function emptyFunction() {}
function emptyFunctionWithReset() {}
emptyFunctionWithReset.resetWarningCache = emptyFunction;

module.exports = function() {
  function shim(props, propName, componentName, location, propFullName, secret) {
    if (secret === ReactPropTypesSecret) {
      // It is still safe when called from React.
      return;
    }
    var err = new Error(
      'Calling PropTypes validators directly is not supported by the `prop-types` package. ' +
      'Use PropTypes.checkPropTypes() to call them. ' +
      'Read more at http://fb.me/use-check-prop-types'
    );
    err.name = 'Invariant Violation';
    throw err;
  };
  shim.isRequired = shim;
  function getShim() {
    return shim;
  };
  // Important!
  // Keep this list in sync with production version in `./factoryWithTypeCheckers.js`.
  var ReactPropTypes = {
    array: shim,
    bigint: shim,
    bool: shim,
    func: shim,
    number: shim,
    object: shim,
    string: shim,
    symbol: shim,

    any: shim,
    arrayOf: getShim,
    element: shim,
    elementType: shim,
    instanceOf: getShim,
    node: shim,
    objectOf: getShim,
    oneOf: getShim,
    oneOfType: getShim,
    shape: getShim,
    exact: getShim,

    checkPropTypes: emptyFunctionWithReset,
    resetWarningCache: emptyFunction
  };

  ReactPropTypes.PropTypes = ReactPropTypes;

  return ReactPropTypes;
};


/***/ }),

/***/ 13980:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

if (false) { var throwOnDirectAccess, ReactIs; } else {
  // By explicitly using `prop-types` you are opting into new production behavior.
  // http://fb.me/prop-types-in-prod
  module.exports = __webpack_require__(68262)();
}


/***/ }),

/***/ 23586:
/***/ (function(module) {

"use strict";
/**
 * Copyright (c) 2013-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */



var ReactPropTypesSecret = 'SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED';

module.exports = ReactPropTypesSecret;


/***/ }),

/***/ 85527:
/***/ (function(module) {

"use strict";


var replace = String.prototype.replace;
var percentTwenties = /%20/g;

var Format = {
    RFC1738: 'RFC1738',
    RFC3986: 'RFC3986'
};

module.exports = {
    'default': Format.RFC3986,
    formatters: {
        RFC1738: function (value) {
            return replace.call(value, percentTwenties, '+');
        },
        RFC3986: function (value) {
            return String(value);
        }
    },
    RFC1738: Format.RFC1738,
    RFC3986: Format.RFC3986
};


/***/ }),

/***/ 19126:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var stringify = __webpack_require__(66845);
var parse = __webpack_require__(29166);
var formats = __webpack_require__(85527);

module.exports = {
    formats: formats,
    parse: parse,
    stringify: stringify
};


/***/ }),

/***/ 29166:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var utils = __webpack_require__(12493);

var has = Object.prototype.hasOwnProperty;
var isArray = Array.isArray;

var defaults = {
    allowDots: false,
    allowPrototypes: false,
    allowSparse: false,
    arrayLimit: 20,
    charset: 'utf-8',
    charsetSentinel: false,
    comma: false,
    decoder: utils.decode,
    delimiter: '&',
    depth: 5,
    ignoreQueryPrefix: false,
    interpretNumericEntities: false,
    parameterLimit: 1000,
    parseArrays: true,
    plainObjects: false,
    strictNullHandling: false
};

var interpretNumericEntities = function (str) {
    return str.replace(/&#(\d+);/g, function ($0, numberStr) {
        return String.fromCharCode(parseInt(numberStr, 10));
    });
};

var parseArrayValue = function (val, options) {
    if (val && typeof val === 'string' && options.comma && val.indexOf(',') > -1) {
        return val.split(',');
    }

    return val;
};

// This is what browsers will submit when the ✓ character occurs in an
// application/x-www-form-urlencoded body and the encoding of the page containing
// the form is iso-8859-1, or when the submitted form has an accept-charset
// attribute of iso-8859-1. Presumably also with other charsets that do not contain
// the ✓ character, such as us-ascii.
var isoSentinel = 'utf8=%26%2310003%3B'; // encodeURIComponent('&#10003;')

// These are the percent-encoded utf-8 octets representing a checkmark, indicating that the request actually is utf-8 encoded.
var charsetSentinel = 'utf8=%E2%9C%93'; // encodeURIComponent('✓')

var parseValues = function parseQueryStringValues(str, options) {
    var obj = {};
    var cleanStr = options.ignoreQueryPrefix ? str.replace(/^\?/, '') : str;
    var limit = options.parameterLimit === Infinity ? undefined : options.parameterLimit;
    var parts = cleanStr.split(options.delimiter, limit);
    var skipIndex = -1; // Keep track of where the utf8 sentinel was found
    var i;

    var charset = options.charset;
    if (options.charsetSentinel) {
        for (i = 0; i < parts.length; ++i) {
            if (parts[i].indexOf('utf8=') === 0) {
                if (parts[i] === charsetSentinel) {
                    charset = 'utf-8';
                } else if (parts[i] === isoSentinel) {
                    charset = 'iso-8859-1';
                }
                skipIndex = i;
                i = parts.length; // The eslint settings do not allow break;
            }
        }
    }

    for (i = 0; i < parts.length; ++i) {
        if (i === skipIndex) {
            continue;
        }
        var part = parts[i];

        var bracketEqualsPos = part.indexOf(']=');
        var pos = bracketEqualsPos === -1 ? part.indexOf('=') : bracketEqualsPos + 1;

        var key, val;
        if (pos === -1) {
            key = options.decoder(part, defaults.decoder, charset, 'key');
            val = options.strictNullHandling ? null : '';
        } else {
            key = options.decoder(part.slice(0, pos), defaults.decoder, charset, 'key');
            val = utils.maybeMap(
                parseArrayValue(part.slice(pos + 1), options),
                function (encodedVal) {
                    return options.decoder(encodedVal, defaults.decoder, charset, 'value');
                }
            );
        }

        if (val && options.interpretNumericEntities && charset === 'iso-8859-1') {
            val = interpretNumericEntities(val);
        }

        if (part.indexOf('[]=') > -1) {
            val = isArray(val) ? [val] : val;
        }

        if (has.call(obj, key)) {
            obj[key] = utils.combine(obj[key], val);
        } else {
            obj[key] = val;
        }
    }

    return obj;
};

var parseObject = function (chain, val, options, valuesParsed) {
    var leaf = valuesParsed ? val : parseArrayValue(val, options);

    for (var i = chain.length - 1; i >= 0; --i) {
        var obj;
        var root = chain[i];

        if (root === '[]' && options.parseArrays) {
            obj = [].concat(leaf);
        } else {
            obj = options.plainObjects ? Object.create(null) : {};
            var cleanRoot = root.charAt(0) === '[' && root.charAt(root.length - 1) === ']' ? root.slice(1, -1) : root;
            var index = parseInt(cleanRoot, 10);
            if (!options.parseArrays && cleanRoot === '') {
                obj = { 0: leaf };
            } else if (
                !isNaN(index)
                && root !== cleanRoot
                && String(index) === cleanRoot
                && index >= 0
                && (options.parseArrays && index <= options.arrayLimit)
            ) {
                obj = [];
                obj[index] = leaf;
            } else if (cleanRoot !== '__proto__') {
                obj[cleanRoot] = leaf;
            }
        }

        leaf = obj;
    }

    return leaf;
};

var parseKeys = function parseQueryStringKeys(givenKey, val, options, valuesParsed) {
    if (!givenKey) {
        return;
    }

    // Transform dot notation to bracket notation
    var key = options.allowDots ? givenKey.replace(/\.([^.[]+)/g, '[$1]') : givenKey;

    // The regex chunks

    var brackets = /(\[[^[\]]*])/;
    var child = /(\[[^[\]]*])/g;

    // Get the parent

    var segment = options.depth > 0 && brackets.exec(key);
    var parent = segment ? key.slice(0, segment.index) : key;

    // Stash the parent if it exists

    var keys = [];
    if (parent) {
        // If we aren't using plain objects, optionally prefix keys that would overwrite object prototype properties
        if (!options.plainObjects && has.call(Object.prototype, parent)) {
            if (!options.allowPrototypes) {
                return;
            }
        }

        keys.push(parent);
    }

    // Loop through children appending to the array until we hit depth

    var i = 0;
    while (options.depth > 0 && (segment = child.exec(key)) !== null && i < options.depth) {
        i += 1;
        if (!options.plainObjects && has.call(Object.prototype, segment[1].slice(1, -1))) {
            if (!options.allowPrototypes) {
                return;
            }
        }
        keys.push(segment[1]);
    }

    // If there's a remainder, just add whatever is left

    if (segment) {
        keys.push('[' + key.slice(segment.index) + ']');
    }

    return parseObject(keys, val, options, valuesParsed);
};

var normalizeParseOptions = function normalizeParseOptions(opts) {
    if (!opts) {
        return defaults;
    }

    if (opts.decoder !== null && opts.decoder !== undefined && typeof opts.decoder !== 'function') {
        throw new TypeError('Decoder has to be a function.');
    }

    if (typeof opts.charset !== 'undefined' && opts.charset !== 'utf-8' && opts.charset !== 'iso-8859-1') {
        throw new TypeError('The charset option must be either utf-8, iso-8859-1, or undefined');
    }
    var charset = typeof opts.charset === 'undefined' ? defaults.charset : opts.charset;

    return {
        allowDots: typeof opts.allowDots === 'undefined' ? defaults.allowDots : !!opts.allowDots,
        allowPrototypes: typeof opts.allowPrototypes === 'boolean' ? opts.allowPrototypes : defaults.allowPrototypes,
        allowSparse: typeof opts.allowSparse === 'boolean' ? opts.allowSparse : defaults.allowSparse,
        arrayLimit: typeof opts.arrayLimit === 'number' ? opts.arrayLimit : defaults.arrayLimit,
        charset: charset,
        charsetSentinel: typeof opts.charsetSentinel === 'boolean' ? opts.charsetSentinel : defaults.charsetSentinel,
        comma: typeof opts.comma === 'boolean' ? opts.comma : defaults.comma,
        decoder: typeof opts.decoder === 'function' ? opts.decoder : defaults.decoder,
        delimiter: typeof opts.delimiter === 'string' || utils.isRegExp(opts.delimiter) ? opts.delimiter : defaults.delimiter,
        // eslint-disable-next-line no-implicit-coercion, no-extra-parens
        depth: (typeof opts.depth === 'number' || opts.depth === false) ? +opts.depth : defaults.depth,
        ignoreQueryPrefix: opts.ignoreQueryPrefix === true,
        interpretNumericEntities: typeof opts.interpretNumericEntities === 'boolean' ? opts.interpretNumericEntities : defaults.interpretNumericEntities,
        parameterLimit: typeof opts.parameterLimit === 'number' ? opts.parameterLimit : defaults.parameterLimit,
        parseArrays: opts.parseArrays !== false,
        plainObjects: typeof opts.plainObjects === 'boolean' ? opts.plainObjects : defaults.plainObjects,
        strictNullHandling: typeof opts.strictNullHandling === 'boolean' ? opts.strictNullHandling : defaults.strictNullHandling
    };
};

module.exports = function (str, opts) {
    var options = normalizeParseOptions(opts);

    if (str === '' || str === null || typeof str === 'undefined') {
        return options.plainObjects ? Object.create(null) : {};
    }

    var tempObj = typeof str === 'string' ? parseValues(str, options) : str;
    var obj = options.plainObjects ? Object.create(null) : {};

    // Iterate over the keys and setup the new object

    var keys = Object.keys(tempObj);
    for (var i = 0; i < keys.length; ++i) {
        var key = keys[i];
        var newObj = parseKeys(key, tempObj[key], options, typeof str === 'string');
        obj = utils.merge(obj, newObj, options);
    }

    if (options.allowSparse === true) {
        return obj;
    }

    return utils.compact(obj);
};


/***/ }),

/***/ 66845:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var getSideChannel = __webpack_require__(74294);
var utils = __webpack_require__(12493);
var formats = __webpack_require__(85527);
var has = Object.prototype.hasOwnProperty;

var arrayPrefixGenerators = {
    brackets: function brackets(prefix) {
        return prefix + '[]';
    },
    comma: 'comma',
    indices: function indices(prefix, key) {
        return prefix + '[' + key + ']';
    },
    repeat: function repeat(prefix) {
        return prefix;
    }
};

var isArray = Array.isArray;
var split = String.prototype.split;
var push = Array.prototype.push;
var pushToArray = function (arr, valueOrArray) {
    push.apply(arr, isArray(valueOrArray) ? valueOrArray : [valueOrArray]);
};

var toISO = Date.prototype.toISOString;

var defaultFormat = formats['default'];
var defaults = {
    addQueryPrefix: false,
    allowDots: false,
    charset: 'utf-8',
    charsetSentinel: false,
    delimiter: '&',
    encode: true,
    encoder: utils.encode,
    encodeValuesOnly: false,
    format: defaultFormat,
    formatter: formats.formatters[defaultFormat],
    // deprecated
    indices: false,
    serializeDate: function serializeDate(date) {
        return toISO.call(date);
    },
    skipNulls: false,
    strictNullHandling: false
};

var isNonNullishPrimitive = function isNonNullishPrimitive(v) {
    return typeof v === 'string'
        || typeof v === 'number'
        || typeof v === 'boolean'
        || typeof v === 'symbol'
        || typeof v === 'bigint';
};

var sentinel = {};

var stringify = function stringify(
    object,
    prefix,
    generateArrayPrefix,
    strictNullHandling,
    skipNulls,
    encoder,
    filter,
    sort,
    allowDots,
    serializeDate,
    format,
    formatter,
    encodeValuesOnly,
    charset,
    sideChannel
) {
    var obj = object;

    var tmpSc = sideChannel;
    var step = 0;
    var findFlag = false;
    while ((tmpSc = tmpSc.get(sentinel)) !== void undefined && !findFlag) {
        // Where object last appeared in the ref tree
        var pos = tmpSc.get(object);
        step += 1;
        if (typeof pos !== 'undefined') {
            if (pos === step) {
                throw new RangeError('Cyclic object value');
            } else {
                findFlag = true; // Break while
            }
        }
        if (typeof tmpSc.get(sentinel) === 'undefined') {
            step = 0;
        }
    }

    if (typeof filter === 'function') {
        obj = filter(prefix, obj);
    } else if (obj instanceof Date) {
        obj = serializeDate(obj);
    } else if (generateArrayPrefix === 'comma' && isArray(obj)) {
        obj = utils.maybeMap(obj, function (value) {
            if (value instanceof Date) {
                return serializeDate(value);
            }
            return value;
        });
    }

    if (obj === null) {
        if (strictNullHandling) {
            return encoder && !encodeValuesOnly ? encoder(prefix, defaults.encoder, charset, 'key', format) : prefix;
        }

        obj = '';
    }

    if (isNonNullishPrimitive(obj) || utils.isBuffer(obj)) {
        if (encoder) {
            var keyValue = encodeValuesOnly ? prefix : encoder(prefix, defaults.encoder, charset, 'key', format);
            if (generateArrayPrefix === 'comma' && encodeValuesOnly) {
                var valuesArray = split.call(String(obj), ',');
                var valuesJoined = '';
                for (var i = 0; i < valuesArray.length; ++i) {
                    valuesJoined += (i === 0 ? '' : ',') + formatter(encoder(valuesArray[i], defaults.encoder, charset, 'value', format));
                }
                return [formatter(keyValue) + '=' + valuesJoined];
            }
            return [formatter(keyValue) + '=' + formatter(encoder(obj, defaults.encoder, charset, 'value', format))];
        }
        return [formatter(prefix) + '=' + formatter(String(obj))];
    }

    var values = [];

    if (typeof obj === 'undefined') {
        return values;
    }

    var objKeys;
    if (generateArrayPrefix === 'comma' && isArray(obj)) {
        // we need to join elements in
        objKeys = [{ value: obj.length > 0 ? obj.join(',') || null : void undefined }];
    } else if (isArray(filter)) {
        objKeys = filter;
    } else {
        var keys = Object.keys(obj);
        objKeys = sort ? keys.sort(sort) : keys;
    }

    for (var j = 0; j < objKeys.length; ++j) {
        var key = objKeys[j];
        var value = typeof key === 'object' && typeof key.value !== 'undefined' ? key.value : obj[key];

        if (skipNulls && value === null) {
            continue;
        }

        var keyPrefix = isArray(obj)
            ? typeof generateArrayPrefix === 'function' ? generateArrayPrefix(prefix, key) : prefix
            : prefix + (allowDots ? '.' + key : '[' + key + ']');

        sideChannel.set(object, step);
        var valueSideChannel = getSideChannel();
        valueSideChannel.set(sentinel, sideChannel);
        pushToArray(values, stringify(
            value,
            keyPrefix,
            generateArrayPrefix,
            strictNullHandling,
            skipNulls,
            encoder,
            filter,
            sort,
            allowDots,
            serializeDate,
            format,
            formatter,
            encodeValuesOnly,
            charset,
            valueSideChannel
        ));
    }

    return values;
};

var normalizeStringifyOptions = function normalizeStringifyOptions(opts) {
    if (!opts) {
        return defaults;
    }

    if (opts.encoder !== null && typeof opts.encoder !== 'undefined' && typeof opts.encoder !== 'function') {
        throw new TypeError('Encoder has to be a function.');
    }

    var charset = opts.charset || defaults.charset;
    if (typeof opts.charset !== 'undefined' && opts.charset !== 'utf-8' && opts.charset !== 'iso-8859-1') {
        throw new TypeError('The charset option must be either utf-8, iso-8859-1, or undefined');
    }

    var format = formats['default'];
    if (typeof opts.format !== 'undefined') {
        if (!has.call(formats.formatters, opts.format)) {
            throw new TypeError('Unknown format option provided.');
        }
        format = opts.format;
    }
    var formatter = formats.formatters[format];

    var filter = defaults.filter;
    if (typeof opts.filter === 'function' || isArray(opts.filter)) {
        filter = opts.filter;
    }

    return {
        addQueryPrefix: typeof opts.addQueryPrefix === 'boolean' ? opts.addQueryPrefix : defaults.addQueryPrefix,
        allowDots: typeof opts.allowDots === 'undefined' ? defaults.allowDots : !!opts.allowDots,
        charset: charset,
        charsetSentinel: typeof opts.charsetSentinel === 'boolean' ? opts.charsetSentinel : defaults.charsetSentinel,
        delimiter: typeof opts.delimiter === 'undefined' ? defaults.delimiter : opts.delimiter,
        encode: typeof opts.encode === 'boolean' ? opts.encode : defaults.encode,
        encoder: typeof opts.encoder === 'function' ? opts.encoder : defaults.encoder,
        encodeValuesOnly: typeof opts.encodeValuesOnly === 'boolean' ? opts.encodeValuesOnly : defaults.encodeValuesOnly,
        filter: filter,
        format: format,
        formatter: formatter,
        serializeDate: typeof opts.serializeDate === 'function' ? opts.serializeDate : defaults.serializeDate,
        skipNulls: typeof opts.skipNulls === 'boolean' ? opts.skipNulls : defaults.skipNulls,
        sort: typeof opts.sort === 'function' ? opts.sort : null,
        strictNullHandling: typeof opts.strictNullHandling === 'boolean' ? opts.strictNullHandling : defaults.strictNullHandling
    };
};

module.exports = function (object, opts) {
    var obj = object;
    var options = normalizeStringifyOptions(opts);

    var objKeys;
    var filter;

    if (typeof options.filter === 'function') {
        filter = options.filter;
        obj = filter('', obj);
    } else if (isArray(options.filter)) {
        filter = options.filter;
        objKeys = filter;
    }

    var keys = [];

    if (typeof obj !== 'object' || obj === null) {
        return '';
    }

    var arrayFormat;
    if (opts && opts.arrayFormat in arrayPrefixGenerators) {
        arrayFormat = opts.arrayFormat;
    } else if (opts && 'indices' in opts) {
        arrayFormat = opts.indices ? 'indices' : 'repeat';
    } else {
        arrayFormat = 'indices';
    }

    var generateArrayPrefix = arrayPrefixGenerators[arrayFormat];

    if (!objKeys) {
        objKeys = Object.keys(obj);
    }

    if (options.sort) {
        objKeys.sort(options.sort);
    }

    var sideChannel = getSideChannel();
    for (var i = 0; i < objKeys.length; ++i) {
        var key = objKeys[i];

        if (options.skipNulls && obj[key] === null) {
            continue;
        }
        pushToArray(keys, stringify(
            obj[key],
            key,
            generateArrayPrefix,
            options.strictNullHandling,
            options.skipNulls,
            options.encode ? options.encoder : null,
            options.filter,
            options.sort,
            options.allowDots,
            options.serializeDate,
            options.format,
            options.formatter,
            options.encodeValuesOnly,
            options.charset,
            sideChannel
        ));
    }

    var joined = keys.join(options.delimiter);
    var prefix = options.addQueryPrefix === true ? '?' : '';

    if (options.charsetSentinel) {
        if (options.charset === 'iso-8859-1') {
            // encodeURIComponent('&#10003;'), the "numeric entity" representation of a checkmark
            prefix += 'utf8=%26%2310003%3B&';
        } else {
            // encodeURIComponent('✓')
            prefix += 'utf8=%E2%9C%93&';
        }
    }

    return joined.length > 0 ? prefix + joined : '';
};


/***/ }),

/***/ 12493:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var formats = __webpack_require__(85527);

var has = Object.prototype.hasOwnProperty;
var isArray = Array.isArray;

var hexTable = (function () {
    var array = [];
    for (var i = 0; i < 256; ++i) {
        array.push('%' + ((i < 16 ? '0' : '') + i.toString(16)).toUpperCase());
    }

    return array;
}());

var compactQueue = function compactQueue(queue) {
    while (queue.length > 1) {
        var item = queue.pop();
        var obj = item.obj[item.prop];

        if (isArray(obj)) {
            var compacted = [];

            for (var j = 0; j < obj.length; ++j) {
                if (typeof obj[j] !== 'undefined') {
                    compacted.push(obj[j]);
                }
            }

            item.obj[item.prop] = compacted;
        }
    }
};

var arrayToObject = function arrayToObject(source, options) {
    var obj = options && options.plainObjects ? Object.create(null) : {};
    for (var i = 0; i < source.length; ++i) {
        if (typeof source[i] !== 'undefined') {
            obj[i] = source[i];
        }
    }

    return obj;
};

var merge = function merge(target, source, options) {
    /* eslint no-param-reassign: 0 */
    if (!source) {
        return target;
    }

    if (typeof source !== 'object') {
        if (isArray(target)) {
            target.push(source);
        } else if (target && typeof target === 'object') {
            if ((options && (options.plainObjects || options.allowPrototypes)) || !has.call(Object.prototype, source)) {
                target[source] = true;
            }
        } else {
            return [target, source];
        }

        return target;
    }

    if (!target || typeof target !== 'object') {
        return [target].concat(source);
    }

    var mergeTarget = target;
    if (isArray(target) && !isArray(source)) {
        mergeTarget = arrayToObject(target, options);
    }

    if (isArray(target) && isArray(source)) {
        source.forEach(function (item, i) {
            if (has.call(target, i)) {
                var targetItem = target[i];
                if (targetItem && typeof targetItem === 'object' && item && typeof item === 'object') {
                    target[i] = merge(targetItem, item, options);
                } else {
                    target.push(item);
                }
            } else {
                target[i] = item;
            }
        });
        return target;
    }

    return Object.keys(source).reduce(function (acc, key) {
        var value = source[key];

        if (has.call(acc, key)) {
            acc[key] = merge(acc[key], value, options);
        } else {
            acc[key] = value;
        }
        return acc;
    }, mergeTarget);
};

var assign = function assignSingleSource(target, source) {
    return Object.keys(source).reduce(function (acc, key) {
        acc[key] = source[key];
        return acc;
    }, target);
};

var decode = function (str, decoder, charset) {
    var strWithoutPlus = str.replace(/\+/g, ' ');
    if (charset === 'iso-8859-1') {
        // unescape never throws, no try...catch needed:
        return strWithoutPlus.replace(/%[0-9a-f]{2}/gi, unescape);
    }
    // utf-8
    try {
        return decodeURIComponent(strWithoutPlus);
    } catch (e) {
        return strWithoutPlus;
    }
};

var encode = function encode(str, defaultEncoder, charset, kind, format) {
    // This code was originally written by Brian White (mscdex) for the io.js core querystring library.
    // It has been adapted here for stricter adherence to RFC 3986
    if (str.length === 0) {
        return str;
    }

    var string = str;
    if (typeof str === 'symbol') {
        string = Symbol.prototype.toString.call(str);
    } else if (typeof str !== 'string') {
        string = String(str);
    }

    if (charset === 'iso-8859-1') {
        return escape(string).replace(/%u[0-9a-f]{4}/gi, function ($0) {
            return '%26%23' + parseInt($0.slice(2), 16) + '%3B';
        });
    }

    var out = '';
    for (var i = 0; i < string.length; ++i) {
        var c = string.charCodeAt(i);

        if (
            c === 0x2D // -
            || c === 0x2E // .
            || c === 0x5F // _
            || c === 0x7E // ~
            || (c >= 0x30 && c <= 0x39) // 0-9
            || (c >= 0x41 && c <= 0x5A) // a-z
            || (c >= 0x61 && c <= 0x7A) // A-Z
            || (format === formats.RFC1738 && (c === 0x28 || c === 0x29)) // ( )
        ) {
            out += string.charAt(i);
            continue;
        }

        if (c < 0x80) {
            out = out + hexTable[c];
            continue;
        }

        if (c < 0x800) {
            out = out + (hexTable[0xC0 | (c >> 6)] + hexTable[0x80 | (c & 0x3F)]);
            continue;
        }

        if (c < 0xD800 || c >= 0xE000) {
            out = out + (hexTable[0xE0 | (c >> 12)] + hexTable[0x80 | ((c >> 6) & 0x3F)] + hexTable[0x80 | (c & 0x3F)]);
            continue;
        }

        i += 1;
        c = 0x10000 + (((c & 0x3FF) << 10) | (string.charCodeAt(i) & 0x3FF));
        /* eslint operator-linebreak: [2, "before"] */
        out += hexTable[0xF0 | (c >> 18)]
            + hexTable[0x80 | ((c >> 12) & 0x3F)]
            + hexTable[0x80 | ((c >> 6) & 0x3F)]
            + hexTable[0x80 | (c & 0x3F)];
    }

    return out;
};

var compact = function compact(value) {
    var queue = [{ obj: { o: value }, prop: 'o' }];
    var refs = [];

    for (var i = 0; i < queue.length; ++i) {
        var item = queue[i];
        var obj = item.obj[item.prop];

        var keys = Object.keys(obj);
        for (var j = 0; j < keys.length; ++j) {
            var key = keys[j];
            var val = obj[key];
            if (typeof val === 'object' && val !== null && refs.indexOf(val) === -1) {
                queue.push({ obj: obj, prop: key });
                refs.push(val);
            }
        }
    }

    compactQueue(queue);

    return value;
};

var isRegExp = function isRegExp(obj) {
    return Object.prototype.toString.call(obj) === '[object RegExp]';
};

var isBuffer = function isBuffer(obj) {
    if (!obj || typeof obj !== 'object') {
        return false;
    }

    return !!(obj.constructor && obj.constructor.isBuffer && obj.constructor.isBuffer(obj));
};

var combine = function combine(a, b) {
    return [].concat(a, b);
};

var maybeMap = function maybeMap(val, fn) {
    if (isArray(val)) {
        var mapped = [];
        for (var i = 0; i < val.length; i += 1) {
            mapped.push(fn(val[i]));
        }
        return mapped;
    }
    return fn(val);
};

module.exports = {
    arrayToObject: arrayToObject,
    assign: assign,
    combine: combine,
    compact: compact,
    decode: decode,
    encode: encode,
    isBuffer: isBuffer,
    isRegExp: isRegExp,
    maybeMap: maybeMap,
    merge: merge
};


/***/ }),

/***/ 97375:
/***/ (function(__unused_webpack_module, exports) {

"use strict";


var has = Object.prototype.hasOwnProperty
  , undef;

/**
 * Decode a URI encoded string.
 *
 * @param {String} input The URI encoded string.
 * @returns {String|Null} The decoded string.
 * @api private
 */
function decode(input) {
  try {
    return decodeURIComponent(input.replace(/\+/g, ' '));
  } catch (e) {
    return null;
  }
}

/**
 * Attempts to encode a given input.
 *
 * @param {String} input The string that needs to be encoded.
 * @returns {String|Null} The encoded string.
 * @api private
 */
function encode(input) {
  try {
    return encodeURIComponent(input);
  } catch (e) {
    return null;
  }
}

/**
 * Simple query string parser.
 *
 * @param {String} query The query string that needs to be parsed.
 * @returns {Object}
 * @api public
 */
function querystring(query) {
  var parser = /([^=?#&]+)=?([^&]*)/g
    , result = {}
    , part;

  while (part = parser.exec(query)) {
    var key = decode(part[1])
      , value = decode(part[2]);

    //
    // Prevent overriding of existing properties. This ensures that build-in
    // methods like `toString` or __proto__ are not overriden by malicious
    // querystrings.
    //
    // In the case if failed decoding, we want to omit the key/value pairs
    // from the result.
    //
    if (key === null || value === null || key in result) continue;
    result[key] = value;
  }

  return result;
}

/**
 * Transform a query string to an object.
 *
 * @param {Object} obj Object that should be transformed.
 * @param {String} prefix Optional prefix.
 * @returns {String}
 * @api public
 */
function querystringify(obj, prefix) {
  prefix = prefix || '';

  var pairs = []
    , value
    , key;

  //
  // Optionally prefix with a '?' if needed
  //
  if ('string' !== typeof prefix) prefix = '?';

  for (key in obj) {
    if (has.call(obj, key)) {
      value = obj[key];

      //
      // Edge cases where we actually want to encode the value to an empty
      // string instead of the stringified value.
      //
      if (!value && (value === null || value === undef || isNaN(value))) {
        value = '';
      }

      key = encode(key);
      value = encode(value);

      //
      // If we failed to encode the strings, we should bail out as we don't
      // want to add invalid strings to the query.
      //
      if (key === null || value === null) continue;
      pairs.push(key +'='+ value);
    }
  }

  return pairs.length ? prefix + pairs.join('&') : '';
}

//
// Expose the module.
//
exports.stringify = querystringify;
exports.parse = querystring;


/***/ }),

/***/ 11997:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

"use strict";


function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
Object.defineProperty(exports, "DraggableCore", ({
  enumerable: true,
  get: function get() {
    return _DraggableCore.default;
  }
}));
exports["default"] = void 0;

var React = _interopRequireWildcard(__webpack_require__(99196));

var _propTypes = _interopRequireDefault(__webpack_require__(13980));

var _reactDom = _interopRequireDefault(__webpack_require__(91850));

var _clsx2 = _interopRequireDefault(__webpack_require__(6277));

var _domFns = __webpack_require__(54688);

var _positionFns = __webpack_require__(93585);

var _shims = __webpack_require__(40136);

var _DraggableCore = _interopRequireDefault(__webpack_require__(93816));

var _log = _interopRequireDefault(__webpack_require__(81177));

var _excluded = ["axis", "bounds", "children", "defaultPosition", "defaultClassName", "defaultClassNameDragging", "defaultClassNameDragged", "position", "positionOffset", "scale"];

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

//
// Define <Draggable>
//
var Draggable = /*#__PURE__*/function (_React$Component) {
  _inherits(Draggable, _React$Component);

  var _super = _createSuper(Draggable);

  function Draggable(props
  /*: DraggableProps*/
  ) {
    var _this;

    _classCallCheck(this, Draggable);

    _this = _super.call(this, props);

    _defineProperty(_assertThisInitialized(_this), "onDragStart", function (e, coreData) {
      (0, _log.default)('Draggable: onDragStart: %j', coreData); // Short-circuit if user's callback killed it.

      var shouldStart = _this.props.onStart(e, (0, _positionFns.createDraggableData)(_assertThisInitialized(_this), coreData)); // Kills start event on core as well, so move handlers are never bound.


      if (shouldStart === false) return false;

      _this.setState({
        dragging: true,
        dragged: true
      });
    });

    _defineProperty(_assertThisInitialized(_this), "onDrag", function (e, coreData) {
      if (!_this.state.dragging) return false;
      (0, _log.default)('Draggable: onDrag: %j', coreData);
      var uiData = (0, _positionFns.createDraggableData)(_assertThisInitialized(_this), coreData);
      var newState
      /*: $Shape<DraggableState>*/
      = {
        x: uiData.x,
        y: uiData.y
      }; // Keep within bounds.

      if (_this.props.bounds) {
        // Save original x and y.
        var x = newState.x,
            y = newState.y; // Add slack to the values used to calculate bound position. This will ensure that if
        // we start removing slack, the element won't react to it right away until it's been
        // completely removed.

        newState.x += _this.state.slackX;
        newState.y += _this.state.slackY; // Get bound position. This will ceil/floor the x and y within the boundaries.

        var _getBoundPosition = (0, _positionFns.getBoundPosition)(_assertThisInitialized(_this), newState.x, newState.y),
            _getBoundPosition2 = _slicedToArray(_getBoundPosition, 2),
            newStateX = _getBoundPosition2[0],
            newStateY = _getBoundPosition2[1];

        newState.x = newStateX;
        newState.y = newStateY; // Recalculate slack by noting how much was shaved by the boundPosition handler.

        newState.slackX = _this.state.slackX + (x - newState.x);
        newState.slackY = _this.state.slackY + (y - newState.y); // Update the event we fire to reflect what really happened after bounds took effect.

        uiData.x = newState.x;
        uiData.y = newState.y;
        uiData.deltaX = newState.x - _this.state.x;
        uiData.deltaY = newState.y - _this.state.y;
      } // Short-circuit if user's callback killed it.


      var shouldUpdate = _this.props.onDrag(e, uiData);

      if (shouldUpdate === false) return false;

      _this.setState(newState);
    });

    _defineProperty(_assertThisInitialized(_this), "onDragStop", function (e, coreData) {
      if (!_this.state.dragging) return false; // Short-circuit if user's callback killed it.

      var shouldContinue = _this.props.onStop(e, (0, _positionFns.createDraggableData)(_assertThisInitialized(_this), coreData));

      if (shouldContinue === false) return false;
      (0, _log.default)('Draggable: onDragStop: %j', coreData);
      var newState
      /*: $Shape<DraggableState>*/
      = {
        dragging: false,
        slackX: 0,
        slackY: 0
      }; // If this is a controlled component, the result of this operation will be to
      // revert back to the old position. We expect a handler on `onDragStop`, at the least.

      var controlled = Boolean(_this.props.position);

      if (controlled) {
        var _this$props$position = _this.props.position,
            x = _this$props$position.x,
            y = _this$props$position.y;
        newState.x = x;
        newState.y = y;
      }

      _this.setState(newState);
    });

    _this.state = {
      // Whether or not we are currently dragging.
      dragging: false,
      // Whether or not we have been dragged before.
      dragged: false,
      // Current transform x and y.
      x: props.position ? props.position.x : props.defaultPosition.x,
      y: props.position ? props.position.y : props.defaultPosition.y,
      prevPropsPosition: _objectSpread({}, props.position),
      // Used for compensating for out-of-bounds drags
      slackX: 0,
      slackY: 0,
      // Can only determine if SVG after mounting
      isElementSVG: false
    };

    if (props.position && !(props.onDrag || props.onStop)) {
      // eslint-disable-next-line no-console
      console.warn('A `position` was applied to this <Draggable>, without drag handlers. This will make this ' + 'component effectively undraggable. Please attach `onDrag` or `onStop` handlers so you can adjust the ' + '`position` of this element.');
    }

    return _this;
  }

  _createClass(Draggable, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      // Check to see if the element passed is an instanceof SVGElement
      if (typeof window.SVGElement !== 'undefined' && this.findDOMNode() instanceof window.SVGElement) {
        this.setState({
          isElementSVG: true
        });
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.setState({
        dragging: false
      }); // prevents invariant if unmounted while dragging
    } // React Strict Mode compatibility: if `nodeRef` is passed, we will use it instead of trying to find
    // the underlying DOM node ourselves. See the README for more information.

  }, {
    key: "findDOMNode",
    value: function findDOMNode()
    /*: ?HTMLElement*/
    {
      var _this$props$nodeRef$c, _this$props, _this$props$nodeRef;

      return (_this$props$nodeRef$c = (_this$props = this.props) === null || _this$props === void 0 ? void 0 : (_this$props$nodeRef = _this$props.nodeRef) === null || _this$props$nodeRef === void 0 ? void 0 : _this$props$nodeRef.current) !== null && _this$props$nodeRef$c !== void 0 ? _this$props$nodeRef$c : _reactDom.default.findDOMNode(this);
    }
  }, {
    key: "render",
    value: function render()
    /*: ReactElement<any>*/
    {
      var _clsx;

      var _this$props2 = this.props,
          axis = _this$props2.axis,
          bounds = _this$props2.bounds,
          children = _this$props2.children,
          defaultPosition = _this$props2.defaultPosition,
          defaultClassName = _this$props2.defaultClassName,
          defaultClassNameDragging = _this$props2.defaultClassNameDragging,
          defaultClassNameDragged = _this$props2.defaultClassNameDragged,
          position = _this$props2.position,
          positionOffset = _this$props2.positionOffset,
          scale = _this$props2.scale,
          draggableCoreProps = _objectWithoutProperties(_this$props2, _excluded);

      var style = {};
      var svgTransform = null; // If this is controlled, we don't want to move it - unless it's dragging.

      var controlled = Boolean(position);
      var draggable = !controlled || this.state.dragging;
      var validPosition = position || defaultPosition;
      var transformOpts = {
        // Set left if horizontal drag is enabled
        x: (0, _positionFns.canDragX)(this) && draggable ? this.state.x : validPosition.x,
        // Set top if vertical drag is enabled
        y: (0, _positionFns.canDragY)(this) && draggable ? this.state.y : validPosition.y
      }; // If this element was SVG, we use the `transform` attribute.

      if (this.state.isElementSVG) {
        svgTransform = (0, _domFns.createSVGTransform)(transformOpts, positionOffset);
      } else {
        // Add a CSS transform to move the element around. This allows us to move the element around
        // without worrying about whether or not it is relatively or absolutely positioned.
        // If the item you are dragging already has a transform set, wrap it in a <span> so <Draggable>
        // has a clean slate.
        style = (0, _domFns.createCSSTransform)(transformOpts, positionOffset);
      } // Mark with class while dragging


      var className = (0, _clsx2.default)(children.props.className || '', defaultClassName, (_clsx = {}, _defineProperty(_clsx, defaultClassNameDragging, this.state.dragging), _defineProperty(_clsx, defaultClassNameDragged, this.state.dragged), _clsx)); // Reuse the child provided
      // This makes it flexible to use whatever element is wanted (div, ul, etc)

      return /*#__PURE__*/React.createElement(_DraggableCore.default, _extends({}, draggableCoreProps, {
        onStart: this.onDragStart,
        onDrag: this.onDrag,
        onStop: this.onDragStop
      }), /*#__PURE__*/React.cloneElement(React.Children.only(children), {
        className: className,
        style: _objectSpread(_objectSpread({}, children.props.style), style),
        transform: svgTransform
      }));
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: // React 16.3+
    // Arity (props, state)
    function getDerivedStateFromProps(_ref, _ref2)
    /*: ?$Shape<DraggableState>*/
    {
      var position = _ref.position;
      var prevPropsPosition = _ref2.prevPropsPosition;

      // Set x/y if a new position is provided in props that is different than the previous.
      if (position && (!prevPropsPosition || position.x !== prevPropsPosition.x || position.y !== prevPropsPosition.y)) {
        (0, _log.default)('Draggable: getDerivedStateFromProps %j', {
          position: position,
          prevPropsPosition: prevPropsPosition
        });
        return {
          x: position.x,
          y: position.y,
          prevPropsPosition: _objectSpread({}, position)
        };
      }

      return null;
    }
  }]);

  return Draggable;
}(React.Component);

exports["default"] = Draggable;

_defineProperty(Draggable, "displayName", 'Draggable');

_defineProperty(Draggable, "propTypes", _objectSpread(_objectSpread({}, _DraggableCore.default.propTypes), {}, {
  /**
   * `axis` determines which axis the draggable can move.
   *
   *  Note that all callbacks will still return data as normal. This only
   *  controls flushing to the DOM.
   *
   * 'both' allows movement horizontally and vertically.
   * 'x' limits movement to horizontal axis.
   * 'y' limits movement to vertical axis.
   * 'none' limits all movement.
   *
   * Defaults to 'both'.
   */
  axis: _propTypes.default.oneOf(['both', 'x', 'y', 'none']),

  /**
   * `bounds` determines the range of movement available to the element.
   * Available values are:
   *
   * 'parent' restricts movement within the Draggable's parent node.
   *
   * Alternatively, pass an object with the following properties, all of which are optional:
   *
   * {left: LEFT_BOUND, right: RIGHT_BOUND, bottom: BOTTOM_BOUND, top: TOP_BOUND}
   *
   * All values are in px.
   *
   * Example:
   *
   * ```jsx
   *   let App = React.createClass({
   *       render: function () {
   *         return (
   *            <Draggable bounds={{right: 300, bottom: 300}}>
   *              <div>Content</div>
   *           </Draggable>
   *         );
   *       }
   *   });
   * ```
   */
  bounds: _propTypes.default.oneOfType([_propTypes.default.shape({
    left: _propTypes.default.number,
    right: _propTypes.default.number,
    top: _propTypes.default.number,
    bottom: _propTypes.default.number
  }), _propTypes.default.string, _propTypes.default.oneOf([false])]),
  defaultClassName: _propTypes.default.string,
  defaultClassNameDragging: _propTypes.default.string,
  defaultClassNameDragged: _propTypes.default.string,

  /**
   * `defaultPosition` specifies the x and y that the dragged item should start at
   *
   * Example:
   *
   * ```jsx
   *      let App = React.createClass({
   *          render: function () {
   *              return (
   *                  <Draggable defaultPosition={{x: 25, y: 25}}>
   *                      <div>I start with transformX: 25px and transformY: 25px;</div>
   *                  </Draggable>
   *              );
   *          }
   *      });
   * ```
   */
  defaultPosition: _propTypes.default.shape({
    x: _propTypes.default.number,
    y: _propTypes.default.number
  }),
  positionOffset: _propTypes.default.shape({
    x: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string]),
    y: _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.string])
  }),

  /**
   * `position`, if present, defines the current position of the element.
   *
   *  This is similar to how form elements in React work - if no `position` is supplied, the component
   *  is uncontrolled.
   *
   * Example:
   *
   * ```jsx
   *      let App = React.createClass({
   *          render: function () {
   *              return (
   *                  <Draggable position={{x: 25, y: 25}}>
   *                      <div>I start with transformX: 25px and transformY: 25px;</div>
   *                  </Draggable>
   *              );
   *          }
   *      });
   * ```
   */
  position: _propTypes.default.shape({
    x: _propTypes.default.number,
    y: _propTypes.default.number
  }),

  /**
   * These properties should be defined on the child, not here.
   */
  className: _shims.dontSetMe,
  style: _shims.dontSetMe,
  transform: _shims.dontSetMe
}));

_defineProperty(Draggable, "defaultProps", _objectSpread(_objectSpread({}, _DraggableCore.default.defaultProps), {}, {
  axis: 'both',
  bounds: false,
  defaultClassName: 'react-draggable',
  defaultClassNameDragging: 'react-draggable-dragging',
  defaultClassNameDragged: 'react-draggable-dragged',
  defaultPosition: {
    x: 0,
    y: 0
  },
  scale: 1
}));

/***/ }),

/***/ 93816:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

"use strict";


function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;

var React = _interopRequireWildcard(__webpack_require__(99196));

var _propTypes = _interopRequireDefault(__webpack_require__(13980));

var _reactDom = _interopRequireDefault(__webpack_require__(91850));

var _domFns = __webpack_require__(54688);

var _positionFns = __webpack_require__(93585);

var _shims = __webpack_require__(40136);

var _log = _interopRequireDefault(__webpack_require__(81177));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

// Simple abstraction for dragging events names.
var eventsFor = {
  touch: {
    start: 'touchstart',
    move: 'touchmove',
    stop: 'touchend'
  },
  mouse: {
    start: 'mousedown',
    move: 'mousemove',
    stop: 'mouseup'
  }
}; // Default to mouse events.

var dragEventFor = eventsFor.mouse;
/*:: type DraggableCoreState = {
  dragging: boolean,
  lastX: number,
  lastY: number,
  touchIdentifier: ?number
};*/

/*:: export type DraggableData = {
  node: HTMLElement,
  x: number, y: number,
  deltaX: number, deltaY: number,
  lastX: number, lastY: number,
};*/

/*:: export type DraggableEventHandler = (e: MouseEvent, data: DraggableData) => void | false;*/

/*:: export type ControlPosition = {x: number, y: number};*/

/*:: export type PositionOffsetControlPosition = {x: number|string, y: number|string};*/

/*:: export type DraggableCoreDefaultProps = {
  allowAnyClick: boolean,
  disabled: boolean,
  enableUserSelectHack: boolean,
  onStart: DraggableEventHandler,
  onDrag: DraggableEventHandler,
  onStop: DraggableEventHandler,
  onMouseDown: (e: MouseEvent) => void,
  scale: number,
};*/

/*:: export type DraggableCoreProps = {
  ...DraggableCoreDefaultProps,
  cancel: string,
  children: ReactElement<any>,
  offsetParent: HTMLElement,
  grid: [number, number],
  handle: string,
  nodeRef?: ?React.ElementRef<any>,
};*/

//
// Define <DraggableCore>.
//
// <DraggableCore> is for advanced usage of <Draggable>. It maintains minimal internal state so it can
// work well with libraries that require more control over the element.
//
var DraggableCore = /*#__PURE__*/function (_React$Component) {
  _inherits(DraggableCore, _React$Component);

  var _super = _createSuper(DraggableCore);

  function DraggableCore() {
    var _this;

    _classCallCheck(this, DraggableCore);

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _super.call.apply(_super, [this].concat(args));

    _defineProperty(_assertThisInitialized(_this), "state", {
      dragging: false,
      // Used while dragging to determine deltas.
      lastX: NaN,
      lastY: NaN,
      touchIdentifier: null
    });

    _defineProperty(_assertThisInitialized(_this), "mounted", false);

    _defineProperty(_assertThisInitialized(_this), "handleDragStart", function (e) {
      // Make it possible to attach event handlers on top of this one.
      _this.props.onMouseDown(e); // Only accept left-clicks.


      if (!_this.props.allowAnyClick && typeof e.button === 'number' && e.button !== 0) return false; // Get nodes. Be sure to grab relative document (could be iframed)

      var thisNode = _this.findDOMNode();

      if (!thisNode || !thisNode.ownerDocument || !thisNode.ownerDocument.body) {
        throw new Error('<DraggableCore> not mounted on DragStart!');
      }

      var ownerDocument = thisNode.ownerDocument; // Short circuit if handle or cancel prop was provided and selector doesn't match.

      if (_this.props.disabled || !(e.target instanceof ownerDocument.defaultView.Node) || _this.props.handle && !(0, _domFns.matchesSelectorAndParentsTo)(e.target, _this.props.handle, thisNode) || _this.props.cancel && (0, _domFns.matchesSelectorAndParentsTo)(e.target, _this.props.cancel, thisNode)) {
        return;
      } // Prevent scrolling on mobile devices, like ipad/iphone.
      // Important that this is after handle/cancel.


      if (e.type === 'touchstart') e.preventDefault(); // Set touch identifier in component state if this is a touch event. This allows us to
      // distinguish between individual touches on multitouch screens by identifying which
      // touchpoint was set to this element.

      var touchIdentifier = (0, _domFns.getTouchIdentifier)(e);

      _this.setState({
        touchIdentifier: touchIdentifier
      }); // Get the current drag point from the event. This is used as the offset.


      var position = (0, _positionFns.getControlPosition)(e, touchIdentifier, _assertThisInitialized(_this));
      if (position == null) return; // not possible but satisfies flow

      var x = position.x,
          y = position.y; // Create an event object with all the data parents need to make a decision here.

      var coreEvent = (0, _positionFns.createCoreData)(_assertThisInitialized(_this), x, y);
      (0, _log.default)('DraggableCore: handleDragStart: %j', coreEvent); // Call event handler. If it returns explicit false, cancel.

      (0, _log.default)('calling', _this.props.onStart);

      var shouldUpdate = _this.props.onStart(e, coreEvent);

      if (shouldUpdate === false || _this.mounted === false) return; // Add a style to the body to disable user-select. This prevents text from
      // being selected all over the page.

      if (_this.props.enableUserSelectHack) (0, _domFns.addUserSelectStyles)(ownerDocument); // Initiate dragging. Set the current x and y as offsets
      // so we know how much we've moved during the drag. This allows us
      // to drag elements around even if they have been moved, without issue.

      _this.setState({
        dragging: true,
        lastX: x,
        lastY: y
      }); // Add events to the document directly so we catch when the user's mouse/touch moves outside of
      // this element. We use different events depending on whether or not we have detected that this
      // is a touch-capable device.


      (0, _domFns.addEvent)(ownerDocument, dragEventFor.move, _this.handleDrag);
      (0, _domFns.addEvent)(ownerDocument, dragEventFor.stop, _this.handleDragStop);
    });

    _defineProperty(_assertThisInitialized(_this), "handleDrag", function (e) {
      // Get the current drag point from the event. This is used as the offset.
      var position = (0, _positionFns.getControlPosition)(e, _this.state.touchIdentifier, _assertThisInitialized(_this));
      if (position == null) return;
      var x = position.x,
          y = position.y; // Snap to grid if prop has been provided

      if (Array.isArray(_this.props.grid)) {
        var deltaX = x - _this.state.lastX,
            deltaY = y - _this.state.lastY;

        var _snapToGrid = (0, _positionFns.snapToGrid)(_this.props.grid, deltaX, deltaY);

        var _snapToGrid2 = _slicedToArray(_snapToGrid, 2);

        deltaX = _snapToGrid2[0];
        deltaY = _snapToGrid2[1];
        if (!deltaX && !deltaY) return; // skip useless drag

        x = _this.state.lastX + deltaX, y = _this.state.lastY + deltaY;
      }

      var coreEvent = (0, _positionFns.createCoreData)(_assertThisInitialized(_this), x, y);
      (0, _log.default)('DraggableCore: handleDrag: %j', coreEvent); // Call event handler. If it returns explicit false, trigger end.

      var shouldUpdate = _this.props.onDrag(e, coreEvent);

      if (shouldUpdate === false || _this.mounted === false) {
        try {
          // $FlowIgnore
          _this.handleDragStop(new MouseEvent('mouseup'));
        } catch (err) {
          // Old browsers
          var event = ((document.createEvent('MouseEvents')
          /*: any*/
          )
          /*: MouseTouchEvent*/
          ); // I see why this insanity was deprecated
          // $FlowIgnore

          event.initMouseEvent('mouseup', true, true, window, 0, 0, 0, 0, 0, false, false, false, false, 0, null);

          _this.handleDragStop(event);
        }

        return;
      }

      _this.setState({
        lastX: x,
        lastY: y
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleDragStop", function (e) {
      if (!_this.state.dragging) return;
      var position = (0, _positionFns.getControlPosition)(e, _this.state.touchIdentifier, _assertThisInitialized(_this));
      if (position == null) return;
      var x = position.x,
          y = position.y;
      var coreEvent = (0, _positionFns.createCoreData)(_assertThisInitialized(_this), x, y); // Call event handler

      var shouldContinue = _this.props.onStop(e, coreEvent);

      if (shouldContinue === false || _this.mounted === false) return false;

      var thisNode = _this.findDOMNode();

      if (thisNode) {
        // Remove user-select hack
        if (_this.props.enableUserSelectHack) (0, _domFns.removeUserSelectStyles)(thisNode.ownerDocument);
      }

      (0, _log.default)('DraggableCore: handleDragStop: %j', coreEvent); // Reset the el.

      _this.setState({
        dragging: false,
        lastX: NaN,
        lastY: NaN
      });

      if (thisNode) {
        // Remove event handlers
        (0, _log.default)('DraggableCore: Removing handlers');
        (0, _domFns.removeEvent)(thisNode.ownerDocument, dragEventFor.move, _this.handleDrag);
        (0, _domFns.removeEvent)(thisNode.ownerDocument, dragEventFor.stop, _this.handleDragStop);
      }
    });

    _defineProperty(_assertThisInitialized(_this), "onMouseDown", function (e) {
      dragEventFor = eventsFor.mouse; // on touchscreen laptops we could switch back to mouse

      return _this.handleDragStart(e);
    });

    _defineProperty(_assertThisInitialized(_this), "onMouseUp", function (e) {
      dragEventFor = eventsFor.mouse;
      return _this.handleDragStop(e);
    });

    _defineProperty(_assertThisInitialized(_this), "onTouchStart", function (e) {
      // We're on a touch device now, so change the event handlers
      dragEventFor = eventsFor.touch;
      return _this.handleDragStart(e);
    });

    _defineProperty(_assertThisInitialized(_this), "onTouchEnd", function (e) {
      // We're on a touch device now, so change the event handlers
      dragEventFor = eventsFor.touch;
      return _this.handleDragStop(e);
    });

    return _this;
  }

  _createClass(DraggableCore, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.mounted = true; // Touch handlers must be added with {passive: false} to be cancelable.
      // https://developers.google.com/web/updates/2017/01/scrolling-intervention

      var thisNode = this.findDOMNode();

      if (thisNode) {
        (0, _domFns.addEvent)(thisNode, eventsFor.touch.start, this.onTouchStart, {
          passive: false
        });
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.mounted = false; // Remove any leftover event handlers. Remove both touch and mouse handlers in case
      // some browser quirk caused a touch event to fire during a mouse move, or vice versa.

      var thisNode = this.findDOMNode();

      if (thisNode) {
        var ownerDocument = thisNode.ownerDocument;
        (0, _domFns.removeEvent)(ownerDocument, eventsFor.mouse.move, this.handleDrag);
        (0, _domFns.removeEvent)(ownerDocument, eventsFor.touch.move, this.handleDrag);
        (0, _domFns.removeEvent)(ownerDocument, eventsFor.mouse.stop, this.handleDragStop);
        (0, _domFns.removeEvent)(ownerDocument, eventsFor.touch.stop, this.handleDragStop);
        (0, _domFns.removeEvent)(thisNode, eventsFor.touch.start, this.onTouchStart, {
          passive: false
        });
        if (this.props.enableUserSelectHack) (0, _domFns.removeUserSelectStyles)(ownerDocument);
      }
    } // React Strict Mode compatibility: if `nodeRef` is passed, we will use it instead of trying to find
    // the underlying DOM node ourselves. See the README for more information.

  }, {
    key: "findDOMNode",
    value: function findDOMNode()
    /*: ?HTMLElement*/
    {
      var _this$props$nodeRef$c, _this$props, _this$props$nodeRef;

      return (_this$props$nodeRef$c = (_this$props = this.props) === null || _this$props === void 0 ? void 0 : (_this$props$nodeRef = _this$props.nodeRef) === null || _this$props$nodeRef === void 0 ? void 0 : _this$props$nodeRef.current) !== null && _this$props$nodeRef$c !== void 0 ? _this$props$nodeRef$c : _reactDom.default.findDOMNode(this);
    }
  }, {
    key: "render",
    value: function render()
    /*: React.Element<any>*/
    {
      // Reuse the child provided
      // This makes it flexible to use whatever element is wanted (div, ul, etc)
      return /*#__PURE__*/React.cloneElement(React.Children.only(this.props.children), {
        // Note: mouseMove handler is attached to document so it will still function
        // when the user drags quickly and leaves the bounds of the element.
        onMouseDown: this.onMouseDown,
        onMouseUp: this.onMouseUp,
        // onTouchStart is added on `componentDidMount` so they can be added with
        // {passive: false}, which allows it to cancel. See
        // https://developers.google.com/web/updates/2017/01/scrolling-intervention
        onTouchEnd: this.onTouchEnd
      });
    }
  }]);

  return DraggableCore;
}(React.Component);

exports["default"] = DraggableCore;

_defineProperty(DraggableCore, "displayName", 'DraggableCore');

_defineProperty(DraggableCore, "propTypes", {
  /**
   * `allowAnyClick` allows dragging using any mouse button.
   * By default, we only accept the left button.
   *
   * Defaults to `false`.
   */
  allowAnyClick: _propTypes.default.bool,

  /**
   * `disabled`, if true, stops the <Draggable> from dragging. All handlers,
   * with the exception of `onMouseDown`, will not fire.
   */
  disabled: _propTypes.default.bool,

  /**
   * By default, we add 'user-select:none' attributes to the document body
   * to prevent ugly text selection during drag. If this is causing problems
   * for your app, set this to `false`.
   */
  enableUserSelectHack: _propTypes.default.bool,

  /**
   * `offsetParent`, if set, uses the passed DOM node to compute drag offsets
   * instead of using the parent node.
   */
  offsetParent: function offsetParent(props
  /*: DraggableCoreProps*/
  , propName
  /*: $Keys<DraggableCoreProps>*/
  ) {
    if (props[propName] && props[propName].nodeType !== 1) {
      throw new Error('Draggable\'s offsetParent must be a DOM Node.');
    }
  },

  /**
   * `grid` specifies the x and y that dragging should snap to.
   */
  grid: _propTypes.default.arrayOf(_propTypes.default.number),

  /**
   * `handle` specifies a selector to be used as the handle that initiates drag.
   *
   * Example:
   *
   * ```jsx
   *   let App = React.createClass({
   *       render: function () {
   *         return (
   *            <Draggable handle=".handle">
   *              <div>
   *                  <div className="handle">Click me to drag</div>
   *                  <div>This is some other content</div>
   *              </div>
   *           </Draggable>
   *         );
   *       }
   *   });
   * ```
   */
  handle: _propTypes.default.string,

  /**
   * `cancel` specifies a selector to be used to prevent drag initialization.
   *
   * Example:
   *
   * ```jsx
   *   let App = React.createClass({
   *       render: function () {
   *           return(
   *               <Draggable cancel=".cancel">
   *                   <div>
   *                     <div className="cancel">You can't drag from here</div>
   *                     <div>Dragging here works fine</div>
   *                   </div>
   *               </Draggable>
   *           );
   *       }
   *   });
   * ```
   */
  cancel: _propTypes.default.string,

  /* If running in React Strict mode, ReactDOM.findDOMNode() is deprecated.
   * Unfortunately, in order for <Draggable> to work properly, we need raw access
   * to the underlying DOM node. If you want to avoid the warning, pass a `nodeRef`
   * as in this example:
   *
   * function MyComponent() {
   *   const nodeRef = React.useRef(null);
   *   return (
   *     <Draggable nodeRef={nodeRef}>
   *       <div ref={nodeRef}>Example Target</div>
   *     </Draggable>
   *   );
   * }
   *
   * This can be used for arbitrarily nested components, so long as the ref ends up
   * pointing to the actual child DOM node and not a custom component.
   */
  nodeRef: _propTypes.default.object,

  /**
   * Called when dragging starts.
   * If this function returns the boolean false, dragging will be canceled.
   */
  onStart: _propTypes.default.func,

  /**
   * Called while dragging.
   * If this function returns the boolean false, dragging will be canceled.
   */
  onDrag: _propTypes.default.func,

  /**
   * Called when dragging stops.
   * If this function returns the boolean false, the drag will remain active.
   */
  onStop: _propTypes.default.func,

  /**
   * A workaround option which can be passed if onMouseDown needs to be accessed,
   * since it'll always be blocked (as there is internal use of onMouseDown)
   */
  onMouseDown: _propTypes.default.func,

  /**
   * `scale`, if set, applies scaling while dragging an element
   */
  scale: _propTypes.default.number,

  /**
   * These properties should be defined on the child, not here.
   */
  className: _shims.dontSetMe,
  style: _shims.dontSetMe,
  transform: _shims.dontSetMe
});

_defineProperty(DraggableCore, "defaultProps", {
  allowAnyClick: false,
  // by default only accept left click
  disabled: false,
  enableUserSelectHack: true,
  onStart: function onStart() {},
  onDrag: function onDrag() {},
  onStop: function onStop() {},
  onMouseDown: function onMouseDown() {},
  scale: 1
});

/***/ }),

/***/ 41327:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var _require = __webpack_require__(11997),
    Draggable = _require.default,
    DraggableCore = _require.DraggableCore; // Previous versions of this lib exported <Draggable> as the root export. As to no-// them, or TypeScript, we export *both* as the root and as 'default'.
// See https://github.com/mzabriskie/react-draggable/pull/254
// and https://github.com/mzabriskie/react-draggable/issues/266


module.exports = Draggable;
module.exports["default"] = Draggable;
module.exports.DraggableCore = DraggableCore;

/***/ }),

/***/ 54688:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

"use strict";


function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.matchesSelector = matchesSelector;
exports.matchesSelectorAndParentsTo = matchesSelectorAndParentsTo;
exports.addEvent = addEvent;
exports.removeEvent = removeEvent;
exports.outerHeight = outerHeight;
exports.outerWidth = outerWidth;
exports.innerHeight = innerHeight;
exports.innerWidth = innerWidth;
exports.offsetXYFromParent = offsetXYFromParent;
exports.createCSSTransform = createCSSTransform;
exports.createSVGTransform = createSVGTransform;
exports.getTranslation = getTranslation;
exports.getTouch = getTouch;
exports.getTouchIdentifier = getTouchIdentifier;
exports.addUserSelectStyles = addUserSelectStyles;
exports.removeUserSelectStyles = removeUserSelectStyles;
exports.addClassName = addClassName;
exports.removeClassName = removeClassName;

var _shims = __webpack_require__(40136);

var _getPrefix = _interopRequireWildcard(__webpack_require__(92185));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var matchesSelectorFunc = '';

function matchesSelector(el
/*: Node*/
, selector
/*: string*/
)
/*: boolean*/
{
  if (!matchesSelectorFunc) {
    matchesSelectorFunc = (0, _shims.findInArray)(['matches', 'webkitMatchesSelector', 'mozMatchesSelector', 'msMatchesSelector', 'oMatchesSelector'], function (method) {
      // $FlowIgnore: Doesn't think elements are indexable
      return (0, _shims.isFunction)(el[method]);
    });
  } // Might not be found entirely (not an Element?) - in that case, bail
  // $FlowIgnore: Doesn't think elements are indexable


  if (!(0, _shims.isFunction)(el[matchesSelectorFunc])) return false; // $FlowIgnore: Doesn't think elements are indexable

  return el[matchesSelectorFunc](selector);
} // Works up the tree to the draggable itself attempting to match selector.


function matchesSelectorAndParentsTo(el
/*: Node*/
, selector
/*: string*/
, baseNode
/*: Node*/
)
/*: boolean*/
{
  var node = el;

  do {
    if (matchesSelector(node, selector)) return true;
    if (node === baseNode) return false;
    node = node.parentNode;
  } while (node);

  return false;
}

function addEvent(el
/*: ?Node*/
, event
/*: string*/
, handler
/*: Function*/
, inputOptions
/*: Object*/
)
/*: void*/
{
  if (!el) return;

  var options = _objectSpread({
    capture: true
  }, inputOptions); // $FlowIgnore[method-unbinding]


  if (el.addEventListener) {
    el.addEventListener(event, handler, options);
  } else if (el.attachEvent) {
    el.attachEvent('on' + event, handler);
  } else {
    // $FlowIgnore: Doesn't think elements are indexable
    el['on' + event] = handler;
  }
}

function removeEvent(el
/*: ?Node*/
, event
/*: string*/
, handler
/*: Function*/
, inputOptions
/*: Object*/
)
/*: void*/
{
  if (!el) return;

  var options = _objectSpread({
    capture: true
  }, inputOptions); // $FlowIgnore[method-unbinding]


  if (el.removeEventListener) {
    el.removeEventListener(event, handler, options);
  } else if (el.detachEvent) {
    el.detachEvent('on' + event, handler);
  } else {
    // $FlowIgnore: Doesn't think elements are indexable
    el['on' + event] = null;
  }
}

function outerHeight(node
/*: HTMLElement*/
)
/*: number*/
{
  // This is deliberately excluding margin for our calculations, since we are using
  // offsetTop which is including margin. See getBoundPosition
  var height = node.clientHeight;
  var computedStyle = node.ownerDocument.defaultView.getComputedStyle(node);
  height += (0, _shims.int)(computedStyle.borderTopWidth);
  height += (0, _shims.int)(computedStyle.borderBottomWidth);
  return height;
}

function outerWidth(node
/*: HTMLElement*/
)
/*: number*/
{
  // This is deliberately excluding margin for our calculations, since we are using
  // offsetLeft which is including margin. See getBoundPosition
  var width = node.clientWidth;
  var computedStyle = node.ownerDocument.defaultView.getComputedStyle(node);
  width += (0, _shims.int)(computedStyle.borderLeftWidth);
  width += (0, _shims.int)(computedStyle.borderRightWidth);
  return width;
}

function innerHeight(node
/*: HTMLElement*/
)
/*: number*/
{
  var height = node.clientHeight;
  var computedStyle = node.ownerDocument.defaultView.getComputedStyle(node);
  height -= (0, _shims.int)(computedStyle.paddingTop);
  height -= (0, _shims.int)(computedStyle.paddingBottom);
  return height;
}

function innerWidth(node
/*: HTMLElement*/
)
/*: number*/
{
  var width = node.clientWidth;
  var computedStyle = node.ownerDocument.defaultView.getComputedStyle(node);
  width -= (0, _shims.int)(computedStyle.paddingLeft);
  width -= (0, _shims.int)(computedStyle.paddingRight);
  return width;
}
/*:: interface EventWithOffset {
  clientX: number, clientY: number
}*/


// Get from offsetParent
function offsetXYFromParent(evt
/*: EventWithOffset*/
, offsetParent
/*: HTMLElement*/
, scale
/*: number*/
)
/*: ControlPosition*/
{
  var isBody = offsetParent === offsetParent.ownerDocument.body;
  var offsetParentRect = isBody ? {
    left: 0,
    top: 0
  } : offsetParent.getBoundingClientRect();
  var x = (evt.clientX + offsetParent.scrollLeft - offsetParentRect.left) / scale;
  var y = (evt.clientY + offsetParent.scrollTop - offsetParentRect.top) / scale;
  return {
    x: x,
    y: y
  };
}

function createCSSTransform(controlPos
/*: ControlPosition*/
, positionOffset
/*: PositionOffsetControlPosition*/
)
/*: Object*/
{
  var translation = getTranslation(controlPos, positionOffset, 'px');
  return _defineProperty({}, (0, _getPrefix.browserPrefixToKey)('transform', _getPrefix.default), translation);
}

function createSVGTransform(controlPos
/*: ControlPosition*/
, positionOffset
/*: PositionOffsetControlPosition*/
)
/*: string*/
{
  var translation = getTranslation(controlPos, positionOffset, '');
  return translation;
}

function getTranslation(_ref2, positionOffset
/*: PositionOffsetControlPosition*/
, unitSuffix
/*: string*/
)
/*: string*/
{
  var x = _ref2.x,
      y = _ref2.y;
  var translation = "translate(".concat(x).concat(unitSuffix, ",").concat(y).concat(unitSuffix, ")");

  if (positionOffset) {
    var defaultX = "".concat(typeof positionOffset.x === 'string' ? positionOffset.x : positionOffset.x + unitSuffix);
    var defaultY = "".concat(typeof positionOffset.y === 'string' ? positionOffset.y : positionOffset.y + unitSuffix);
    translation = "translate(".concat(defaultX, ", ").concat(defaultY, ")") + translation;
  }

  return translation;
}

function getTouch(e
/*: MouseTouchEvent*/
, identifier
/*: number*/
)
/*: ?{clientX: number, clientY: number}*/
{
  return e.targetTouches && (0, _shims.findInArray)(e.targetTouches, function (t) {
    return identifier === t.identifier;
  }) || e.changedTouches && (0, _shims.findInArray)(e.changedTouches, function (t) {
    return identifier === t.identifier;
  });
}

function getTouchIdentifier(e
/*: MouseTouchEvent*/
)
/*: ?number*/
{
  if (e.targetTouches && e.targetTouches[0]) return e.targetTouches[0].identifier;
  if (e.changedTouches && e.changedTouches[0]) return e.changedTouches[0].identifier;
} // User-select Hacks:
//
// Useful for preventing blue highlights all over everything when dragging.
// Note we're passing `document` b/c we could be iframed


function addUserSelectStyles(doc
/*: ?Document*/
) {
  if (!doc) return;
  var styleEl = doc.getElementById('react-draggable-style-el');

  if (!styleEl) {
    styleEl = doc.createElement('style');
    styleEl.type = 'text/css';
    styleEl.id = 'react-draggable-style-el';
    styleEl.innerHTML = '.react-draggable-transparent-selection *::-moz-selection {all: inherit;}\n';
    styleEl.innerHTML += '.react-draggable-transparent-selection *::selection {all: inherit;}\n';
    doc.getElementsByTagName('head')[0].appendChild(styleEl);
  }

  if (doc.body) addClassName(doc.body, 'react-draggable-transparent-selection');
}

function removeUserSelectStyles(doc
/*: ?Document*/
) {
  if (!doc) return;

  try {
    if (doc.body) removeClassName(doc.body, 'react-draggable-transparent-selection'); // $FlowIgnore: IE

    if (doc.selection) {
      // $FlowIgnore: IE
      doc.selection.empty();
    } else {
      // Remove selection caused by scroll, unless it's a focused input
      // (we use doc.defaultView in case we're in an iframe)
      var selection = (doc.defaultView || window).getSelection();

      if (selection && selection.type !== 'Caret') {
        selection.removeAllRanges();
      }
    }
  } catch (e) {// probably IE
  }
}

function addClassName(el
/*: HTMLElement*/
, className
/*: string*/
) {
  if (el.classList) {
    el.classList.add(className);
  } else {
    if (!el.className.match(new RegExp("(?:^|\\s)".concat(className, "(?!\\S)")))) {
      el.className += " ".concat(className);
    }
  }
}

function removeClassName(el
/*: HTMLElement*/
, className
/*: string*/
) {
  if (el.classList) {
    el.classList.remove(className);
  } else {
    el.className = el.className.replace(new RegExp("(?:^|\\s)".concat(className, "(?!\\S)"), 'g'), '');
  }
}

/***/ }),

/***/ 92185:
/***/ (function(__unused_webpack_module, exports) {

"use strict";


Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.getPrefix = getPrefix;
exports.browserPrefixToKey = browserPrefixToKey;
exports.browserPrefixToStyle = browserPrefixToStyle;
exports["default"] = void 0;
var prefixes = ['Moz', 'Webkit', 'O', 'ms'];

function getPrefix()
/*: string*/
{
  var _window$document, _window$document$docu;

  var prop
  /*: string*/
  = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'transform';
  // Ensure we're running in an environment where there is actually a global
  // `window` obj
  if (typeof window === 'undefined') return ''; // If we're in a pseudo-browser server-side environment, this access
  // path may not exist, so bail out if it doesn't.

  var style = (_window$document = window.document) === null || _window$document === void 0 ? void 0 : (_window$document$docu = _window$document.documentElement) === null || _window$document$docu === void 0 ? void 0 : _window$document$docu.style;
  if (!style) return '';
  if (prop in style) return '';

  for (var i = 0; i < prefixes.length; i++) {
    if (browserPrefixToKey(prop, prefixes[i]) in style) return prefixes[i];
  }

  return '';
}

function browserPrefixToKey(prop
/*: string*/
, prefix
/*: string*/
)
/*: string*/
{
  return prefix ? "".concat(prefix).concat(kebabToTitleCase(prop)) : prop;
}

function browserPrefixToStyle(prop
/*: string*/
, prefix
/*: string*/
)
/*: string*/
{
  return prefix ? "-".concat(prefix.toLowerCase(), "-").concat(prop) : prop;
}

function kebabToTitleCase(str
/*: string*/
)
/*: string*/
{
  var out = '';
  var shouldCapitalize = true;

  for (var i = 0; i < str.length; i++) {
    if (shouldCapitalize) {
      out += str[i].toUpperCase();
      shouldCapitalize = false;
    } else if (str[i] === '-') {
      shouldCapitalize = true;
    } else {
      out += str[i];
    }
  }

  return out;
} // Default export is the prefix itself, like 'Moz', 'Webkit', etc
// Note that you may have to re-test for certain things; for instance, Chrome 50
// can handle unprefixed `transform`, but not unprefixed `user-select`


var _default = (getPrefix()
/*: string*/
);

exports["default"] = _default;

/***/ }),

/***/ 81177:
/***/ (function(__unused_webpack_module, exports) {

"use strict";


Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = log;

/*eslint no-console:0*/
function log() {
  var _console;

  if (false) {}
}

/***/ }),

/***/ 93585:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

"use strict";


Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.getBoundPosition = getBoundPosition;
exports.snapToGrid = snapToGrid;
exports.canDragX = canDragX;
exports.canDragY = canDragY;
exports.getControlPosition = getControlPosition;
exports.createCoreData = createCoreData;
exports.createDraggableData = createDraggableData;

var _shims = __webpack_require__(40136);

var _domFns = __webpack_require__(54688);

function getBoundPosition(draggable
/*: Draggable*/
, x
/*: number*/
, y
/*: number*/
)
/*: [number, number]*/
{
  // If no bounds, short-circuit and move on
  if (!draggable.props.bounds) return [x, y]; // Clone new bounds

  var bounds = draggable.props.bounds;
  bounds = typeof bounds === 'string' ? bounds : cloneBounds(bounds);
  var node = findDOMNode(draggable);

  if (typeof bounds === 'string') {
    var ownerDocument = node.ownerDocument;
    var ownerWindow = ownerDocument.defaultView;
    var boundNode;

    if (bounds === 'parent') {
      boundNode = node.parentNode;
    } else {
      boundNode = ownerDocument.querySelector(bounds);
    }

    if (!(boundNode instanceof ownerWindow.HTMLElement)) {
      throw new Error('Bounds selector "' + bounds + '" could not find an element.');
    }

    var boundNodeEl
    /*: HTMLElement*/
    = boundNode; // for Flow, can't seem to refine correctly

    var nodeStyle = ownerWindow.getComputedStyle(node);
    var boundNodeStyle = ownerWindow.getComputedStyle(boundNodeEl); // Compute bounds. This is a pain with padding and offsets but this gets it exactly right.

    bounds = {
      left: -node.offsetLeft + (0, _shims.int)(boundNodeStyle.paddingLeft) + (0, _shims.int)(nodeStyle.marginLeft),
      top: -node.offsetTop + (0, _shims.int)(boundNodeStyle.paddingTop) + (0, _shims.int)(nodeStyle.marginTop),
      right: (0, _domFns.innerWidth)(boundNodeEl) - (0, _domFns.outerWidth)(node) - node.offsetLeft + (0, _shims.int)(boundNodeStyle.paddingRight) - (0, _shims.int)(nodeStyle.marginRight),
      bottom: (0, _domFns.innerHeight)(boundNodeEl) - (0, _domFns.outerHeight)(node) - node.offsetTop + (0, _shims.int)(boundNodeStyle.paddingBottom) - (0, _shims.int)(nodeStyle.marginBottom)
    };
  } // Keep x and y below right and bottom limits...


  if ((0, _shims.isNum)(bounds.right)) x = Math.min(x, bounds.right);
  if ((0, _shims.isNum)(bounds.bottom)) y = Math.min(y, bounds.bottom); // But above left and top limits.

  if ((0, _shims.isNum)(bounds.left)) x = Math.max(x, bounds.left);
  if ((0, _shims.isNum)(bounds.top)) y = Math.max(y, bounds.top);
  return [x, y];
}

function snapToGrid(grid
/*: [number, number]*/
, pendingX
/*: number*/
, pendingY
/*: number*/
)
/*: [number, number]*/
{
  var x = Math.round(pendingX / grid[0]) * grid[0];
  var y = Math.round(pendingY / grid[1]) * grid[1];
  return [x, y];
}

function canDragX(draggable
/*: Draggable*/
)
/*: boolean*/
{
  return draggable.props.axis === 'both' || draggable.props.axis === 'x';
}

function canDragY(draggable
/*: Draggable*/
)
/*: boolean*/
{
  return draggable.props.axis === 'both' || draggable.props.axis === 'y';
} // Get {x, y} positions from event.


function getControlPosition(e
/*: MouseTouchEvent*/
, touchIdentifier
/*: ?number*/
, draggableCore
/*: DraggableCore*/
)
/*: ?ControlPosition*/
{
  var touchObj = typeof touchIdentifier === 'number' ? (0, _domFns.getTouch)(e, touchIdentifier) : null;
  if (typeof touchIdentifier === 'number' && !touchObj) return null; // not the right touch

  var node = findDOMNode(draggableCore); // User can provide an offsetParent if desired.

  var offsetParent = draggableCore.props.offsetParent || node.offsetParent || node.ownerDocument.body;
  return (0, _domFns.offsetXYFromParent)(touchObj || e, offsetParent, draggableCore.props.scale);
} // Create an data object exposed by <DraggableCore>'s events


function createCoreData(draggable
/*: DraggableCore*/
, x
/*: number*/
, y
/*: number*/
)
/*: DraggableData*/
{
  var state = draggable.state;
  var isStart = !(0, _shims.isNum)(state.lastX);
  var node = findDOMNode(draggable);

  if (isStart) {
    // If this is our first move, use the x and y as last coords.
    return {
      node: node,
      deltaX: 0,
      deltaY: 0,
      lastX: x,
      lastY: y,
      x: x,
      y: y
    };
  } else {
    // Otherwise calculate proper values.
    return {
      node: node,
      deltaX: x - state.lastX,
      deltaY: y - state.lastY,
      lastX: state.lastX,
      lastY: state.lastY,
      x: x,
      y: y
    };
  }
} // Create an data exposed by <Draggable>'s events


function createDraggableData(draggable
/*: Draggable*/
, coreData
/*: DraggableData*/
)
/*: DraggableData*/
{
  var scale = draggable.props.scale;
  return {
    node: coreData.node,
    x: draggable.state.x + coreData.deltaX / scale,
    y: draggable.state.y + coreData.deltaY / scale,
    deltaX: coreData.deltaX / scale,
    deltaY: coreData.deltaY / scale,
    lastX: draggable.state.x,
    lastY: draggable.state.y
  };
} // A lot faster than stringify/parse


function cloneBounds(bounds
/*: Bounds*/
)
/*: Bounds*/
{
  return {
    left: bounds.left,
    top: bounds.top,
    right: bounds.right,
    bottom: bounds.bottom
  };
}

function findDOMNode(draggable
/*: Draggable | DraggableCore*/
)
/*: HTMLElement*/
{
  var node = draggable.findDOMNode();

  if (!node) {
    throw new Error('<DraggableCore>: Unmounted during event!');
  } // $FlowIgnore we can't assert on HTMLElement due to tests... FIXME


  return node;
}

/***/ }),

/***/ 40136:
/***/ (function(__unused_webpack_module, exports) {

"use strict";


Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports.findInArray = findInArray;
exports.isFunction = isFunction;
exports.isNum = isNum;
exports.int = int;
exports.dontSetMe = dontSetMe;

// @credits https://gist.github.com/rogozhnikoff/a43cfed27c41e4e68cdc
function findInArray(array
/*: Array<any> | TouchList*/
, callback
/*: Function*/
)
/*: any*/
{
  for (var i = 0, length = array.length; i < length; i++) {
    if (callback.apply(callback, [array[i], i, array])) return array[i];
  }
}

function isFunction(func
/*: any*/
)
/*: boolean %checks*/
{
  // $FlowIgnore[method-unbinding]
  return typeof func === 'function' || Object.prototype.toString.call(func) === '[object Function]';
}

function isNum(num
/*: any*/
)
/*: boolean %checks*/
{
  return typeof num === 'number' && !isNaN(num);
}

function int(a
/*: string*/
)
/*: number*/
{
  return parseInt(a, 10);
}

function dontSetMe(props
/*: Object*/
, propName
/*: string*/
, componentName
/*: string*/
)
/*: ?Error*/
{
  if (props[propName]) {
    return new Error("Invalid prop ".concat(propName, " passed to ").concat(componentName, " - do not set this, set it on the child."));
  }
}

/***/ }),

/***/ 66866:
/***/ (function(__unused_webpack_module, exports) {

"use strict";
var __webpack_unused_export__;
/** @license React v17.0.2
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var b=60103,c=60106,d=60107,e=60108,f=60114,g=60109,h=60110,k=60112,l=60113,m=60120,n=60115,p=60116,q=60121,r=60122,u=60117,v=60129,w=60131;
if("function"===typeof Symbol&&Symbol.for){var x=Symbol.for;b=x("react.element");c=x("react.portal");d=x("react.fragment");e=x("react.strict_mode");f=x("react.profiler");g=x("react.provider");h=x("react.context");k=x("react.forward_ref");l=x("react.suspense");m=x("react.suspense_list");n=x("react.memo");p=x("react.lazy");q=x("react.block");r=x("react.server.block");u=x("react.fundamental");v=x("react.debug_trace_mode");w=x("react.legacy_hidden")}
function y(a){if("object"===typeof a&&null!==a){var t=a.$$typeof;switch(t){case b:switch(a=a.type,a){case d:case f:case e:case l:case m:return a;default:switch(a=a&&a.$$typeof,a){case h:case k:case p:case n:case g:return a;default:return t}}case c:return t}}}var z=g,A=b,B=k,C=d,D=p,E=n,F=c,G=f,H=e,I=l;__webpack_unused_export__=h;__webpack_unused_export__=z;__webpack_unused_export__=A;__webpack_unused_export__=B;__webpack_unused_export__=C;__webpack_unused_export__=D;__webpack_unused_export__=E;__webpack_unused_export__=F;__webpack_unused_export__=G;__webpack_unused_export__=H;
__webpack_unused_export__=I;__webpack_unused_export__=function(){return!1};__webpack_unused_export__=function(){return!1};exports.isContextConsumer=function(a){return y(a)===h};__webpack_unused_export__=function(a){return y(a)===g};__webpack_unused_export__=function(a){return"object"===typeof a&&null!==a&&a.$$typeof===b};__webpack_unused_export__=function(a){return y(a)===k};__webpack_unused_export__=function(a){return y(a)===d};__webpack_unused_export__=function(a){return y(a)===p};__webpack_unused_export__=function(a){return y(a)===n};
__webpack_unused_export__=function(a){return y(a)===c};__webpack_unused_export__=function(a){return y(a)===f};__webpack_unused_export__=function(a){return y(a)===e};__webpack_unused_export__=function(a){return y(a)===l};__webpack_unused_export__=function(a){return"string"===typeof a||"function"===typeof a||a===d||a===f||a===v||a===e||a===l||a===m||a===w||"object"===typeof a&&null!==a&&(a.$$typeof===p||a.$$typeof===n||a.$$typeof===g||a.$$typeof===h||a.$$typeof===k||a.$$typeof===u||a.$$typeof===q||a[0]===r)?!0:!1};
__webpack_unused_export__=y;


/***/ }),

/***/ 48570:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


if (true) {
  module.exports = __webpack_require__(66866);
} else {}


/***/ }),

/***/ 27483:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "j": function() { return /* binding */ focusManager; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(81665);
/* harmony import */ var _subscribable__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(92693);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(10774);




var FocusManager = /*#__PURE__*/function (_Subscribable) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(FocusManager, _Subscribable);

  function FocusManager() {
    return _Subscribable.apply(this, arguments) || this;
  }

  var _proto = FocusManager.prototype;

  _proto.onSubscribe = function onSubscribe() {
    if (!this.removeEventListener) {
      this.setDefaultEventListener();
    }
  };

  _proto.setEventListener = function setEventListener(setup) {
    var _this = this;

    if (this.removeEventListener) {
      this.removeEventListener();
    }

    this.removeEventListener = setup(function (focused) {
      if (typeof focused === 'boolean') {
        _this.setFocused(focused);
      } else {
        _this.onFocus();
      }
    });
  };

  _proto.setFocused = function setFocused(focused) {
    this.focused = focused;

    if (focused) {
      this.onFocus();
    }
  };

  _proto.onFocus = function onFocus() {
    this.listeners.forEach(function (listener) {
      listener();
    });
  };

  _proto.isFocused = function isFocused() {
    if (typeof this.focused === 'boolean') {
      return this.focused;
    } // document global can be unavailable in react native


    if (typeof document === 'undefined') {
      return true;
    }

    return [undefined, 'visible', 'prerender'].includes(document.visibilityState);
  };

  _proto.setDefaultEventListener = function setDefaultEventListener() {
    var _window;

    if (!_utils__WEBPACK_IMPORTED_MODULE_1__/* .isServer */ .sk && ((_window = window) == null ? void 0 : _window.addEventListener)) {
      this.setEventListener(function (onFocus) {
        var listener = function listener() {
          return onFocus();
        }; // Listen to visibillitychange and focus


        window.addEventListener('visibilitychange', listener, false);
        window.addEventListener('focus', listener, false);
        return function () {
          // Be sure to unsubscribe if a new handler is set
          window.removeEventListener('visibilitychange', listener);
          window.removeEventListener('focus', listener);
        };
      });
    }
  };

  return FocusManager;
}(_subscribable__WEBPACK_IMPORTED_MODULE_2__/* .Subscribable */ .l);

var focusManager = new FocusManager();

/***/ }),

/***/ 60002:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Su": function() { return /* reexport safe */ _queryClient__WEBPACK_IMPORTED_MODULE_0__.S; }
/* harmony export */ });
/* harmony import */ var _queryClient__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(29446);
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(77820);
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_types__WEBPACK_IMPORTED_MODULE_1__);
/* harmony reexport (checked) */ if(__webpack_require__.o(_types__WEBPACK_IMPORTED_MODULE_1__, "QueryClientProvider")) __webpack_require__.d(__webpack_exports__, { "QueryClientProvider": function() { return _types__WEBPACK_IMPORTED_MODULE_1__.QueryClientProvider; } });
/* harmony reexport (checked) */ if(__webpack_require__.o(_types__WEBPACK_IMPORTED_MODULE_1__, "useMutation")) __webpack_require__.d(__webpack_exports__, { "useMutation": function() { return _types__WEBPACK_IMPORTED_MODULE_1__.useMutation; } });
/* harmony reexport (checked) */ if(__webpack_require__.o(_types__WEBPACK_IMPORTED_MODULE_1__, "useQuery")) __webpack_require__.d(__webpack_exports__, { "useQuery": function() { return _types__WEBPACK_IMPORTED_MODULE_1__.useQuery; } });
/* harmony reexport (checked) */ if(__webpack_require__.o(_types__WEBPACK_IMPORTED_MODULE_1__, "useQueryClient")) __webpack_require__.d(__webpack_exports__, { "useQueryClient": function() { return _types__WEBPACK_IMPORTED_MODULE_1__.useQueryClient; } });














 // Types



/***/ }),

/***/ 20560:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Gm": function() { return /* binding */ infiniteQueryBehavior; }
/* harmony export */ });
/* unused harmony exports getNextPageParam, getPreviousPageParam, hasNextPage, hasPreviousPage */
/* harmony import */ var _retryer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(22348);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(10774);


function infiniteQueryBehavior() {
  return {
    onFetch: function onFetch(context) {
      context.fetchFn = function () {
        var _context$fetchOptions, _context$fetchOptions2, _context$fetchOptions3, _context$fetchOptions4, _context$state$data, _context$state$data2;

        var refetchPage = (_context$fetchOptions = context.fetchOptions) == null ? void 0 : (_context$fetchOptions2 = _context$fetchOptions.meta) == null ? void 0 : _context$fetchOptions2.refetchPage;
        var fetchMore = (_context$fetchOptions3 = context.fetchOptions) == null ? void 0 : (_context$fetchOptions4 = _context$fetchOptions3.meta) == null ? void 0 : _context$fetchOptions4.fetchMore;
        var pageParam = fetchMore == null ? void 0 : fetchMore.pageParam;
        var isFetchingNextPage = (fetchMore == null ? void 0 : fetchMore.direction) === 'forward';
        var isFetchingPreviousPage = (fetchMore == null ? void 0 : fetchMore.direction) === 'backward';
        var oldPages = ((_context$state$data = context.state.data) == null ? void 0 : _context$state$data.pages) || [];
        var oldPageParams = ((_context$state$data2 = context.state.data) == null ? void 0 : _context$state$data2.pageParams) || [];
        var abortController = (0,_utils__WEBPACK_IMPORTED_MODULE_0__/* .getAbortController */ .G9)();
        var abortSignal = abortController == null ? void 0 : abortController.signal;
        var newPageParams = oldPageParams;
        var cancelled = false; // Get query function

        var queryFn = context.options.queryFn || function () {
          return Promise.reject('Missing queryFn');
        };

        var buildNewPages = function buildNewPages(pages, param, page, previous) {
          newPageParams = previous ? [param].concat(newPageParams) : [].concat(newPageParams, [param]);
          return previous ? [page].concat(pages) : [].concat(pages, [page]);
        }; // Create function to fetch a page


        var fetchPage = function fetchPage(pages, manual, param, previous) {
          if (cancelled) {
            return Promise.reject('Cancelled');
          }

          if (typeof param === 'undefined' && !manual && pages.length) {
            return Promise.resolve(pages);
          }

          var queryFnContext = {
            queryKey: context.queryKey,
            signal: abortSignal,
            pageParam: param,
            meta: context.meta
          };
          var queryFnResult = queryFn(queryFnContext);
          var promise = Promise.resolve(queryFnResult).then(function (page) {
            return buildNewPages(pages, param, page, previous);
          });

          if ((0,_retryer__WEBPACK_IMPORTED_MODULE_1__/* .isCancelable */ .LE)(queryFnResult)) {
            var promiseAsAny = promise;
            promiseAsAny.cancel = queryFnResult.cancel;
          }

          return promise;
        };

        var promise; // Fetch first page?

        if (!oldPages.length) {
          promise = fetchPage([]);
        } // Fetch next page?
        else if (isFetchingNextPage) {
            var manual = typeof pageParam !== 'undefined';
            var param = manual ? pageParam : getNextPageParam(context.options, oldPages);
            promise = fetchPage(oldPages, manual, param);
          } // Fetch previous page?
          else if (isFetchingPreviousPage) {
              var _manual = typeof pageParam !== 'undefined';

              var _param = _manual ? pageParam : getPreviousPageParam(context.options, oldPages);

              promise = fetchPage(oldPages, _manual, _param, true);
            } // Refetch pages
            else {
                (function () {
                  newPageParams = [];
                  var manual = typeof context.options.getNextPageParam === 'undefined';
                  var shouldFetchFirstPage = refetchPage && oldPages[0] ? refetchPage(oldPages[0], 0, oldPages) : true; // Fetch first page

                  promise = shouldFetchFirstPage ? fetchPage([], manual, oldPageParams[0]) : Promise.resolve(buildNewPages([], oldPageParams[0], oldPages[0])); // Fetch remaining pages

                  var _loop = function _loop(i) {
                    promise = promise.then(function (pages) {
                      var shouldFetchNextPage = refetchPage && oldPages[i] ? refetchPage(oldPages[i], i, oldPages) : true;

                      if (shouldFetchNextPage) {
                        var _param2 = manual ? oldPageParams[i] : getNextPageParam(context.options, pages);

                        return fetchPage(pages, manual, _param2);
                      }

                      return Promise.resolve(buildNewPages(pages, oldPageParams[i], oldPages[i]));
                    });
                  };

                  for (var i = 1; i < oldPages.length; i++) {
                    _loop(i);
                  }
                })();
              }

        var finalPromise = promise.then(function (pages) {
          return {
            pages: pages,
            pageParams: newPageParams
          };
        });
        var finalPromiseAsAny = finalPromise;

        finalPromiseAsAny.cancel = function () {
          cancelled = true;
          abortController == null ? void 0 : abortController.abort();

          if ((0,_retryer__WEBPACK_IMPORTED_MODULE_1__/* .isCancelable */ .LE)(promise)) {
            promise.cancel();
          }
        };

        return finalPromise;
      };
    }
  };
}
function getNextPageParam(options, pages) {
  return options.getNextPageParam == null ? void 0 : options.getNextPageParam(pages[pages.length - 1], pages);
}
function getPreviousPageParam(options, pages) {
  return options.getPreviousPageParam == null ? void 0 : options.getPreviousPageParam(pages[0], pages);
}
/**
 * Checks if there is a next page.
 * Returns `undefined` if it cannot be determined.
 */

function hasNextPage(options, pages) {
  if (options.getNextPageParam && Array.isArray(pages)) {
    var nextPageParam = getNextPageParam(options, pages);
    return typeof nextPageParam !== 'undefined' && nextPageParam !== null && nextPageParam !== false;
  }
}
/**
 * Checks if there is a previous page.
 * Returns `undefined` if it cannot be determined.
 */

function hasPreviousPage(options, pages) {
  if (options.getPreviousPageParam && Array.isArray(pages)) {
    var previousPageParam = getPreviousPageParam(options, pages);
    return typeof previousPageParam !== 'undefined' && previousPageParam !== null && previousPageParam !== false;
  }
}

/***/ }),

/***/ 53579:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "j": function() { return /* binding */ getLogger; },
/* harmony export */   "E": function() { return /* binding */ setLogger; }
/* harmony export */ });
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(10774);
 // TYPES

// FUNCTIONS
var logger = console || {
  error: _utils__WEBPACK_IMPORTED_MODULE_0__/* .noop */ .ZT,
  warn: _utils__WEBPACK_IMPORTED_MODULE_0__/* .noop */ .ZT,
  log: _utils__WEBPACK_IMPORTED_MODULE_0__/* .noop */ .ZT
};
function getLogger() {
  return logger;
}
function setLogger(newLogger) {
  logger = newLogger;
}

/***/ }),

/***/ 3284:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "m": function() { return /* binding */ Mutation; },
/* harmony export */   "R": function() { return /* binding */ getDefaultState; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7896);
/* harmony import */ var _logger__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(53579);
/* harmony import */ var _notifyManager__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(50667);
/* harmony import */ var _retryer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(22348);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(10774);




 // TYPES

// CLASS
var Mutation = /*#__PURE__*/function () {
  function Mutation(config) {
    this.options = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, config.defaultOptions, config.options);
    this.mutationId = config.mutationId;
    this.mutationCache = config.mutationCache;
    this.observers = [];
    this.state = config.state || getDefaultState();
  }

  var _proto = Mutation.prototype;

  _proto.setState = function setState(state) {
    this.dispatch({
      type: 'setState',
      state: state
    });
  };

  _proto.addObserver = function addObserver(observer) {
    if (this.observers.indexOf(observer) === -1) {
      this.observers.push(observer);
    }
  };

  _proto.removeObserver = function removeObserver(observer) {
    this.observers = this.observers.filter(function (x) {
      return x !== observer;
    });
  };

  _proto.cancel = function cancel() {
    if (this.retryer) {
      this.retryer.cancel();
      return this.retryer.promise.then(_utils__WEBPACK_IMPORTED_MODULE_1__/* .noop */ .ZT).catch(_utils__WEBPACK_IMPORTED_MODULE_1__/* .noop */ .ZT);
    }

    return Promise.resolve();
  };

  _proto.continue = function _continue() {
    if (this.retryer) {
      this.retryer.continue();
      return this.retryer.promise;
    }

    return this.execute();
  };

  _proto.execute = function execute() {
    var _this = this;

    var data;
    var restored = this.state.status === 'loading';
    var promise = Promise.resolve();

    if (!restored) {
      this.dispatch({
        type: 'loading',
        variables: this.options.variables
      });
      promise = promise.then(function () {
        return _this.options.onMutate == null ? void 0 : _this.options.onMutate(_this.state.variables);
      }).then(function (context) {
        if (context !== _this.state.context) {
          _this.dispatch({
            type: 'loading',
            context: context,
            variables: _this.state.variables
          });
        }
      });
    }

    return promise.then(function () {
      return _this.executeMutation();
    }).then(function (result) {
      data = result; // Notify cache callback

      _this.mutationCache.config.onSuccess == null ? void 0 : _this.mutationCache.config.onSuccess(data, _this.state.variables, _this.state.context, _this);
    }).then(function () {
      return _this.options.onSuccess == null ? void 0 : _this.options.onSuccess(data, _this.state.variables, _this.state.context);
    }).then(function () {
      return _this.options.onSettled == null ? void 0 : _this.options.onSettled(data, null, _this.state.variables, _this.state.context);
    }).then(function () {
      _this.dispatch({
        type: 'success',
        data: data
      });

      return data;
    }).catch(function (error) {
      // Notify cache callback
      _this.mutationCache.config.onError == null ? void 0 : _this.mutationCache.config.onError(error, _this.state.variables, _this.state.context, _this); // Log error

      (0,_logger__WEBPACK_IMPORTED_MODULE_2__/* .getLogger */ .j)().error(error);
      return Promise.resolve().then(function () {
        return _this.options.onError == null ? void 0 : _this.options.onError(error, _this.state.variables, _this.state.context);
      }).then(function () {
        return _this.options.onSettled == null ? void 0 : _this.options.onSettled(undefined, error, _this.state.variables, _this.state.context);
      }).then(function () {
        _this.dispatch({
          type: 'error',
          error: error
        });

        throw error;
      });
    });
  };

  _proto.executeMutation = function executeMutation() {
    var _this2 = this,
        _this$options$retry;

    this.retryer = new _retryer__WEBPACK_IMPORTED_MODULE_3__/* .Retryer */ .m4({
      fn: function fn() {
        if (!_this2.options.mutationFn) {
          return Promise.reject('No mutationFn found');
        }

        return _this2.options.mutationFn(_this2.state.variables);
      },
      onFail: function onFail() {
        _this2.dispatch({
          type: 'failed'
        });
      },
      onPause: function onPause() {
        _this2.dispatch({
          type: 'pause'
        });
      },
      onContinue: function onContinue() {
        _this2.dispatch({
          type: 'continue'
        });
      },
      retry: (_this$options$retry = this.options.retry) != null ? _this$options$retry : 0,
      retryDelay: this.options.retryDelay
    });
    return this.retryer.promise;
  };

  _proto.dispatch = function dispatch(action) {
    var _this3 = this;

    this.state = reducer(this.state, action);
    _notifyManager__WEBPACK_IMPORTED_MODULE_4__/* .notifyManager.batch */ .V.batch(function () {
      _this3.observers.forEach(function (observer) {
        observer.onMutationUpdate(action);
      });

      _this3.mutationCache.notify(_this3);
    });
  };

  return Mutation;
}();
function getDefaultState() {
  return {
    context: undefined,
    data: undefined,
    error: null,
    failureCount: 0,
    isPaused: false,
    status: 'idle',
    variables: undefined
  };
}

function reducer(state, action) {
  switch (action.type) {
    case 'failed':
      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
        failureCount: state.failureCount + 1
      });

    case 'pause':
      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
        isPaused: true
      });

    case 'continue':
      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
        isPaused: false
      });

    case 'loading':
      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
        context: action.context,
        data: undefined,
        error: null,
        isPaused: false,
        status: 'loading',
        variables: action.variables
      });

    case 'success':
      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
        data: action.data,
        error: null,
        status: 'success',
        isPaused: false
      });

    case 'error':
      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
        data: undefined,
        error: action.error,
        failureCount: state.failureCount + 1,
        isPaused: false,
        status: 'error'
      });

    case 'setState':
      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, action.state);

    default:
      return state;
  }
}

/***/ }),

/***/ 9601:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "L": function() { return /* binding */ MutationCache; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(81665);
/* harmony import */ var _notifyManager__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(50667);
/* harmony import */ var _mutation__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(3284);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(10774);
/* harmony import */ var _subscribable__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(92693);




 // TYPES

// CLASS
var MutationCache = /*#__PURE__*/function (_Subscribable) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(MutationCache, _Subscribable);

  function MutationCache(config) {
    var _this;

    _this = _Subscribable.call(this) || this;
    _this.config = config || {};
    _this.mutations = [];
    _this.mutationId = 0;
    return _this;
  }

  var _proto = MutationCache.prototype;

  _proto.build = function build(client, options, state) {
    var mutation = new _mutation__WEBPACK_IMPORTED_MODULE_1__/* .Mutation */ .m({
      mutationCache: this,
      mutationId: ++this.mutationId,
      options: client.defaultMutationOptions(options),
      state: state,
      defaultOptions: options.mutationKey ? client.getMutationDefaults(options.mutationKey) : undefined
    });
    this.add(mutation);
    return mutation;
  };

  _proto.add = function add(mutation) {
    this.mutations.push(mutation);
    this.notify(mutation);
  };

  _proto.remove = function remove(mutation) {
    this.mutations = this.mutations.filter(function (x) {
      return x !== mutation;
    });
    mutation.cancel();
    this.notify(mutation);
  };

  _proto.clear = function clear() {
    var _this2 = this;

    _notifyManager__WEBPACK_IMPORTED_MODULE_2__/* .notifyManager.batch */ .V.batch(function () {
      _this2.mutations.forEach(function (mutation) {
        _this2.remove(mutation);
      });
    });
  };

  _proto.getAll = function getAll() {
    return this.mutations;
  };

  _proto.find = function find(filters) {
    if (typeof filters.exact === 'undefined') {
      filters.exact = true;
    }

    return this.mutations.find(function (mutation) {
      return (0,_utils__WEBPACK_IMPORTED_MODULE_3__/* .matchMutation */ .X7)(filters, mutation);
    });
  };

  _proto.findAll = function findAll(filters) {
    return this.mutations.filter(function (mutation) {
      return (0,_utils__WEBPACK_IMPORTED_MODULE_3__/* .matchMutation */ .X7)(filters, mutation);
    });
  };

  _proto.notify = function notify(mutation) {
    var _this3 = this;

    _notifyManager__WEBPACK_IMPORTED_MODULE_2__/* .notifyManager.batch */ .V.batch(function () {
      _this3.listeners.forEach(function (listener) {
        listener(mutation);
      });
    });
  };

  _proto.onFocus = function onFocus() {
    this.resumePausedMutations();
  };

  _proto.onOnline = function onOnline() {
    this.resumePausedMutations();
  };

  _proto.resumePausedMutations = function resumePausedMutations() {
    var pausedMutations = this.mutations.filter(function (x) {
      return x.state.isPaused;
    });
    return _notifyManager__WEBPACK_IMPORTED_MODULE_2__/* .notifyManager.batch */ .V.batch(function () {
      return pausedMutations.reduce(function (promise, mutation) {
        return promise.then(function () {
          return mutation.continue().catch(_utils__WEBPACK_IMPORTED_MODULE_3__/* .noop */ .ZT);
        });
      }, Promise.resolve());
    });
  };

  return MutationCache;
}(_subscribable__WEBPACK_IMPORTED_MODULE_4__/* .Subscribable */ .l);

/***/ }),

/***/ 74856:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "X": function() { return /* binding */ MutationObserver; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(7896);
/* harmony import */ var _babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(81665);
/* harmony import */ var _mutation__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(3284);
/* harmony import */ var _notifyManager__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(50667);
/* harmony import */ var _subscribable__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(92693);





// CLASS
var MutationObserver = /*#__PURE__*/function (_Subscribable) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(MutationObserver, _Subscribable);

  function MutationObserver(client, options) {
    var _this;

    _this = _Subscribable.call(this) || this;
    _this.client = client;

    _this.setOptions(options);

    _this.bindMethods();

    _this.updateResult();

    return _this;
  }

  var _proto = MutationObserver.prototype;

  _proto.bindMethods = function bindMethods() {
    this.mutate = this.mutate.bind(this);
    this.reset = this.reset.bind(this);
  };

  _proto.setOptions = function setOptions(options) {
    this.options = this.client.defaultMutationOptions(options);
  };

  _proto.onUnsubscribe = function onUnsubscribe() {
    if (!this.listeners.length) {
      var _this$currentMutation;

      (_this$currentMutation = this.currentMutation) == null ? void 0 : _this$currentMutation.removeObserver(this);
    }
  };

  _proto.onMutationUpdate = function onMutationUpdate(action) {
    this.updateResult(); // Determine which callbacks to trigger

    var notifyOptions = {
      listeners: true
    };

    if (action.type === 'success') {
      notifyOptions.onSuccess = true;
    } else if (action.type === 'error') {
      notifyOptions.onError = true;
    }

    this.notify(notifyOptions);
  };

  _proto.getCurrentResult = function getCurrentResult() {
    return this.currentResult;
  };

  _proto.reset = function reset() {
    this.currentMutation = undefined;
    this.updateResult();
    this.notify({
      listeners: true
    });
  };

  _proto.mutate = function mutate(variables, options) {
    this.mutateOptions = options;

    if (this.currentMutation) {
      this.currentMutation.removeObserver(this);
    }

    this.currentMutation = this.client.getMutationCache().build(this.client, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)({}, this.options, {
      variables: typeof variables !== 'undefined' ? variables : this.options.variables
    }));
    this.currentMutation.addObserver(this);
    return this.currentMutation.execute();
  };

  _proto.updateResult = function updateResult() {
    var state = this.currentMutation ? this.currentMutation.state : (0,_mutation__WEBPACK_IMPORTED_MODULE_2__/* .getDefaultState */ .R)();

    var result = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)({}, state, {
      isLoading: state.status === 'loading',
      isSuccess: state.status === 'success',
      isError: state.status === 'error',
      isIdle: state.status === 'idle',
      mutate: this.mutate,
      reset: this.reset
    });

    this.currentResult = result;
  };

  _proto.notify = function notify(options) {
    var _this2 = this;

    _notifyManager__WEBPACK_IMPORTED_MODULE_3__/* .notifyManager.batch */ .V.batch(function () {
      // First trigger the mutate callbacks
      if (_this2.mutateOptions) {
        if (options.onSuccess) {
          _this2.mutateOptions.onSuccess == null ? void 0 : _this2.mutateOptions.onSuccess(_this2.currentResult.data, _this2.currentResult.variables, _this2.currentResult.context);
          _this2.mutateOptions.onSettled == null ? void 0 : _this2.mutateOptions.onSettled(_this2.currentResult.data, null, _this2.currentResult.variables, _this2.currentResult.context);
        } else if (options.onError) {
          _this2.mutateOptions.onError == null ? void 0 : _this2.mutateOptions.onError(_this2.currentResult.error, _this2.currentResult.variables, _this2.currentResult.context);
          _this2.mutateOptions.onSettled == null ? void 0 : _this2.mutateOptions.onSettled(undefined, _this2.currentResult.error, _this2.currentResult.variables, _this2.currentResult.context);
        }
      } // Then trigger the listeners


      if (options.listeners) {
        _this2.listeners.forEach(function (listener) {
          listener(_this2.currentResult);
        });
      }
    });
  };

  return MutationObserver;
}(_subscribable__WEBPACK_IMPORTED_MODULE_4__/* .Subscribable */ .l);

/***/ }),

/***/ 50667:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "V": function() { return /* binding */ notifyManager; }
/* harmony export */ });
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(10774);
 // TYPES

// CLASS
var NotifyManager = /*#__PURE__*/function () {
  function NotifyManager() {
    this.queue = [];
    this.transactions = 0;

    this.notifyFn = function (callback) {
      callback();
    };

    this.batchNotifyFn = function (callback) {
      callback();
    };
  }

  var _proto = NotifyManager.prototype;

  _proto.batch = function batch(callback) {
    this.transactions++;
    var result = callback();
    this.transactions--;

    if (!this.transactions) {
      this.flush();
    }

    return result;
  };

  _proto.schedule = function schedule(callback) {
    var _this = this;

    if (this.transactions) {
      this.queue.push(callback);
    } else {
      (0,_utils__WEBPACK_IMPORTED_MODULE_0__/* .scheduleMicrotask */ .A4)(function () {
        _this.notifyFn(callback);
      });
    }
  }
  /**
   * All calls to the wrapped function will be batched.
   */
  ;

  _proto.batchCalls = function batchCalls(callback) {
    var _this2 = this;

    return function () {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this2.schedule(function () {
        callback.apply(void 0, args);
      });
    };
  };

  _proto.flush = function flush() {
    var _this3 = this;

    var queue = this.queue;
    this.queue = [];

    if (queue.length) {
      (0,_utils__WEBPACK_IMPORTED_MODULE_0__/* .scheduleMicrotask */ .A4)(function () {
        _this3.batchNotifyFn(function () {
          queue.forEach(function (callback) {
            _this3.notifyFn(callback);
          });
        });
      });
    }
  }
  /**
   * Use this method to set a custom notify function.
   * This can be used to for example wrap notifications with `React.act` while running tests.
   */
  ;

  _proto.setNotifyFunction = function setNotifyFunction(fn) {
    this.notifyFn = fn;
  }
  /**
   * Use this method to set a custom function to batch notifications together into a single tick.
   * By default React Query will use the batch function provided by ReactDOM or React Native.
   */
  ;

  _proto.setBatchNotifyFunction = function setBatchNotifyFunction(fn) {
    this.batchNotifyFn = fn;
  };

  return NotifyManager;
}(); // SINGLETON


var notifyManager = new NotifyManager();

/***/ }),

/***/ 58927:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "N": function() { return /* binding */ onlineManager; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(81665);
/* harmony import */ var _subscribable__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(92693);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(10774);




var OnlineManager = /*#__PURE__*/function (_Subscribable) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(OnlineManager, _Subscribable);

  function OnlineManager() {
    return _Subscribable.apply(this, arguments) || this;
  }

  var _proto = OnlineManager.prototype;

  _proto.onSubscribe = function onSubscribe() {
    if (!this.removeEventListener) {
      this.setDefaultEventListener();
    }
  };

  _proto.setEventListener = function setEventListener(setup) {
    var _this = this;

    if (this.removeEventListener) {
      this.removeEventListener();
    }

    this.removeEventListener = setup(function (online) {
      if (typeof online === 'boolean') {
        _this.setOnline(online);
      } else {
        _this.onOnline();
      }
    });
  };

  _proto.setOnline = function setOnline(online) {
    this.online = online;

    if (online) {
      this.onOnline();
    }
  };

  _proto.onOnline = function onOnline() {
    this.listeners.forEach(function (listener) {
      listener();
    });
  };

  _proto.isOnline = function isOnline() {
    if (typeof this.online === 'boolean') {
      return this.online;
    }

    if (typeof navigator === 'undefined' || typeof navigator.onLine === 'undefined') {
      return true;
    }

    return navigator.onLine;
  };

  _proto.setDefaultEventListener = function setDefaultEventListener() {
    var _window;

    if (!_utils__WEBPACK_IMPORTED_MODULE_1__/* .isServer */ .sk && ((_window = window) == null ? void 0 : _window.addEventListener)) {
      this.setEventListener(function (onOnline) {
        var listener = function listener() {
          return onOnline();
        }; // Listen to online


        window.addEventListener('online', listener, false);
        window.addEventListener('offline', listener, false);
        return function () {
          // Be sure to unsubscribe if a new handler is set
          window.removeEventListener('online', listener);
          window.removeEventListener('offline', listener);
        };
      });
    }
  };

  return OnlineManager;
}(_subscribable__WEBPACK_IMPORTED_MODULE_2__/* .Subscribable */ .l);

var onlineManager = new OnlineManager();

/***/ }),

/***/ 81257:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "A": function() { return /* binding */ Query; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7896);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(10774);
/* harmony import */ var _notifyManager__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(50667);
/* harmony import */ var _logger__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(53579);
/* harmony import */ var _retryer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(22348);




 // TYPES

// CLASS
var Query = /*#__PURE__*/function () {
  function Query(config) {
    this.abortSignalConsumed = false;
    this.defaultOptions = config.defaultOptions;
    this.setOptions(config.options);
    this.observers = [];
    this.cache = config.cache;
    this.queryKey = config.queryKey;
    this.queryHash = config.queryHash;
    this.initialState = config.state || this.getDefaultState(this.options);
    this.state = this.initialState;
    this.meta = config.meta;
    this.scheduleGc();
  }

  var _proto = Query.prototype;

  _proto.setOptions = function setOptions(options) {
    var _this$options$cacheTi;

    this.options = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, this.defaultOptions, options);
    this.meta = options == null ? void 0 : options.meta; // Default to 5 minutes if not cache time is set

    this.cacheTime = Math.max(this.cacheTime || 0, (_this$options$cacheTi = this.options.cacheTime) != null ? _this$options$cacheTi : 5 * 60 * 1000);
  };

  _proto.setDefaultOptions = function setDefaultOptions(options) {
    this.defaultOptions = options;
  };

  _proto.scheduleGc = function scheduleGc() {
    var _this = this;

    this.clearGcTimeout();

    if ((0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .isValidTimeout */ .PN)(this.cacheTime)) {
      this.gcTimeout = setTimeout(function () {
        _this.optionalRemove();
      }, this.cacheTime);
    }
  };

  _proto.clearGcTimeout = function clearGcTimeout() {
    clearTimeout(this.gcTimeout);
    this.gcTimeout = undefined;
  };

  _proto.optionalRemove = function optionalRemove() {
    if (!this.observers.length && !this.state.isFetching) {
      this.cache.remove(this);
    }
  };

  _proto.setData = function setData(updater, options) {
    var _this$options$isDataE, _this$options;

    var prevData = this.state.data; // Get the new data

    var data = (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .functionalUpdate */ .SE)(updater, prevData); // Use prev data if an isDataEqual function is defined and returns `true`

    if ((_this$options$isDataE = (_this$options = this.options).isDataEqual) == null ? void 0 : _this$options$isDataE.call(_this$options, prevData, data)) {
      data = prevData;
    } else if (this.options.structuralSharing !== false) {
      // Structurally share data between prev and new data if needed
      data = (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .replaceEqualDeep */ .Q$)(prevData, data);
    } // Set data and mark it as cached


    this.dispatch({
      data: data,
      type: 'success',
      dataUpdatedAt: options == null ? void 0 : options.updatedAt
    });
    return data;
  };

  _proto.setState = function setState(state, setStateOptions) {
    this.dispatch({
      type: 'setState',
      state: state,
      setStateOptions: setStateOptions
    });
  };

  _proto.cancel = function cancel(options) {
    var _this$retryer;

    var promise = this.promise;
    (_this$retryer = this.retryer) == null ? void 0 : _this$retryer.cancel(options);
    return promise ? promise.then(_utils__WEBPACK_IMPORTED_MODULE_1__/* .noop */ .ZT).catch(_utils__WEBPACK_IMPORTED_MODULE_1__/* .noop */ .ZT) : Promise.resolve();
  };

  _proto.destroy = function destroy() {
    this.clearGcTimeout();
    this.cancel({
      silent: true
    });
  };

  _proto.reset = function reset() {
    this.destroy();
    this.setState(this.initialState);
  };

  _proto.isActive = function isActive() {
    return this.observers.some(function (observer) {
      return observer.options.enabled !== false;
    });
  };

  _proto.isFetching = function isFetching() {
    return this.state.isFetching;
  };

  _proto.isStale = function isStale() {
    return this.state.isInvalidated || !this.state.dataUpdatedAt || this.observers.some(function (observer) {
      return observer.getCurrentResult().isStale;
    });
  };

  _proto.isStaleByTime = function isStaleByTime(staleTime) {
    if (staleTime === void 0) {
      staleTime = 0;
    }

    return this.state.isInvalidated || !this.state.dataUpdatedAt || !(0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .timeUntilStale */ .Kp)(this.state.dataUpdatedAt, staleTime);
  };

  _proto.onFocus = function onFocus() {
    var _this$retryer2;

    var observer = this.observers.find(function (x) {
      return x.shouldFetchOnWindowFocus();
    });

    if (observer) {
      observer.refetch();
    } // Continue fetch if currently paused


    (_this$retryer2 = this.retryer) == null ? void 0 : _this$retryer2.continue();
  };

  _proto.onOnline = function onOnline() {
    var _this$retryer3;

    var observer = this.observers.find(function (x) {
      return x.shouldFetchOnReconnect();
    });

    if (observer) {
      observer.refetch();
    } // Continue fetch if currently paused


    (_this$retryer3 = this.retryer) == null ? void 0 : _this$retryer3.continue();
  };

  _proto.addObserver = function addObserver(observer) {
    if (this.observers.indexOf(observer) === -1) {
      this.observers.push(observer); // Stop the query from being garbage collected

      this.clearGcTimeout();
      this.cache.notify({
        type: 'observerAdded',
        query: this,
        observer: observer
      });
    }
  };

  _proto.removeObserver = function removeObserver(observer) {
    if (this.observers.indexOf(observer) !== -1) {
      this.observers = this.observers.filter(function (x) {
        return x !== observer;
      });

      if (!this.observers.length) {
        // If the transport layer does not support cancellation
        // we'll let the query continue so the result can be cached
        if (this.retryer) {
          if (this.retryer.isTransportCancelable || this.abortSignalConsumed) {
            this.retryer.cancel({
              revert: true
            });
          } else {
            this.retryer.cancelRetry();
          }
        }

        if (this.cacheTime) {
          this.scheduleGc();
        } else {
          this.cache.remove(this);
        }
      }

      this.cache.notify({
        type: 'observerRemoved',
        query: this,
        observer: observer
      });
    }
  };

  _proto.getObserversCount = function getObserversCount() {
    return this.observers.length;
  };

  _proto.invalidate = function invalidate() {
    if (!this.state.isInvalidated) {
      this.dispatch({
        type: 'invalidate'
      });
    }
  };

  _proto.fetch = function fetch(options, fetchOptions) {
    var _this2 = this,
        _this$options$behavio,
        _context$fetchOptions,
        _abortController$abor;

    if (this.state.isFetching) {
      if (this.state.dataUpdatedAt && (fetchOptions == null ? void 0 : fetchOptions.cancelRefetch)) {
        // Silently cancel current fetch if the user wants to cancel refetches
        this.cancel({
          silent: true
        });
      } else if (this.promise) {
        // Return current promise if we are already fetching
        return this.promise;
      }
    } // Update config if passed, otherwise the config from the last execution is used


    if (options) {
      this.setOptions(options);
    } // Use the options from the first observer with a query function if no function is found.
    // This can happen when the query is hydrated or created with setQueryData.


    if (!this.options.queryFn) {
      var observer = this.observers.find(function (x) {
        return x.options.queryFn;
      });

      if (observer) {
        this.setOptions(observer.options);
      }
    }

    var queryKey = (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .ensureQueryKeyArray */ .mc)(this.queryKey);
    var abortController = (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .getAbortController */ .G9)(); // Create query function context

    var queryFnContext = {
      queryKey: queryKey,
      pageParam: undefined,
      meta: this.meta
    };
    Object.defineProperty(queryFnContext, 'signal', {
      enumerable: true,
      get: function get() {
        if (abortController) {
          _this2.abortSignalConsumed = true;
          return abortController.signal;
        }

        return undefined;
      }
    }); // Create fetch function

    var fetchFn = function fetchFn() {
      if (!_this2.options.queryFn) {
        return Promise.reject('Missing queryFn');
      }

      _this2.abortSignalConsumed = false;
      return _this2.options.queryFn(queryFnContext);
    }; // Trigger behavior hook


    var context = {
      fetchOptions: fetchOptions,
      options: this.options,
      queryKey: queryKey,
      state: this.state,
      fetchFn: fetchFn,
      meta: this.meta
    };

    if ((_this$options$behavio = this.options.behavior) == null ? void 0 : _this$options$behavio.onFetch) {
      var _this$options$behavio2;

      (_this$options$behavio2 = this.options.behavior) == null ? void 0 : _this$options$behavio2.onFetch(context);
    } // Store state in case the current fetch needs to be reverted


    this.revertState = this.state; // Set to fetching state if not already in it

    if (!this.state.isFetching || this.state.fetchMeta !== ((_context$fetchOptions = context.fetchOptions) == null ? void 0 : _context$fetchOptions.meta)) {
      var _context$fetchOptions2;

      this.dispatch({
        type: 'fetch',
        meta: (_context$fetchOptions2 = context.fetchOptions) == null ? void 0 : _context$fetchOptions2.meta
      });
    } // Try to fetch the data


    this.retryer = new _retryer__WEBPACK_IMPORTED_MODULE_2__/* .Retryer */ .m4({
      fn: context.fetchFn,
      abort: abortController == null ? void 0 : (_abortController$abor = abortController.abort) == null ? void 0 : _abortController$abor.bind(abortController),
      onSuccess: function onSuccess(data) {
        _this2.setData(data); // Notify cache callback


        _this2.cache.config.onSuccess == null ? void 0 : _this2.cache.config.onSuccess(data, _this2); // Remove query after fetching if cache time is 0

        if (_this2.cacheTime === 0) {
          _this2.optionalRemove();
        }
      },
      onError: function onError(error) {
        // Optimistically update state if needed
        if (!((0,_retryer__WEBPACK_IMPORTED_MODULE_2__/* .isCancelledError */ .DV)(error) && error.silent)) {
          _this2.dispatch({
            type: 'error',
            error: error
          });
        }

        if (!(0,_retryer__WEBPACK_IMPORTED_MODULE_2__/* .isCancelledError */ .DV)(error)) {
          // Notify cache callback
          _this2.cache.config.onError == null ? void 0 : _this2.cache.config.onError(error, _this2); // Log error

          (0,_logger__WEBPACK_IMPORTED_MODULE_3__/* .getLogger */ .j)().error(error);
        } // Remove query after fetching if cache time is 0


        if (_this2.cacheTime === 0) {
          _this2.optionalRemove();
        }
      },
      onFail: function onFail() {
        _this2.dispatch({
          type: 'failed'
        });
      },
      onPause: function onPause() {
        _this2.dispatch({
          type: 'pause'
        });
      },
      onContinue: function onContinue() {
        _this2.dispatch({
          type: 'continue'
        });
      },
      retry: context.options.retry,
      retryDelay: context.options.retryDelay
    });
    this.promise = this.retryer.promise;
    return this.promise;
  };

  _proto.dispatch = function dispatch(action) {
    var _this3 = this;

    this.state = this.reducer(this.state, action);
    _notifyManager__WEBPACK_IMPORTED_MODULE_4__/* .notifyManager.batch */ .V.batch(function () {
      _this3.observers.forEach(function (observer) {
        observer.onQueryUpdate(action);
      });

      _this3.cache.notify({
        query: _this3,
        type: 'queryUpdated',
        action: action
      });
    });
  };

  _proto.getDefaultState = function getDefaultState(options) {
    var data = typeof options.initialData === 'function' ? options.initialData() : options.initialData;
    var hasInitialData = typeof options.initialData !== 'undefined';
    var initialDataUpdatedAt = hasInitialData ? typeof options.initialDataUpdatedAt === 'function' ? options.initialDataUpdatedAt() : options.initialDataUpdatedAt : 0;
    var hasData = typeof data !== 'undefined';
    return {
      data: data,
      dataUpdateCount: 0,
      dataUpdatedAt: hasData ? initialDataUpdatedAt != null ? initialDataUpdatedAt : Date.now() : 0,
      error: null,
      errorUpdateCount: 0,
      errorUpdatedAt: 0,
      fetchFailureCount: 0,
      fetchMeta: null,
      isFetching: false,
      isInvalidated: false,
      isPaused: false,
      status: hasData ? 'success' : 'idle'
    };
  };

  _proto.reducer = function reducer(state, action) {
    var _action$meta, _action$dataUpdatedAt;

    switch (action.type) {
      case 'failed':
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
          fetchFailureCount: state.fetchFailureCount + 1
        });

      case 'pause':
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
          isPaused: true
        });

      case 'continue':
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
          isPaused: false
        });

      case 'fetch':
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
          fetchFailureCount: 0,
          fetchMeta: (_action$meta = action.meta) != null ? _action$meta : null,
          isFetching: true,
          isPaused: false,
          status: !state.dataUpdatedAt ? 'loading' : state.status
        });

      case 'success':
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
          data: action.data,
          dataUpdateCount: state.dataUpdateCount + 1,
          dataUpdatedAt: (_action$dataUpdatedAt = action.dataUpdatedAt) != null ? _action$dataUpdatedAt : Date.now(),
          error: null,
          fetchFailureCount: 0,
          isFetching: false,
          isInvalidated: false,
          isPaused: false,
          status: 'success'
        });

      case 'error':
        var error = action.error;

        if ((0,_retryer__WEBPACK_IMPORTED_MODULE_2__/* .isCancelledError */ .DV)(error) && error.revert && this.revertState) {
          return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, this.revertState);
        }

        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
          error: error,
          errorUpdateCount: state.errorUpdateCount + 1,
          errorUpdatedAt: Date.now(),
          fetchFailureCount: state.fetchFailureCount + 1,
          isFetching: false,
          isPaused: false,
          status: 'error'
        });

      case 'invalidate':
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, {
          isInvalidated: true
        });

      case 'setState':
        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, state, action.state);

      default:
        return state;
    }
  };

  return Query;
}();

/***/ }),

/***/ 10384:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "t": function() { return /* binding */ QueryCache; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(81665);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(10774);
/* harmony import */ var _query__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(81257);
/* harmony import */ var _notifyManager__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(50667);
/* harmony import */ var _subscribable__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(92693);





// CLASS
var QueryCache = /*#__PURE__*/function (_Subscribable) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(QueryCache, _Subscribable);

  function QueryCache(config) {
    var _this;

    _this = _Subscribable.call(this) || this;
    _this.config = config || {};
    _this.queries = [];
    _this.queriesMap = {};
    return _this;
  }

  var _proto = QueryCache.prototype;

  _proto.build = function build(client, options, state) {
    var _options$queryHash;

    var queryKey = options.queryKey;
    var queryHash = (_options$queryHash = options.queryHash) != null ? _options$queryHash : (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .hashQueryKeyByOptions */ .Rm)(queryKey, options);
    var query = this.get(queryHash);

    if (!query) {
      query = new _query__WEBPACK_IMPORTED_MODULE_2__/* .Query */ .A({
        cache: this,
        queryKey: queryKey,
        queryHash: queryHash,
        options: client.defaultQueryOptions(options),
        state: state,
        defaultOptions: client.getQueryDefaults(queryKey),
        meta: options.meta
      });
      this.add(query);
    }

    return query;
  };

  _proto.add = function add(query) {
    if (!this.queriesMap[query.queryHash]) {
      this.queriesMap[query.queryHash] = query;
      this.queries.push(query);
      this.notify({
        type: 'queryAdded',
        query: query
      });
    }
  };

  _proto.remove = function remove(query) {
    var queryInMap = this.queriesMap[query.queryHash];

    if (queryInMap) {
      query.destroy();
      this.queries = this.queries.filter(function (x) {
        return x !== query;
      });

      if (queryInMap === query) {
        delete this.queriesMap[query.queryHash];
      }

      this.notify({
        type: 'queryRemoved',
        query: query
      });
    }
  };

  _proto.clear = function clear() {
    var _this2 = this;

    _notifyManager__WEBPACK_IMPORTED_MODULE_3__/* .notifyManager.batch */ .V.batch(function () {
      _this2.queries.forEach(function (query) {
        _this2.remove(query);
      });
    });
  };

  _proto.get = function get(queryHash) {
    return this.queriesMap[queryHash];
  };

  _proto.getAll = function getAll() {
    return this.queries;
  };

  _proto.find = function find(arg1, arg2) {
    var _parseFilterArgs = (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .parseFilterArgs */ .I6)(arg1, arg2),
        filters = _parseFilterArgs[0];

    if (typeof filters.exact === 'undefined') {
      filters.exact = true;
    }

    return this.queries.find(function (query) {
      return (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .matchQuery */ ._x)(filters, query);
    });
  };

  _proto.findAll = function findAll(arg1, arg2) {
    var _parseFilterArgs2 = (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .parseFilterArgs */ .I6)(arg1, arg2),
        filters = _parseFilterArgs2[0];

    return filters ? this.queries.filter(function (query) {
      return (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .matchQuery */ ._x)(filters, query);
    }) : this.queries;
  };

  _proto.notify = function notify(event) {
    var _this3 = this;

    _notifyManager__WEBPACK_IMPORTED_MODULE_3__/* .notifyManager.batch */ .V.batch(function () {
      _this3.listeners.forEach(function (listener) {
        listener(event);
      });
    });
  };

  _proto.onFocus = function onFocus() {
    var _this4 = this;

    _notifyManager__WEBPACK_IMPORTED_MODULE_3__/* .notifyManager.batch */ .V.batch(function () {
      _this4.queries.forEach(function (query) {
        query.onFocus();
      });
    });
  };

  _proto.onOnline = function onOnline() {
    var _this5 = this;

    _notifyManager__WEBPACK_IMPORTED_MODULE_3__/* .notifyManager.batch */ .V.batch(function () {
      _this5.queries.forEach(function (query) {
        query.onOnline();
      });
    });
  };

  return QueryCache;
}(_subscribable__WEBPACK_IMPORTED_MODULE_4__/* .Subscribable */ .l);

/***/ }),

/***/ 29446:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "S": function() { return /* binding */ QueryClient; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(7896);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(10774);
/* harmony import */ var _queryCache__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(10384);
/* harmony import */ var _mutationCache__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9601);
/* harmony import */ var _focusManager__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(27483);
/* harmony import */ var _onlineManager__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(58927);
/* harmony import */ var _notifyManager__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(50667);
/* harmony import */ var _infiniteQueryBehavior__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(20560);








// CLASS
var QueryClient = /*#__PURE__*/function () {
  function QueryClient(config) {
    if (config === void 0) {
      config = {};
    }

    this.queryCache = config.queryCache || new _queryCache__WEBPACK_IMPORTED_MODULE_0__/* .QueryCache */ .t();
    this.mutationCache = config.mutationCache || new _mutationCache__WEBPACK_IMPORTED_MODULE_1__/* .MutationCache */ .L();
    this.defaultOptions = config.defaultOptions || {};
    this.queryDefaults = [];
    this.mutationDefaults = [];
  }

  var _proto = QueryClient.prototype;

  _proto.mount = function mount() {
    var _this = this;

    this.unsubscribeFocus = _focusManager__WEBPACK_IMPORTED_MODULE_2__/* .focusManager.subscribe */ .j.subscribe(function () {
      if (_focusManager__WEBPACK_IMPORTED_MODULE_2__/* .focusManager.isFocused */ .j.isFocused() && _onlineManager__WEBPACK_IMPORTED_MODULE_3__/* .onlineManager.isOnline */ .N.isOnline()) {
        _this.mutationCache.onFocus();

        _this.queryCache.onFocus();
      }
    });
    this.unsubscribeOnline = _onlineManager__WEBPACK_IMPORTED_MODULE_3__/* .onlineManager.subscribe */ .N.subscribe(function () {
      if (_focusManager__WEBPACK_IMPORTED_MODULE_2__/* .focusManager.isFocused */ .j.isFocused() && _onlineManager__WEBPACK_IMPORTED_MODULE_3__/* .onlineManager.isOnline */ .N.isOnline()) {
        _this.mutationCache.onOnline();

        _this.queryCache.onOnline();
      }
    });
  };

  _proto.unmount = function unmount() {
    var _this$unsubscribeFocu, _this$unsubscribeOnli;

    (_this$unsubscribeFocu = this.unsubscribeFocus) == null ? void 0 : _this$unsubscribeFocu.call(this);
    (_this$unsubscribeOnli = this.unsubscribeOnline) == null ? void 0 : _this$unsubscribeOnli.call(this);
  };

  _proto.isFetching = function isFetching(arg1, arg2) {
    var _parseFilterArgs = (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .parseFilterArgs */ .I6)(arg1, arg2),
        filters = _parseFilterArgs[0];

    filters.fetching = true;
    return this.queryCache.findAll(filters).length;
  };

  _proto.isMutating = function isMutating(filters) {
    return this.mutationCache.findAll((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({}, filters, {
      fetching: true
    })).length;
  };

  _proto.getQueryData = function getQueryData(queryKey, filters) {
    var _this$queryCache$find;

    return (_this$queryCache$find = this.queryCache.find(queryKey, filters)) == null ? void 0 : _this$queryCache$find.state.data;
  };

  _proto.getQueriesData = function getQueriesData(queryKeyOrFilters) {
    return this.getQueryCache().findAll(queryKeyOrFilters).map(function (_ref) {
      var queryKey = _ref.queryKey,
          state = _ref.state;
      var data = state.data;
      return [queryKey, data];
    });
  };

  _proto.setQueryData = function setQueryData(queryKey, updater, options) {
    var parsedOptions = (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .parseQueryArgs */ ._v)(queryKey);
    var defaultedOptions = this.defaultQueryOptions(parsedOptions);
    return this.queryCache.build(this, defaultedOptions).setData(updater, options);
  };

  _proto.setQueriesData = function setQueriesData(queryKeyOrFilters, updater, options) {
    var _this2 = this;

    return _notifyManager__WEBPACK_IMPORTED_MODULE_6__/* .notifyManager.batch */ .V.batch(function () {
      return _this2.getQueryCache().findAll(queryKeyOrFilters).map(function (_ref2) {
        var queryKey = _ref2.queryKey;
        return [queryKey, _this2.setQueryData(queryKey, updater, options)];
      });
    });
  };

  _proto.getQueryState = function getQueryState(queryKey, filters) {
    var _this$queryCache$find2;

    return (_this$queryCache$find2 = this.queryCache.find(queryKey, filters)) == null ? void 0 : _this$queryCache$find2.state;
  };

  _proto.removeQueries = function removeQueries(arg1, arg2) {
    var _parseFilterArgs2 = (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .parseFilterArgs */ .I6)(arg1, arg2),
        filters = _parseFilterArgs2[0];

    var queryCache = this.queryCache;
    _notifyManager__WEBPACK_IMPORTED_MODULE_6__/* .notifyManager.batch */ .V.batch(function () {
      queryCache.findAll(filters).forEach(function (query) {
        queryCache.remove(query);
      });
    });
  };

  _proto.resetQueries = function resetQueries(arg1, arg2, arg3) {
    var _this3 = this;

    var _parseFilterArgs3 = (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .parseFilterArgs */ .I6)(arg1, arg2, arg3),
        filters = _parseFilterArgs3[0],
        options = _parseFilterArgs3[1];

    var queryCache = this.queryCache;

    var refetchFilters = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({}, filters, {
      active: true
    });

    return _notifyManager__WEBPACK_IMPORTED_MODULE_6__/* .notifyManager.batch */ .V.batch(function () {
      queryCache.findAll(filters).forEach(function (query) {
        query.reset();
      });
      return _this3.refetchQueries(refetchFilters, options);
    });
  };

  _proto.cancelQueries = function cancelQueries(arg1, arg2, arg3) {
    var _this4 = this;

    var _parseFilterArgs4 = (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .parseFilterArgs */ .I6)(arg1, arg2, arg3),
        filters = _parseFilterArgs4[0],
        _parseFilterArgs4$ = _parseFilterArgs4[1],
        cancelOptions = _parseFilterArgs4$ === void 0 ? {} : _parseFilterArgs4$;

    if (typeof cancelOptions.revert === 'undefined') {
      cancelOptions.revert = true;
    }

    var promises = _notifyManager__WEBPACK_IMPORTED_MODULE_6__/* .notifyManager.batch */ .V.batch(function () {
      return _this4.queryCache.findAll(filters).map(function (query) {
        return query.cancel(cancelOptions);
      });
    });
    return Promise.all(promises).then(_utils__WEBPACK_IMPORTED_MODULE_4__/* .noop */ .ZT).catch(_utils__WEBPACK_IMPORTED_MODULE_4__/* .noop */ .ZT);
  };

  _proto.invalidateQueries = function invalidateQueries(arg1, arg2, arg3) {
    var _ref3,
        _filters$refetchActiv,
        _filters$refetchInact,
        _this5 = this;

    var _parseFilterArgs5 = (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .parseFilterArgs */ .I6)(arg1, arg2, arg3),
        filters = _parseFilterArgs5[0],
        options = _parseFilterArgs5[1];

    var refetchFilters = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({}, filters, {
      // if filters.refetchActive is not provided and filters.active is explicitly false,
      // e.g. invalidateQueries({ active: false }), we don't want to refetch active queries
      active: (_ref3 = (_filters$refetchActiv = filters.refetchActive) != null ? _filters$refetchActiv : filters.active) != null ? _ref3 : true,
      inactive: (_filters$refetchInact = filters.refetchInactive) != null ? _filters$refetchInact : false
    });

    return _notifyManager__WEBPACK_IMPORTED_MODULE_6__/* .notifyManager.batch */ .V.batch(function () {
      _this5.queryCache.findAll(filters).forEach(function (query) {
        query.invalidate();
      });

      return _this5.refetchQueries(refetchFilters, options);
    });
  };

  _proto.refetchQueries = function refetchQueries(arg1, arg2, arg3) {
    var _this6 = this;

    var _parseFilterArgs6 = (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .parseFilterArgs */ .I6)(arg1, arg2, arg3),
        filters = _parseFilterArgs6[0],
        options = _parseFilterArgs6[1];

    var promises = _notifyManager__WEBPACK_IMPORTED_MODULE_6__/* .notifyManager.batch */ .V.batch(function () {
      return _this6.queryCache.findAll(filters).map(function (query) {
        return query.fetch(undefined, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({}, options, {
          meta: {
            refetchPage: filters == null ? void 0 : filters.refetchPage
          }
        }));
      });
    });
    var promise = Promise.all(promises).then(_utils__WEBPACK_IMPORTED_MODULE_4__/* .noop */ .ZT);

    if (!(options == null ? void 0 : options.throwOnError)) {
      promise = promise.catch(_utils__WEBPACK_IMPORTED_MODULE_4__/* .noop */ .ZT);
    }

    return promise;
  };

  _proto.fetchQuery = function fetchQuery(arg1, arg2, arg3) {
    var parsedOptions = (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .parseQueryArgs */ ._v)(arg1, arg2, arg3);
    var defaultedOptions = this.defaultQueryOptions(parsedOptions); // https://github.com/tannerlinsley/react-query/issues/652

    if (typeof defaultedOptions.retry === 'undefined') {
      defaultedOptions.retry = false;
    }

    var query = this.queryCache.build(this, defaultedOptions);
    return query.isStaleByTime(defaultedOptions.staleTime) ? query.fetch(defaultedOptions) : Promise.resolve(query.state.data);
  };

  _proto.prefetchQuery = function prefetchQuery(arg1, arg2, arg3) {
    return this.fetchQuery(arg1, arg2, arg3).then(_utils__WEBPACK_IMPORTED_MODULE_4__/* .noop */ .ZT).catch(_utils__WEBPACK_IMPORTED_MODULE_4__/* .noop */ .ZT);
  };

  _proto.fetchInfiniteQuery = function fetchInfiniteQuery(arg1, arg2, arg3) {
    var parsedOptions = (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .parseQueryArgs */ ._v)(arg1, arg2, arg3);
    parsedOptions.behavior = (0,_infiniteQueryBehavior__WEBPACK_IMPORTED_MODULE_7__/* .infiniteQueryBehavior */ .Gm)();
    return this.fetchQuery(parsedOptions);
  };

  _proto.prefetchInfiniteQuery = function prefetchInfiniteQuery(arg1, arg2, arg3) {
    return this.fetchInfiniteQuery(arg1, arg2, arg3).then(_utils__WEBPACK_IMPORTED_MODULE_4__/* .noop */ .ZT).catch(_utils__WEBPACK_IMPORTED_MODULE_4__/* .noop */ .ZT);
  };

  _proto.cancelMutations = function cancelMutations() {
    var _this7 = this;

    var promises = _notifyManager__WEBPACK_IMPORTED_MODULE_6__/* .notifyManager.batch */ .V.batch(function () {
      return _this7.mutationCache.getAll().map(function (mutation) {
        return mutation.cancel();
      });
    });
    return Promise.all(promises).then(_utils__WEBPACK_IMPORTED_MODULE_4__/* .noop */ .ZT).catch(_utils__WEBPACK_IMPORTED_MODULE_4__/* .noop */ .ZT);
  };

  _proto.resumePausedMutations = function resumePausedMutations() {
    return this.getMutationCache().resumePausedMutations();
  };

  _proto.executeMutation = function executeMutation(options) {
    return this.mutationCache.build(this, options).execute();
  };

  _proto.getQueryCache = function getQueryCache() {
    return this.queryCache;
  };

  _proto.getMutationCache = function getMutationCache() {
    return this.mutationCache;
  };

  _proto.getDefaultOptions = function getDefaultOptions() {
    return this.defaultOptions;
  };

  _proto.setDefaultOptions = function setDefaultOptions(options) {
    this.defaultOptions = options;
  };

  _proto.setQueryDefaults = function setQueryDefaults(queryKey, options) {
    var result = this.queryDefaults.find(function (x) {
      return (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .hashQueryKey */ .yF)(queryKey) === (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .hashQueryKey */ .yF)(x.queryKey);
    });

    if (result) {
      result.defaultOptions = options;
    } else {
      this.queryDefaults.push({
        queryKey: queryKey,
        defaultOptions: options
      });
    }
  };

  _proto.getQueryDefaults = function getQueryDefaults(queryKey) {
    var _this$queryDefaults$f;

    return queryKey ? (_this$queryDefaults$f = this.queryDefaults.find(function (x) {
      return (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .partialMatchKey */ .to)(queryKey, x.queryKey);
    })) == null ? void 0 : _this$queryDefaults$f.defaultOptions : undefined;
  };

  _proto.setMutationDefaults = function setMutationDefaults(mutationKey, options) {
    var result = this.mutationDefaults.find(function (x) {
      return (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .hashQueryKey */ .yF)(mutationKey) === (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .hashQueryKey */ .yF)(x.mutationKey);
    });

    if (result) {
      result.defaultOptions = options;
    } else {
      this.mutationDefaults.push({
        mutationKey: mutationKey,
        defaultOptions: options
      });
    }
  };

  _proto.getMutationDefaults = function getMutationDefaults(mutationKey) {
    var _this$mutationDefault;

    return mutationKey ? (_this$mutationDefault = this.mutationDefaults.find(function (x) {
      return (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .partialMatchKey */ .to)(mutationKey, x.mutationKey);
    })) == null ? void 0 : _this$mutationDefault.defaultOptions : undefined;
  };

  _proto.defaultQueryOptions = function defaultQueryOptions(options) {
    if (options == null ? void 0 : options._defaulted) {
      return options;
    }

    var defaultedOptions = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({}, this.defaultOptions.queries, this.getQueryDefaults(options == null ? void 0 : options.queryKey), options, {
      _defaulted: true
    });

    if (!defaultedOptions.queryHash && defaultedOptions.queryKey) {
      defaultedOptions.queryHash = (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .hashQueryKeyByOptions */ .Rm)(defaultedOptions.queryKey, defaultedOptions);
    }

    return defaultedOptions;
  };

  _proto.defaultQueryObserverOptions = function defaultQueryObserverOptions(options) {
    return this.defaultQueryOptions(options);
  };

  _proto.defaultMutationOptions = function defaultMutationOptions(options) {
    if (options == null ? void 0 : options._defaulted) {
      return options;
    }

    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({}, this.defaultOptions.mutations, this.getMutationDefaults(options == null ? void 0 : options.mutationKey), options, {
      _defaulted: true
    });
  };

  _proto.clear = function clear() {
    this.queryCache.clear();
    this.mutationCache.clear();
  };

  return QueryClient;
}();

/***/ }),

/***/ 24198:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "z": function() { return /* binding */ QueryObserver; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(7896);
/* harmony import */ var _babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(81665);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(10774);
/* harmony import */ var _notifyManager__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(50667);
/* harmony import */ var _focusManager__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(27483);
/* harmony import */ var _subscribable__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(92693);
/* harmony import */ var _logger__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(53579);
/* harmony import */ var _retryer__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(22348);








var QueryObserver = /*#__PURE__*/function (_Subscribable) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(QueryObserver, _Subscribable);

  function QueryObserver(client, options) {
    var _this;

    _this = _Subscribable.call(this) || this;
    _this.client = client;
    _this.options = options;
    _this.trackedProps = [];
    _this.previousSelectError = null;

    _this.bindMethods();

    _this.setOptions(options);

    return _this;
  }

  var _proto = QueryObserver.prototype;

  _proto.bindMethods = function bindMethods() {
    this.remove = this.remove.bind(this);
    this.refetch = this.refetch.bind(this);
  };

  _proto.onSubscribe = function onSubscribe() {
    if (this.listeners.length === 1) {
      this.currentQuery.addObserver(this);

      if (shouldFetchOnMount(this.currentQuery, this.options)) {
        this.executeFetch();
      }

      this.updateTimers();
    }
  };

  _proto.onUnsubscribe = function onUnsubscribe() {
    if (!this.listeners.length) {
      this.destroy();
    }
  };

  _proto.shouldFetchOnReconnect = function shouldFetchOnReconnect() {
    return _shouldFetchOnReconnect(this.currentQuery, this.options);
  };

  _proto.shouldFetchOnWindowFocus = function shouldFetchOnWindowFocus() {
    return _shouldFetchOnWindowFocus(this.currentQuery, this.options);
  };

  _proto.destroy = function destroy() {
    this.listeners = [];
    this.clearTimers();
    this.currentQuery.removeObserver(this);
  };

  _proto.setOptions = function setOptions(options, notifyOptions) {
    var prevOptions = this.options;
    var prevQuery = this.currentQuery;
    this.options = this.client.defaultQueryObserverOptions(options);

    if (typeof this.options.enabled !== 'undefined' && typeof this.options.enabled !== 'boolean') {
      throw new Error('Expected enabled to be a boolean');
    } // Keep previous query key if the user does not supply one


    if (!this.options.queryKey) {
      this.options.queryKey = prevOptions.queryKey;
    }

    this.updateQuery();
    var mounted = this.hasListeners(); // Fetch if there are subscribers

    if (mounted && shouldFetchOptionally(this.currentQuery, prevQuery, this.options, prevOptions)) {
      this.executeFetch();
    } // Update result


    this.updateResult(notifyOptions); // Update stale interval if needed

    if (mounted && (this.currentQuery !== prevQuery || this.options.enabled !== prevOptions.enabled || this.options.staleTime !== prevOptions.staleTime)) {
      this.updateStaleTimeout();
    }

    var nextRefetchInterval = this.computeRefetchInterval(); // Update refetch interval if needed

    if (mounted && (this.currentQuery !== prevQuery || this.options.enabled !== prevOptions.enabled || nextRefetchInterval !== this.currentRefetchInterval)) {
      this.updateRefetchInterval(nextRefetchInterval);
    }
  };

  _proto.getOptimisticResult = function getOptimisticResult(options) {
    var defaultedOptions = this.client.defaultQueryObserverOptions(options);
    var query = this.client.getQueryCache().build(this.client, defaultedOptions);
    return this.createResult(query, defaultedOptions);
  };

  _proto.getCurrentResult = function getCurrentResult() {
    return this.currentResult;
  };

  _proto.trackResult = function trackResult(result) {
    var _this2 = this;

    var trackedResult = {};
    Object.keys(result).forEach(function (key) {
      Object.defineProperty(trackedResult, key, {
        configurable: false,
        enumerable: true,
        get: function get() {
          var typedKey = key;

          if (!_this2.trackedProps.includes(typedKey)) {
            _this2.trackedProps.push(typedKey);
          }

          return result[typedKey];
        }
      });
    });
    return trackedResult;
  };

  _proto.getNextResult = function getNextResult(options) {
    var _this3 = this;

    return new Promise(function (resolve, reject) {
      var unsubscribe = _this3.subscribe(function (result) {
        if (!result.isFetching) {
          unsubscribe();

          if (result.isError && (options == null ? void 0 : options.throwOnError)) {
            reject(result.error);
          } else {
            resolve(result);
          }
        }
      });
    });
  };

  _proto.getCurrentQuery = function getCurrentQuery() {
    return this.currentQuery;
  };

  _proto.remove = function remove() {
    this.client.getQueryCache().remove(this.currentQuery);
  };

  _proto.refetch = function refetch(options) {
    return this.fetch((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)({}, options, {
      meta: {
        refetchPage: options == null ? void 0 : options.refetchPage
      }
    }));
  };

  _proto.fetchOptimistic = function fetchOptimistic(options) {
    var _this4 = this;

    var defaultedOptions = this.client.defaultQueryObserverOptions(options);
    var query = this.client.getQueryCache().build(this.client, defaultedOptions);
    return query.fetch().then(function () {
      return _this4.createResult(query, defaultedOptions);
    });
  };

  _proto.fetch = function fetch(fetchOptions) {
    var _this5 = this;

    return this.executeFetch(fetchOptions).then(function () {
      _this5.updateResult();

      return _this5.currentResult;
    });
  };

  _proto.executeFetch = function executeFetch(fetchOptions) {
    // Make sure we reference the latest query as the current one might have been removed
    this.updateQuery(); // Fetch

    var promise = this.currentQuery.fetch(this.options, fetchOptions);

    if (!(fetchOptions == null ? void 0 : fetchOptions.throwOnError)) {
      promise = promise.catch(_utils__WEBPACK_IMPORTED_MODULE_2__/* .noop */ .ZT);
    }

    return promise;
  };

  _proto.updateStaleTimeout = function updateStaleTimeout() {
    var _this6 = this;

    this.clearStaleTimeout();

    if (_utils__WEBPACK_IMPORTED_MODULE_2__/* .isServer */ .sk || this.currentResult.isStale || !(0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .isValidTimeout */ .PN)(this.options.staleTime)) {
      return;
    }

    var time = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .timeUntilStale */ .Kp)(this.currentResult.dataUpdatedAt, this.options.staleTime); // The timeout is sometimes triggered 1 ms before the stale time expiration.
    // To mitigate this issue we always add 1 ms to the timeout.

    var timeout = time + 1;
    this.staleTimeoutId = setTimeout(function () {
      if (!_this6.currentResult.isStale) {
        _this6.updateResult();
      }
    }, timeout);
  };

  _proto.computeRefetchInterval = function computeRefetchInterval() {
    var _this$options$refetch;

    return typeof this.options.refetchInterval === 'function' ? this.options.refetchInterval(this.currentResult.data, this.currentQuery) : (_this$options$refetch = this.options.refetchInterval) != null ? _this$options$refetch : false;
  };

  _proto.updateRefetchInterval = function updateRefetchInterval(nextInterval) {
    var _this7 = this;

    this.clearRefetchInterval();
    this.currentRefetchInterval = nextInterval;

    if (_utils__WEBPACK_IMPORTED_MODULE_2__/* .isServer */ .sk || this.options.enabled === false || !(0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .isValidTimeout */ .PN)(this.currentRefetchInterval) || this.currentRefetchInterval === 0) {
      return;
    }

    this.refetchIntervalId = setInterval(function () {
      if (_this7.options.refetchIntervalInBackground || _focusManager__WEBPACK_IMPORTED_MODULE_3__/* .focusManager.isFocused */ .j.isFocused()) {
        _this7.executeFetch();
      }
    }, this.currentRefetchInterval);
  };

  _proto.updateTimers = function updateTimers() {
    this.updateStaleTimeout();
    this.updateRefetchInterval(this.computeRefetchInterval());
  };

  _proto.clearTimers = function clearTimers() {
    this.clearStaleTimeout();
    this.clearRefetchInterval();
  };

  _proto.clearStaleTimeout = function clearStaleTimeout() {
    clearTimeout(this.staleTimeoutId);
    this.staleTimeoutId = undefined;
  };

  _proto.clearRefetchInterval = function clearRefetchInterval() {
    clearInterval(this.refetchIntervalId);
    this.refetchIntervalId = undefined;
  };

  _proto.createResult = function createResult(query, options) {
    var prevQuery = this.currentQuery;
    var prevOptions = this.options;
    var prevResult = this.currentResult;
    var prevResultState = this.currentResultState;
    var prevResultOptions = this.currentResultOptions;
    var queryChange = query !== prevQuery;
    var queryInitialState = queryChange ? query.state : this.currentQueryInitialState;
    var prevQueryResult = queryChange ? this.currentResult : this.previousQueryResult;
    var state = query.state;
    var dataUpdatedAt = state.dataUpdatedAt,
        error = state.error,
        errorUpdatedAt = state.errorUpdatedAt,
        isFetching = state.isFetching,
        status = state.status;
    var isPreviousData = false;
    var isPlaceholderData = false;
    var data; // Optimistically set result in fetching state if needed

    if (options.optimisticResults) {
      var mounted = this.hasListeners();
      var fetchOnMount = !mounted && shouldFetchOnMount(query, options);
      var fetchOptionally = mounted && shouldFetchOptionally(query, prevQuery, options, prevOptions);

      if (fetchOnMount || fetchOptionally) {
        isFetching = true;

        if (!dataUpdatedAt) {
          status = 'loading';
        }
      }
    } // Keep previous data if needed


    if (options.keepPreviousData && !state.dataUpdateCount && (prevQueryResult == null ? void 0 : prevQueryResult.isSuccess) && status !== 'error') {
      data = prevQueryResult.data;
      dataUpdatedAt = prevQueryResult.dataUpdatedAt;
      status = prevQueryResult.status;
      isPreviousData = true;
    } // Select data if needed
    else if (options.select && typeof state.data !== 'undefined') {
        // Memoize select result
        if (prevResult && state.data === (prevResultState == null ? void 0 : prevResultState.data) && options.select === (prevResultOptions == null ? void 0 : prevResultOptions.select) && !this.previousSelectError) {
          data = prevResult.data;
        } else {
          try {
            data = options.select(state.data);

            if (options.structuralSharing !== false) {
              data = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .replaceEqualDeep */ .Q$)(prevResult == null ? void 0 : prevResult.data, data);
            }

            this.previousSelectError = null;
          } catch (selectError) {
            (0,_logger__WEBPACK_IMPORTED_MODULE_4__/* .getLogger */ .j)().error(selectError);
            error = selectError;
            this.previousSelectError = selectError;
            errorUpdatedAt = Date.now();
            status = 'error';
          }
        }
      } // Use query data
      else {
          data = state.data;
        } // Show placeholder data if needed


    if (typeof options.placeholderData !== 'undefined' && typeof data === 'undefined' && (status === 'loading' || status === 'idle')) {
      var placeholderData; // Memoize placeholder data

      if ((prevResult == null ? void 0 : prevResult.isPlaceholderData) && options.placeholderData === (prevResultOptions == null ? void 0 : prevResultOptions.placeholderData)) {
        placeholderData = prevResult.data;
      } else {
        placeholderData = typeof options.placeholderData === 'function' ? options.placeholderData() : options.placeholderData;

        if (options.select && typeof placeholderData !== 'undefined') {
          try {
            placeholderData = options.select(placeholderData);

            if (options.structuralSharing !== false) {
              placeholderData = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .replaceEqualDeep */ .Q$)(prevResult == null ? void 0 : prevResult.data, placeholderData);
            }

            this.previousSelectError = null;
          } catch (selectError) {
            (0,_logger__WEBPACK_IMPORTED_MODULE_4__/* .getLogger */ .j)().error(selectError);
            error = selectError;
            this.previousSelectError = selectError;
            errorUpdatedAt = Date.now();
            status = 'error';
          }
        }
      }

      if (typeof placeholderData !== 'undefined') {
        status = 'success';
        data = placeholderData;
        isPlaceholderData = true;
      }
    }

    var result = {
      status: status,
      isLoading: status === 'loading',
      isSuccess: status === 'success',
      isError: status === 'error',
      isIdle: status === 'idle',
      data: data,
      dataUpdatedAt: dataUpdatedAt,
      error: error,
      errorUpdatedAt: errorUpdatedAt,
      failureCount: state.fetchFailureCount,
      isFetched: state.dataUpdateCount > 0 || state.errorUpdateCount > 0,
      isFetchedAfterMount: state.dataUpdateCount > queryInitialState.dataUpdateCount || state.errorUpdateCount > queryInitialState.errorUpdateCount,
      isFetching: isFetching,
      isRefetching: isFetching && status !== 'loading',
      isLoadingError: status === 'error' && state.dataUpdatedAt === 0,
      isPlaceholderData: isPlaceholderData,
      isPreviousData: isPreviousData,
      isRefetchError: status === 'error' && state.dataUpdatedAt !== 0,
      isStale: isStale(query, options),
      refetch: this.refetch,
      remove: this.remove
    };
    return result;
  };

  _proto.shouldNotifyListeners = function shouldNotifyListeners(result, prevResult) {
    if (!prevResult) {
      return true;
    }

    if (result === prevResult) {
      return false;
    }

    var _this$options = this.options,
        notifyOnChangeProps = _this$options.notifyOnChangeProps,
        notifyOnChangePropsExclusions = _this$options.notifyOnChangePropsExclusions;

    if (!notifyOnChangeProps && !notifyOnChangePropsExclusions) {
      return true;
    }

    if (notifyOnChangeProps === 'tracked' && !this.trackedProps.length) {
      return true;
    }

    var includedProps = notifyOnChangeProps === 'tracked' ? this.trackedProps : notifyOnChangeProps;
    return Object.keys(result).some(function (key) {
      var typedKey = key;
      var changed = result[typedKey] !== prevResult[typedKey];
      var isIncluded = includedProps == null ? void 0 : includedProps.some(function (x) {
        return x === key;
      });
      var isExcluded = notifyOnChangePropsExclusions == null ? void 0 : notifyOnChangePropsExclusions.some(function (x) {
        return x === key;
      });
      return changed && !isExcluded && (!includedProps || isIncluded);
    });
  };

  _proto.updateResult = function updateResult(notifyOptions) {
    var prevResult = this.currentResult;
    this.currentResult = this.createResult(this.currentQuery, this.options);
    this.currentResultState = this.currentQuery.state;
    this.currentResultOptions = this.options; // Only notify if something has changed

    if ((0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .shallowEqualObjects */ .VS)(this.currentResult, prevResult)) {
      return;
    } // Determine which callbacks to trigger


    var defaultNotifyOptions = {
      cache: true
    };

    if ((notifyOptions == null ? void 0 : notifyOptions.listeners) !== false && this.shouldNotifyListeners(this.currentResult, prevResult)) {
      defaultNotifyOptions.listeners = true;
    }

    this.notify((0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)({}, defaultNotifyOptions, notifyOptions));
  };

  _proto.updateQuery = function updateQuery() {
    var query = this.client.getQueryCache().build(this.client, this.options);

    if (query === this.currentQuery) {
      return;
    }

    var prevQuery = this.currentQuery;
    this.currentQuery = query;
    this.currentQueryInitialState = query.state;
    this.previousQueryResult = this.currentResult;

    if (this.hasListeners()) {
      prevQuery == null ? void 0 : prevQuery.removeObserver(this);
      query.addObserver(this);
    }
  };

  _proto.onQueryUpdate = function onQueryUpdate(action) {
    var notifyOptions = {};

    if (action.type === 'success') {
      notifyOptions.onSuccess = true;
    } else if (action.type === 'error' && !(0,_retryer__WEBPACK_IMPORTED_MODULE_5__/* .isCancelledError */ .DV)(action.error)) {
      notifyOptions.onError = true;
    }

    this.updateResult(notifyOptions);

    if (this.hasListeners()) {
      this.updateTimers();
    }
  };

  _proto.notify = function notify(notifyOptions) {
    var _this8 = this;

    _notifyManager__WEBPACK_IMPORTED_MODULE_6__/* .notifyManager.batch */ .V.batch(function () {
      // First trigger the configuration callbacks
      if (notifyOptions.onSuccess) {
        _this8.options.onSuccess == null ? void 0 : _this8.options.onSuccess(_this8.currentResult.data);
        _this8.options.onSettled == null ? void 0 : _this8.options.onSettled(_this8.currentResult.data, null);
      } else if (notifyOptions.onError) {
        _this8.options.onError == null ? void 0 : _this8.options.onError(_this8.currentResult.error);
        _this8.options.onSettled == null ? void 0 : _this8.options.onSettled(undefined, _this8.currentResult.error);
      } // Then trigger the listeners


      if (notifyOptions.listeners) {
        _this8.listeners.forEach(function (listener) {
          listener(_this8.currentResult);
        });
      } // Then the cache listeners


      if (notifyOptions.cache) {
        _this8.client.getQueryCache().notify({
          query: _this8.currentQuery,
          type: 'observerResultsUpdated'
        });
      }
    });
  };

  return QueryObserver;
}(_subscribable__WEBPACK_IMPORTED_MODULE_7__/* .Subscribable */ .l);

function shouldLoadOnMount(query, options) {
  return options.enabled !== false && !query.state.dataUpdatedAt && !(query.state.status === 'error' && options.retryOnMount === false);
}

function shouldRefetchOnMount(query, options) {
  return options.enabled !== false && query.state.dataUpdatedAt > 0 && (options.refetchOnMount === 'always' || options.refetchOnMount !== false && isStale(query, options));
}

function shouldFetchOnMount(query, options) {
  return shouldLoadOnMount(query, options) || shouldRefetchOnMount(query, options);
}

function _shouldFetchOnReconnect(query, options) {
  return options.enabled !== false && (options.refetchOnReconnect === 'always' || options.refetchOnReconnect !== false && isStale(query, options));
}

function _shouldFetchOnWindowFocus(query, options) {
  return options.enabled !== false && (options.refetchOnWindowFocus === 'always' || options.refetchOnWindowFocus !== false && isStale(query, options));
}

function shouldFetchOptionally(query, prevQuery, options, prevOptions) {
  return options.enabled !== false && (query !== prevQuery || prevOptions.enabled === false) && (!options.suspense || query.state.status !== 'error' || prevOptions.enabled === false) && isStale(query, options);
}

function isStale(query, options) {
  return query.isStaleByTime(options.staleTime);
}

/***/ }),

/***/ 22348:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "LE": function() { return /* binding */ isCancelable; },
/* harmony export */   "DV": function() { return /* binding */ isCancelledError; },
/* harmony export */   "m4": function() { return /* binding */ Retryer; }
/* harmony export */ });
/* unused harmony export CancelledError */
/* harmony import */ var _focusManager__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(27483);
/* harmony import */ var _onlineManager__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(58927);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(10774);




function defaultRetryDelay(failureCount) {
  return Math.min(1000 * Math.pow(2, failureCount), 30000);
}

function isCancelable(value) {
  return typeof (value == null ? void 0 : value.cancel) === 'function';
}
var CancelledError = function CancelledError(options) {
  this.revert = options == null ? void 0 : options.revert;
  this.silent = options == null ? void 0 : options.silent;
};
function isCancelledError(value) {
  return value instanceof CancelledError;
} // CLASS

var Retryer = function Retryer(config) {
  var _this = this;

  var cancelRetry = false;
  var cancelFn;
  var continueFn;
  var promiseResolve;
  var promiseReject;
  this.abort = config.abort;

  this.cancel = function (cancelOptions) {
    return cancelFn == null ? void 0 : cancelFn(cancelOptions);
  };

  this.cancelRetry = function () {
    cancelRetry = true;
  };

  this.continue = function () {
    return continueFn == null ? void 0 : continueFn();
  };

  this.failureCount = 0;
  this.isPaused = false;
  this.isResolved = false;
  this.isTransportCancelable = false;
  this.promise = new Promise(function (outerResolve, outerReject) {
    promiseResolve = outerResolve;
    promiseReject = outerReject;
  });

  var resolve = function resolve(value) {
    if (!_this.isResolved) {
      _this.isResolved = true;
      config.onSuccess == null ? void 0 : config.onSuccess(value);
      continueFn == null ? void 0 : continueFn();
      promiseResolve(value);
    }
  };

  var reject = function reject(value) {
    if (!_this.isResolved) {
      _this.isResolved = true;
      config.onError == null ? void 0 : config.onError(value);
      continueFn == null ? void 0 : continueFn();
      promiseReject(value);
    }
  };

  var pause = function pause() {
    return new Promise(function (continueResolve) {
      continueFn = continueResolve;
      _this.isPaused = true;
      config.onPause == null ? void 0 : config.onPause();
    }).then(function () {
      continueFn = undefined;
      _this.isPaused = false;
      config.onContinue == null ? void 0 : config.onContinue();
    });
  }; // Create loop function


  var run = function run() {
    // Do nothing if already resolved
    if (_this.isResolved) {
      return;
    }

    var promiseOrValue; // Execute query

    try {
      promiseOrValue = config.fn();
    } catch (error) {
      promiseOrValue = Promise.reject(error);
    } // Create callback to cancel this fetch


    cancelFn = function cancelFn(cancelOptions) {
      if (!_this.isResolved) {
        reject(new CancelledError(cancelOptions));
        _this.abort == null ? void 0 : _this.abort(); // Cancel transport if supported

        if (isCancelable(promiseOrValue)) {
          try {
            promiseOrValue.cancel();
          } catch (_unused) {}
        }
      }
    }; // Check if the transport layer support cancellation


    _this.isTransportCancelable = isCancelable(promiseOrValue);
    Promise.resolve(promiseOrValue).then(resolve).catch(function (error) {
      var _config$retry, _config$retryDelay;

      // Stop if the fetch is already resolved
      if (_this.isResolved) {
        return;
      } // Do we need to retry the request?


      var retry = (_config$retry = config.retry) != null ? _config$retry : 3;
      var retryDelay = (_config$retryDelay = config.retryDelay) != null ? _config$retryDelay : defaultRetryDelay;
      var delay = typeof retryDelay === 'function' ? retryDelay(_this.failureCount, error) : retryDelay;
      var shouldRetry = retry === true || typeof retry === 'number' && _this.failureCount < retry || typeof retry === 'function' && retry(_this.failureCount, error);

      if (cancelRetry || !shouldRetry) {
        // We are done if the query does not need to be retried
        reject(error);
        return;
      }

      _this.failureCount++; // Notify on fail

      config.onFail == null ? void 0 : config.onFail(_this.failureCount, error); // Delay

      (0,_utils__WEBPACK_IMPORTED_MODULE_0__/* .sleep */ .Gh)(delay) // Pause if the document is not visible or when the device is offline
      .then(function () {
        if (!_focusManager__WEBPACK_IMPORTED_MODULE_1__/* .focusManager.isFocused */ .j.isFocused() || !_onlineManager__WEBPACK_IMPORTED_MODULE_2__/* .onlineManager.isOnline */ .N.isOnline()) {
          return pause();
        }
      }).then(function () {
        if (cancelRetry) {
          reject(error);
        } else {
          run();
        }
      });
    });
  }; // Start loop


  run();
};

/***/ }),

/***/ 92693:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "l": function() { return /* binding */ Subscribable; }
/* harmony export */ });
var Subscribable = /*#__PURE__*/function () {
  function Subscribable() {
    this.listeners = [];
  }

  var _proto = Subscribable.prototype;

  _proto.subscribe = function subscribe(listener) {
    var _this = this;

    var callback = listener || function () {
      return undefined;
    };

    this.listeners.push(callback);
    this.onSubscribe();
    return function () {
      _this.listeners = _this.listeners.filter(function (x) {
        return x !== callback;
      });

      _this.onUnsubscribe();
    };
  };

  _proto.hasListeners = function hasListeners() {
    return this.listeners.length > 0;
  };

  _proto.onSubscribe = function onSubscribe() {// Do nothing
  };

  _proto.onUnsubscribe = function onUnsubscribe() {// Do nothing
  };

  return Subscribable;
}();

/***/ }),

/***/ 77820:
/***/ (function() {



/***/ }),

/***/ 10774:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "sk": function() { return /* binding */ isServer; },
/* harmony export */   "ZT": function() { return /* binding */ noop; },
/* harmony export */   "SE": function() { return /* binding */ functionalUpdate; },
/* harmony export */   "PN": function() { return /* binding */ isValidTimeout; },
/* harmony export */   "mc": function() { return /* binding */ ensureQueryKeyArray; },
/* harmony export */   "Kp": function() { return /* binding */ timeUntilStale; },
/* harmony export */   "_v": function() { return /* binding */ parseQueryArgs; },
/* harmony export */   "lV": function() { return /* binding */ parseMutationArgs; },
/* harmony export */   "I6": function() { return /* binding */ parseFilterArgs; },
/* harmony export */   "_x": function() { return /* binding */ matchQuery; },
/* harmony export */   "X7": function() { return /* binding */ matchMutation; },
/* harmony export */   "Rm": function() { return /* binding */ hashQueryKeyByOptions; },
/* harmony export */   "yF": function() { return /* binding */ hashQueryKey; },
/* harmony export */   "to": function() { return /* binding */ partialMatchKey; },
/* harmony export */   "Q$": function() { return /* binding */ replaceEqualDeep; },
/* harmony export */   "VS": function() { return /* binding */ shallowEqualObjects; },
/* harmony export */   "Gh": function() { return /* binding */ sleep; },
/* harmony export */   "A4": function() { return /* binding */ scheduleMicrotask; },
/* harmony export */   "G9": function() { return /* binding */ getAbortController; }
/* harmony export */ });
/* unused harmony exports difference, replaceAt, parseMutationFilterArgs, mapQueryStatusFilter, stableValueHash, partialDeepEqual, isPlainObject, isQueryKey, isError */
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7896);

// TYPES
// UTILS
var isServer = typeof window === 'undefined';
function noop() {
  return undefined;
}
function functionalUpdate(updater, input) {
  return typeof updater === 'function' ? updater(input) : updater;
}
function isValidTimeout(value) {
  return typeof value === 'number' && value >= 0 && value !== Infinity;
}
function ensureQueryKeyArray(value) {
  return Array.isArray(value) ? value : [value];
}
function difference(array1, array2) {
  return array1.filter(function (x) {
    return array2.indexOf(x) === -1;
  });
}
function replaceAt(array, index, value) {
  var copy = array.slice(0);
  copy[index] = value;
  return copy;
}
function timeUntilStale(updatedAt, staleTime) {
  return Math.max(updatedAt + (staleTime || 0) - Date.now(), 0);
}
function parseQueryArgs(arg1, arg2, arg3) {
  if (!isQueryKey(arg1)) {
    return arg1;
  }

  if (typeof arg2 === 'function') {
    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, arg3, {
      queryKey: arg1,
      queryFn: arg2
    });
  }

  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, arg2, {
    queryKey: arg1
  });
}
function parseMutationArgs(arg1, arg2, arg3) {
  if (isQueryKey(arg1)) {
    if (typeof arg2 === 'function') {
      return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, arg3, {
        mutationKey: arg1,
        mutationFn: arg2
      });
    }

    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, arg2, {
      mutationKey: arg1
    });
  }

  if (typeof arg1 === 'function') {
    return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, arg2, {
      mutationFn: arg1
    });
  }

  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, arg1);
}
function parseFilterArgs(arg1, arg2, arg3) {
  return isQueryKey(arg1) ? [(0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, arg2, {
    queryKey: arg1
  }), arg3] : [arg1 || {}, arg2];
}
function parseMutationFilterArgs(arg1, arg2) {
  return isQueryKey(arg1) ? _extends({}, arg2, {
    mutationKey: arg1
  }) : arg1;
}
function mapQueryStatusFilter(active, inactive) {
  if (active === true && inactive === true || active == null && inactive == null) {
    return 'all';
  } else if (active === false && inactive === false) {
    return 'none';
  } else {
    // At this point, active|inactive can only be true|false or false|true
    // so, when only one value is provided, the missing one has to be the negated value
    var isActive = active != null ? active : !inactive;
    return isActive ? 'active' : 'inactive';
  }
}
function matchQuery(filters, query) {
  var active = filters.active,
      exact = filters.exact,
      fetching = filters.fetching,
      inactive = filters.inactive,
      predicate = filters.predicate,
      queryKey = filters.queryKey,
      stale = filters.stale;

  if (isQueryKey(queryKey)) {
    if (exact) {
      if (query.queryHash !== hashQueryKeyByOptions(queryKey, query.options)) {
        return false;
      }
    } else if (!partialMatchKey(query.queryKey, queryKey)) {
      return false;
    }
  }

  var queryStatusFilter = mapQueryStatusFilter(active, inactive);

  if (queryStatusFilter === 'none') {
    return false;
  } else if (queryStatusFilter !== 'all') {
    var isActive = query.isActive();

    if (queryStatusFilter === 'active' && !isActive) {
      return false;
    }

    if (queryStatusFilter === 'inactive' && isActive) {
      return false;
    }
  }

  if (typeof stale === 'boolean' && query.isStale() !== stale) {
    return false;
  }

  if (typeof fetching === 'boolean' && query.isFetching() !== fetching) {
    return false;
  }

  if (predicate && !predicate(query)) {
    return false;
  }

  return true;
}
function matchMutation(filters, mutation) {
  var exact = filters.exact,
      fetching = filters.fetching,
      predicate = filters.predicate,
      mutationKey = filters.mutationKey;

  if (isQueryKey(mutationKey)) {
    if (!mutation.options.mutationKey) {
      return false;
    }

    if (exact) {
      if (hashQueryKey(mutation.options.mutationKey) !== hashQueryKey(mutationKey)) {
        return false;
      }
    } else if (!partialMatchKey(mutation.options.mutationKey, mutationKey)) {
      return false;
    }
  }

  if (typeof fetching === 'boolean' && mutation.state.status === 'loading' !== fetching) {
    return false;
  }

  if (predicate && !predicate(mutation)) {
    return false;
  }

  return true;
}
function hashQueryKeyByOptions(queryKey, options) {
  var hashFn = (options == null ? void 0 : options.queryKeyHashFn) || hashQueryKey;
  return hashFn(queryKey);
}
/**
 * Default query keys hash function.
 */

function hashQueryKey(queryKey) {
  var asArray = ensureQueryKeyArray(queryKey);
  return stableValueHash(asArray);
}
/**
 * Hashes the value into a stable hash.
 */

function stableValueHash(value) {
  return JSON.stringify(value, function (_, val) {
    return isPlainObject(val) ? Object.keys(val).sort().reduce(function (result, key) {
      result[key] = val[key];
      return result;
    }, {}) : val;
  });
}
/**
 * Checks if key `b` partially matches with key `a`.
 */

function partialMatchKey(a, b) {
  return partialDeepEqual(ensureQueryKeyArray(a), ensureQueryKeyArray(b));
}
/**
 * Checks if `b` partially matches with `a`.
 */

function partialDeepEqual(a, b) {
  if (a === b) {
    return true;
  }

  if (typeof a !== typeof b) {
    return false;
  }

  if (a && b && typeof a === 'object' && typeof b === 'object') {
    return !Object.keys(b).some(function (key) {
      return !partialDeepEqual(a[key], b[key]);
    });
  }

  return false;
}
/**
 * This function returns `a` if `b` is deeply equal.
 * If not, it will replace any deeply equal children of `b` with those of `a`.
 * This can be used for structural sharing between JSON values for example.
 */

function replaceEqualDeep(a, b) {
  if (a === b) {
    return a;
  }

  var array = Array.isArray(a) && Array.isArray(b);

  if (array || isPlainObject(a) && isPlainObject(b)) {
    var aSize = array ? a.length : Object.keys(a).length;
    var bItems = array ? b : Object.keys(b);
    var bSize = bItems.length;
    var copy = array ? [] : {};
    var equalItems = 0;

    for (var i = 0; i < bSize; i++) {
      var key = array ? i : bItems[i];
      copy[key] = replaceEqualDeep(a[key], b[key]);

      if (copy[key] === a[key]) {
        equalItems++;
      }
    }

    return aSize === bSize && equalItems === aSize ? a : copy;
  }

  return b;
}
/**
 * Shallow compare objects. Only works with objects that always have the same properties.
 */

function shallowEqualObjects(a, b) {
  if (a && !b || b && !a) {
    return false;
  }

  for (var key in a) {
    if (a[key] !== b[key]) {
      return false;
    }
  }

  return true;
} // Copied from: https://github.com/jonschlinkert/is-plain-object

function isPlainObject(o) {
  if (!hasObjectPrototype(o)) {
    return false;
  } // If has modified constructor


  var ctor = o.constructor;

  if (typeof ctor === 'undefined') {
    return true;
  } // If has modified prototype


  var prot = ctor.prototype;

  if (!hasObjectPrototype(prot)) {
    return false;
  } // If constructor does not have an Object-specific method


  if (!prot.hasOwnProperty('isPrototypeOf')) {
    return false;
  } // Most likely a plain Object


  return true;
}

function hasObjectPrototype(o) {
  return Object.prototype.toString.call(o) === '[object Object]';
}

function isQueryKey(value) {
  return typeof value === 'string' || Array.isArray(value);
}
function isError(value) {
  return value instanceof Error;
}
function sleep(timeout) {
  return new Promise(function (resolve) {
    setTimeout(resolve, timeout);
  });
}
/**
 * Schedules a microtask.
 * This can be useful to schedule state updates after rendering.
 */

function scheduleMicrotask(callback) {
  Promise.resolve().then(callback).catch(function (error) {
    return setTimeout(function () {
      throw error;
    });
  });
}
function getAbortController() {
  if (typeof AbortController === 'function') {
    return new AbortController();
  }
}

/***/ }),

/***/ 82066:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "QueryClient": function() { return /* reexport safe */ _core__WEBPACK_IMPORTED_MODULE_0__.Su; },
/* harmony export */   "QueryClientProvider": function() { return /* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.aH; },
/* harmony export */   "useMutation": function() { return /* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.Db; },
/* harmony export */   "useQuery": function() { return /* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.aM; },
/* harmony export */   "useQueryClient": function() { return /* reexport safe */ _react__WEBPACK_IMPORTED_MODULE_1__.NL; }
/* harmony export */ });
/* harmony import */ var _core__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(60002);
/* harmony reexport (checked) */ if(__webpack_require__.o(_core__WEBPACK_IMPORTED_MODULE_0__, "QueryClientProvider")) __webpack_require__.d(__webpack_exports__, { "QueryClientProvider": function() { return _core__WEBPACK_IMPORTED_MODULE_0__.QueryClientProvider; } });
/* harmony reexport (checked) */ if(__webpack_require__.o(_core__WEBPACK_IMPORTED_MODULE_0__, "useMutation")) __webpack_require__.d(__webpack_exports__, { "useMutation": function() { return _core__WEBPACK_IMPORTED_MODULE_0__.useMutation; } });
/* harmony reexport (checked) */ if(__webpack_require__.o(_core__WEBPACK_IMPORTED_MODULE_0__, "useQuery")) __webpack_require__.d(__webpack_exports__, { "useQuery": function() { return _core__WEBPACK_IMPORTED_MODULE_0__.useQuery; } });
/* harmony reexport (checked) */ if(__webpack_require__.o(_core__WEBPACK_IMPORTED_MODULE_0__, "useQueryClient")) __webpack_require__.d(__webpack_exports__, { "useQueryClient": function() { return _core__WEBPACK_IMPORTED_MODULE_0__.useQueryClient; } });
/* harmony import */ var _react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(33577);



/***/ }),

/***/ 77639:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "N": function() { return /* binding */ useQueryClient; },
/* harmony export */   "a": function() { return /* binding */ QueryClientProvider; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);

var defaultContext = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createContext(undefined);
var QueryClientSharingContext = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createContext(false); // if contextSharing is on, we share the first and at least one
// instance of the context across the window
// to ensure that if React Query is used across
// different bundles or microfrontends they will
// all use the same **instance** of context, regardless
// of module scoping.

function getQueryClientContext(contextSharing) {
  if (contextSharing && typeof window !== 'undefined') {
    if (!window.ReactQueryClientContext) {
      window.ReactQueryClientContext = defaultContext;
    }

    return window.ReactQueryClientContext;
  }

  return defaultContext;
}

var useQueryClient = function useQueryClient() {
  var queryClient = react__WEBPACK_IMPORTED_MODULE_0___default().useContext(getQueryClientContext(react__WEBPACK_IMPORTED_MODULE_0___default().useContext(QueryClientSharingContext)));

  if (!queryClient) {
    throw new Error('No QueryClient set, use QueryClientProvider to set one');
  }

  return queryClient;
};
var QueryClientProvider = function QueryClientProvider(_ref) {
  var client = _ref.client,
      _ref$contextSharing = _ref.contextSharing,
      contextSharing = _ref$contextSharing === void 0 ? false : _ref$contextSharing,
      children = _ref.children;
  react__WEBPACK_IMPORTED_MODULE_0___default().useEffect(function () {
    client.mount();
    return function () {
      client.unmount();
    };
  }, [client]);
  var Context = getQueryClientContext(contextSharing);
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(QueryClientSharingContext.Provider, {
    value: contextSharing
  }, /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Context.Provider, {
    value: client
  }, children));
};

/***/ }),

/***/ 4578:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_": function() { return /* binding */ useQueryErrorResetBoundary; }
/* harmony export */ });
/* unused harmony export QueryErrorResetBoundary */
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
 // CONTEXT

function createValue() {
  var _isReset = false;
  return {
    clearReset: function clearReset() {
      _isReset = false;
    },
    reset: function reset() {
      _isReset = true;
    },
    isReset: function isReset() {
      return _isReset;
    }
  };
}

var QueryErrorResetBoundaryContext = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createContext(createValue()); // HOOK

var useQueryErrorResetBoundary = function useQueryErrorResetBoundary() {
  return react__WEBPACK_IMPORTED_MODULE_0___default().useContext(QueryErrorResetBoundaryContext);
}; // COMPONENT

var QueryErrorResetBoundary = function QueryErrorResetBoundary(_ref) {
  var children = _ref.children;
  var value = React.useMemo(function () {
    return createValue();
  }, []);
  return /*#__PURE__*/React.createElement(QueryErrorResetBoundaryContext.Provider, {
    value: value
  }, typeof children === 'function' ? children(value) : children);
};

/***/ }),

/***/ 33577:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "aH": function() { return /* reexport safe */ _QueryClientProvider__WEBPACK_IMPORTED_MODULE_2__.a; },
/* harmony export */   "NL": function() { return /* reexport safe */ _QueryClientProvider__WEBPACK_IMPORTED_MODULE_2__.N; },
/* harmony export */   "Db": function() { return /* reexport safe */ _useMutation__WEBPACK_IMPORTED_MODULE_3__.D; },
/* harmony export */   "aM": function() { return /* reexport safe */ _useQuery__WEBPACK_IMPORTED_MODULE_4__.a; }
/* harmony export */ });
/* harmony import */ var _setBatchUpdatesFn__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(96328);
/* harmony import */ var _setLogger__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(94091);
/* harmony import */ var _QueryClientProvider__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(77639);
/* harmony import */ var _useMutation__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(82127);
/* harmony import */ var _useQuery__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(18067);
// Side effects










 // Types



/***/ }),

/***/ 51733:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "k": function() { return /* binding */ logger; }
/* harmony export */ });
var logger = console;

/***/ }),

/***/ 63520:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "m": function() { return /* binding */ unstable_batchedUpdates; }
/* harmony export */ });
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(91850);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_0__);

var unstable_batchedUpdates = (react_dom__WEBPACK_IMPORTED_MODULE_0___default().unstable_batchedUpdates);

/***/ }),

/***/ 96328:
/***/ (function(__unused_webpack_module, __unused_webpack___webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _core__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(50667);
/* harmony import */ var _reactBatchedUpdates__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(63520);


_core__WEBPACK_IMPORTED_MODULE_0__/* .notifyManager.setBatchNotifyFunction */ .V.setBatchNotifyFunction(_reactBatchedUpdates__WEBPACK_IMPORTED_MODULE_1__/* .unstable_batchedUpdates */ .m);

/***/ }),

/***/ 94091:
/***/ (function(__unused_webpack_module, __unused_webpack___webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _core__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(53579);
/* harmony import */ var _logger__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(51733);


(0,_core__WEBPACK_IMPORTED_MODULE_0__/* .setLogger */ .E)(_logger__WEBPACK_IMPORTED_MODULE_1__/* .logger */ .k);

/***/ }),

/***/ 96744:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "r": function() { return /* binding */ useBaseQuery; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _core_notifyManager__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(50667);
/* harmony import */ var _QueryErrorResetBoundary__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(4578);
/* harmony import */ var _QueryClientProvider__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(77639);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(13774);





function useBaseQuery(options, Observer) {
  var mountedRef = react__WEBPACK_IMPORTED_MODULE_0___default().useRef(false);

  var _React$useState = react__WEBPACK_IMPORTED_MODULE_0___default().useState(0),
      forceUpdate = _React$useState[1];

  var queryClient = (0,_QueryClientProvider__WEBPACK_IMPORTED_MODULE_1__/* .useQueryClient */ .N)();
  var errorResetBoundary = (0,_QueryErrorResetBoundary__WEBPACK_IMPORTED_MODULE_2__/* .useQueryErrorResetBoundary */ ._)();
  var defaultedOptions = queryClient.defaultQueryObserverOptions(options); // Make sure results are optimistically set in fetching state before subscribing or updating options

  defaultedOptions.optimisticResults = true; // Include callbacks in batch renders

  if (defaultedOptions.onError) {
    defaultedOptions.onError = _core_notifyManager__WEBPACK_IMPORTED_MODULE_3__/* .notifyManager.batchCalls */ .V.batchCalls(defaultedOptions.onError);
  }

  if (defaultedOptions.onSuccess) {
    defaultedOptions.onSuccess = _core_notifyManager__WEBPACK_IMPORTED_MODULE_3__/* .notifyManager.batchCalls */ .V.batchCalls(defaultedOptions.onSuccess);
  }

  if (defaultedOptions.onSettled) {
    defaultedOptions.onSettled = _core_notifyManager__WEBPACK_IMPORTED_MODULE_3__/* .notifyManager.batchCalls */ .V.batchCalls(defaultedOptions.onSettled);
  }

  if (defaultedOptions.suspense) {
    // Always set stale time when using suspense to prevent
    // fetching again when directly mounting after suspending
    if (typeof defaultedOptions.staleTime !== 'number') {
      defaultedOptions.staleTime = 1000;
    } // Set cache time to 1 if the option has been set to 0
    // when using suspense to prevent infinite loop of fetches


    if (defaultedOptions.cacheTime === 0) {
      defaultedOptions.cacheTime = 1;
    }
  }

  if (defaultedOptions.suspense || defaultedOptions.useErrorBoundary) {
    // Prevent retrying failed query if the error boundary has not been reset yet
    if (!errorResetBoundary.isReset()) {
      defaultedOptions.retryOnMount = false;
    }
  }

  var _React$useState2 = react__WEBPACK_IMPORTED_MODULE_0___default().useState(function () {
    return new Observer(queryClient, defaultedOptions);
  }),
      observer = _React$useState2[0];

  var result = observer.getOptimisticResult(defaultedOptions);
  react__WEBPACK_IMPORTED_MODULE_0___default().useEffect(function () {
    mountedRef.current = true;
    errorResetBoundary.clearReset();
    var unsubscribe = observer.subscribe(_core_notifyManager__WEBPACK_IMPORTED_MODULE_3__/* .notifyManager.batchCalls */ .V.batchCalls(function () {
      if (mountedRef.current) {
        forceUpdate(function (x) {
          return x + 1;
        });
      }
    })); // Update result to make sure we did not miss any query updates
    // between creating the observer and subscribing to it.

    observer.updateResult();
    return function () {
      mountedRef.current = false;
      unsubscribe();
    };
  }, [errorResetBoundary, observer]);
  react__WEBPACK_IMPORTED_MODULE_0___default().useEffect(function () {
    // Do not notify on updates because of changes in the options because
    // these changes should already be reflected in the optimistic result.
    observer.setOptions(defaultedOptions, {
      listeners: false
    });
  }, [defaultedOptions, observer]); // Handle suspense

  if (defaultedOptions.suspense && result.isLoading) {
    throw observer.fetchOptimistic(defaultedOptions).then(function (_ref) {
      var data = _ref.data;
      defaultedOptions.onSuccess == null ? void 0 : defaultedOptions.onSuccess(data);
      defaultedOptions.onSettled == null ? void 0 : defaultedOptions.onSettled(data, null);
    }).catch(function (error) {
      errorResetBoundary.clearReset();
      defaultedOptions.onError == null ? void 0 : defaultedOptions.onError(error);
      defaultedOptions.onSettled == null ? void 0 : defaultedOptions.onSettled(undefined, error);
    });
  } // Handle error boundary


  if (result.isError && !result.isFetching && (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .shouldThrowError */ .L)(defaultedOptions.suspense, defaultedOptions.useErrorBoundary, result.error)) {
    throw result.error;
  } // Handle result property usage tracking


  if (defaultedOptions.notifyOnChangeProps === 'tracked') {
    result = observer.trackResult(result);
  }

  return result;
}

/***/ }),

/***/ 82127:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "D": function() { return /* binding */ useMutation; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(7896);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _core_notifyManager__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(50667);
/* harmony import */ var _core_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(10774);
/* harmony import */ var _core_mutationObserver__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(74856);
/* harmony import */ var _QueryClientProvider__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(77639);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(13774);






 // HOOK

function useMutation(arg1, arg2, arg3) {
  var mountedRef = react__WEBPACK_IMPORTED_MODULE_0___default().useRef(false);

  var _React$useState = react__WEBPACK_IMPORTED_MODULE_0___default().useState(0),
      forceUpdate = _React$useState[1];

  var options = (0,_core_utils__WEBPACK_IMPORTED_MODULE_1__/* .parseMutationArgs */ .lV)(arg1, arg2, arg3);
  var queryClient = (0,_QueryClientProvider__WEBPACK_IMPORTED_MODULE_2__/* .useQueryClient */ .N)();
  var obsRef = react__WEBPACK_IMPORTED_MODULE_0___default().useRef();

  if (!obsRef.current) {
    obsRef.current = new _core_mutationObserver__WEBPACK_IMPORTED_MODULE_3__/* .MutationObserver */ .X(queryClient, options);
  } else {
    obsRef.current.setOptions(options);
  }

  var currentResult = obsRef.current.getCurrentResult();
  react__WEBPACK_IMPORTED_MODULE_0___default().useEffect(function () {
    mountedRef.current = true;
    var unsubscribe = obsRef.current.subscribe(_core_notifyManager__WEBPACK_IMPORTED_MODULE_4__/* .notifyManager.batchCalls */ .V.batchCalls(function () {
      if (mountedRef.current) {
        forceUpdate(function (x) {
          return x + 1;
        });
      }
    }));
    return function () {
      mountedRef.current = false;
      unsubscribe();
    };
  }, []);
  var mutate = react__WEBPACK_IMPORTED_MODULE_0___default().useCallback(function (variables, mutateOptions) {
    obsRef.current.mutate(variables, mutateOptions).catch(_core_utils__WEBPACK_IMPORTED_MODULE_1__/* .noop */ .ZT);
  }, []);

  if (currentResult.error && (0,_utils__WEBPACK_IMPORTED_MODULE_5__/* .shouldThrowError */ .L)(undefined, obsRef.current.options.useErrorBoundary, currentResult.error)) {
    throw currentResult.error;
  }

  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)({}, currentResult, {
    mutate: mutate,
    mutateAsync: currentResult.mutate
  });
}

/***/ }),

/***/ 18067:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "a": function() { return /* binding */ useQuery; }
/* harmony export */ });
/* harmony import */ var _core__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(24198);
/* harmony import */ var _core_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(10774);
/* harmony import */ var _useBaseQuery__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(96744);


 // HOOK

function useQuery(arg1, arg2, arg3) {
  var parsedOptions = (0,_core_utils__WEBPACK_IMPORTED_MODULE_0__/* .parseQueryArgs */ ._v)(arg1, arg2, arg3);
  return (0,_useBaseQuery__WEBPACK_IMPORTED_MODULE_1__/* .useBaseQuery */ .r)(parsedOptions, _core__WEBPACK_IMPORTED_MODULE_2__/* .QueryObserver */ .z);
}

/***/ }),

/***/ 13774:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "L": function() { return /* binding */ shouldThrowError; }
/* harmony export */ });
function shouldThrowError(suspense, _useErrorBoundary, error) {
  // Allow useErrorBoundary function to override throwing behavior on a per-error basis
  if (typeof _useErrorBoundary === 'function') {
    return _useErrorBoundary(error);
  } // Allow useErrorBoundary to override suspense's throwing behaviour


  if (typeof _useErrorBoundary === 'boolean') return _useErrorBoundary; // If suspense is enabled default to throwing errors

  return !!suspense;
}

/***/ }),

/***/ 81346:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "E": function() { return /* binding */ ReactReduxContext; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);

var ReactReduxContext = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createContext(null);

if (false) {}

/* unused harmony default export */ var __WEBPACK_DEFAULT_EXPORT__ = ((/* unused pure expression or super */ null && (ReactReduxContext)));

/***/ }),

/***/ 42533:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _Context__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(81346);
/* harmony import */ var _utils_Subscription__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(82062);
/* harmony import */ var _utils_useIsomorphicLayoutEffect__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(44282);






function Provider(_ref) {
  var store = _ref.store,
      context = _ref.context,
      children = _ref.children;
  var contextValue = (0,react__WEBPACK_IMPORTED_MODULE_0__.useMemo)(function () {
    var subscription = (0,_utils_Subscription__WEBPACK_IMPORTED_MODULE_2__/* .createSubscription */ .X)(store);
    subscription.onStateChange = subscription.notifyNestedSubs;
    return {
      store: store,
      subscription: subscription
    };
  }, [store]);
  var previousState = (0,react__WEBPACK_IMPORTED_MODULE_0__.useMemo)(function () {
    return store.getState();
  }, [store]);
  (0,_utils_useIsomorphicLayoutEffect__WEBPACK_IMPORTED_MODULE_3__/* .useIsomorphicLayoutEffect */ .L)(function () {
    var subscription = contextValue.subscription;
    subscription.trySubscribe();

    if (previousState !== store.getState()) {
      subscription.notifyNestedSubs();
    }

    return function () {
      subscription.tryUnsubscribe();
      subscription.onStateChange = null;
    };
  }, [contextValue, previousState]);
  var Context = context || _Context__WEBPACK_IMPORTED_MODULE_1__/* .ReactReduxContext */ .E;
  return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Context.Provider, {
    value: contextValue
  }, children);
}

if (false) {}

/* harmony default export */ __webpack_exports__["Z"] = (Provider);

/***/ }),

/***/ 49484:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ connectAdvanced; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(7896);
/* harmony import */ var _babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(31461);
/* harmony import */ var hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(73463);
/* harmony import */ var hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react_is__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(48570);
/* harmony import */ var _utils_Subscription__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(82062);
/* harmony import */ var _utils_useIsomorphicLayoutEffect__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(44282);
/* harmony import */ var _Context__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(81346);


var _excluded = ["getDisplayName", "methodName", "renderCountProp", "shouldHandleStateChanges", "storeKey", "withRef", "forwardRef", "context"],
    _excluded2 = ["reactReduxForwardedRef"];





 // Define some constant arrays just to avoid re-creating these

var EMPTY_ARRAY = [];
var NO_SUBSCRIPTION_ARRAY = [null, null];

var stringifyComponent = function stringifyComponent(Comp) {
  try {
    return JSON.stringify(Comp);
  } catch (err) {
    return String(Comp);
  }
};

function storeStateUpdatesReducer(state, action) {
  var updateCount = state[1];
  return [action.payload, updateCount + 1];
}

function useIsomorphicLayoutEffectWithArgs(effectFunc, effectArgs, dependencies) {
  (0,_utils_useIsomorphicLayoutEffect__WEBPACK_IMPORTED_MODULE_4__/* .useIsomorphicLayoutEffect */ .L)(function () {
    return effectFunc.apply(void 0, effectArgs);
  }, dependencies);
}

function captureWrapperProps(lastWrapperProps, lastChildProps, renderIsScheduled, wrapperProps, actualChildProps, childPropsFromStoreUpdate, notifyNestedSubs) {
  // We want to capture the wrapper props and child props we used for later comparisons
  lastWrapperProps.current = wrapperProps;
  lastChildProps.current = actualChildProps;
  renderIsScheduled.current = false; // If the render was from a store update, clear out that reference and cascade the subscriber update

  if (childPropsFromStoreUpdate.current) {
    childPropsFromStoreUpdate.current = null;
    notifyNestedSubs();
  }
}

function subscribeUpdates(shouldHandleStateChanges, store, subscription, childPropsSelector, lastWrapperProps, lastChildProps, renderIsScheduled, childPropsFromStoreUpdate, notifyNestedSubs, forceComponentUpdateDispatch) {
  // If we're not subscribed to the store, nothing to do here
  if (!shouldHandleStateChanges) return; // Capture values for checking if and when this component unmounts

  var didUnsubscribe = false;
  var lastThrownError = null; // We'll run this callback every time a store subscription update propagates to this component

  var checkForUpdates = function checkForUpdates() {
    if (didUnsubscribe) {
      // Don't run stale listeners.
      // Redux doesn't guarantee unsubscriptions happen until next dispatch.
      return;
    }

    var latestStoreState = store.getState();
    var newChildProps, error;

    try {
      // Actually run the selector with the most recent store state and wrapper props
      // to determine what the child props should be
      newChildProps = childPropsSelector(latestStoreState, lastWrapperProps.current);
    } catch (e) {
      error = e;
      lastThrownError = e;
    }

    if (!error) {
      lastThrownError = null;
    } // If the child props haven't changed, nothing to do here - cascade the subscription update


    if (newChildProps === lastChildProps.current) {
      if (!renderIsScheduled.current) {
        notifyNestedSubs();
      }
    } else {
      // Save references to the new child props.  Note that we track the "child props from store update"
      // as a ref instead of a useState/useReducer because we need a way to determine if that value has
      // been processed.  If this went into useState/useReducer, we couldn't clear out the value without
      // forcing another re-render, which we don't want.
      lastChildProps.current = newChildProps;
      childPropsFromStoreUpdate.current = newChildProps;
      renderIsScheduled.current = true; // If the child props _did_ change (or we caught an error), this wrapper component needs to re-render

      forceComponentUpdateDispatch({
        type: 'STORE_UPDATED',
        payload: {
          error: error
        }
      });
    }
  }; // Actually subscribe to the nearest connected ancestor (or store)


  subscription.onStateChange = checkForUpdates;
  subscription.trySubscribe(); // Pull data from the store after first render in case the store has
  // changed since we began.

  checkForUpdates();

  var unsubscribeWrapper = function unsubscribeWrapper() {
    didUnsubscribe = true;
    subscription.tryUnsubscribe();
    subscription.onStateChange = null;

    if (lastThrownError) {
      // It's possible that we caught an error due to a bad mapState function, but the
      // parent re-rendered without this component and we're about to unmount.
      // This shouldn't happen as long as we do top-down subscriptions correctly, but
      // if we ever do those wrong, this throw will surface the error in our tests.
      // In that case, throw the error from here so it doesn't get lost.
      throw lastThrownError;
    }
  };

  return unsubscribeWrapper;
}

var initStateUpdates = function initStateUpdates() {
  return [null, 0];
};

function connectAdvanced(
/*
  selectorFactory is a func that is responsible for returning the selector function used to
  compute new props from state, props, and dispatch. For example:
     export default connectAdvanced((dispatch, options) => (state, props) => ({
      thing: state.things[props.thingId],
      saveThing: fields => dispatch(actionCreators.saveThing(props.thingId, fields)),
    }))(YourComponent)
   Access to dispatch is provided to the factory so selectorFactories can bind actionCreators
  outside of their selector as an optimization. Options passed to connectAdvanced are passed to
  the selectorFactory, along with displayName and WrappedComponent, as the second argument.
   Note that selectorFactory is responsible for all caching/memoization of inbound and outbound
  props. Do not use connectAdvanced directly without memoizing results between calls to your
  selector, otherwise the Connect component will re-render on every state or props change.
*/
selectorFactory, // options object:
_ref) {
  if (_ref === void 0) {
    _ref = {};
  }

  var _ref2 = _ref,
      _ref2$getDisplayName = _ref2.getDisplayName,
      getDisplayName = _ref2$getDisplayName === void 0 ? function (name) {
    return "ConnectAdvanced(" + name + ")";
  } : _ref2$getDisplayName,
      _ref2$methodName = _ref2.methodName,
      methodName = _ref2$methodName === void 0 ? 'connectAdvanced' : _ref2$methodName,
      _ref2$renderCountProp = _ref2.renderCountProp,
      renderCountProp = _ref2$renderCountProp === void 0 ? undefined : _ref2$renderCountProp,
      _ref2$shouldHandleSta = _ref2.shouldHandleStateChanges,
      shouldHandleStateChanges = _ref2$shouldHandleSta === void 0 ? true : _ref2$shouldHandleSta,
      _ref2$storeKey = _ref2.storeKey,
      storeKey = _ref2$storeKey === void 0 ? 'store' : _ref2$storeKey,
      _ref2$withRef = _ref2.withRef,
      withRef = _ref2$withRef === void 0 ? false : _ref2$withRef,
      _ref2$forwardRef = _ref2.forwardRef,
      forwardRef = _ref2$forwardRef === void 0 ? false : _ref2$forwardRef,
      _ref2$context = _ref2.context,
      context = _ref2$context === void 0 ? _Context__WEBPACK_IMPORTED_MODULE_5__/* .ReactReduxContext */ .E : _ref2$context,
      connectOptions = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(_ref2, _excluded);

  if (false) { var customStoreWarningMessage; }

  var Context = context;
  return function wrapWithConnect(WrappedComponent) {
    if (false) {}

    var wrappedComponentName = WrappedComponent.displayName || WrappedComponent.name || 'Component';
    var displayName = getDisplayName(wrappedComponentName);

    var selectorFactoryOptions = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)({}, connectOptions, {
      getDisplayName: getDisplayName,
      methodName: methodName,
      renderCountProp: renderCountProp,
      shouldHandleStateChanges: shouldHandleStateChanges,
      storeKey: storeKey,
      displayName: displayName,
      wrappedComponentName: wrappedComponentName,
      WrappedComponent: WrappedComponent
    });

    var pure = connectOptions.pure;

    function createChildSelector(store) {
      return selectorFactory(store.dispatch, selectorFactoryOptions);
    } // If we aren't running in "pure" mode, we don't want to memoize values.
    // To avoid conditionally calling hooks, we fall back to a tiny wrapper
    // that just executes the given callback immediately.


    var usePureOnlyMemo = pure ? react__WEBPACK_IMPORTED_MODULE_1__.useMemo : function (callback) {
      return callback();
    };

    function ConnectFunction(props) {
      var _useMemo = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(function () {
        // Distinguish between actual "data" props that were passed to the wrapper component,
        // and values needed to control behavior (forwarded refs, alternate context instances).
        // To maintain the wrapperProps object reference, memoize this destructuring.
        var reactReduxForwardedRef = props.reactReduxForwardedRef,
            wrapperProps = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(props, _excluded2);

        return [props.context, reactReduxForwardedRef, wrapperProps];
      }, [props]),
          propsContext = _useMemo[0],
          reactReduxForwardedRef = _useMemo[1],
          wrapperProps = _useMemo[2];

      var ContextToUse = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(function () {
        // Users may optionally pass in a custom context instance to use instead of our ReactReduxContext.
        // Memoize the check that determines which context instance we should use.
        return propsContext && propsContext.Consumer && (0,react_is__WEBPACK_IMPORTED_MODULE_2__.isContextConsumer)( /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_1___default().createElement(propsContext.Consumer, null)) ? propsContext : Context;
      }, [propsContext, Context]); // Retrieve the store and ancestor subscription via context, if available

      var contextValue = (0,react__WEBPACK_IMPORTED_MODULE_1__.useContext)(ContextToUse); // The store _must_ exist as either a prop or in context.
      // We'll check to see if it _looks_ like a Redux store first.
      // This allows us to pass through a `store` prop that is just a plain value.

      var didStoreComeFromProps = Boolean(props.store) && Boolean(props.store.getState) && Boolean(props.store.dispatch);
      var didStoreComeFromContext = Boolean(contextValue) && Boolean(contextValue.store);

      if (false) {} // Based on the previous check, one of these must be true


      var store = didStoreComeFromProps ? props.store : contextValue.store;
      var childPropsSelector = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(function () {
        // The child props selector needs the store reference as an input.
        // Re-create this selector whenever the store changes.
        return createChildSelector(store);
      }, [store]);

      var _useMemo2 = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(function () {
        if (!shouldHandleStateChanges) return NO_SUBSCRIPTION_ARRAY; // This Subscription's source should match where store came from: props vs. context. A component
        // connected to the store via props shouldn't use subscription from context, or vice versa.

        // This Subscription's source should match where store came from: props vs. context. A component
        // connected to the store via props shouldn't use subscription from context, or vice versa.
        var subscription = (0,_utils_Subscription__WEBPACK_IMPORTED_MODULE_3__/* .createSubscription */ .X)(store, didStoreComeFromProps ? null : contextValue.subscription); // `notifyNestedSubs` is duplicated to handle the case where the component is unmounted in
        // the middle of the notification loop, where `subscription` will then be null. This can
        // probably be avoided if Subscription's listeners logic is changed to not call listeners
        // that have been unsubscribed in the  middle of the notification loop.

        // `notifyNestedSubs` is duplicated to handle the case where the component is unmounted in
        // the middle of the notification loop, where `subscription` will then be null. This can
        // probably be avoided if Subscription's listeners logic is changed to not call listeners
        // that have been unsubscribed in the  middle of the notification loop.
        var notifyNestedSubs = subscription.notifyNestedSubs.bind(subscription);
        return [subscription, notifyNestedSubs];
      }, [store, didStoreComeFromProps, contextValue]),
          subscription = _useMemo2[0],
          notifyNestedSubs = _useMemo2[1]; // Determine what {store, subscription} value should be put into nested context, if necessary,
      // and memoize that value to avoid unnecessary context updates.


      var overriddenContextValue = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(function () {
        if (didStoreComeFromProps) {
          // This component is directly subscribed to a store from props.
          // We don't want descendants reading from this store - pass down whatever
          // the existing context value is from the nearest connected ancestor.
          return contextValue;
        } // Otherwise, put this component's subscription instance into context, so that
        // connected descendants won't update until after this component is done


        return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)({}, contextValue, {
          subscription: subscription
        });
      }, [didStoreComeFromProps, contextValue, subscription]); // We need to force this wrapper component to re-render whenever a Redux store update
      // causes a change to the calculated child component props (or we caught an error in mapState)

      var _useReducer = (0,react__WEBPACK_IMPORTED_MODULE_1__.useReducer)(storeStateUpdatesReducer, EMPTY_ARRAY, initStateUpdates),
          _useReducer$ = _useReducer[0],
          previousStateUpdateResult = _useReducer$[0],
          forceComponentUpdateDispatch = _useReducer[1]; // Propagate any mapState/mapDispatch errors upwards


      if (previousStateUpdateResult && previousStateUpdateResult.error) {
        throw previousStateUpdateResult.error;
      } // Set up refs to coordinate values between the subscription effect and the render logic


      var lastChildProps = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)();
      var lastWrapperProps = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(wrapperProps);
      var childPropsFromStoreUpdate = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)();
      var renderIsScheduled = (0,react__WEBPACK_IMPORTED_MODULE_1__.useRef)(false);
      var actualChildProps = usePureOnlyMemo(function () {
        // Tricky logic here:
        // - This render may have been triggered by a Redux store update that produced new child props
        // - However, we may have gotten new wrapper props after that
        // If we have new child props, and the same wrapper props, we know we should use the new child props as-is.
        // But, if we have new wrapper props, those might change the child props, so we have to recalculate things.
        // So, we'll use the child props from store update only if the wrapper props are the same as last time.
        if (childPropsFromStoreUpdate.current && wrapperProps === lastWrapperProps.current) {
          return childPropsFromStoreUpdate.current;
        } // TODO We're reading the store directly in render() here. Bad idea?
        // This will likely cause Bad Things (TM) to happen in Concurrent Mode.
        // Note that we do this because on renders _not_ caused by store updates, we need the latest store state
        // to determine what the child props should be.


        return childPropsSelector(store.getState(), wrapperProps);
      }, [store, previousStateUpdateResult, wrapperProps]); // We need this to execute synchronously every time we re-render. However, React warns
      // about useLayoutEffect in SSR, so we try to detect environment and fall back to
      // just useEffect instead to avoid the warning, since neither will run anyway.

      useIsomorphicLayoutEffectWithArgs(captureWrapperProps, [lastWrapperProps, lastChildProps, renderIsScheduled, wrapperProps, actualChildProps, childPropsFromStoreUpdate, notifyNestedSubs]); // Our re-subscribe logic only runs when the store/subscription setup changes

      useIsomorphicLayoutEffectWithArgs(subscribeUpdates, [shouldHandleStateChanges, store, subscription, childPropsSelector, lastWrapperProps, lastChildProps, renderIsScheduled, childPropsFromStoreUpdate, notifyNestedSubs, forceComponentUpdateDispatch], [store, subscription, childPropsSelector]); // Now that all that's done, we can finally try to actually render the child component.
      // We memoize the elements for the rendered child component as an optimization.

      var renderedWrappedComponent = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(function () {
        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_1___default().createElement(WrappedComponent, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)({}, actualChildProps, {
          ref: reactReduxForwardedRef
        }));
      }, [reactReduxForwardedRef, WrappedComponent, actualChildProps]); // If React sees the exact same element reference as last time, it bails out of re-rendering
      // that child, same as if it was wrapped in React.memo() or returned false from shouldComponentUpdate.

      var renderedChild = (0,react__WEBPACK_IMPORTED_MODULE_1__.useMemo)(function () {
        if (shouldHandleStateChanges) {
          // If this component is subscribed to store updates, we need to pass its own
          // subscription instance down to our descendants. That means rendering the same
          // Context instance, and putting a different value into the context.
          return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_1___default().createElement(ContextToUse.Provider, {
            value: overriddenContextValue
          }, renderedWrappedComponent);
        }

        return renderedWrappedComponent;
      }, [ContextToUse, renderedWrappedComponent, overriddenContextValue]);
      return renderedChild;
    } // If we're in "pure" mode, ensure our wrapper component only re-renders when incoming props have changed.


    var Connect = pure ? react__WEBPACK_IMPORTED_MODULE_1___default().memo(ConnectFunction) : ConnectFunction;
    Connect.WrappedComponent = WrappedComponent;
    Connect.displayName = ConnectFunction.displayName = displayName;

    if (forwardRef) {
      var forwarded = react__WEBPACK_IMPORTED_MODULE_1___default().forwardRef(function forwardConnectRef(props, ref) {
        return /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_1___default().createElement(Connect, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)({}, props, {
          reactReduxForwardedRef: ref
        }));
      });
      forwarded.displayName = displayName;
      forwarded.WrappedComponent = WrappedComponent;
      return hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_0___default()(forwarded, WrappedComponent);
    }

    return hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_0___default()(Connect, WrappedComponent);
  };
}

/***/ }),

/***/ 55443:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export createConnect */
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(7896);
/* harmony import */ var _babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(31461);
/* harmony import */ var _components_connectAdvanced__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(49484);
/* harmony import */ var _utils_shallowEqual__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(74570);
/* harmony import */ var _mapDispatchToProps__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(99174);
/* harmony import */ var _mapStateToProps__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(79600);
/* harmony import */ var _mergeProps__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(79553);
/* harmony import */ var _selectorFactory__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(77405);


var _excluded = ["pure", "areStatesEqual", "areOwnPropsEqual", "areStatePropsEqual", "areMergedPropsEqual"];






/*
  connect is a facade over connectAdvanced. It turns its args into a compatible
  selectorFactory, which has the signature:

    (dispatch, options) => (nextState, nextOwnProps) => nextFinalProps
  
  connect passes its args to connectAdvanced as options, which will in turn pass them to
  selectorFactory each time a Connect component instance is instantiated or hot reloaded.

  selectorFactory returns a final props selector from its mapStateToProps,
  mapStateToPropsFactories, mapDispatchToProps, mapDispatchToPropsFactories, mergeProps,
  mergePropsFactories, and pure args.

  The resulting final props selector is called by the Connect component instance whenever
  it receives new props or store state.
 */

function match(arg, factories, name) {
  for (var i = factories.length - 1; i >= 0; i--) {
    var result = factories[i](arg);
    if (result) return result;
  }

  return function (dispatch, options) {
    throw new Error("Invalid value of type " + typeof arg + " for " + name + " argument when connecting component " + options.wrappedComponentName + ".");
  };
}

function strictEqual(a, b) {
  return a === b;
} // createConnect with default args builds the 'official' connect behavior. Calling it with
// different options opens up some testing and extensibility scenarios


function createConnect(_temp) {
  var _ref = _temp === void 0 ? {} : _temp,
      _ref$connectHOC = _ref.connectHOC,
      connectHOC = _ref$connectHOC === void 0 ? _components_connectAdvanced__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z : _ref$connectHOC,
      _ref$mapStateToPropsF = _ref.mapStateToPropsFactories,
      mapStateToPropsFactories = _ref$mapStateToPropsF === void 0 ? _mapStateToProps__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP : _ref$mapStateToPropsF,
      _ref$mapDispatchToPro = _ref.mapDispatchToPropsFactories,
      mapDispatchToPropsFactories = _ref$mapDispatchToPro === void 0 ? _mapDispatchToProps__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP : _ref$mapDispatchToPro,
      _ref$mergePropsFactor = _ref.mergePropsFactories,
      mergePropsFactories = _ref$mergePropsFactor === void 0 ? _mergeProps__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP : _ref$mergePropsFactor,
      _ref$selectorFactory = _ref.selectorFactory,
      selectorFactory = _ref$selectorFactory === void 0 ? _selectorFactory__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .ZP : _ref$selectorFactory;

  return function connect(mapStateToProps, mapDispatchToProps, mergeProps, _ref2) {
    if (_ref2 === void 0) {
      _ref2 = {};
    }

    var _ref3 = _ref2,
        _ref3$pure = _ref3.pure,
        pure = _ref3$pure === void 0 ? true : _ref3$pure,
        _ref3$areStatesEqual = _ref3.areStatesEqual,
        areStatesEqual = _ref3$areStatesEqual === void 0 ? strictEqual : _ref3$areStatesEqual,
        _ref3$areOwnPropsEqua = _ref3.areOwnPropsEqual,
        areOwnPropsEqual = _ref3$areOwnPropsEqua === void 0 ? _utils_shallowEqual__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z : _ref3$areOwnPropsEqua,
        _ref3$areStatePropsEq = _ref3.areStatePropsEqual,
        areStatePropsEqual = _ref3$areStatePropsEq === void 0 ? _utils_shallowEqual__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z : _ref3$areStatePropsEq,
        _ref3$areMergedPropsE = _ref3.areMergedPropsEqual,
        areMergedPropsEqual = _ref3$areMergedPropsE === void 0 ? _utils_shallowEqual__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z : _ref3$areMergedPropsE,
        extraOptions = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(_ref3, _excluded);

    var initMapStateToProps = match(mapStateToProps, mapStateToPropsFactories, 'mapStateToProps');
    var initMapDispatchToProps = match(mapDispatchToProps, mapDispatchToPropsFactories, 'mapDispatchToProps');
    var initMergeProps = match(mergeProps, mergePropsFactories, 'mergeProps');
    return connectHOC(selectorFactory, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)({
      // used in error messages
      methodName: 'connect',
      // used to compute Connect's displayName from the wrapped component's displayName.
      getDisplayName: function getDisplayName(name) {
        return "Connect(" + name + ")";
      },
      // if mapStateToProps is falsy, the Connect component doesn't subscribe to store state changes
      shouldHandleStateChanges: Boolean(mapStateToProps),
      // passed through to selectorFactory
      initMapStateToProps: initMapStateToProps,
      initMapDispatchToProps: initMapDispatchToProps,
      initMergeProps: initMergeProps,
      pure: pure,
      areStatesEqual: areStatesEqual,
      areOwnPropsEqual: areOwnPropsEqual,
      areStatePropsEqual: areStatePropsEqual,
      areMergedPropsEqual: areMergedPropsEqual
    }, extraOptions));
  };
}
/* harmony default export */ __webpack_exports__["Z"] = (/*#__PURE__*/createConnect());

/***/ }),

/***/ 99174:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports whenMapDispatchToPropsIsFunction, whenMapDispatchToPropsIsMissing, whenMapDispatchToPropsIsObject */
/* harmony import */ var _utils_bindActionCreators__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(56750);
/* harmony import */ var _wrapMapToProps__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(8528);


function whenMapDispatchToPropsIsFunction(mapDispatchToProps) {
  return typeof mapDispatchToProps === 'function' ? (0,_wrapMapToProps__WEBPACK_IMPORTED_MODULE_0__/* .wrapMapToPropsFunc */ .xv)(mapDispatchToProps, 'mapDispatchToProps') : undefined;
}
function whenMapDispatchToPropsIsMissing(mapDispatchToProps) {
  return !mapDispatchToProps ? (0,_wrapMapToProps__WEBPACK_IMPORTED_MODULE_0__/* .wrapMapToPropsConstant */ .dX)(function (dispatch) {
    return {
      dispatch: dispatch
    };
  }) : undefined;
}
function whenMapDispatchToPropsIsObject(mapDispatchToProps) {
  return mapDispatchToProps && typeof mapDispatchToProps === 'object' ? (0,_wrapMapToProps__WEBPACK_IMPORTED_MODULE_0__/* .wrapMapToPropsConstant */ .dX)(function (dispatch) {
    return (0,_utils_bindActionCreators__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(mapDispatchToProps, dispatch);
  }) : undefined;
}
/* harmony default export */ __webpack_exports__["ZP"] = ([whenMapDispatchToPropsIsFunction, whenMapDispatchToPropsIsMissing, whenMapDispatchToPropsIsObject]);

/***/ }),

/***/ 79600:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports whenMapStateToPropsIsFunction, whenMapStateToPropsIsMissing */
/* harmony import */ var _wrapMapToProps__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(8528);

function whenMapStateToPropsIsFunction(mapStateToProps) {
  return typeof mapStateToProps === 'function' ? (0,_wrapMapToProps__WEBPACK_IMPORTED_MODULE_0__/* .wrapMapToPropsFunc */ .xv)(mapStateToProps, 'mapStateToProps') : undefined;
}
function whenMapStateToPropsIsMissing(mapStateToProps) {
  return !mapStateToProps ? (0,_wrapMapToProps__WEBPACK_IMPORTED_MODULE_0__/* .wrapMapToPropsConstant */ .dX)(function () {
    return {};
  }) : undefined;
}
/* harmony default export */ __webpack_exports__["ZP"] = ([whenMapStateToPropsIsFunction, whenMapStateToPropsIsMissing]);

/***/ }),

/***/ 79553:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports defaultMergeProps, wrapMergePropsFunc, whenMergePropsIsFunction, whenMergePropsIsOmitted */
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7896);


function defaultMergeProps(stateProps, dispatchProps, ownProps) {
  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, ownProps, stateProps, dispatchProps);
}
function wrapMergePropsFunc(mergeProps) {
  return function initMergePropsProxy(dispatch, _ref) {
    var displayName = _ref.displayName,
        pure = _ref.pure,
        areMergedPropsEqual = _ref.areMergedPropsEqual;
    var hasRunOnce = false;
    var mergedProps;
    return function mergePropsProxy(stateProps, dispatchProps, ownProps) {
      var nextMergedProps = mergeProps(stateProps, dispatchProps, ownProps);

      if (hasRunOnce) {
        if (!pure || !areMergedPropsEqual(nextMergedProps, mergedProps)) mergedProps = nextMergedProps;
      } else {
        hasRunOnce = true;
        mergedProps = nextMergedProps;
        if (false) {}
      }

      return mergedProps;
    };
  };
}
function whenMergePropsIsFunction(mergeProps) {
  return typeof mergeProps === 'function' ? wrapMergePropsFunc(mergeProps) : undefined;
}
function whenMergePropsIsOmitted(mergeProps) {
  return !mergeProps ? function () {
    return defaultMergeProps;
  } : undefined;
}
/* harmony default export */ __webpack_exports__["ZP"] = ([whenMergePropsIsFunction, whenMergePropsIsOmitted]);

/***/ }),

/***/ 77405:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ZP": function() { return /* binding */ finalPropsSelectorFactory; }
/* harmony export */ });
/* unused harmony exports impureFinalPropsSelectorFactory, pureFinalPropsSelectorFactory */
/* harmony import */ var _babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(31461);

var _excluded = ["initMapStateToProps", "initMapDispatchToProps", "initMergeProps"];

function impureFinalPropsSelectorFactory(mapStateToProps, mapDispatchToProps, mergeProps, dispatch) {
  return function impureFinalPropsSelector(state, ownProps) {
    return mergeProps(mapStateToProps(state, ownProps), mapDispatchToProps(dispatch, ownProps), ownProps);
  };
}
function pureFinalPropsSelectorFactory(mapStateToProps, mapDispatchToProps, mergeProps, dispatch, _ref) {
  var areStatesEqual = _ref.areStatesEqual,
      areOwnPropsEqual = _ref.areOwnPropsEqual,
      areStatePropsEqual = _ref.areStatePropsEqual;
  var hasRunAtLeastOnce = false;
  var state;
  var ownProps;
  var stateProps;
  var dispatchProps;
  var mergedProps;

  function handleFirstCall(firstState, firstOwnProps) {
    state = firstState;
    ownProps = firstOwnProps;
    stateProps = mapStateToProps(state, ownProps);
    dispatchProps = mapDispatchToProps(dispatch, ownProps);
    mergedProps = mergeProps(stateProps, dispatchProps, ownProps);
    hasRunAtLeastOnce = true;
    return mergedProps;
  }

  function handleNewPropsAndNewState() {
    stateProps = mapStateToProps(state, ownProps);
    if (mapDispatchToProps.dependsOnOwnProps) dispatchProps = mapDispatchToProps(dispatch, ownProps);
    mergedProps = mergeProps(stateProps, dispatchProps, ownProps);
    return mergedProps;
  }

  function handleNewProps() {
    if (mapStateToProps.dependsOnOwnProps) stateProps = mapStateToProps(state, ownProps);
    if (mapDispatchToProps.dependsOnOwnProps) dispatchProps = mapDispatchToProps(dispatch, ownProps);
    mergedProps = mergeProps(stateProps, dispatchProps, ownProps);
    return mergedProps;
  }

  function handleNewState() {
    var nextStateProps = mapStateToProps(state, ownProps);
    var statePropsChanged = !areStatePropsEqual(nextStateProps, stateProps);
    stateProps = nextStateProps;
    if (statePropsChanged) mergedProps = mergeProps(stateProps, dispatchProps, ownProps);
    return mergedProps;
  }

  function handleSubsequentCalls(nextState, nextOwnProps) {
    var propsChanged = !areOwnPropsEqual(nextOwnProps, ownProps);
    var stateChanged = !areStatesEqual(nextState, state);
    state = nextState;
    ownProps = nextOwnProps;
    if (propsChanged && stateChanged) return handleNewPropsAndNewState();
    if (propsChanged) return handleNewProps();
    if (stateChanged) return handleNewState();
    return mergedProps;
  }

  return function pureFinalPropsSelector(nextState, nextOwnProps) {
    return hasRunAtLeastOnce ? handleSubsequentCalls(nextState, nextOwnProps) : handleFirstCall(nextState, nextOwnProps);
  };
} // TODO: Add more comments
// If pure is true, the selector returned by selectorFactory will memoize its results,
// allowing connectAdvanced's shouldComponentUpdate to return false if final
// props have not changed. If false, the selector will always return a new
// object and shouldComponentUpdate will always return true.

function finalPropsSelectorFactory(dispatch, _ref2) {
  var initMapStateToProps = _ref2.initMapStateToProps,
      initMapDispatchToProps = _ref2.initMapDispatchToProps,
      initMergeProps = _ref2.initMergeProps,
      options = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(_ref2, _excluded);

  var mapStateToProps = initMapStateToProps(dispatch, options);
  var mapDispatchToProps = initMapDispatchToProps(dispatch, options);
  var mergeProps = initMergeProps(dispatch, options);

  if (false) {}

  var selectorFactory = options.pure ? pureFinalPropsSelectorFactory : impureFinalPropsSelectorFactory;
  return selectorFactory(mapStateToProps, mapDispatchToProps, mergeProps, dispatch, options);
}

/***/ }),

/***/ 8528:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "dX": function() { return /* binding */ wrapMapToPropsConstant; },
/* harmony export */   "xv": function() { return /* binding */ wrapMapToPropsFunc; }
/* harmony export */ });
/* unused harmony export getDependsOnOwnProps */

function wrapMapToPropsConstant(getConstant) {
  return function initConstantSelector(dispatch, options) {
    var constant = getConstant(dispatch, options);

    function constantSelector() {
      return constant;
    }

    constantSelector.dependsOnOwnProps = false;
    return constantSelector;
  };
} // dependsOnOwnProps is used by createMapToPropsProxy to determine whether to pass props as args
// to the mapToProps function being wrapped. It is also used by makePurePropsSelector to determine
// whether mapToProps needs to be invoked when props have changed.
//
// A length of one signals that mapToProps does not depend on props from the parent component.
// A length of zero is assumed to mean mapToProps is getting args via arguments or ...args and
// therefore not reporting its length accurately..

function getDependsOnOwnProps(mapToProps) {
  return mapToProps.dependsOnOwnProps !== null && mapToProps.dependsOnOwnProps !== undefined ? Boolean(mapToProps.dependsOnOwnProps) : mapToProps.length !== 1;
} // Used by whenMapStateToPropsIsFunction and whenMapDispatchToPropsIsFunction,
// this function wraps mapToProps in a proxy function which does several things:
//
//  * Detects whether the mapToProps function being called depends on props, which
//    is used by selectorFactory to decide if it should reinvoke on props changes.
//
//  * On first call, handles mapToProps if returns another function, and treats that
//    new function as the true mapToProps for subsequent calls.
//
//  * On first call, verifies the first result is a plain object, in order to warn
//    the developer that their mapToProps function is not returning a valid result.
//

function wrapMapToPropsFunc(mapToProps, methodName) {
  return function initProxySelector(dispatch, _ref) {
    var displayName = _ref.displayName;

    var proxy = function mapToPropsProxy(stateOrDispatch, ownProps) {
      return proxy.dependsOnOwnProps ? proxy.mapToProps(stateOrDispatch, ownProps) : proxy.mapToProps(stateOrDispatch);
    }; // allow detectFactoryAndVerify to get ownProps


    proxy.dependsOnOwnProps = true;

    proxy.mapToProps = function detectFactoryAndVerify(stateOrDispatch, ownProps) {
      proxy.mapToProps = mapToProps;
      proxy.dependsOnOwnProps = getDependsOnOwnProps(mapToProps);
      var props = proxy(stateOrDispatch, ownProps);

      if (typeof props === 'function') {
        proxy.mapToProps = props;
        proxy.dependsOnOwnProps = getDependsOnOwnProps(props);
        props = proxy(stateOrDispatch, ownProps);
      }

      if (false) {}
      return props;
    };

    return proxy;
  };
}

/***/ }),

/***/ 14283:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "zt": function() { return /* reexport safe */ _components_Provider__WEBPACK_IMPORTED_MODULE_0__.Z; },
/* harmony export */   "$j": function() { return /* reexport safe */ _connect_connect__WEBPACK_IMPORTED_MODULE_3__.Z; },
/* harmony export */   "I0": function() { return /* reexport safe */ _hooks_useDispatch__WEBPACK_IMPORTED_MODULE_4__.I; },
/* harmony export */   "v9": function() { return /* reexport safe */ _hooks_useSelector__WEBPACK_IMPORTED_MODULE_5__.v; }
/* harmony export */ });
/* harmony import */ var _components_Provider__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(42533);
/* harmony import */ var _components_connectAdvanced__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(49484);
/* harmony import */ var _components_Context__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(81346);
/* harmony import */ var _connect_connect__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(55443);
/* harmony import */ var _hooks_useDispatch__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(23102);
/* harmony import */ var _hooks_useSelector__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(85247);
/* harmony import */ var _hooks_useStore__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(87166);










/***/ }),

/***/ 23102:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "I": function() { return /* binding */ useDispatch; }
/* harmony export */ });
/* unused harmony export createDispatchHook */
/* harmony import */ var _components_Context__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(81346);
/* harmony import */ var _useStore__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(87166);


/**
 * Hook factory, which creates a `useDispatch` hook bound to a given context.
 *
 * @param {React.Context} [context=ReactReduxContext] Context passed to your `<Provider>`.
 * @returns {Function} A `useDispatch` hook bound to the specified context.
 */

function createDispatchHook(context) {
  if (context === void 0) {
    context = _components_Context__WEBPACK_IMPORTED_MODULE_0__/* .ReactReduxContext */ .E;
  }

  var useStore = context === _components_Context__WEBPACK_IMPORTED_MODULE_0__/* .ReactReduxContext */ .E ? _useStore__WEBPACK_IMPORTED_MODULE_1__/* .useStore */ .o : (0,_useStore__WEBPACK_IMPORTED_MODULE_1__/* .createStoreHook */ .f)(context);
  return function useDispatch() {
    var store = useStore();
    return store.dispatch;
  };
}
/**
 * A hook to access the redux `dispatch` function.
 *
 * @returns {any|function} redux store's `dispatch` function
 *
 * @example
 *
 * import React, { useCallback } from 'react'
 * import { useDispatch } from 'react-redux'
 *
 * export const CounterComponent = ({ value }) => {
 *   const dispatch = useDispatch()
 *   const increaseCounter = useCallback(() => dispatch({ type: 'increase-counter' }), [])
 *   return (
 *     <div>
 *       <span>{value}</span>
 *       <button onClick={increaseCounter}>Increase counter</button>
 *     </div>
 *   )
 * }
 */

var useDispatch = /*#__PURE__*/createDispatchHook();

/***/ }),

/***/ 24274:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "x": function() { return /* binding */ useReduxContext; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _components_Context__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(81346);


/**
 * A hook to access the value of the `ReactReduxContext`. This is a low-level
 * hook that you should usually not need to call directly.
 *
 * @returns {any} the value of the `ReactReduxContext`
 *
 * @example
 *
 * import React from 'react'
 * import { useReduxContext } from 'react-redux'
 *
 * export const CounterComponent = ({ value }) => {
 *   const { store } = useReduxContext()
 *   return <div>{store.getState()}</div>
 * }
 */

function useReduxContext() {
  var contextValue = (0,react__WEBPACK_IMPORTED_MODULE_0__.useContext)(_components_Context__WEBPACK_IMPORTED_MODULE_1__/* .ReactReduxContext */ .E);

  if (false) {}

  return contextValue;
}

/***/ }),

/***/ 85247:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "v": function() { return /* binding */ useSelector; }
/* harmony export */ });
/* unused harmony export createSelectorHook */
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _useReduxContext__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(24274);
/* harmony import */ var _utils_Subscription__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(82062);
/* harmony import */ var _utils_useIsomorphicLayoutEffect__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(44282);
/* harmony import */ var _components_Context__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(81346);






var refEquality = function refEquality(a, b) {
  return a === b;
};

function useSelectorWithStoreAndSubscription(selector, equalityFn, store, contextSub) {
  var _useReducer = (0,react__WEBPACK_IMPORTED_MODULE_0__.useReducer)(function (s) {
    return s + 1;
  }, 0),
      forceRender = _useReducer[1];

  var subscription = (0,react__WEBPACK_IMPORTED_MODULE_0__.useMemo)(function () {
    return (0,_utils_Subscription__WEBPACK_IMPORTED_MODULE_2__/* .createSubscription */ .X)(store, contextSub);
  }, [store, contextSub]);
  var latestSubscriptionCallbackError = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)();
  var latestSelector = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)();
  var latestStoreState = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)();
  var latestSelectedState = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)();
  var storeState = store.getState();
  var selectedState;

  try {
    if (selector !== latestSelector.current || storeState !== latestStoreState.current || latestSubscriptionCallbackError.current) {
      var newSelectedState = selector(storeState); // ensure latest selected state is reused so that a custom equality function can result in identical references

      if (latestSelectedState.current === undefined || !equalityFn(newSelectedState, latestSelectedState.current)) {
        selectedState = newSelectedState;
      } else {
        selectedState = latestSelectedState.current;
      }
    } else {
      selectedState = latestSelectedState.current;
    }
  } catch (err) {
    if (latestSubscriptionCallbackError.current) {
      err.message += "\nThe error may be correlated with this previous error:\n" + latestSubscriptionCallbackError.current.stack + "\n\n";
    }

    throw err;
  }

  (0,_utils_useIsomorphicLayoutEffect__WEBPACK_IMPORTED_MODULE_3__/* .useIsomorphicLayoutEffect */ .L)(function () {
    latestSelector.current = selector;
    latestStoreState.current = storeState;
    latestSelectedState.current = selectedState;
    latestSubscriptionCallbackError.current = undefined;
  });
  (0,_utils_useIsomorphicLayoutEffect__WEBPACK_IMPORTED_MODULE_3__/* .useIsomorphicLayoutEffect */ .L)(function () {
    function checkForUpdates() {
      try {
        var newStoreState = store.getState(); // Avoid calling selector multiple times if the store's state has not changed

        if (newStoreState === latestStoreState.current) {
          return;
        }

        var _newSelectedState = latestSelector.current(newStoreState);

        if (equalityFn(_newSelectedState, latestSelectedState.current)) {
          return;
        }

        latestSelectedState.current = _newSelectedState;
        latestStoreState.current = newStoreState;
      } catch (err) {
        // we ignore all errors here, since when the component
        // is re-rendered, the selectors are called again, and
        // will throw again, if neither props nor store state
        // changed
        latestSubscriptionCallbackError.current = err;
      }

      forceRender();
    }

    subscription.onStateChange = checkForUpdates;
    subscription.trySubscribe();
    checkForUpdates();
    return function () {
      return subscription.tryUnsubscribe();
    };
  }, [store, subscription]);
  return selectedState;
}
/**
 * Hook factory, which creates a `useSelector` hook bound to a given context.
 *
 * @param {React.Context} [context=ReactReduxContext] Context passed to your `<Provider>`.
 * @returns {Function} A `useSelector` hook bound to the specified context.
 */


function createSelectorHook(context) {
  if (context === void 0) {
    context = _components_Context__WEBPACK_IMPORTED_MODULE_4__/* .ReactReduxContext */ .E;
  }

  var useReduxContext = context === _components_Context__WEBPACK_IMPORTED_MODULE_4__/* .ReactReduxContext */ .E ? _useReduxContext__WEBPACK_IMPORTED_MODULE_1__/* .useReduxContext */ .x : function () {
    return (0,react__WEBPACK_IMPORTED_MODULE_0__.useContext)(context);
  };
  return function useSelector(selector, equalityFn) {
    if (equalityFn === void 0) {
      equalityFn = refEquality;
    }

    if (false) {}

    var _useReduxContext = useReduxContext(),
        store = _useReduxContext.store,
        contextSub = _useReduxContext.subscription;

    var selectedState = useSelectorWithStoreAndSubscription(selector, equalityFn, store, contextSub);
    (0,react__WEBPACK_IMPORTED_MODULE_0__.useDebugValue)(selectedState);
    return selectedState;
  };
}
/**
 * A hook to access the redux store's state. This hook takes a selector function
 * as an argument. The selector is called with the store state.
 *
 * This hook takes an optional equality comparison function as the second parameter
 * that allows you to customize the way the selected state is compared to determine
 * whether the component needs to be re-rendered.
 *
 * @param {Function} selector the selector function
 * @param {Function=} equalityFn the function that will be used to determine equality
 *
 * @returns {any} the selected state
 *
 * @example
 *
 * import React from 'react'
 * import { useSelector } from 'react-redux'
 *
 * export const CounterComponent = () => {
 *   const counter = useSelector(state => state.counter)
 *   return <div>{counter}</div>
 * }
 */

var useSelector = /*#__PURE__*/createSelectorHook();

/***/ }),

/***/ 87166:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "f": function() { return /* binding */ createStoreHook; },
/* harmony export */   "o": function() { return /* binding */ useStore; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _components_Context__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(81346);
/* harmony import */ var _useReduxContext__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(24274);



/**
 * Hook factory, which creates a `useStore` hook bound to a given context.
 *
 * @param {React.Context} [context=ReactReduxContext] Context passed to your `<Provider>`.
 * @returns {Function} A `useStore` hook bound to the specified context.
 */

function createStoreHook(context) {
  if (context === void 0) {
    context = _components_Context__WEBPACK_IMPORTED_MODULE_1__/* .ReactReduxContext */ .E;
  }

  var useReduxContext = context === _components_Context__WEBPACK_IMPORTED_MODULE_1__/* .ReactReduxContext */ .E ? _useReduxContext__WEBPACK_IMPORTED_MODULE_2__/* .useReduxContext */ .x : function () {
    return (0,react__WEBPACK_IMPORTED_MODULE_0__.useContext)(context);
  };
  return function useStore() {
    var _useReduxContext = useReduxContext(),
        store = _useReduxContext.store;

    return store;
  };
}
/**
 * A hook to access the redux store.
 *
 * @returns {any} the redux store
 *
 * @example
 *
 * import React from 'react'
 * import { useStore } from 'react-redux'
 *
 * export const ExampleComponent = () => {
 *   const store = useStore()
 *   return <div>{store.getState()}</div>
 * }
 */

var useStore = /*#__PURE__*/createStoreHook();

/***/ }),

/***/ 4792:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "zt": function() { return /* reexport safe */ _exports__WEBPACK_IMPORTED_MODULE_0__.zt; },
/* harmony export */   "$j": function() { return /* reexport safe */ _exports__WEBPACK_IMPORTED_MODULE_0__.$j; },
/* harmony export */   "I0": function() { return /* reexport safe */ _exports__WEBPACK_IMPORTED_MODULE_0__.I0; },
/* harmony export */   "v9": function() { return /* reexport safe */ _exports__WEBPACK_IMPORTED_MODULE_0__.v9; }
/* harmony export */ });
/* harmony import */ var _exports__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(14283);
/* harmony import */ var _utils_reactBatchedUpdates__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(41369);
/* harmony import */ var _utils_batch__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(14210);


 // Enable batched updates in our subscriptions for use
// with standard React renderers (ReactDOM, React Native)

(0,_utils_batch__WEBPACK_IMPORTED_MODULE_2__/* .setBatch */ .F)(_utils_reactBatchedUpdates__WEBPACK_IMPORTED_MODULE_1__/* .unstable_batchedUpdates */ .m);


/***/ }),

/***/ 82062:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "X": function() { return /* binding */ createSubscription; }
/* harmony export */ });
/* harmony import */ var _batch__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(14210);
 // encapsulates the subscription logic for connecting a component to the redux store, as
// well as nesting subscriptions of descendant components, so that we can ensure the
// ancestor components re-render before descendants

function createListenerCollection() {
  var batch = (0,_batch__WEBPACK_IMPORTED_MODULE_0__/* .getBatch */ .k)();
  var first = null;
  var last = null;
  return {
    clear: function clear() {
      first = null;
      last = null;
    },
    notify: function notify() {
      batch(function () {
        var listener = first;

        while (listener) {
          listener.callback();
          listener = listener.next;
        }
      });
    },
    get: function get() {
      var listeners = [];
      var listener = first;

      while (listener) {
        listeners.push(listener);
        listener = listener.next;
      }

      return listeners;
    },
    subscribe: function subscribe(callback) {
      var isSubscribed = true;
      var listener = last = {
        callback: callback,
        next: null,
        prev: last
      };

      if (listener.prev) {
        listener.prev.next = listener;
      } else {
        first = listener;
      }

      return function unsubscribe() {
        if (!isSubscribed || first === null) return;
        isSubscribed = false;

        if (listener.next) {
          listener.next.prev = listener.prev;
        } else {
          last = listener.prev;
        }

        if (listener.prev) {
          listener.prev.next = listener.next;
        } else {
          first = listener.next;
        }
      };
    }
  };
}

var nullListeners = {
  notify: function notify() {},
  get: function get() {
    return [];
  }
};
function createSubscription(store, parentSub) {
  var unsubscribe;
  var listeners = nullListeners;

  function addNestedSub(listener) {
    trySubscribe();
    return listeners.subscribe(listener);
  }

  function notifyNestedSubs() {
    listeners.notify();
  }

  function handleChangeWrapper() {
    if (subscription.onStateChange) {
      subscription.onStateChange();
    }
  }

  function isSubscribed() {
    return Boolean(unsubscribe);
  }

  function trySubscribe() {
    if (!unsubscribe) {
      unsubscribe = parentSub ? parentSub.addNestedSub(handleChangeWrapper) : store.subscribe(handleChangeWrapper);
      listeners = createListenerCollection();
    }
  }

  function tryUnsubscribe() {
    if (unsubscribe) {
      unsubscribe();
      unsubscribe = undefined;
      listeners.clear();
      listeners = nullListeners;
    }
  }

  var subscription = {
    addNestedSub: addNestedSub,
    notifyNestedSubs: notifyNestedSubs,
    handleChangeWrapper: handleChangeWrapper,
    isSubscribed: isSubscribed,
    trySubscribe: trySubscribe,
    tryUnsubscribe: tryUnsubscribe,
    getListeners: function getListeners() {
      return listeners;
    }
  };
  return subscription;
}

/***/ }),

/***/ 14210:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "F": function() { return /* binding */ setBatch; },
/* harmony export */   "k": function() { return /* binding */ getBatch; }
/* harmony export */ });
// Default to a dummy "batch" implementation that just runs the callback
function defaultNoopBatch(callback) {
  callback();
}

var batch = defaultNoopBatch; // Allow injecting another batching function later

var setBatch = function setBatch(newBatch) {
  return batch = newBatch;
}; // Supply a getter just to skip dealing with ESM bindings

var getBatch = function getBatch() {
  return batch;
};

/***/ }),

/***/ 56750:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ bindActionCreators; }
/* harmony export */ });
function bindActionCreators(actionCreators, dispatch) {
  var boundActionCreators = {};

  var _loop = function _loop(key) {
    var actionCreator = actionCreators[key];

    if (typeof actionCreator === 'function') {
      boundActionCreators[key] = function () {
        return dispatch(actionCreator.apply(void 0, arguments));
      };
    }
  };

  for (var key in actionCreators) {
    _loop(key);
  }

  return boundActionCreators;
}

/***/ }),

/***/ 41369:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "m": function() { return /* reexport safe */ react_dom__WEBPACK_IMPORTED_MODULE_0__.unstable_batchedUpdates; }
/* harmony export */ });
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(91850);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_0__);
/* eslint-disable import/no-unresolved */


/***/ }),

/***/ 74570:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ shallowEqual; }
/* harmony export */ });
function is(x, y) {
  if (x === y) {
    return x !== 0 || y !== 0 || 1 / x === 1 / y;
  } else {
    return x !== x && y !== y;
  }
}

function shallowEqual(objA, objB) {
  if (is(objA, objB)) return true;

  if (typeof objA !== 'object' || objA === null || typeof objB !== 'object' || objB === null) {
    return false;
  }

  var keysA = Object.keys(objA);
  var keysB = Object.keys(objB);
  if (keysA.length !== keysB.length) return false;

  for (var i = 0; i < keysA.length; i++) {
    if (!Object.prototype.hasOwnProperty.call(objB, keysA[i]) || !is(objA[keysA[i]], objB[keysA[i]])) {
      return false;
    }
  }

  return true;
}

/***/ }),

/***/ 44282:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "L": function() { return /* binding */ useIsomorphicLayoutEffect; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
 // React currently throws a warning when using useLayoutEffect on the server.
// To get around it, we can conditionally useEffect on the server (no-op) and
// useLayoutEffect in the browser. We need useLayoutEffect to ensure the store
// subscription callback always has the selector from the latest render commit
// available, otherwise a store update may happen between render and the effect,
// which may cause missed updates; we also must ensure the store subscription
// is created synchronously, otherwise a store update may occur before the
// subscription is created and an inconsistent state may be observed

var useIsomorphicLayoutEffect = typeof window !== 'undefined' && typeof window.document !== 'undefined' && typeof window.document.createElement !== 'undefined' ? react__WEBPACK_IMPORTED_MODULE_0__.useLayoutEffect : react__WEBPACK_IMPORTED_MODULE_0__.useEffect;

/***/ }),

/***/ 47933:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "rU": function() { return /* binding */ Link; }
/* harmony export */ });
/* unused harmony exports BrowserRouter, HashRouter, NavLink */
/* harmony import */ var react_router__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(29175);
/* harmony import */ var _babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(81665);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var history__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(95878);
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(7896);
/* harmony import */ var _babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(31461);
/* harmony import */ var tiny_invariant__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(61898);











/**
 * The public API for a <Router> that uses HTML5 history.
 */

var BrowserRouter =
/*#__PURE__*/
function (_React$Component) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(BrowserRouter, _React$Component);

  function BrowserRouter() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;
    _this.history = (0,history__WEBPACK_IMPORTED_MODULE_2__/* .createBrowserHistory */ .lX)(_this.props);
    return _this;
  }

  var _proto = BrowserRouter.prototype;

  _proto.render = function render() {
    return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_router__WEBPACK_IMPORTED_MODULE_3__/* .Router */ .F0, {
      history: this.history,
      children: this.props.children
    });
  };

  return BrowserRouter;
}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));

if (false) {}

/**
 * The public API for a <Router> that uses window.location.hash.
 */

var HashRouter =
/*#__PURE__*/
function (_React$Component) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(HashRouter, _React$Component);

  function HashRouter() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;
    _this.history = (0,history__WEBPACK_IMPORTED_MODULE_2__/* .createHashHistory */ .q_)(_this.props);
    return _this;
  }

  var _proto = HashRouter.prototype;

  _proto.render = function render() {
    return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_router__WEBPACK_IMPORTED_MODULE_3__/* .Router */ .F0, {
      history: this.history,
      children: this.props.children
    });
  };

  return HashRouter;
}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));

if (false) {}

var resolveToLocation = function resolveToLocation(to, currentLocation) {
  return typeof to === "function" ? to(currentLocation) : to;
};
var normalizeToLocation = function normalizeToLocation(to, currentLocation) {
  return typeof to === "string" ? (0,history__WEBPACK_IMPORTED_MODULE_2__/* .createLocation */ .ob)(to, null, null, currentLocation) : to;
};

var forwardRefShim = function forwardRefShim(C) {
  return C;
};

var forwardRef = (react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef);

if (typeof forwardRef === "undefined") {
  forwardRef = forwardRefShim;
}

function isModifiedEvent(event) {
  return !!(event.metaKey || event.altKey || event.ctrlKey || event.shiftKey);
}

var LinkAnchor = forwardRef(function (_ref, forwardedRef) {
  var innerRef = _ref.innerRef,
      navigate = _ref.navigate,
      _onClick = _ref.onClick,
      rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(_ref, ["innerRef", "navigate", "onClick"]);

  var target = rest.target;

  var props = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({}, rest, {
    onClick: function onClick(event) {
      try {
        if (_onClick) _onClick(event);
      } catch (ex) {
        event.preventDefault();
        throw ex;
      }

      if (!event.defaultPrevented && // onClick prevented default
      event.button === 0 && ( // ignore everything but left clicks
      !target || target === "_self") && // let browser handle "target=_blank" etc.
      !isModifiedEvent(event) // ignore clicks with modifier keys
      ) {
          event.preventDefault();
          navigate();
        }
    }
  }); // React 15 compat


  if (forwardRefShim !== forwardRef) {
    props.ref = forwardedRef || innerRef;
  } else {
    props.ref = innerRef;
  }
  /* eslint-disable-next-line jsx-a11y/anchor-has-content */


  return react__WEBPACK_IMPORTED_MODULE_0___default().createElement("a", props);
});

if (false) {}
/**
 * The public API for rendering a history-aware <a>.
 */


var Link = forwardRef(function (_ref2, forwardedRef) {
  var _ref2$component = _ref2.component,
      component = _ref2$component === void 0 ? LinkAnchor : _ref2$component,
      replace = _ref2.replace,
      to = _ref2.to,
      innerRef = _ref2.innerRef,
      rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(_ref2, ["component", "replace", "to", "innerRef"]);

  return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_router__WEBPACK_IMPORTED_MODULE_3__/* .__RouterContext.Consumer */ .s6.Consumer, null, function (context) {
    !context ?  false ? 0 : (0,tiny_invariant__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(false) : void 0;
    var history = context.history;
    var location = normalizeToLocation(resolveToLocation(to, context.location), context.location);
    var href = location ? history.createHref(location) : "";

    var props = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({}, rest, {
      href: href,
      navigate: function navigate() {
        var location = resolveToLocation(to, context.location);
        var method = replace ? history.replace : history.push;
        method(location);
      }
    }); // React 15 compat


    if (forwardRefShim !== forwardRef) {
      props.ref = forwardedRef || innerRef;
    } else {
      props.innerRef = innerRef;
    }

    return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(component, props);
  });
});

if (false) { var refType, toType; }

var forwardRefShim$1 = function forwardRefShim(C) {
  return C;
};

var forwardRef$1 = (react__WEBPACK_IMPORTED_MODULE_0___default().forwardRef);

if (typeof forwardRef$1 === "undefined") {
  forwardRef$1 = forwardRefShim$1;
}

function joinClassnames() {
  for (var _len = arguments.length, classnames = new Array(_len), _key = 0; _key < _len; _key++) {
    classnames[_key] = arguments[_key];
  }

  return classnames.filter(function (i) {
    return i;
  }).join(" ");
}
/**
 * A <Link> wrapper that knows if it's "active" or not.
 */


var NavLink = forwardRef$1(function (_ref, forwardedRef) {
  var _ref$ariaCurrent = _ref["aria-current"],
      ariaCurrent = _ref$ariaCurrent === void 0 ? "page" : _ref$ariaCurrent,
      _ref$activeClassName = _ref.activeClassName,
      activeClassName = _ref$activeClassName === void 0 ? "active" : _ref$activeClassName,
      activeStyle = _ref.activeStyle,
      classNameProp = _ref.className,
      exact = _ref.exact,
      isActiveProp = _ref.isActive,
      locationProp = _ref.location,
      sensitive = _ref.sensitive,
      strict = _ref.strict,
      styleProp = _ref.style,
      to = _ref.to,
      innerRef = _ref.innerRef,
      rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(_ref, ["aria-current", "activeClassName", "activeStyle", "className", "exact", "isActive", "location", "sensitive", "strict", "style", "to", "innerRef"]);

  return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(react_router__WEBPACK_IMPORTED_MODULE_3__/* .__RouterContext.Consumer */ .s6.Consumer, null, function (context) {
    !context ?  false ? 0 : (0,tiny_invariant__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(false) : void 0;
    var currentLocation = locationProp || context.location;
    var toLocation = normalizeToLocation(resolveToLocation(to, currentLocation), currentLocation);
    var path = toLocation.pathname; // Regex taken from: https://github.com/pillarjs/path-to-regexp/blob/master/index.js#L202

    var escapedPath = path && path.replace(/([.+*?=^!:${}()[\]|/\\])/g, "\\$1");
    var match = escapedPath ? (0,react_router__WEBPACK_IMPORTED_MODULE_3__/* .matchPath */ .LX)(currentLocation.pathname, {
      path: escapedPath,
      exact: exact,
      sensitive: sensitive,
      strict: strict
    }) : null;
    var isActive = !!(isActiveProp ? isActiveProp(match, currentLocation) : match);
    var className = isActive ? joinClassnames(classNameProp, activeClassName) : classNameProp;
    var style = isActive ? (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({}, styleProp, {}, activeStyle) : styleProp;

    var props = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({
      "aria-current": isActive && ariaCurrent || null,
      className: className,
      style: style,
      to: toLocation
    }, rest); // React 15 compat


    if (forwardRefShim$1 !== forwardRef$1) {
      props.ref = forwardedRef || innerRef;
    } else {
      props.innerRef = innerRef;
    }

    return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Link, props);
  });
});

if (false) { var ariaCurrentType; }


//# sourceMappingURL=react-router-dom.js.map


/***/ }),

/***/ 95878:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "lX": function() { return /* binding */ createBrowserHistory; },
/* harmony export */   "q_": function() { return /* binding */ createHashHistory; },
/* harmony export */   "PP": function() { return /* binding */ createMemoryHistory; },
/* harmony export */   "ob": function() { return /* binding */ createLocation; },
/* harmony export */   "Ep": function() { return /* binding */ createPath; }
/* harmony export */ });
/* unused harmony exports locationsAreEqual, parsePath */
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(7896);
/* harmony import */ var resolve_pathname__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(57613);
/* harmony import */ var tiny_invariant__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(61898);






function addLeadingSlash(path) {
  return path.charAt(0) === '/' ? path : '/' + path;
}
function stripLeadingSlash(path) {
  return path.charAt(0) === '/' ? path.substr(1) : path;
}
function hasBasename(path, prefix) {
  return path.toLowerCase().indexOf(prefix.toLowerCase()) === 0 && '/?#'.indexOf(path.charAt(prefix.length)) !== -1;
}
function stripBasename(path, prefix) {
  return hasBasename(path, prefix) ? path.substr(prefix.length) : path;
}
function stripTrailingSlash(path) {
  return path.charAt(path.length - 1) === '/' ? path.slice(0, -1) : path;
}
function parsePath(path) {
  var pathname = path || '/';
  var search = '';
  var hash = '';
  var hashIndex = pathname.indexOf('#');

  if (hashIndex !== -1) {
    hash = pathname.substr(hashIndex);
    pathname = pathname.substr(0, hashIndex);
  }

  var searchIndex = pathname.indexOf('?');

  if (searchIndex !== -1) {
    search = pathname.substr(searchIndex);
    pathname = pathname.substr(0, searchIndex);
  }

  return {
    pathname: pathname,
    search: search === '?' ? '' : search,
    hash: hash === '#' ? '' : hash
  };
}
function createPath(location) {
  var pathname = location.pathname,
      search = location.search,
      hash = location.hash;
  var path = pathname || '/';
  if (search && search !== '?') path += search.charAt(0) === '?' ? search : "?" + search;
  if (hash && hash !== '#') path += hash.charAt(0) === '#' ? hash : "#" + hash;
  return path;
}

function createLocation(path, state, key, currentLocation) {
  var location;

  if (typeof path === 'string') {
    // Two-arg form: push(path, state)
    location = parsePath(path);
    location.state = state;
  } else {
    // One-arg form: push(location)
    location = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, path);
    if (location.pathname === undefined) location.pathname = '';

    if (location.search) {
      if (location.search.charAt(0) !== '?') location.search = '?' + location.search;
    } else {
      location.search = '';
    }

    if (location.hash) {
      if (location.hash.charAt(0) !== '#') location.hash = '#' + location.hash;
    } else {
      location.hash = '';
    }

    if (state !== undefined && location.state === undefined) location.state = state;
  }

  try {
    location.pathname = decodeURI(location.pathname);
  } catch (e) {
    if (e instanceof URIError) {
      throw new URIError('Pathname "' + location.pathname + '" could not be decoded. ' + 'This is likely caused by an invalid percent-encoding.');
    } else {
      throw e;
    }
  }

  if (key) location.key = key;

  if (currentLocation) {
    // Resolve incomplete/relative pathname relative to current location.
    if (!location.pathname) {
      location.pathname = currentLocation.pathname;
    } else if (location.pathname.charAt(0) !== '/') {
      location.pathname = (0,resolve_pathname__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(location.pathname, currentLocation.pathname);
    }
  } else {
    // When there is no prior location and pathname is empty, set it to /
    if (!location.pathname) {
      location.pathname = '/';
    }
  }

  return location;
}
function locationsAreEqual(a, b) {
  return a.pathname === b.pathname && a.search === b.search && a.hash === b.hash && a.key === b.key && valueEqual(a.state, b.state);
}

function createTransitionManager() {
  var prompt = null;

  function setPrompt(nextPrompt) {
     false ? 0 : void 0;
    prompt = nextPrompt;
    return function () {
      if (prompt === nextPrompt) prompt = null;
    };
  }

  function confirmTransitionTo(location, action, getUserConfirmation, callback) {
    // TODO: If another transition starts while we're still confirming
    // the previous one, we may end up in a weird state. Figure out the
    // best way to handle this.
    if (prompt != null) {
      var result = typeof prompt === 'function' ? prompt(location, action) : prompt;

      if (typeof result === 'string') {
        if (typeof getUserConfirmation === 'function') {
          getUserConfirmation(result, callback);
        } else {
           false ? 0 : void 0;
          callback(true);
        }
      } else {
        // Return false from a transition hook to cancel the transition.
        callback(result !== false);
      }
    } else {
      callback(true);
    }
  }

  var listeners = [];

  function appendListener(fn) {
    var isActive = true;

    function listener() {
      if (isActive) fn.apply(void 0, arguments);
    }

    listeners.push(listener);
    return function () {
      isActive = false;
      listeners = listeners.filter(function (item) {
        return item !== listener;
      });
    };
  }

  function notifyListeners() {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    listeners.forEach(function (listener) {
      return listener.apply(void 0, args);
    });
  }

  return {
    setPrompt: setPrompt,
    confirmTransitionTo: confirmTransitionTo,
    appendListener: appendListener,
    notifyListeners: notifyListeners
  };
}

var canUseDOM = !!(typeof window !== 'undefined' && window.document && window.document.createElement);
function getConfirmation(message, callback) {
  callback(window.confirm(message)); // eslint-disable-line no-alert
}
/**
 * Returns true if the HTML5 history API is supported. Taken from Modernizr.
 *
 * https://github.com/Modernizr/Modernizr/blob/master/LICENSE
 * https://github.com/Modernizr/Modernizr/blob/master/feature-detects/history.js
 * changed to avoid false negatives for Windows Phones: https://github.com/reactjs/react-router/issues/586
 */

function supportsHistory() {
  var ua = window.navigator.userAgent;
  if ((ua.indexOf('Android 2.') !== -1 || ua.indexOf('Android 4.0') !== -1) && ua.indexOf('Mobile Safari') !== -1 && ua.indexOf('Chrome') === -1 && ua.indexOf('Windows Phone') === -1) return false;
  return window.history && 'pushState' in window.history;
}
/**
 * Returns true if browser fires popstate on hash change.
 * IE10 and IE11 do not.
 */

function supportsPopStateOnHashChange() {
  return window.navigator.userAgent.indexOf('Trident') === -1;
}
/**
 * Returns false if using go(n) with hash history causes a full page reload.
 */

function supportsGoWithoutReloadUsingHash() {
  return window.navigator.userAgent.indexOf('Firefox') === -1;
}
/**
 * Returns true if a given popstate event is an extraneous WebKit event.
 * Accounts for the fact that Chrome on iOS fires real popstate events
 * containing undefined state when pressing the back button.
 */

function isExtraneousPopstateEvent(event) {
  return event.state === undefined && navigator.userAgent.indexOf('CriOS') === -1;
}

var PopStateEvent = 'popstate';
var HashChangeEvent = 'hashchange';

function getHistoryState() {
  try {
    return window.history.state || {};
  } catch (e) {
    // IE 11 sometimes throws when accessing window.history.state
    // See https://github.com/ReactTraining/history/pull/289
    return {};
  }
}
/**
 * Creates a history object that uses the HTML5 history API including
 * pushState, replaceState, and the popstate event.
 */


function createBrowserHistory(props) {
  if (props === void 0) {
    props = {};
  }

  !canUseDOM ?  false ? 0 : (0,tiny_invariant__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(false) : void 0;
  var globalHistory = window.history;
  var canUseHistory = supportsHistory();
  var needsHashChangeListener = !supportsPopStateOnHashChange();
  var _props = props,
      _props$forceRefresh = _props.forceRefresh,
      forceRefresh = _props$forceRefresh === void 0 ? false : _props$forceRefresh,
      _props$getUserConfirm = _props.getUserConfirmation,
      getUserConfirmation = _props$getUserConfirm === void 0 ? getConfirmation : _props$getUserConfirm,
      _props$keyLength = _props.keyLength,
      keyLength = _props$keyLength === void 0 ? 6 : _props$keyLength;
  var basename = props.basename ? stripTrailingSlash(addLeadingSlash(props.basename)) : '';

  function getDOMLocation(historyState) {
    var _ref = historyState || {},
        key = _ref.key,
        state = _ref.state;

    var _window$location = window.location,
        pathname = _window$location.pathname,
        search = _window$location.search,
        hash = _window$location.hash;
    var path = pathname + search + hash;
     false ? 0 : void 0;
    if (basename) path = stripBasename(path, basename);
    return createLocation(path, state, key);
  }

  function createKey() {
    return Math.random().toString(36).substr(2, keyLength);
  }

  var transitionManager = createTransitionManager();

  function setState(nextState) {
    (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(history, nextState);

    history.length = globalHistory.length;
    transitionManager.notifyListeners(history.location, history.action);
  }

  function handlePopState(event) {
    // Ignore extraneous popstate events in WebKit.
    if (isExtraneousPopstateEvent(event)) return;
    handlePop(getDOMLocation(event.state));
  }

  function handleHashChange() {
    handlePop(getDOMLocation(getHistoryState()));
  }

  var forceNextPop = false;

  function handlePop(location) {
    if (forceNextPop) {
      forceNextPop = false;
      setState();
    } else {
      var action = 'POP';
      transitionManager.confirmTransitionTo(location, action, getUserConfirmation, function (ok) {
        if (ok) {
          setState({
            action: action,
            location: location
          });
        } else {
          revertPop(location);
        }
      });
    }
  }

  function revertPop(fromLocation) {
    var toLocation = history.location; // TODO: We could probably make this more reliable by
    // keeping a list of keys we've seen in sessionStorage.
    // Instead, we just default to 0 for keys we don't know.

    var toIndex = allKeys.indexOf(toLocation.key);
    if (toIndex === -1) toIndex = 0;
    var fromIndex = allKeys.indexOf(fromLocation.key);
    if (fromIndex === -1) fromIndex = 0;
    var delta = toIndex - fromIndex;

    if (delta) {
      forceNextPop = true;
      go(delta);
    }
  }

  var initialLocation = getDOMLocation(getHistoryState());
  var allKeys = [initialLocation.key]; // Public interface

  function createHref(location) {
    return basename + createPath(location);
  }

  function push(path, state) {
     false ? 0 : void 0;
    var action = 'PUSH';
    var location = createLocation(path, state, createKey(), history.location);
    transitionManager.confirmTransitionTo(location, action, getUserConfirmation, function (ok) {
      if (!ok) return;
      var href = createHref(location);
      var key = location.key,
          state = location.state;

      if (canUseHistory) {
        globalHistory.pushState({
          key: key,
          state: state
        }, null, href);

        if (forceRefresh) {
          window.location.href = href;
        } else {
          var prevIndex = allKeys.indexOf(history.location.key);
          var nextKeys = allKeys.slice(0, prevIndex + 1);
          nextKeys.push(location.key);
          allKeys = nextKeys;
          setState({
            action: action,
            location: location
          });
        }
      } else {
         false ? 0 : void 0;
        window.location.href = href;
      }
    });
  }

  function replace(path, state) {
     false ? 0 : void 0;
    var action = 'REPLACE';
    var location = createLocation(path, state, createKey(), history.location);
    transitionManager.confirmTransitionTo(location, action, getUserConfirmation, function (ok) {
      if (!ok) return;
      var href = createHref(location);
      var key = location.key,
          state = location.state;

      if (canUseHistory) {
        globalHistory.replaceState({
          key: key,
          state: state
        }, null, href);

        if (forceRefresh) {
          window.location.replace(href);
        } else {
          var prevIndex = allKeys.indexOf(history.location.key);
          if (prevIndex !== -1) allKeys[prevIndex] = location.key;
          setState({
            action: action,
            location: location
          });
        }
      } else {
         false ? 0 : void 0;
        window.location.replace(href);
      }
    });
  }

  function go(n) {
    globalHistory.go(n);
  }

  function goBack() {
    go(-1);
  }

  function goForward() {
    go(1);
  }

  var listenerCount = 0;

  function checkDOMListeners(delta) {
    listenerCount += delta;

    if (listenerCount === 1 && delta === 1) {
      window.addEventListener(PopStateEvent, handlePopState);
      if (needsHashChangeListener) window.addEventListener(HashChangeEvent, handleHashChange);
    } else if (listenerCount === 0) {
      window.removeEventListener(PopStateEvent, handlePopState);
      if (needsHashChangeListener) window.removeEventListener(HashChangeEvent, handleHashChange);
    }
  }

  var isBlocked = false;

  function block(prompt) {
    if (prompt === void 0) {
      prompt = false;
    }

    var unblock = transitionManager.setPrompt(prompt);

    if (!isBlocked) {
      checkDOMListeners(1);
      isBlocked = true;
    }

    return function () {
      if (isBlocked) {
        isBlocked = false;
        checkDOMListeners(-1);
      }

      return unblock();
    };
  }

  function listen(listener) {
    var unlisten = transitionManager.appendListener(listener);
    checkDOMListeners(1);
    return function () {
      checkDOMListeners(-1);
      unlisten();
    };
  }

  var history = {
    length: globalHistory.length,
    action: 'POP',
    location: initialLocation,
    createHref: createHref,
    push: push,
    replace: replace,
    go: go,
    goBack: goBack,
    goForward: goForward,
    block: block,
    listen: listen
  };
  return history;
}

var HashChangeEvent$1 = 'hashchange';
var HashPathCoders = {
  hashbang: {
    encodePath: function encodePath(path) {
      return path.charAt(0) === '!' ? path : '!/' + stripLeadingSlash(path);
    },
    decodePath: function decodePath(path) {
      return path.charAt(0) === '!' ? path.substr(1) : path;
    }
  },
  noslash: {
    encodePath: stripLeadingSlash,
    decodePath: addLeadingSlash
  },
  slash: {
    encodePath: addLeadingSlash,
    decodePath: addLeadingSlash
  }
};

function stripHash(url) {
  var hashIndex = url.indexOf('#');
  return hashIndex === -1 ? url : url.slice(0, hashIndex);
}

function getHashPath() {
  // We can't use window.location.hash here because it's not
  // consistent across browsers - Firefox will pre-decode it!
  var href = window.location.href;
  var hashIndex = href.indexOf('#');
  return hashIndex === -1 ? '' : href.substring(hashIndex + 1);
}

function pushHashPath(path) {
  window.location.hash = path;
}

function replaceHashPath(path) {
  window.location.replace(stripHash(window.location.href) + '#' + path);
}

function createHashHistory(props) {
  if (props === void 0) {
    props = {};
  }

  !canUseDOM ?  false ? 0 : (0,tiny_invariant__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(false) : void 0;
  var globalHistory = window.history;
  var canGoWithoutReload = supportsGoWithoutReloadUsingHash();
  var _props = props,
      _props$getUserConfirm = _props.getUserConfirmation,
      getUserConfirmation = _props$getUserConfirm === void 0 ? getConfirmation : _props$getUserConfirm,
      _props$hashType = _props.hashType,
      hashType = _props$hashType === void 0 ? 'slash' : _props$hashType;
  var basename = props.basename ? stripTrailingSlash(addLeadingSlash(props.basename)) : '';
  var _HashPathCoders$hashT = HashPathCoders[hashType],
      encodePath = _HashPathCoders$hashT.encodePath,
      decodePath = _HashPathCoders$hashT.decodePath;

  function getDOMLocation() {
    var path = decodePath(getHashPath());
     false ? 0 : void 0;
    if (basename) path = stripBasename(path, basename);
    return createLocation(path);
  }

  var transitionManager = createTransitionManager();

  function setState(nextState) {
    (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(history, nextState);

    history.length = globalHistory.length;
    transitionManager.notifyListeners(history.location, history.action);
  }

  var forceNextPop = false;
  var ignorePath = null;

  function locationsAreEqual$$1(a, b) {
    return a.pathname === b.pathname && a.search === b.search && a.hash === b.hash;
  }

  function handleHashChange() {
    var path = getHashPath();
    var encodedPath = encodePath(path);

    if (path !== encodedPath) {
      // Ensure we always have a properly-encoded hash.
      replaceHashPath(encodedPath);
    } else {
      var location = getDOMLocation();
      var prevLocation = history.location;
      if (!forceNextPop && locationsAreEqual$$1(prevLocation, location)) return; // A hashchange doesn't always == location change.

      if (ignorePath === createPath(location)) return; // Ignore this change; we already setState in push/replace.

      ignorePath = null;
      handlePop(location);
    }
  }

  function handlePop(location) {
    if (forceNextPop) {
      forceNextPop = false;
      setState();
    } else {
      var action = 'POP';
      transitionManager.confirmTransitionTo(location, action, getUserConfirmation, function (ok) {
        if (ok) {
          setState({
            action: action,
            location: location
          });
        } else {
          revertPop(location);
        }
      });
    }
  }

  function revertPop(fromLocation) {
    var toLocation = history.location; // TODO: We could probably make this more reliable by
    // keeping a list of paths we've seen in sessionStorage.
    // Instead, we just default to 0 for paths we don't know.

    var toIndex = allPaths.lastIndexOf(createPath(toLocation));
    if (toIndex === -1) toIndex = 0;
    var fromIndex = allPaths.lastIndexOf(createPath(fromLocation));
    if (fromIndex === -1) fromIndex = 0;
    var delta = toIndex - fromIndex;

    if (delta) {
      forceNextPop = true;
      go(delta);
    }
  } // Ensure the hash is encoded properly before doing anything else.


  var path = getHashPath();
  var encodedPath = encodePath(path);
  if (path !== encodedPath) replaceHashPath(encodedPath);
  var initialLocation = getDOMLocation();
  var allPaths = [createPath(initialLocation)]; // Public interface

  function createHref(location) {
    var baseTag = document.querySelector('base');
    var href = '';

    if (baseTag && baseTag.getAttribute('href')) {
      href = stripHash(window.location.href);
    }

    return href + '#' + encodePath(basename + createPath(location));
  }

  function push(path, state) {
     false ? 0 : void 0;
    var action = 'PUSH';
    var location = createLocation(path, undefined, undefined, history.location);
    transitionManager.confirmTransitionTo(location, action, getUserConfirmation, function (ok) {
      if (!ok) return;
      var path = createPath(location);
      var encodedPath = encodePath(basename + path);
      var hashChanged = getHashPath() !== encodedPath;

      if (hashChanged) {
        // We cannot tell if a hashchange was caused by a PUSH, so we'd
        // rather setState here and ignore the hashchange. The caveat here
        // is that other hash histories in the page will consider it a POP.
        ignorePath = path;
        pushHashPath(encodedPath);
        var prevIndex = allPaths.lastIndexOf(createPath(history.location));
        var nextPaths = allPaths.slice(0, prevIndex + 1);
        nextPaths.push(path);
        allPaths = nextPaths;
        setState({
          action: action,
          location: location
        });
      } else {
         false ? 0 : void 0;
        setState();
      }
    });
  }

  function replace(path, state) {
     false ? 0 : void 0;
    var action = 'REPLACE';
    var location = createLocation(path, undefined, undefined, history.location);
    transitionManager.confirmTransitionTo(location, action, getUserConfirmation, function (ok) {
      if (!ok) return;
      var path = createPath(location);
      var encodedPath = encodePath(basename + path);
      var hashChanged = getHashPath() !== encodedPath;

      if (hashChanged) {
        // We cannot tell if a hashchange was caused by a REPLACE, so we'd
        // rather setState here and ignore the hashchange. The caveat here
        // is that other hash histories in the page will consider it a POP.
        ignorePath = path;
        replaceHashPath(encodedPath);
      }

      var prevIndex = allPaths.indexOf(createPath(history.location));
      if (prevIndex !== -1) allPaths[prevIndex] = path;
      setState({
        action: action,
        location: location
      });
    });
  }

  function go(n) {
     false ? 0 : void 0;
    globalHistory.go(n);
  }

  function goBack() {
    go(-1);
  }

  function goForward() {
    go(1);
  }

  var listenerCount = 0;

  function checkDOMListeners(delta) {
    listenerCount += delta;

    if (listenerCount === 1 && delta === 1) {
      window.addEventListener(HashChangeEvent$1, handleHashChange);
    } else if (listenerCount === 0) {
      window.removeEventListener(HashChangeEvent$1, handleHashChange);
    }
  }

  var isBlocked = false;

  function block(prompt) {
    if (prompt === void 0) {
      prompt = false;
    }

    var unblock = transitionManager.setPrompt(prompt);

    if (!isBlocked) {
      checkDOMListeners(1);
      isBlocked = true;
    }

    return function () {
      if (isBlocked) {
        isBlocked = false;
        checkDOMListeners(-1);
      }

      return unblock();
    };
  }

  function listen(listener) {
    var unlisten = transitionManager.appendListener(listener);
    checkDOMListeners(1);
    return function () {
      checkDOMListeners(-1);
      unlisten();
    };
  }

  var history = {
    length: globalHistory.length,
    action: 'POP',
    location: initialLocation,
    createHref: createHref,
    push: push,
    replace: replace,
    go: go,
    goBack: goBack,
    goForward: goForward,
    block: block,
    listen: listen
  };
  return history;
}

function clamp(n, lowerBound, upperBound) {
  return Math.min(Math.max(n, lowerBound), upperBound);
}
/**
 * Creates a history object that stores locations in memory.
 */


function createMemoryHistory(props) {
  if (props === void 0) {
    props = {};
  }

  var _props = props,
      getUserConfirmation = _props.getUserConfirmation,
      _props$initialEntries = _props.initialEntries,
      initialEntries = _props$initialEntries === void 0 ? ['/'] : _props$initialEntries,
      _props$initialIndex = _props.initialIndex,
      initialIndex = _props$initialIndex === void 0 ? 0 : _props$initialIndex,
      _props$keyLength = _props.keyLength,
      keyLength = _props$keyLength === void 0 ? 6 : _props$keyLength;
  var transitionManager = createTransitionManager();

  function setState(nextState) {
    (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(history, nextState);

    history.length = history.entries.length;
    transitionManager.notifyListeners(history.location, history.action);
  }

  function createKey() {
    return Math.random().toString(36).substr(2, keyLength);
  }

  var index = clamp(initialIndex, 0, initialEntries.length - 1);
  var entries = initialEntries.map(function (entry) {
    return typeof entry === 'string' ? createLocation(entry, undefined, createKey()) : createLocation(entry, undefined, entry.key || createKey());
  }); // Public interface

  var createHref = createPath;

  function push(path, state) {
     false ? 0 : void 0;
    var action = 'PUSH';
    var location = createLocation(path, state, createKey(), history.location);
    transitionManager.confirmTransitionTo(location, action, getUserConfirmation, function (ok) {
      if (!ok) return;
      var prevIndex = history.index;
      var nextIndex = prevIndex + 1;
      var nextEntries = history.entries.slice(0);

      if (nextEntries.length > nextIndex) {
        nextEntries.splice(nextIndex, nextEntries.length - nextIndex, location);
      } else {
        nextEntries.push(location);
      }

      setState({
        action: action,
        location: location,
        index: nextIndex,
        entries: nextEntries
      });
    });
  }

  function replace(path, state) {
     false ? 0 : void 0;
    var action = 'REPLACE';
    var location = createLocation(path, state, createKey(), history.location);
    transitionManager.confirmTransitionTo(location, action, getUserConfirmation, function (ok) {
      if (!ok) return;
      history.entries[history.index] = location;
      setState({
        action: action,
        location: location
      });
    });
  }

  function go(n) {
    var nextIndex = clamp(history.index + n, 0, history.entries.length - 1);
    var action = 'POP';
    var location = history.entries[nextIndex];
    transitionManager.confirmTransitionTo(location, action, getUserConfirmation, function (ok) {
      if (ok) {
        setState({
          action: action,
          location: location,
          index: nextIndex
        });
      } else {
        // Mimic the behavior of DOM histories by
        // causing a render after a cancelled POP.
        setState();
      }
    });
  }

  function goBack() {
    go(-1);
  }

  function goForward() {
    go(1);
  }

  function canGo(n) {
    var nextIndex = history.index + n;
    return nextIndex >= 0 && nextIndex < history.entries.length;
  }

  function block(prompt) {
    if (prompt === void 0) {
      prompt = false;
    }

    return transitionManager.setPrompt(prompt);
  }

  function listen(listener) {
    return transitionManager.appendListener(listener);
  }

  var history = {
    length: entries.length,
    action: 'POP',
    location: entries[index],
    index: index,
    entries: entries,
    createHref: createHref,
    push: push,
    replace: replace,
    go: go,
    goBack: goBack,
    goForward: goForward,
    canGo: canGo,
    block: block,
    listen: listen
  };
  return history;
}




/***/ }),

/***/ 86141:
/***/ (function(__unused_webpack_module, exports) {

"use strict";
var __webpack_unused_export__;
/** @license React v16.13.1
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var b="function"===typeof Symbol&&Symbol.for,c=b?Symbol.for("react.element"):60103,d=b?Symbol.for("react.portal"):60106,e=b?Symbol.for("react.fragment"):60107,f=b?Symbol.for("react.strict_mode"):60108,g=b?Symbol.for("react.profiler"):60114,h=b?Symbol.for("react.provider"):60109,k=b?Symbol.for("react.context"):60110,l=b?Symbol.for("react.async_mode"):60111,m=b?Symbol.for("react.concurrent_mode"):60111,n=b?Symbol.for("react.forward_ref"):60112,p=b?Symbol.for("react.suspense"):60113,q=b?
Symbol.for("react.suspense_list"):60120,r=b?Symbol.for("react.memo"):60115,t=b?Symbol.for("react.lazy"):60116,v=b?Symbol.for("react.block"):60121,w=b?Symbol.for("react.fundamental"):60117,x=b?Symbol.for("react.responder"):60118,y=b?Symbol.for("react.scope"):60119;
function z(a){if("object"===typeof a&&null!==a){var u=a.$$typeof;switch(u){case c:switch(a=a.type,a){case l:case m:case e:case g:case f:case p:return a;default:switch(a=a&&a.$$typeof,a){case k:case n:case t:case r:case h:return a;default:return u}}case d:return u}}}function A(a){return z(a)===m}__webpack_unused_export__=l;__webpack_unused_export__=m;__webpack_unused_export__=k;__webpack_unused_export__=h;__webpack_unused_export__=c;__webpack_unused_export__=n;__webpack_unused_export__=e;__webpack_unused_export__=t;__webpack_unused_export__=r;__webpack_unused_export__=d;
__webpack_unused_export__=g;__webpack_unused_export__=f;__webpack_unused_export__=p;__webpack_unused_export__=function(a){return A(a)||z(a)===l};__webpack_unused_export__=A;__webpack_unused_export__=function(a){return z(a)===k};__webpack_unused_export__=function(a){return z(a)===h};__webpack_unused_export__=function(a){return"object"===typeof a&&null!==a&&a.$$typeof===c};__webpack_unused_export__=function(a){return z(a)===n};__webpack_unused_export__=function(a){return z(a)===e};__webpack_unused_export__=function(a){return z(a)===t};
__webpack_unused_export__=function(a){return z(a)===r};__webpack_unused_export__=function(a){return z(a)===d};__webpack_unused_export__=function(a){return z(a)===g};__webpack_unused_export__=function(a){return z(a)===f};__webpack_unused_export__=function(a){return z(a)===p};
__webpack_unused_export__=function(a){return"string"===typeof a||"function"===typeof a||a===e||a===m||a===g||a===f||a===p||a===q||"object"===typeof a&&null!==a&&(a.$$typeof===t||a.$$typeof===r||a.$$typeof===h||a.$$typeof===k||a.$$typeof===n||a.$$typeof===w||a.$$typeof===x||a.$$typeof===y||a.$$typeof===v)};__webpack_unused_export__=z;


/***/ }),

/***/ 14971:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


if (true) {
  /* unused reexport */ __webpack_require__(86141);
} else {}


/***/ }),

/***/ 29175:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "VA": function() { return /* binding */ MemoryRouter; },
/* harmony export */   "AW": function() { return /* binding */ Route; },
/* harmony export */   "F0": function() { return /* binding */ Router; },
/* harmony export */   "rs": function() { return /* binding */ Switch; },
/* harmony export */   "s6": function() { return /* binding */ context; },
/* harmony export */   "LX": function() { return /* binding */ matchPath; },
/* harmony export */   "k6": function() { return /* binding */ useHistory; },
/* harmony export */   "TH": function() { return /* binding */ useLocation; }
/* harmony export */ });
/* unused harmony exports Prompt, Redirect, StaticRouter, __HistoryContext, generatePath, useParams, useRouteMatch, withRouter */
/* harmony import */ var _babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(81665);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var history__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(95878);
/* harmony import */ var mini_create_react_context__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(81549);
/* harmony import */ var tiny_invariant__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(61898);
/* harmony import */ var _babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(7896);
/* harmony import */ var path_to_regexp__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(20099);
/* harmony import */ var path_to_regexp__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(path_to_regexp__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react_is__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(14971);
/* harmony import */ var _babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(31461);
/* harmony import */ var hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(73463);
/* harmony import */ var hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(hoist_non_react_statics__WEBPACK_IMPORTED_MODULE_4__);













// TODO: Replace with React.createContext once we can assume React 16+

var createNamedContext = function createNamedContext(name) {
  var context = (0,mini_create_react_context__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)();
  context.displayName = name;
  return context;
};

var historyContext =
/*#__PURE__*/
createNamedContext("Router-History");

// TODO: Replace with React.createContext once we can assume React 16+

var createNamedContext$1 = function createNamedContext(name) {
  var context = (0,mini_create_react_context__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)();
  context.displayName = name;
  return context;
};

var context =
/*#__PURE__*/
createNamedContext$1("Router");

/**
 * The public API for putting history on context.
 */

var Router =
/*#__PURE__*/
function (_React$Component) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(Router, _React$Component);

  Router.computeRootMatch = function computeRootMatch(pathname) {
    return {
      path: "/",
      url: "/",
      params: {},
      isExact: pathname === "/"
    };
  };

  function Router(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;
    _this.state = {
      location: props.history.location
    }; // This is a bit of a hack. We have to start listening for location
    // changes here in the constructor in case there are any <Redirect>s
    // on the initial render. If there are, they will replace/push when
    // they mount and since cDM fires in children before parents, we may
    // get a new location before the <Router> is mounted.

    _this._isMounted = false;
    _this._pendingLocation = null;

    if (!props.staticContext) {
      _this.unlisten = props.history.listen(function (location) {
        if (_this._isMounted) {
          _this.setState({
            location: location
          });
        } else {
          _this._pendingLocation = location;
        }
      });
    }

    return _this;
  }

  var _proto = Router.prototype;

  _proto.componentDidMount = function componentDidMount() {
    this._isMounted = true;

    if (this._pendingLocation) {
      this.setState({
        location: this._pendingLocation
      });
    }
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    if (this.unlisten) this.unlisten();
  };

  _proto.render = function render() {
    return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(context.Provider, {
      value: {
        history: this.props.history,
        location: this.state.location,
        match: Router.computeRootMatch(this.state.location.pathname),
        staticContext: this.props.staticContext
      }
    }, react__WEBPACK_IMPORTED_MODULE_0___default().createElement(historyContext.Provider, {
      children: this.props.children || null,
      value: this.props.history
    }));
  };

  return Router;
}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));

if (false) {}

/**
 * The public API for a <Router> that stores location in memory.
 */

var MemoryRouter =
/*#__PURE__*/
function (_React$Component) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(MemoryRouter, _React$Component);

  function MemoryRouter() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;
    _this.history = (0,history__WEBPACK_IMPORTED_MODULE_6__/* .createMemoryHistory */ .PP)(_this.props);
    return _this;
  }

  var _proto = MemoryRouter.prototype;

  _proto.render = function render() {
    return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Router, {
      history: this.history,
      children: this.props.children
    });
  };

  return MemoryRouter;
}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));

if (false) {}

var Lifecycle =
/*#__PURE__*/
function (_React$Component) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(Lifecycle, _React$Component);

  function Lifecycle() {
    return _React$Component.apply(this, arguments) || this;
  }

  var _proto = Lifecycle.prototype;

  _proto.componentDidMount = function componentDidMount() {
    if (this.props.onMount) this.props.onMount.call(this, this);
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    if (this.props.onUpdate) this.props.onUpdate.call(this, this, prevProps);
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    if (this.props.onUnmount) this.props.onUnmount.call(this, this);
  };

  _proto.render = function render() {
    return null;
  };

  return Lifecycle;
}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));

/**
 * The public API for prompting the user before navigating away from a screen.
 */

function Prompt(_ref) {
  var message = _ref.message,
      _ref$when = _ref.when,
      when = _ref$when === void 0 ? true : _ref$when;
  return React.createElement(context.Consumer, null, function (context) {
    !context ?  false ? 0 : invariant(false) : void 0;
    if (!when || context.staticContext) return null;
    var method = context.history.block;
    return React.createElement(Lifecycle, {
      onMount: function onMount(self) {
        self.release = method(message);
      },
      onUpdate: function onUpdate(self, prevProps) {
        if (prevProps.message !== message) {
          self.release();
          self.release = method(message);
        }
      },
      onUnmount: function onUnmount(self) {
        self.release();
      },
      message: message
    });
  });
}

if (false) { var messageType; }

var cache = {};
var cacheLimit = 10000;
var cacheCount = 0;

function compilePath(path) {
  if (cache[path]) return cache[path];
  var generator = pathToRegexp.compile(path);

  if (cacheCount < cacheLimit) {
    cache[path] = generator;
    cacheCount++;
  }

  return generator;
}
/**
 * Public API for generating a URL pathname from a path and parameters.
 */


function generatePath(path, params) {
  if (path === void 0) {
    path = "/";
  }

  if (params === void 0) {
    params = {};
  }

  return path === "/" ? path : compilePath(path)(params, {
    pretty: true
  });
}

/**
 * The public API for navigating programmatically with a component.
 */

function Redirect(_ref) {
  var computedMatch = _ref.computedMatch,
      to = _ref.to,
      _ref$push = _ref.push,
      push = _ref$push === void 0 ? false : _ref$push;
  return React.createElement(context.Consumer, null, function (context) {
    !context ?  false ? 0 : invariant(false) : void 0;
    var history = context.history,
        staticContext = context.staticContext;
    var method = push ? history.push : history.replace;
    var location = createLocation(computedMatch ? typeof to === "string" ? generatePath(to, computedMatch.params) : _extends({}, to, {
      pathname: generatePath(to.pathname, computedMatch.params)
    }) : to); // When rendering in a static context,
    // set the new location immediately.

    if (staticContext) {
      method(location);
      return null;
    }

    return React.createElement(Lifecycle, {
      onMount: function onMount() {
        method(location);
      },
      onUpdate: function onUpdate(self, prevProps) {
        var prevLocation = createLocation(prevProps.to);

        if (!locationsAreEqual(prevLocation, _extends({}, location, {
          key: prevLocation.key
        }))) {
          method(location);
        }
      },
      to: to
    });
  });
}

if (false) {}

var cache$1 = {};
var cacheLimit$1 = 10000;
var cacheCount$1 = 0;

function compilePath$1(path, options) {
  var cacheKey = "" + options.end + options.strict + options.sensitive;
  var pathCache = cache$1[cacheKey] || (cache$1[cacheKey] = {});
  if (pathCache[path]) return pathCache[path];
  var keys = [];
  var regexp = path_to_regexp__WEBPACK_IMPORTED_MODULE_2___default()(path, keys, options);
  var result = {
    regexp: regexp,
    keys: keys
  };

  if (cacheCount$1 < cacheLimit$1) {
    pathCache[path] = result;
    cacheCount$1++;
  }

  return result;
}
/**
 * Public API for matching a URL pathname to a path.
 */


function matchPath(pathname, options) {
  if (options === void 0) {
    options = {};
  }

  if (typeof options === "string" || Array.isArray(options)) {
    options = {
      path: options
    };
  }

  var _options = options,
      path = _options.path,
      _options$exact = _options.exact,
      exact = _options$exact === void 0 ? false : _options$exact,
      _options$strict = _options.strict,
      strict = _options$strict === void 0 ? false : _options$strict,
      _options$sensitive = _options.sensitive,
      sensitive = _options$sensitive === void 0 ? false : _options$sensitive;
  var paths = [].concat(path);
  return paths.reduce(function (matched, path) {
    if (!path && path !== "") return null;
    if (matched) return matched;

    var _compilePath = compilePath$1(path, {
      end: exact,
      strict: strict,
      sensitive: sensitive
    }),
        regexp = _compilePath.regexp,
        keys = _compilePath.keys;

    var match = regexp.exec(pathname);
    if (!match) return null;
    var url = match[0],
        values = match.slice(1);
    var isExact = pathname === url;
    if (exact && !isExact) return null;
    return {
      path: path,
      // the path used to match
      url: path === "/" && url === "" ? "/" : url,
      // the matched portion of the URL
      isExact: isExact,
      // whether or not we matched exactly
      params: keys.reduce(function (memo, key, index) {
        memo[key.name] = values[index];
        return memo;
      }, {})
    };
  }, null);
}

function isEmptyChildren(children) {
  return React.Children.count(children) === 0;
}

function evalChildrenDev(children, props, path) {
  var value = children(props);
   false ? 0 : void 0;
  return value || null;
}
/**
 * The public API for matching a single path and rendering.
 */


var Route =
/*#__PURE__*/
function (_React$Component) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(Route, _React$Component);

  function Route() {
    return _React$Component.apply(this, arguments) || this;
  }

  var _proto = Route.prototype;

  _proto.render = function render() {
    var _this = this;

    return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(context.Consumer, null, function (context$1) {
      !context$1 ?  false ? 0 : (0,tiny_invariant__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(false) : void 0;
      var location = _this.props.location || context$1.location;
      var match = _this.props.computedMatch ? _this.props.computedMatch // <Switch> already computed the match for us
      : _this.props.path ? matchPath(location.pathname, _this.props) : context$1.match;

      var props = (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)({}, context$1, {
        location: location,
        match: match
      });

      var _this$props = _this.props,
          children = _this$props.children,
          component = _this$props.component,
          render = _this$props.render; // Preact uses an empty array as children by
      // default, so use null if that's the case.

      if (Array.isArray(children) && children.length === 0) {
        children = null;
      }

      return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(context.Provider, {
        value: props
      }, props.match ? children ? typeof children === "function" ?  false ? 0 : children(props) : children : component ? react__WEBPACK_IMPORTED_MODULE_0___default().createElement(component, props) : render ? render(props) : null : typeof children === "function" ?  false ? 0 : children(props) : null);
    });
  };

  return Route;
}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));

if (false) {}

function addLeadingSlash(path) {
  return path.charAt(0) === "/" ? path : "/" + path;
}

function addBasename(basename, location) {
  if (!basename) return location;
  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)({}, location, {
    pathname: addLeadingSlash(basename) + location.pathname
  });
}

function stripBasename(basename, location) {
  if (!basename) return location;
  var base = addLeadingSlash(basename);
  if (location.pathname.indexOf(base) !== 0) return location;
  return (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)({}, location, {
    pathname: location.pathname.substr(base.length)
  });
}

function createURL(location) {
  return typeof location === "string" ? location : (0,history__WEBPACK_IMPORTED_MODULE_6__/* .createPath */ .Ep)(location);
}

function staticHandler(methodName) {
  return function () {
      false ? 0 : (0,tiny_invariant__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(false) ;
  };
}

function noop() {}
/**
 * The public top-level API for a "static" <Router>, so-called because it
 * can't actually change the current location. Instead, it just records
 * location changes in a context object. Useful mainly in testing and
 * server-rendering scenarios.
 */


var StaticRouter =
/*#__PURE__*/
function (_React$Component) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(StaticRouter, _React$Component);

  function StaticRouter() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _this.handlePush = function (location) {
      return _this.navigateTo(location, "PUSH");
    };

    _this.handleReplace = function (location) {
      return _this.navigateTo(location, "REPLACE");
    };

    _this.handleListen = function () {
      return noop;
    };

    _this.handleBlock = function () {
      return noop;
    };

    return _this;
  }

  var _proto = StaticRouter.prototype;

  _proto.navigateTo = function navigateTo(location, action) {
    var _this$props = this.props,
        _this$props$basename = _this$props.basename,
        basename = _this$props$basename === void 0 ? "" : _this$props$basename,
        _this$props$context = _this$props.context,
        context = _this$props$context === void 0 ? {} : _this$props$context;
    context.action = action;
    context.location = addBasename(basename, (0,history__WEBPACK_IMPORTED_MODULE_6__/* .createLocation */ .ob)(location));
    context.url = createURL(context.location);
  };

  _proto.render = function render() {
    var _this$props2 = this.props,
        _this$props2$basename = _this$props2.basename,
        basename = _this$props2$basename === void 0 ? "" : _this$props2$basename,
        _this$props2$context = _this$props2.context,
        context = _this$props2$context === void 0 ? {} : _this$props2$context,
        _this$props2$location = _this$props2.location,
        location = _this$props2$location === void 0 ? "/" : _this$props2$location,
        rest = (0,_babel_runtime_helpers_esm_objectWithoutPropertiesLoose__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z)(_this$props2, ["basename", "context", "location"]);

    var history = {
      createHref: function createHref(path) {
        return addLeadingSlash(basename + createURL(path));
      },
      action: "POP",
      location: stripBasename(basename, (0,history__WEBPACK_IMPORTED_MODULE_6__/* .createLocation */ .ob)(location)),
      push: this.handlePush,
      replace: this.handleReplace,
      go: staticHandler("go"),
      goBack: staticHandler("goBack"),
      goForward: staticHandler("goForward"),
      listen: this.handleListen,
      block: this.handleBlock
    };
    return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(Router, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)({}, rest, {
      history: history,
      staticContext: context
    }));
  };

  return StaticRouter;
}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));

if (false) {}

/**
 * The public API for rendering the first <Route> that matches.
 */

var Switch =
/*#__PURE__*/
function (_React$Component) {
  (0,_babel_runtime_helpers_esm_inheritsLoose__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(Switch, _React$Component);

  function Switch() {
    return _React$Component.apply(this, arguments) || this;
  }

  var _proto = Switch.prototype;

  _proto.render = function render() {
    var _this = this;

    return react__WEBPACK_IMPORTED_MODULE_0___default().createElement(context.Consumer, null, function (context) {
      !context ?  false ? 0 : (0,tiny_invariant__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(false) : void 0;
      var location = _this.props.location || context.location;
      var element, match; // We use React.Children.forEach instead of React.Children.toArray().find()
      // here because toArray adds keys to all child elements and we do not want
      // to trigger an unmount/remount for two <Route>s that render the same
      // component at different URLs.

      react__WEBPACK_IMPORTED_MODULE_0___default().Children.forEach(_this.props.children, function (child) {
        if (match == null && react__WEBPACK_IMPORTED_MODULE_0___default().isValidElement(child)) {
          element = child;
          var path = child.props.path || child.props.from;
          match = path ? matchPath(location.pathname, (0,_babel_runtime_helpers_esm_extends__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)({}, child.props, {
            path: path
          })) : context.match;
        }
      });
      return match ? react__WEBPACK_IMPORTED_MODULE_0___default().cloneElement(element, {
        location: location,
        computedMatch: match
      }) : null;
    });
  };

  return Switch;
}((react__WEBPACK_IMPORTED_MODULE_0___default().Component));

if (false) {}

/**
 * A public higher-order component to access the imperative API
 */

function withRouter(Component) {
  var displayName = "withRouter(" + (Component.displayName || Component.name) + ")";

  var C = function C(props) {
    var wrappedComponentRef = props.wrappedComponentRef,
        remainingProps = _objectWithoutPropertiesLoose(props, ["wrappedComponentRef"]);

    return React.createElement(context.Consumer, null, function (context) {
      !context ?  false ? 0 : invariant(false) : void 0;
      return React.createElement(Component, _extends({}, remainingProps, context, {
        ref: wrappedComponentRef
      }));
    });
  };

  C.displayName = displayName;
  C.WrappedComponent = Component;

  if (false) {}

  return hoistStatics(C, Component);
}

var useContext = (react__WEBPACK_IMPORTED_MODULE_0___default().useContext);
function useHistory() {
  if (false) {}

  return useContext(historyContext);
}
function useLocation() {
  if (false) {}

  return useContext(context).location;
}
function useParams() {
  if (false) {}

  var match = useContext(context).match;
  return match ? match.params : {};
}
function useRouteMatch(path) {
  if (false) {}

  var location = useLocation();
  var match = useContext(context).match;
  return path ? matchPath(location.pathname, path) : match;
}

if (false) { var secondaryBuildName, initialBuildName, buildNames, key, global; }


//# sourceMappingURL=react-router.js.map


/***/ }),

/***/ 43292:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
function createThunkMiddleware(extraArgument) {
  return function (_ref) {
    var dispatch = _ref.dispatch,
        getState = _ref.getState;
    return function (next) {
      return function (action) {
        if (typeof action === 'function') {
          return action(dispatch, getState, extraArgument);
        }

        return next(action);
      };
    };
  };
}

var thunk = createThunkMiddleware();
thunk.withExtraArgument = createThunkMiddleware;

/* harmony default export */ __webpack_exports__["Z"] = (thunk);

/***/ }),

/***/ 18717:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "md": function() { return /* binding */ applyMiddleware; },
/* harmony export */   "UY": function() { return /* binding */ combineReducers; },
/* harmony export */   "qC": function() { return /* binding */ compose; },
/* harmony export */   "MT": function() { return /* binding */ createStore; }
/* harmony export */ });
/* unused harmony exports __DO_NOT_USE__ActionTypes, bindActionCreators */
/* harmony import */ var _babel_runtime_helpers_esm_objectSpread2__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(33028);


/**
 * Adapted from React: https://github.com/facebook/react/blob/master/packages/shared/formatProdErrorMessage.js
 *
 * Do not require this module directly! Use normal throw error calls. These messages will be replaced with error codes
 * during build.
 * @param {number} code
 */
function formatProdErrorMessage(code) {
  return "Minified Redux error #" + code + "; visit https://redux.js.org/Errors?code=" + code + " for the full message or " + 'use the non-minified dev environment for full errors. ';
}

// Inlined version of the `symbol-observable` polyfill
var $$observable = (function () {
  return typeof Symbol === 'function' && Symbol.observable || '@@observable';
})();

/**
 * These are private action types reserved by Redux.
 * For any unknown actions, you must return the current state.
 * If the current state is undefined, you must return the initial state.
 * Do not reference these action types directly in your code.
 */
var randomString = function randomString() {
  return Math.random().toString(36).substring(7).split('').join('.');
};

var ActionTypes = {
  INIT: "@@redux/INIT" + randomString(),
  REPLACE: "@@redux/REPLACE" + randomString(),
  PROBE_UNKNOWN_ACTION: function PROBE_UNKNOWN_ACTION() {
    return "@@redux/PROBE_UNKNOWN_ACTION" + randomString();
  }
};

/**
 * @param {any} obj The object to inspect.
 * @returns {boolean} True if the argument appears to be a plain object.
 */
function isPlainObject(obj) {
  if (typeof obj !== 'object' || obj === null) return false;
  var proto = obj;

  while (Object.getPrototypeOf(proto) !== null) {
    proto = Object.getPrototypeOf(proto);
  }

  return Object.getPrototypeOf(obj) === proto;
}

// Inlined / shortened version of `kindOf` from https://github.com/jonschlinkert/kind-of
function miniKindOf(val) {
  if (val === void 0) return 'undefined';
  if (val === null) return 'null';
  var type = typeof val;

  switch (type) {
    case 'boolean':
    case 'string':
    case 'number':
    case 'symbol':
    case 'function':
      {
        return type;
      }
  }

  if (Array.isArray(val)) return 'array';
  if (isDate(val)) return 'date';
  if (isError(val)) return 'error';
  var constructorName = ctorName(val);

  switch (constructorName) {
    case 'Symbol':
    case 'Promise':
    case 'WeakMap':
    case 'WeakSet':
    case 'Map':
    case 'Set':
      return constructorName;
  } // other


  return type.slice(8, -1).toLowerCase().replace(/\s/g, '');
}

function ctorName(val) {
  return typeof val.constructor === 'function' ? val.constructor.name : null;
}

function isError(val) {
  return val instanceof Error || typeof val.message === 'string' && val.constructor && typeof val.constructor.stackTraceLimit === 'number';
}

function isDate(val) {
  if (val instanceof Date) return true;
  return typeof val.toDateString === 'function' && typeof val.getDate === 'function' && typeof val.setDate === 'function';
}

function kindOf(val) {
  var typeOfVal = typeof val;

  if (false) {}

  return typeOfVal;
}

/**
 * Creates a Redux store that holds the state tree.
 * The only way to change the data in the store is to call `dispatch()` on it.
 *
 * There should only be a single store in your app. To specify how different
 * parts of the state tree respond to actions, you may combine several reducers
 * into a single reducer function by using `combineReducers`.
 *
 * @param {Function} reducer A function that returns the next state tree, given
 * the current state tree and the action to handle.
 *
 * @param {any} [preloadedState] The initial state. You may optionally specify it
 * to hydrate the state from the server in universal apps, or to restore a
 * previously serialized user session.
 * If you use `combineReducers` to produce the root reducer function, this must be
 * an object with the same shape as `combineReducers` keys.
 *
 * @param {Function} [enhancer] The store enhancer. You may optionally specify it
 * to enhance the store with third-party capabilities such as middleware,
 * time travel, persistence, etc. The only store enhancer that ships with Redux
 * is `applyMiddleware()`.
 *
 * @returns {Store} A Redux store that lets you read the state, dispatch actions
 * and subscribe to changes.
 */

function createStore(reducer, preloadedState, enhancer) {
  var _ref2;

  if (typeof preloadedState === 'function' && typeof enhancer === 'function' || typeof enhancer === 'function' && typeof arguments[3] === 'function') {
    throw new Error( true ? formatProdErrorMessage(0) : 0);
  }

  if (typeof preloadedState === 'function' && typeof enhancer === 'undefined') {
    enhancer = preloadedState;
    preloadedState = undefined;
  }

  if (typeof enhancer !== 'undefined') {
    if (typeof enhancer !== 'function') {
      throw new Error( true ? formatProdErrorMessage(1) : 0);
    }

    return enhancer(createStore)(reducer, preloadedState);
  }

  if (typeof reducer !== 'function') {
    throw new Error( true ? formatProdErrorMessage(2) : 0);
  }

  var currentReducer = reducer;
  var currentState = preloadedState;
  var currentListeners = [];
  var nextListeners = currentListeners;
  var isDispatching = false;
  /**
   * This makes a shallow copy of currentListeners so we can use
   * nextListeners as a temporary list while dispatching.
   *
   * This prevents any bugs around consumers calling
   * subscribe/unsubscribe in the middle of a dispatch.
   */

  function ensureCanMutateNextListeners() {
    if (nextListeners === currentListeners) {
      nextListeners = currentListeners.slice();
    }
  }
  /**
   * Reads the state tree managed by the store.
   *
   * @returns {any} The current state tree of your application.
   */


  function getState() {
    if (isDispatching) {
      throw new Error( true ? formatProdErrorMessage(3) : 0);
    }

    return currentState;
  }
  /**
   * Adds a change listener. It will be called any time an action is dispatched,
   * and some part of the state tree may potentially have changed. You may then
   * call `getState()` to read the current state tree inside the callback.
   *
   * You may call `dispatch()` from a change listener, with the following
   * caveats:
   *
   * 1. The subscriptions are snapshotted just before every `dispatch()` call.
   * If you subscribe or unsubscribe while the listeners are being invoked, this
   * will not have any effect on the `dispatch()` that is currently in progress.
   * However, the next `dispatch()` call, whether nested or not, will use a more
   * recent snapshot of the subscription list.
   *
   * 2. The listener should not expect to see all state changes, as the state
   * might have been updated multiple times during a nested `dispatch()` before
   * the listener is called. It is, however, guaranteed that all subscribers
   * registered before the `dispatch()` started will be called with the latest
   * state by the time it exits.
   *
   * @param {Function} listener A callback to be invoked on every dispatch.
   * @returns {Function} A function to remove this change listener.
   */


  function subscribe(listener) {
    if (typeof listener !== 'function') {
      throw new Error( true ? formatProdErrorMessage(4) : 0);
    }

    if (isDispatching) {
      throw new Error( true ? formatProdErrorMessage(5) : 0);
    }

    var isSubscribed = true;
    ensureCanMutateNextListeners();
    nextListeners.push(listener);
    return function unsubscribe() {
      if (!isSubscribed) {
        return;
      }

      if (isDispatching) {
        throw new Error( true ? formatProdErrorMessage(6) : 0);
      }

      isSubscribed = false;
      ensureCanMutateNextListeners();
      var index = nextListeners.indexOf(listener);
      nextListeners.splice(index, 1);
      currentListeners = null;
    };
  }
  /**
   * Dispatches an action. It is the only way to trigger a state change.
   *
   * The `reducer` function, used to create the store, will be called with the
   * current state tree and the given `action`. Its return value will
   * be considered the **next** state of the tree, and the change listeners
   * will be notified.
   *
   * The base implementation only supports plain object actions. If you want to
   * dispatch a Promise, an Observable, a thunk, or something else, you need to
   * wrap your store creating function into the corresponding middleware. For
   * example, see the documentation for the `redux-thunk` package. Even the
   * middleware will eventually dispatch plain object actions using this method.
   *
   * @param {Object} action A plain object representing “what changed”. It is
   * a good idea to keep actions serializable so you can record and replay user
   * sessions, or use the time travelling `redux-devtools`. An action must have
   * a `type` property which may not be `undefined`. It is a good idea to use
   * string constants for action types.
   *
   * @returns {Object} For convenience, the same action object you dispatched.
   *
   * Note that, if you use a custom middleware, it may wrap `dispatch()` to
   * return something else (for example, a Promise you can await).
   */


  function dispatch(action) {
    if (!isPlainObject(action)) {
      throw new Error( true ? formatProdErrorMessage(7) : 0);
    }

    if (typeof action.type === 'undefined') {
      throw new Error( true ? formatProdErrorMessage(8) : 0);
    }

    if (isDispatching) {
      throw new Error( true ? formatProdErrorMessage(9) : 0);
    }

    try {
      isDispatching = true;
      currentState = currentReducer(currentState, action);
    } finally {
      isDispatching = false;
    }

    var listeners = currentListeners = nextListeners;

    for (var i = 0; i < listeners.length; i++) {
      var listener = listeners[i];
      listener();
    }

    return action;
  }
  /**
   * Replaces the reducer currently used by the store to calculate the state.
   *
   * You might need this if your app implements code splitting and you want to
   * load some of the reducers dynamically. You might also need this if you
   * implement a hot reloading mechanism for Redux.
   *
   * @param {Function} nextReducer The reducer for the store to use instead.
   * @returns {void}
   */


  function replaceReducer(nextReducer) {
    if (typeof nextReducer !== 'function') {
      throw new Error( true ? formatProdErrorMessage(10) : 0);
    }

    currentReducer = nextReducer; // This action has a similiar effect to ActionTypes.INIT.
    // Any reducers that existed in both the new and old rootReducer
    // will receive the previous state. This effectively populates
    // the new state tree with any relevant data from the old one.

    dispatch({
      type: ActionTypes.REPLACE
    });
  }
  /**
   * Interoperability point for observable/reactive libraries.
   * @returns {observable} A minimal observable of state changes.
   * For more information, see the observable proposal:
   * https://github.com/tc39/proposal-observable
   */


  function observable() {
    var _ref;

    var outerSubscribe = subscribe;
    return _ref = {
      /**
       * The minimal observable subscription method.
       * @param {Object} observer Any object that can be used as an observer.
       * The observer object should have a `next` method.
       * @returns {subscription} An object with an `unsubscribe` method that can
       * be used to unsubscribe the observable from the store, and prevent further
       * emission of values from the observable.
       */
      subscribe: function subscribe(observer) {
        if (typeof observer !== 'object' || observer === null) {
          throw new Error( true ? formatProdErrorMessage(11) : 0);
        }

        function observeState() {
          if (observer.next) {
            observer.next(getState());
          }
        }

        observeState();
        var unsubscribe = outerSubscribe(observeState);
        return {
          unsubscribe: unsubscribe
        };
      }
    }, _ref[$$observable] = function () {
      return this;
    }, _ref;
  } // When a store is created, an "INIT" action is dispatched so that every
  // reducer returns their initial state. This effectively populates
  // the initial state tree.


  dispatch({
    type: ActionTypes.INIT
  });
  return _ref2 = {
    dispatch: dispatch,
    subscribe: subscribe,
    getState: getState,
    replaceReducer: replaceReducer
  }, _ref2[$$observable] = observable, _ref2;
}

/**
 * Prints a warning in the console if it exists.
 *
 * @param {String} message The warning message.
 * @returns {void}
 */
function warning(message) {
  /* eslint-disable no-console */
  if (typeof console !== 'undefined' && typeof console.error === 'function') {
    console.error(message);
  }
  /* eslint-enable no-console */


  try {
    // This error was thrown as a convenience so that if you enable
    // "break on all exceptions" in your console,
    // it would pause the execution at this line.
    throw new Error(message);
  } catch (e) {} // eslint-disable-line no-empty

}

function getUnexpectedStateShapeWarningMessage(inputState, reducers, action, unexpectedKeyCache) {
  var reducerKeys = Object.keys(reducers);
  var argumentName = action && action.type === ActionTypes.INIT ? 'preloadedState argument passed to createStore' : 'previous state received by the reducer';

  if (reducerKeys.length === 0) {
    return 'Store does not have a valid reducer. Make sure the argument passed ' + 'to combineReducers is an object whose values are reducers.';
  }

  if (!isPlainObject(inputState)) {
    return "The " + argumentName + " has unexpected type of \"" + kindOf(inputState) + "\". Expected argument to be an object with the following " + ("keys: \"" + reducerKeys.join('", "') + "\"");
  }

  var unexpectedKeys = Object.keys(inputState).filter(function (key) {
    return !reducers.hasOwnProperty(key) && !unexpectedKeyCache[key];
  });
  unexpectedKeys.forEach(function (key) {
    unexpectedKeyCache[key] = true;
  });
  if (action && action.type === ActionTypes.REPLACE) return;

  if (unexpectedKeys.length > 0) {
    return "Unexpected " + (unexpectedKeys.length > 1 ? 'keys' : 'key') + " " + ("\"" + unexpectedKeys.join('", "') + "\" found in " + argumentName + ". ") + "Expected to find one of the known reducer keys instead: " + ("\"" + reducerKeys.join('", "') + "\". Unexpected keys will be ignored.");
  }
}

function assertReducerShape(reducers) {
  Object.keys(reducers).forEach(function (key) {
    var reducer = reducers[key];
    var initialState = reducer(undefined, {
      type: ActionTypes.INIT
    });

    if (typeof initialState === 'undefined') {
      throw new Error( true ? formatProdErrorMessage(12) : 0);
    }

    if (typeof reducer(undefined, {
      type: ActionTypes.PROBE_UNKNOWN_ACTION()
    }) === 'undefined') {
      throw new Error( true ? formatProdErrorMessage(13) : 0);
    }
  });
}
/**
 * Turns an object whose values are different reducer functions, into a single
 * reducer function. It will call every child reducer, and gather their results
 * into a single state object, whose keys correspond to the keys of the passed
 * reducer functions.
 *
 * @param {Object} reducers An object whose values correspond to different
 * reducer functions that need to be combined into one. One handy way to obtain
 * it is to use ES6 `import * as reducers` syntax. The reducers may never return
 * undefined for any action. Instead, they should return their initial state
 * if the state passed to them was undefined, and the current state for any
 * unrecognized action.
 *
 * @returns {Function} A reducer function that invokes every reducer inside the
 * passed object, and builds a state object with the same shape.
 */


function combineReducers(reducers) {
  var reducerKeys = Object.keys(reducers);
  var finalReducers = {};

  for (var i = 0; i < reducerKeys.length; i++) {
    var key = reducerKeys[i];

    if (false) {}

    if (typeof reducers[key] === 'function') {
      finalReducers[key] = reducers[key];
    }
  }

  var finalReducerKeys = Object.keys(finalReducers); // This is used to make sure we don't warn about the same
  // keys multiple times.

  var unexpectedKeyCache;

  if (false) {}

  var shapeAssertionError;

  try {
    assertReducerShape(finalReducers);
  } catch (e) {
    shapeAssertionError = e;
  }

  return function combination(state, action) {
    if (state === void 0) {
      state = {};
    }

    if (shapeAssertionError) {
      throw shapeAssertionError;
    }

    if (false) { var warningMessage; }

    var hasChanged = false;
    var nextState = {};

    for (var _i = 0; _i < finalReducerKeys.length; _i++) {
      var _key = finalReducerKeys[_i];
      var reducer = finalReducers[_key];
      var previousStateForKey = state[_key];
      var nextStateForKey = reducer(previousStateForKey, action);

      if (typeof nextStateForKey === 'undefined') {
        var actionType = action && action.type;
        throw new Error( true ? formatProdErrorMessage(14) : 0);
      }

      nextState[_key] = nextStateForKey;
      hasChanged = hasChanged || nextStateForKey !== previousStateForKey;
    }

    hasChanged = hasChanged || finalReducerKeys.length !== Object.keys(state).length;
    return hasChanged ? nextState : state;
  };
}

function bindActionCreator(actionCreator, dispatch) {
  return function () {
    return dispatch(actionCreator.apply(this, arguments));
  };
}
/**
 * Turns an object whose values are action creators, into an object with the
 * same keys, but with every function wrapped into a `dispatch` call so they
 * may be invoked directly. This is just a convenience method, as you can call
 * `store.dispatch(MyActionCreators.doSomething())` yourself just fine.
 *
 * For convenience, you can also pass an action creator as the first argument,
 * and get a dispatch wrapped function in return.
 *
 * @param {Function|Object} actionCreators An object whose values are action
 * creator functions. One handy way to obtain it is to use ES6 `import * as`
 * syntax. You may also pass a single function.
 *
 * @param {Function} dispatch The `dispatch` function available on your Redux
 * store.
 *
 * @returns {Function|Object} The object mimicking the original object, but with
 * every action creator wrapped into the `dispatch` call. If you passed a
 * function as `actionCreators`, the return value will also be a single
 * function.
 */


function bindActionCreators(actionCreators, dispatch) {
  if (typeof actionCreators === 'function') {
    return bindActionCreator(actionCreators, dispatch);
  }

  if (typeof actionCreators !== 'object' || actionCreators === null) {
    throw new Error( true ? formatProdErrorMessage(16) : 0);
  }

  var boundActionCreators = {};

  for (var key in actionCreators) {
    var actionCreator = actionCreators[key];

    if (typeof actionCreator === 'function') {
      boundActionCreators[key] = bindActionCreator(actionCreator, dispatch);
    }
  }

  return boundActionCreators;
}

/**
 * Composes single-argument functions from right to left. The rightmost
 * function can take multiple arguments as it provides the signature for
 * the resulting composite function.
 *
 * @param {...Function} funcs The functions to compose.
 * @returns {Function} A function obtained by composing the argument functions
 * from right to left. For example, compose(f, g, h) is identical to doing
 * (...args) => f(g(h(...args))).
 */
function compose() {
  for (var _len = arguments.length, funcs = new Array(_len), _key = 0; _key < _len; _key++) {
    funcs[_key] = arguments[_key];
  }

  if (funcs.length === 0) {
    return function (arg) {
      return arg;
    };
  }

  if (funcs.length === 1) {
    return funcs[0];
  }

  return funcs.reduce(function (a, b) {
    return function () {
      return a(b.apply(void 0, arguments));
    };
  });
}

/**
 * Creates a store enhancer that applies middleware to the dispatch method
 * of the Redux store. This is handy for a variety of tasks, such as expressing
 * asynchronous actions in a concise manner, or logging every action payload.
 *
 * See `redux-thunk` package as an example of the Redux middleware.
 *
 * Because middleware is potentially asynchronous, this should be the first
 * store enhancer in the composition chain.
 *
 * Note that each middleware will be given the `dispatch` and `getState` functions
 * as named arguments.
 *
 * @param {...Function} middlewares The middleware chain to be applied.
 * @returns {Function} A store enhancer applying the middleware.
 */

function applyMiddleware() {
  for (var _len = arguments.length, middlewares = new Array(_len), _key = 0; _key < _len; _key++) {
    middlewares[_key] = arguments[_key];
  }

  return function (createStore) {
    return function () {
      var store = createStore.apply(void 0, arguments);

      var _dispatch = function dispatch() {
        throw new Error( true ? formatProdErrorMessage(15) : 0);
      };

      var middlewareAPI = {
        getState: store.getState,
        dispatch: function dispatch() {
          return _dispatch.apply(void 0, arguments);
        }
      };
      var chain = middlewares.map(function (middleware) {
        return middleware(middlewareAPI);
      });
      _dispatch = compose.apply(void 0, chain)(store.dispatch);
      return (0,_babel_runtime_helpers_esm_objectSpread2__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)((0,_babel_runtime_helpers_esm_objectSpread2__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)({}, store), {}, {
        dispatch: _dispatch
      });
    };
  };
}

/*
 * This is a dummy function to check if the function name has been altered by minification.
 * If the function has been minified and NODE_ENV !== 'production', warn the user.
 */

function isCrushed() {}

if (false) {}




/***/ }),

/***/ 57245:
/***/ (function(module) {

"use strict";


/**
 * Check if we're required to add a port number.
 *
 * @see https://url.spec.whatwg.org/#default-port
 * @param {Number|String} port Port number we need to check
 * @param {String} protocol Protocol we need to check against.
 * @returns {Boolean} Is it a default port for the given protocol
 * @api private
 */
module.exports = function required(port, protocol) {
  protocol = protocol.split(':')[0];
  port = +port;

  if (!port) return false;

  switch (protocol) {
    case 'http':
    case 'ws':
    return port !== 80;

    case 'https':
    case 'wss':
    return port !== 443;

    case 'ftp':
    return port !== 21;

    case 'gopher':
    return port !== 70;

    case 'file':
    return false;
  }

  return port !== 0;
};


/***/ }),

/***/ 57613:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
function isAbsolute(pathname) {
  return pathname.charAt(0) === '/';
}

// About 1.5x faster than the two-arg version of Array#splice()
function spliceOne(list, index) {
  for (var i = index, k = i + 1, n = list.length; k < n; i += 1, k += 1) {
    list[i] = list[k];
  }

  list.pop();
}

// This implementation is based heavily on node's url.parse
function resolvePathname(to, from) {
  if (from === undefined) from = '';

  var toParts = (to && to.split('/')) || [];
  var fromParts = (from && from.split('/')) || [];

  var isToAbs = to && isAbsolute(to);
  var isFromAbs = from && isAbsolute(from);
  var mustEndAbs = isToAbs || isFromAbs;

  if (to && isAbsolute(to)) {
    // to is absolute
    fromParts = toParts;
  } else if (toParts.length) {
    // to is relative, drop the filename
    fromParts.pop();
    fromParts = fromParts.concat(toParts);
  }

  if (!fromParts.length) return '/';

  var hasTrailingSlash;
  if (fromParts.length) {
    var last = fromParts[fromParts.length - 1];
    hasTrailingSlash = last === '.' || last === '..' || last === '';
  } else {
    hasTrailingSlash = false;
  }

  var up = 0;
  for (var i = fromParts.length; i >= 0; i--) {
    var part = fromParts[i];

    if (part === '.') {
      spliceOne(fromParts, i);
    } else if (part === '..') {
      spliceOne(fromParts, i);
      up++;
    } else if (up) {
      spliceOne(fromParts, i);
      up--;
    }
  }

  if (!mustEndAbs) for (; up--; up) fromParts.unshift('..');

  if (
    mustEndAbs &&
    fromParts[0] !== '' &&
    (!fromParts[0] || !isAbsolute(fromParts[0]))
  )
    fromParts.unshift('');

  var result = fromParts.join('/');

  if (hasTrailingSlash && result.substr(-1) !== '/') result += '/';

  return result;
}

/* harmony default export */ __webpack_exports__["Z"] = (resolvePathname);


/***/ }),

/***/ 10547:
/***/ (function(module) {

"use strict";


var width = 256;// each RC4 output is 0 <= x < 256
var chunks = 6;// at least six RC4 outputs for each double
var digits = 52;// there are 52 significant digits in a double
var pool = [];// pool: entropy pool starts empty
var GLOBAL = typeof window === 'undefined' ? window : window;

//
// The following constants are related to IEEE 754 limits.
//
var startdenom = Math.pow(width, chunks),
    significance = Math.pow(2, digits),
    overflow = significance * 2,
    mask = width - 1;


var oldRandom = Math.random;

//
// seedrandom()
// This is the seedrandom function described above.
//
module.exports = function(seed, options) {
  if (options && options.global === true) {
    options.global = false;
    Math.random = module.exports(seed, options);
    options.global = true;
    return Math.random;
  }
  var use_entropy = (options && options.entropy) || false;
  var key = [];

  // Flatten the seed string or build one from local entropy if needed.
  var shortseed = mixkey(flatten(
    use_entropy ? [seed, tostring(pool)] :
    0 in arguments ? seed : autoseed(), 3), key);

  // Use the seed to initialize an ARC4 generator.
  var arc4 = new ARC4(key);

  // Mix the randomness into accumulated entropy.
  mixkey(tostring(arc4.S), pool);

  // Override Math.random

  // This function returns a random double in [0, 1) that contains
  // randomness in every bit of the mantissa of the IEEE 754 value.

  return function() {         // Closure to return a random double:
    var n = arc4.g(chunks),             // Start with a numerator n < 2 ^ 48
        d = startdenom,                 //   and denominator d = 2 ^ 48.
        x = 0;                          //   and no 'extra last byte'.
    while (n < significance) {          // Fill up all significant digits by
      n = (n + x) * width;              //   shifting numerator and
      d *= width;                       //   denominator and generating a
      x = arc4.g(1);                    //   new least-significant-byte.
    }
    while (n >= overflow) {             // To avoid rounding up, before adding
      n /= 2;                           //   last byte, shift everything
      d /= 2;                           //   right using integer Math until
      x >>>= 1;                         //   we have exactly the desired bits.
    }
    return (n + x) / d;                 // Form the number within [0, 1).
  };
};

module.exports.resetGlobal = function () {
  Math.random = oldRandom;
};

//
// ARC4
//
// An ARC4 implementation.  The constructor takes a key in the form of
// an array of at most (width) integers that should be 0 <= x < (width).
//
// The g(count) method returns a pseudorandom integer that concatenates
// the next (count) outputs from ARC4.  Its return value is a number x
// that is in the range 0 <= x < (width ^ count).
//
/** @constructor */
function ARC4(key) {
  var t, keylen = key.length,
      me = this, i = 0, j = me.i = me.j = 0, s = me.S = [];

  // The empty key [] is treated as [0].
  if (!keylen) { key = [keylen++]; }

  // Set up S using the standard key scheduling algorithm.
  while (i < width) {
    s[i] = i++;
  }
  for (i = 0; i < width; i++) {
    s[i] = s[j = mask & (j + key[i % keylen] + (t = s[i]))];
    s[j] = t;
  }

  // The "g" method returns the next (count) outputs as one number.
  (me.g = function(count) {
    // Using instance members instead of closure state nearly doubles speed.
    var t, r = 0,
        i = me.i, j = me.j, s = me.S;
    while (count--) {
      t = s[i = mask & (i + 1)];
      r = r * width + s[mask & ((s[i] = s[j = mask & (j + t)]) + (s[j] = t))];
    }
    me.i = i; me.j = j;
    return r;
    // For robust unpredictability discard an initial batch of values.
    // See http://www.rsa.com/rsalabs/node.asp?id=2009
  })(width);
}

//
// flatten()
// Converts an object tree to nested arrays of strings.
//
function flatten(obj, depth) {
  var result = [], typ = (typeof obj)[0], prop;
  if (depth && typ == 'o') {
    for (prop in obj) {
      try { result.push(flatten(obj[prop], depth - 1)); } catch (e) {}
    }
  }
  return (result.length ? result : typ == 's' ? obj : obj + '\0');
}

//
// mixkey()
// Mixes a string seed into a key that is an array of integers, and
// returns a shortened string seed that is equivalent to the result key.
//
function mixkey(seed, key) {
  var stringseed = seed + '', smear, j = 0;
  while (j < stringseed.length) {
    key[mask & j] =
      mask & ((smear ^= key[mask & j] * 19) + stringseed.charCodeAt(j++));
  }
  return tostring(key);
}

//
// autoseed()
// Returns an object for autoseeding, using window.crypto if available.
//
/** @param {Uint8Array=} seed */
function autoseed(seed) {
  try {
    GLOBAL.crypto.getRandomValues(seed = new Uint8Array(width));
    return tostring(seed);
  } catch (e) {
    return [+new Date, GLOBAL, GLOBAL.navigator && GLOBAL.navigator.plugins,
            GLOBAL.screen, tostring(pool)];
  }
}

//
// tostring()
// Converts an array of charcodes to a string
//
function tostring(a) {
  return String.fromCharCode.apply(0, a);
}

//
// When seedrandom.js is loaded, we immediately mix a few bits
// from the built-in RNG into the entropy pool.  Because we do
// not want to intefere with determinstic PRNG state later,
// seedrandom will not call Math.random on its own again after
// initialization.
//
mixkey(Math.random(), pool);


/***/ }),

/***/ 74294:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var GetIntrinsic = __webpack_require__(67286);
var callBound = __webpack_require__(62680);
var inspect = __webpack_require__(99500);

var $TypeError = GetIntrinsic('%TypeError%');
var $WeakMap = GetIntrinsic('%WeakMap%', true);
var $Map = GetIntrinsic('%Map%', true);

var $weakMapGet = callBound('WeakMap.prototype.get', true);
var $weakMapSet = callBound('WeakMap.prototype.set', true);
var $weakMapHas = callBound('WeakMap.prototype.has', true);
var $mapGet = callBound('Map.prototype.get', true);
var $mapSet = callBound('Map.prototype.set', true);
var $mapHas = callBound('Map.prototype.has', true);

/*
 * This function traverses the list returning the node corresponding to the
 * given key.
 *
 * That node is also moved to the head of the list, so that if it's accessed
 * again we don't need to traverse the whole list. By doing so, all the recently
 * used nodes can be accessed relatively quickly.
 */
var listGetNode = function (list, key) { // eslint-disable-line consistent-return
	for (var prev = list, curr; (curr = prev.next) !== null; prev = curr) {
		if (curr.key === key) {
			prev.next = curr.next;
			curr.next = list.next;
			list.next = curr; // eslint-disable-line no-param-reassign
			return curr;
		}
	}
};

var listGet = function (objects, key) {
	var node = listGetNode(objects, key);
	return node && node.value;
};
var listSet = function (objects, key, value) {
	var node = listGetNode(objects, key);
	if (node) {
		node.value = value;
	} else {
		// Prepend the new node to the beginning of the list
		objects.next = { // eslint-disable-line no-param-reassign
			key: key,
			next: objects.next,
			value: value
		};
	}
};
var listHas = function (objects, key) {
	return !!listGetNode(objects, key);
};

module.exports = function getSideChannel() {
	var $wm;
	var $m;
	var $o;
	var channel = {
		assert: function (key) {
			if (!channel.has(key)) {
				throw new $TypeError('Side channel does not contain ' + inspect(key));
			}
		},
		get: function (key) { // eslint-disable-line consistent-return
			if ($WeakMap && key && (typeof key === 'object' || typeof key === 'function')) {
				if ($wm) {
					return $weakMapGet($wm, key);
				}
			} else if ($Map) {
				if ($m) {
					return $mapGet($m, key);
				}
			} else {
				if ($o) { // eslint-disable-line no-lonely-if
					return listGet($o, key);
				}
			}
		},
		has: function (key) {
			if ($WeakMap && key && (typeof key === 'object' || typeof key === 'function')) {
				if ($wm) {
					return $weakMapHas($wm, key);
				}
			} else if ($Map) {
				if ($m) {
					return $mapHas($m, key);
				}
			} else {
				if ($o) { // eslint-disable-line no-lonely-if
					return listHas($o, key);
				}
			}
			return false;
		},
		set: function (key, value) {
			if ($WeakMap && key && (typeof key === 'object' || typeof key === 'function')) {
				if (!$wm) {
					$wm = new $WeakMap();
				}
				$weakMapSet($wm, key, value);
			} else if ($Map) {
				if (!$m) {
					$m = new $Map();
				}
				$mapSet($m, key, value);
			} else {
				if (!$o) {
					/*
					 * Initialize the linked list as an empty node, so that we don't have
					 * to special-case handling of the first node: we can always refer to
					 * it as (previous node).next, instead of something like (list).head
					 */
					$o = { key: {}, next: null };
				}
				listSet($o, key, value);
			}
		}
	};
	return channel;
};


/***/ }),

/***/ 17768:
/***/ (function(module, exports, __webpack_require__) {


/**
 * Module dependencies.
 */

var url = __webpack_require__(58749);
var parser = __webpack_require__(87170);
var Manager = __webpack_require__(39431);
var debug = __webpack_require__(31035)('socket.io-client');

/**
 * Module exports.
 */

module.exports = exports = lookup;

/**
 * Managers cache.
 */

var cache = exports.managers = {};

/**
 * Looks up an existing `Manager` for multiplexing.
 * If the user summons:
 *
 *   `io('http://localhost/a');`
 *   `io('http://localhost/b');`
 *
 * We reuse the existing instance based on same scheme/port/host,
 * and we initialize sockets for each namespace.
 *
 * @api public
 */

function lookup (uri, opts) {
  if (typeof uri === 'object') {
    opts = uri;
    uri = undefined;
  }

  opts = opts || {};

  var parsed = url(uri);
  var source = parsed.source;
  var id = parsed.id;
  var path = parsed.path;
  var sameNamespace = cache[id] && path in cache[id].nsps;
  var newConnection = opts.forceNew || opts['force new connection'] ||
                      false === opts.multiplex || sameNamespace;

  var io;

  if (newConnection) {
    debug('ignoring socket cache for %s', source);
    io = Manager(source, opts);
  } else {
    if (!cache[id]) {
      debug('new io instance for %s', source);
      cache[id] = Manager(source, opts);
    }
    io = cache[id];
  }
  if (parsed.query && !opts.query) {
    opts.query = parsed.query;
  }
  return io.socket(parsed.path, opts);
}

/**
 * Protocol version.
 *
 * @api public
 */

exports.protocol = parser.protocol;

/**
 * `connect`.
 *
 * @param {String} uri
 * @api public
 */

exports.connect = lookup;

/**
 * Expose constructors for standalone build.
 *
 * @api public
 */

exports.Manager = __webpack_require__(39431);
exports.Socket = __webpack_require__(72243);


/***/ }),

/***/ 39431:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {


/**
 * Module dependencies.
 */

var eio = __webpack_require__(44065);
var Socket = __webpack_require__(72243);
var Emitter = __webpack_require__(8023);
var parser = __webpack_require__(87170);
var on = __webpack_require__(93073);
var bind = __webpack_require__(42150);
var debug = __webpack_require__(31035)('socket.io-client:manager');
var indexOf = __webpack_require__(92543);
var Backoff = __webpack_require__(87911);

/**
 * IE6+ hasOwnProperty
 */

var has = Object.prototype.hasOwnProperty;

/**
 * Module exports
 */

module.exports = Manager;

/**
 * `Manager` constructor.
 *
 * @param {String} engine instance or engine uri/opts
 * @param {Object} options
 * @api public
 */

function Manager (uri, opts) {
  if (!(this instanceof Manager)) return new Manager(uri, opts);
  if (uri && ('object' === typeof uri)) {
    opts = uri;
    uri = undefined;
  }
  opts = opts || {};

  opts.path = opts.path || '/socket.io';
  this.nsps = {};
  this.subs = [];
  this.opts = opts;
  this.reconnection(opts.reconnection !== false);
  this.reconnectionAttempts(opts.reconnectionAttempts || Infinity);
  this.reconnectionDelay(opts.reconnectionDelay || 1000);
  this.reconnectionDelayMax(opts.reconnectionDelayMax || 5000);
  this.randomizationFactor(opts.randomizationFactor || 0.5);
  this.backoff = new Backoff({
    min: this.reconnectionDelay(),
    max: this.reconnectionDelayMax(),
    jitter: this.randomizationFactor()
  });
  this.timeout(null == opts.timeout ? 20000 : opts.timeout);
  this.readyState = 'closed';
  this.uri = uri;
  this.connecting = [];
  this.lastPing = null;
  this.encoding = false;
  this.packetBuffer = [];
  var _parser = opts.parser || parser;
  this.encoder = new _parser.Encoder();
  this.decoder = new _parser.Decoder();
  this.autoConnect = opts.autoConnect !== false;
  if (this.autoConnect) this.open();
}

/**
 * Propagate given event to sockets and emit on `this`
 *
 * @api private
 */

Manager.prototype.emitAll = function () {
  this.emit.apply(this, arguments);
  for (var nsp in this.nsps) {
    if (has.call(this.nsps, nsp)) {
      this.nsps[nsp].emit.apply(this.nsps[nsp], arguments);
    }
  }
};

/**
 * Update `socket.id` of all sockets
 *
 * @api private
 */

Manager.prototype.updateSocketIds = function () {
  for (var nsp in this.nsps) {
    if (has.call(this.nsps, nsp)) {
      this.nsps[nsp].id = this.generateId(nsp);
    }
  }
};

/**
 * generate `socket.id` for the given `nsp`
 *
 * @param {String} nsp
 * @return {String}
 * @api private
 */

Manager.prototype.generateId = function (nsp) {
  return (nsp === '/' ? '' : (nsp + '#')) + this.engine.id;
};

/**
 * Mix in `Emitter`.
 */

Emitter(Manager.prototype);

/**
 * Sets the `reconnection` config.
 *
 * @param {Boolean} true/false if it should automatically reconnect
 * @return {Manager} self or value
 * @api public
 */

Manager.prototype.reconnection = function (v) {
  if (!arguments.length) return this._reconnection;
  this._reconnection = !!v;
  return this;
};

/**
 * Sets the reconnection attempts config.
 *
 * @param {Number} max reconnection attempts before giving up
 * @return {Manager} self or value
 * @api public
 */

Manager.prototype.reconnectionAttempts = function (v) {
  if (!arguments.length) return this._reconnectionAttempts;
  this._reconnectionAttempts = v;
  return this;
};

/**
 * Sets the delay between reconnections.
 *
 * @param {Number} delay
 * @return {Manager} self or value
 * @api public
 */

Manager.prototype.reconnectionDelay = function (v) {
  if (!arguments.length) return this._reconnectionDelay;
  this._reconnectionDelay = v;
  this.backoff && this.backoff.setMin(v);
  return this;
};

Manager.prototype.randomizationFactor = function (v) {
  if (!arguments.length) return this._randomizationFactor;
  this._randomizationFactor = v;
  this.backoff && this.backoff.setJitter(v);
  return this;
};

/**
 * Sets the maximum delay between reconnections.
 *
 * @param {Number} delay
 * @return {Manager} self or value
 * @api public
 */

Manager.prototype.reconnectionDelayMax = function (v) {
  if (!arguments.length) return this._reconnectionDelayMax;
  this._reconnectionDelayMax = v;
  this.backoff && this.backoff.setMax(v);
  return this;
};

/**
 * Sets the connection timeout. `false` to disable
 *
 * @return {Manager} self or value
 * @api public
 */

Manager.prototype.timeout = function (v) {
  if (!arguments.length) return this._timeout;
  this._timeout = v;
  return this;
};

/**
 * Starts trying to reconnect if reconnection is enabled and we have not
 * started reconnecting yet
 *
 * @api private
 */

Manager.prototype.maybeReconnectOnOpen = function () {
  // Only try to reconnect if it's the first time we're connecting
  if (!this.reconnecting && this._reconnection && this.backoff.attempts === 0) {
    // keeps reconnection from firing twice for the same reconnection loop
    this.reconnect();
  }
};

/**
 * Sets the current transport `socket`.
 *
 * @param {Function} optional, callback
 * @return {Manager} self
 * @api public
 */

Manager.prototype.open =
Manager.prototype.connect = function (fn, opts) {
  debug('readyState %s', this.readyState);
  if (~this.readyState.indexOf('open')) return this;

  debug('opening %s', this.uri);
  this.engine = eio(this.uri, this.opts);
  var socket = this.engine;
  var self = this;
  this.readyState = 'opening';
  this.skipReconnect = false;

  // emit `open`
  var openSub = on(socket, 'open', function () {
    self.onopen();
    fn && fn();
  });

  // emit `connect_error`
  var errorSub = on(socket, 'error', function (data) {
    debug('connect_error');
    self.cleanup();
    self.readyState = 'closed';
    self.emitAll('connect_error', data);
    if (fn) {
      var err = new Error('Connection error');
      err.data = data;
      fn(err);
    } else {
      // Only do this if there is no fn to handle the error
      self.maybeReconnectOnOpen();
    }
  });

  // emit `connect_timeout`
  if (false !== this._timeout) {
    var timeout = this._timeout;
    debug('connect attempt will timeout after %d', timeout);

    // set timer
    var timer = setTimeout(function () {
      debug('connect attempt timed out after %d', timeout);
      openSub.destroy();
      socket.close();
      socket.emit('error', 'timeout');
      self.emitAll('connect_timeout', timeout);
    }, timeout);

    this.subs.push({
      destroy: function () {
        clearTimeout(timer);
      }
    });
  }

  this.subs.push(openSub);
  this.subs.push(errorSub);

  return this;
};

/**
 * Called upon transport open.
 *
 * @api private
 */

Manager.prototype.onopen = function () {
  debug('open');

  // clear old subs
  this.cleanup();

  // mark as open
  this.readyState = 'open';
  this.emit('open');

  // add new subs
  var socket = this.engine;
  this.subs.push(on(socket, 'data', bind(this, 'ondata')));
  this.subs.push(on(socket, 'ping', bind(this, 'onping')));
  this.subs.push(on(socket, 'pong', bind(this, 'onpong')));
  this.subs.push(on(socket, 'error', bind(this, 'onerror')));
  this.subs.push(on(socket, 'close', bind(this, 'onclose')));
  this.subs.push(on(this.decoder, 'decoded', bind(this, 'ondecoded')));
};

/**
 * Called upon a ping.
 *
 * @api private
 */

Manager.prototype.onping = function () {
  this.lastPing = new Date();
  this.emitAll('ping');
};

/**
 * Called upon a packet.
 *
 * @api private
 */

Manager.prototype.onpong = function () {
  this.emitAll('pong', new Date() - this.lastPing);
};

/**
 * Called with data.
 *
 * @api private
 */

Manager.prototype.ondata = function (data) {
  this.decoder.add(data);
};

/**
 * Called when parser fully decodes a packet.
 *
 * @api private
 */

Manager.prototype.ondecoded = function (packet) {
  this.emit('packet', packet);
};

/**
 * Called upon socket error.
 *
 * @api private
 */

Manager.prototype.onerror = function (err) {
  debug('error', err);
  this.emitAll('error', err);
};

/**
 * Creates a new socket for the given `nsp`.
 *
 * @return {Socket}
 * @api public
 */

Manager.prototype.socket = function (nsp, opts) {
  var socket = this.nsps[nsp];
  if (!socket) {
    socket = new Socket(this, nsp, opts);
    this.nsps[nsp] = socket;
    var self = this;
    socket.on('connecting', onConnecting);
    socket.on('connect', function () {
      socket.id = self.generateId(nsp);
    });

    if (this.autoConnect) {
      // manually call here since connecting event is fired before listening
      onConnecting();
    }
  }

  function onConnecting () {
    if (!~indexOf(self.connecting, socket)) {
      self.connecting.push(socket);
    }
  }

  return socket;
};

/**
 * Called upon a socket close.
 *
 * @param {Socket} socket
 */

Manager.prototype.destroy = function (socket) {
  var index = indexOf(this.connecting, socket);
  if (~index) this.connecting.splice(index, 1);
  if (this.connecting.length) return;

  this.close();
};

/**
 * Writes a packet.
 *
 * @param {Object} packet
 * @api private
 */

Manager.prototype.packet = function (packet) {
  debug('writing packet %j', packet);
  var self = this;
  if (packet.query && packet.type === 0) packet.nsp += '?' + packet.query;

  if (!self.encoding) {
    // encode, then write to engine with result
    self.encoding = true;
    this.encoder.encode(packet, function (encodedPackets) {
      for (var i = 0; i < encodedPackets.length; i++) {
        self.engine.write(encodedPackets[i], packet.options);
      }
      self.encoding = false;
      self.processPacketQueue();
    });
  } else { // add packet to the queue
    self.packetBuffer.push(packet);
  }
};

/**
 * If packet buffer is non-empty, begins encoding the
 * next packet in line.
 *
 * @api private
 */

Manager.prototype.processPacketQueue = function () {
  if (this.packetBuffer.length > 0 && !this.encoding) {
    var pack = this.packetBuffer.shift();
    this.packet(pack);
  }
};

/**
 * Clean up transport subscriptions and packet buffer.
 *
 * @api private
 */

Manager.prototype.cleanup = function () {
  debug('cleanup');

  var subsLength = this.subs.length;
  for (var i = 0; i < subsLength; i++) {
    var sub = this.subs.shift();
    sub.destroy();
  }

  this.packetBuffer = [];
  this.encoding = false;
  this.lastPing = null;

  this.decoder.destroy();
};

/**
 * Close the current socket.
 *
 * @api private
 */

Manager.prototype.close =
Manager.prototype.disconnect = function () {
  debug('disconnect');
  this.skipReconnect = true;
  this.reconnecting = false;
  if ('opening' === this.readyState) {
    // `onclose` will not fire because
    // an open event never happened
    this.cleanup();
  }
  this.backoff.reset();
  this.readyState = 'closed';
  if (this.engine) this.engine.close();
};

/**
 * Called upon engine close.
 *
 * @api private
 */

Manager.prototype.onclose = function (reason) {
  debug('onclose');

  this.cleanup();
  this.backoff.reset();
  this.readyState = 'closed';
  this.emit('close', reason);

  if (this._reconnection && !this.skipReconnect) {
    this.reconnect();
  }
};

/**
 * Attempt a reconnection.
 *
 * @api private
 */

Manager.prototype.reconnect = function () {
  if (this.reconnecting || this.skipReconnect) return this;

  var self = this;

  if (this.backoff.attempts >= this._reconnectionAttempts) {
    debug('reconnect failed');
    this.backoff.reset();
    this.emitAll('reconnect_failed');
    this.reconnecting = false;
  } else {
    var delay = this.backoff.duration();
    debug('will wait %dms before reconnect attempt', delay);

    this.reconnecting = true;
    var timer = setTimeout(function () {
      if (self.skipReconnect) return;

      debug('attempting reconnect');
      self.emitAll('reconnect_attempt', self.backoff.attempts);
      self.emitAll('reconnecting', self.backoff.attempts);

      // check again for the case socket closed in above events
      if (self.skipReconnect) return;

      self.open(function (err) {
        if (err) {
          debug('reconnect attempt error');
          self.reconnecting = false;
          self.reconnect();
          self.emitAll('reconnect_error', err.data);
        } else {
          debug('reconnect success');
          self.onreconnect();
        }
      });
    }, delay);

    this.subs.push({
      destroy: function () {
        clearTimeout(timer);
      }
    });
  }
};

/**
 * Called upon successful reconnect.
 *
 * @api private
 */

Manager.prototype.onreconnect = function () {
  var attempt = this.backoff.attempts;
  this.reconnecting = false;
  this.backoff.reset();
  this.updateSocketIds();
  this.emitAll('reconnect', attempt);
};


/***/ }),

/***/ 93073:
/***/ (function(module) {


/**
 * Module exports.
 */

module.exports = on;

/**
 * Helper for subscriptions.
 *
 * @param {Object|EventEmitter} obj with `Emitter` mixin or `EventEmitter`
 * @param {String} event name
 * @param {Function} callback
 * @api public
 */

function on (obj, ev, fn) {
  obj.on(ev, fn);
  return {
    destroy: function () {
      obj.removeListener(ev, fn);
    }
  };
}


/***/ }),

/***/ 72243:
/***/ (function(module, exports, __webpack_require__) {


/**
 * Module dependencies.
 */

var parser = __webpack_require__(87170);
var Emitter = __webpack_require__(8023);
var toArray = __webpack_require__(81396);
var on = __webpack_require__(93073);
var bind = __webpack_require__(42150);
var debug = __webpack_require__(31035)('socket.io-client:socket');
var parseqs = __webpack_require__(54355);
var hasBin = __webpack_require__(54632);

/**
 * Module exports.
 */

module.exports = exports = Socket;

/**
 * Internal events (blacklisted).
 * These events can't be emitted by the user.
 *
 * @api private
 */

var events = {
  connect: 1,
  connect_error: 1,
  connect_timeout: 1,
  connecting: 1,
  disconnect: 1,
  error: 1,
  reconnect: 1,
  reconnect_attempt: 1,
  reconnect_failed: 1,
  reconnect_error: 1,
  reconnecting: 1,
  ping: 1,
  pong: 1
};

/**
 * Shortcut to `Emitter#emit`.
 */

var emit = Emitter.prototype.emit;

/**
 * `Socket` constructor.
 *
 * @api public
 */

function Socket (io, nsp, opts) {
  this.io = io;
  this.nsp = nsp;
  this.json = this; // compat
  this.ids = 0;
  this.acks = {};
  this.receiveBuffer = [];
  this.sendBuffer = [];
  this.connected = false;
  this.disconnected = true;
  this.flags = {};
  if (opts && opts.query) {
    this.query = opts.query;
  }
  if (this.io.autoConnect) this.open();
}

/**
 * Mix in `Emitter`.
 */

Emitter(Socket.prototype);

/**
 * Subscribe to open, close and packet events
 *
 * @api private
 */

Socket.prototype.subEvents = function () {
  if (this.subs) return;

  var io = this.io;
  this.subs = [
    on(io, 'open', bind(this, 'onopen')),
    on(io, 'packet', bind(this, 'onpacket')),
    on(io, 'close', bind(this, 'onclose'))
  ];
};

/**
 * "Opens" the socket.
 *
 * @api public
 */

Socket.prototype.open =
Socket.prototype.connect = function () {
  if (this.connected) return this;

  this.subEvents();
  this.io.open(); // ensure open
  if ('open' === this.io.readyState) this.onopen();
  this.emit('connecting');
  return this;
};

/**
 * Sends a `message` event.
 *
 * @return {Socket} self
 * @api public
 */

Socket.prototype.send = function () {
  var args = toArray(arguments);
  args.unshift('message');
  this.emit.apply(this, args);
  return this;
};

/**
 * Override `emit`.
 * If the event is in `events`, it's emitted normally.
 *
 * @param {String} event name
 * @return {Socket} self
 * @api public
 */

Socket.prototype.emit = function (ev) {
  if (events.hasOwnProperty(ev)) {
    emit.apply(this, arguments);
    return this;
  }

  var args = toArray(arguments);
  var packet = {
    type: (this.flags.binary !== undefined ? this.flags.binary : hasBin(args)) ? parser.BINARY_EVENT : parser.EVENT,
    data: args
  };

  packet.options = {};
  packet.options.compress = !this.flags || false !== this.flags.compress;

  // event ack callback
  if ('function' === typeof args[args.length - 1]) {
    debug('emitting packet with ack id %d', this.ids);
    this.acks[this.ids] = args.pop();
    packet.id = this.ids++;
  }

  if (this.connected) {
    this.packet(packet);
  } else {
    this.sendBuffer.push(packet);
  }

  this.flags = {};

  return this;
};

/**
 * Sends a packet.
 *
 * @param {Object} packet
 * @api private
 */

Socket.prototype.packet = function (packet) {
  packet.nsp = this.nsp;
  this.io.packet(packet);
};

/**
 * Called upon engine `open`.
 *
 * @api private
 */

Socket.prototype.onopen = function () {
  debug('transport is open - connecting');

  // write connect packet if necessary
  if ('/' !== this.nsp) {
    if (this.query) {
      var query = typeof this.query === 'object' ? parseqs.encode(this.query) : this.query;
      debug('sending connect packet with query %s', query);
      this.packet({type: parser.CONNECT, query: query});
    } else {
      this.packet({type: parser.CONNECT});
    }
  }
};

/**
 * Called upon engine `close`.
 *
 * @param {String} reason
 * @api private
 */

Socket.prototype.onclose = function (reason) {
  debug('close (%s)', reason);
  this.connected = false;
  this.disconnected = true;
  delete this.id;
  this.emit('disconnect', reason);
};

/**
 * Called with socket packet.
 *
 * @param {Object} packet
 * @api private
 */

Socket.prototype.onpacket = function (packet) {
  var sameNamespace = packet.nsp === this.nsp;
  var rootNamespaceError = packet.type === parser.ERROR && packet.nsp === '/';

  if (!sameNamespace && !rootNamespaceError) return;

  switch (packet.type) {
    case parser.CONNECT:
      this.onconnect();
      break;

    case parser.EVENT:
      this.onevent(packet);
      break;

    case parser.BINARY_EVENT:
      this.onevent(packet);
      break;

    case parser.ACK:
      this.onack(packet);
      break;

    case parser.BINARY_ACK:
      this.onack(packet);
      break;

    case parser.DISCONNECT:
      this.ondisconnect();
      break;

    case parser.ERROR:
      this.emit('error', packet.data);
      break;
  }
};

/**
 * Called upon a server event.
 *
 * @param {Object} packet
 * @api private
 */

Socket.prototype.onevent = function (packet) {
  var args = packet.data || [];
  debug('emitting event %j', args);

  if (null != packet.id) {
    debug('attaching ack callback to event');
    args.push(this.ack(packet.id));
  }

  if (this.connected) {
    emit.apply(this, args);
  } else {
    this.receiveBuffer.push(args);
  }
};

/**
 * Produces an ack callback to emit with an event.
 *
 * @api private
 */

Socket.prototype.ack = function (id) {
  var self = this;
  var sent = false;
  return function () {
    // prevent double callbacks
    if (sent) return;
    sent = true;
    var args = toArray(arguments);
    debug('sending ack %j', args);

    self.packet({
      type: hasBin(args) ? parser.BINARY_ACK : parser.ACK,
      id: id,
      data: args
    });
  };
};

/**
 * Called upon a server acknowlegement.
 *
 * @param {Object} packet
 * @api private
 */

Socket.prototype.onack = function (packet) {
  var ack = this.acks[packet.id];
  if ('function' === typeof ack) {
    debug('calling ack %s with %j', packet.id, packet.data);
    ack.apply(this, packet.data);
    delete this.acks[packet.id];
  } else {
    debug('bad ack %s', packet.id);
  }
};

/**
 * Called upon server connect.
 *
 * @api private
 */

Socket.prototype.onconnect = function () {
  this.connected = true;
  this.disconnected = false;
  this.emit('connect');
  this.emitBuffered();
};

/**
 * Emit buffered events (received and emitted).
 *
 * @api private
 */

Socket.prototype.emitBuffered = function () {
  var i;
  for (i = 0; i < this.receiveBuffer.length; i++) {
    emit.apply(this, this.receiveBuffer[i]);
  }
  this.receiveBuffer = [];

  for (i = 0; i < this.sendBuffer.length; i++) {
    this.packet(this.sendBuffer[i]);
  }
  this.sendBuffer = [];
};

/**
 * Called upon server disconnect.
 *
 * @api private
 */

Socket.prototype.ondisconnect = function () {
  debug('server disconnect (%s)', this.nsp);
  this.destroy();
  this.onclose('io server disconnect');
};

/**
 * Called upon forced client/server side disconnections,
 * this method ensures the manager stops tracking us and
 * that reconnections don't get triggered for this.
 *
 * @api private.
 */

Socket.prototype.destroy = function () {
  if (this.subs) {
    // clean subscriptions to avoid reconnections
    for (var i = 0; i < this.subs.length; i++) {
      this.subs[i].destroy();
    }
    this.subs = null;
  }

  this.io.destroy(this);
};

/**
 * Disconnects the socket manually.
 *
 * @return {Socket} self
 * @api public
 */

Socket.prototype.close =
Socket.prototype.disconnect = function () {
  if (this.connected) {
    debug('performing disconnect (%s)', this.nsp);
    this.packet({ type: parser.DISCONNECT });
  }

  // remove socket from pool
  this.destroy();

  if (this.connected) {
    // fire events
    this.onclose('io client disconnect');
  }
  return this;
};

/**
 * Sets the compress flag.
 *
 * @param {Boolean} if `true`, compresses the sending data
 * @return {Socket} self
 * @api public
 */

Socket.prototype.compress = function (compress) {
  this.flags.compress = compress;
  return this;
};

/**
 * Sets the binary flag
 *
 * @param {Boolean} whether the emitted data contains binary
 * @return {Socket} self
 * @api public
 */

Socket.prototype.binary = function (binary) {
  this.flags.binary = binary;
  return this;
};


/***/ }),

/***/ 58749:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {


/**
 * Module dependencies.
 */

var parseuri = __webpack_require__(14243);
var debug = __webpack_require__(31035)('socket.io-client:url');

/**
 * Module exports.
 */

module.exports = url;

/**
 * URL parser.
 *
 * @param {String} url
 * @param {Object} An object meant to mimic window.location.
 *                 Defaults to window.location.
 * @api public
 */

function url (uri, loc) {
  var obj = uri;

  // default to window.location
  loc = loc || (typeof location !== 'undefined' && location);
  if (null == uri) uri = loc.protocol + '//' + loc.host;

  // relative path support
  if ('string' === typeof uri) {
    if ('/' === uri.charAt(0)) {
      if ('/' === uri.charAt(1)) {
        uri = loc.protocol + uri;
      } else {
        uri = loc.host + uri;
      }
    }

    if (!/^(https?|wss?):\/\//.test(uri)) {
      debug('protocol-less url %s', uri);
      if ('undefined' !== typeof loc) {
        uri = loc.protocol + '//' + uri;
      } else {
        uri = 'https://' + uri;
      }
    }

    // parse
    debug('parse %s', uri);
    obj = parseuri(uri);
  }

  // make sure we treat `localhost:80` and `localhost` equally
  if (!obj.port) {
    if (/^(http|ws)$/.test(obj.protocol)) {
      obj.port = '80';
    } else if (/^(http|ws)s$/.test(obj.protocol)) {
      obj.port = '443';
    }
  }

  obj.path = obj.path || '/';

  var ipv6 = obj.host.indexOf(':') !== -1;
  var host = ipv6 ? '[' + obj.host + ']' : obj.host;

  // define unique id
  obj.id = obj.protocol + '://' + host + ':' + obj.port;
  // define href
  obj.href = obj.protocol + '://' + host + (loc && loc.port === obj.port ? '' : (':' + obj.port));

  return obj;
}


/***/ }),

/***/ 8023:
/***/ (function(module) {


/**
 * Expose `Emitter`.
 */

if (true) {
  module.exports = Emitter;
}

/**
 * Initialize a new `Emitter`.
 *
 * @api public
 */

function Emitter(obj) {
  if (obj) return mixin(obj);
};

/**
 * Mixin the emitter properties.
 *
 * @param {Object} obj
 * @return {Object}
 * @api private
 */

function mixin(obj) {
  for (var key in Emitter.prototype) {
    obj[key] = Emitter.prototype[key];
  }
  return obj;
}

/**
 * Listen on the given `event` with `fn`.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Emitter}
 * @api public
 */

Emitter.prototype.on =
Emitter.prototype.addEventListener = function(event, fn){
  this._callbacks = this._callbacks || {};
  (this._callbacks['$' + event] = this._callbacks['$' + event] || [])
    .push(fn);
  return this;
};

/**
 * Adds an `event` listener that will be invoked a single
 * time then automatically removed.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Emitter}
 * @api public
 */

Emitter.prototype.once = function(event, fn){
  function on() {
    this.off(event, on);
    fn.apply(this, arguments);
  }

  on.fn = fn;
  this.on(event, on);
  return this;
};

/**
 * Remove the given callback for `event` or all
 * registered callbacks.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Emitter}
 * @api public
 */

Emitter.prototype.off =
Emitter.prototype.removeListener =
Emitter.prototype.removeAllListeners =
Emitter.prototype.removeEventListener = function(event, fn){
  this._callbacks = this._callbacks || {};

  // all
  if (0 == arguments.length) {
    this._callbacks = {};
    return this;
  }

  // specific event
  var callbacks = this._callbacks['$' + event];
  if (!callbacks) return this;

  // remove all handlers
  if (1 == arguments.length) {
    delete this._callbacks['$' + event];
    return this;
  }

  // remove specific handler
  var cb;
  for (var i = 0; i < callbacks.length; i++) {
    cb = callbacks[i];
    if (cb === fn || cb.fn === fn) {
      callbacks.splice(i, 1);
      break;
    }
  }
  return this;
};

/**
 * Emit `event` with the given args.
 *
 * @param {String} event
 * @param {Mixed} ...
 * @return {Emitter}
 */

Emitter.prototype.emit = function(event){
  this._callbacks = this._callbacks || {};
  var args = [].slice.call(arguments, 1)
    , callbacks = this._callbacks['$' + event];

  if (callbacks) {
    callbacks = callbacks.slice(0);
    for (var i = 0, len = callbacks.length; i < len; ++i) {
      callbacks[i].apply(this, args);
    }
  }

  return this;
};

/**
 * Return array of callbacks for `event`.
 *
 * @param {String} event
 * @return {Array}
 * @api public
 */

Emitter.prototype.listeners = function(event){
  this._callbacks = this._callbacks || {};
  return this._callbacks['$' + event] || [];
};

/**
 * Check if this emitter has `event` handlers.
 *
 * @param {String} event
 * @return {Boolean}
 * @api public
 */

Emitter.prototype.hasListeners = function(event){
  return !! this.listeners(event).length;
};


/***/ }),

/***/ 54146:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

/*global Blob,File*/

/**
 * Module requirements
 */

var isArray = __webpack_require__(81708);
var isBuf = __webpack_require__(24787);
var toString = Object.prototype.toString;
var withNativeBlob = typeof Blob === 'function' || (typeof Blob !== 'undefined' && toString.call(Blob) === '[object BlobConstructor]');
var withNativeFile = typeof File === 'function' || (typeof File !== 'undefined' && toString.call(File) === '[object FileConstructor]');

/**
 * Replaces every Buffer | ArrayBuffer in packet with a numbered placeholder.
 * Anything with blobs or files should be fed through removeBlobs before coming
 * here.
 *
 * @param {Object} packet - socket.io event packet
 * @return {Object} with deconstructed packet and list of buffers
 * @api public
 */

exports.deconstructPacket = function(packet) {
  var buffers = [];
  var packetData = packet.data;
  var pack = packet;
  pack.data = _deconstructPacket(packetData, buffers);
  pack.attachments = buffers.length; // number of binary 'attachments'
  return {packet: pack, buffers: buffers};
};

function _deconstructPacket(data, buffers) {
  if (!data) return data;

  if (isBuf(data)) {
    var placeholder = { _placeholder: true, num: buffers.length };
    buffers.push(data);
    return placeholder;
  } else if (isArray(data)) {
    var newData = new Array(data.length);
    for (var i = 0; i < data.length; i++) {
      newData[i] = _deconstructPacket(data[i], buffers);
    }
    return newData;
  } else if (typeof data === 'object' && !(data instanceof Date)) {
    var newData = {};
    for (var key in data) {
      newData[key] = _deconstructPacket(data[key], buffers);
    }
    return newData;
  }
  return data;
}

/**
 * Reconstructs a binary packet from its placeholder packet and buffers
 *
 * @param {Object} packet - event packet with placeholders
 * @param {Array} buffers - binary buffers to put in placeholder positions
 * @return {Object} reconstructed packet
 * @api public
 */

exports.reconstructPacket = function(packet, buffers) {
  packet.data = _reconstructPacket(packet.data, buffers);
  packet.attachments = undefined; // no longer useful
  return packet;
};

function _reconstructPacket(data, buffers) {
  if (!data) return data;

  if (data && data._placeholder) {
    return buffers[data.num]; // appropriate buffer (should be natural order anyway)
  } else if (isArray(data)) {
    for (var i = 0; i < data.length; i++) {
      data[i] = _reconstructPacket(data[i], buffers);
    }
  } else if (typeof data === 'object') {
    for (var key in data) {
      data[key] = _reconstructPacket(data[key], buffers);
    }
  }

  return data;
}

/**
 * Asynchronously removes Blobs or Files from data via
 * FileReader's readAsArrayBuffer method. Used before encoding
 * data as msgpack. Calls callback with the blobless data.
 *
 * @param {Object} data
 * @param {Function} callback
 * @api private
 */

exports.removeBlobs = function(data, callback) {
  function _removeBlobs(obj, curKey, containingObject) {
    if (!obj) return obj;

    // convert any blob
    if ((withNativeBlob && obj instanceof Blob) ||
        (withNativeFile && obj instanceof File)) {
      pendingBlobs++;

      // async filereader
      var fileReader = new FileReader();
      fileReader.onload = function() { // this.result == arraybuffer
        if (containingObject) {
          containingObject[curKey] = this.result;
        }
        else {
          bloblessData = this.result;
        }

        // if nothing pending its callback time
        if(! --pendingBlobs) {
          callback(bloblessData);
        }
      };

      fileReader.readAsArrayBuffer(obj); // blob -> arraybuffer
    } else if (isArray(obj)) { // handle array
      for (var i = 0; i < obj.length; i++) {
        _removeBlobs(obj[i], i, obj);
      }
    } else if (typeof obj === 'object' && !isBuf(obj)) { // and object
      for (var key in obj) {
        _removeBlobs(obj[key], key, obj);
      }
    }
  }

  var pendingBlobs = 0;
  var bloblessData = data;
  _removeBlobs(bloblessData);
  if (!pendingBlobs) {
    callback(bloblessData);
  }
};


/***/ }),

/***/ 87170:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {


/**
 * Module dependencies.
 */

var debug = __webpack_require__(40744)('socket.io-parser');
var Emitter = __webpack_require__(2679);
var binary = __webpack_require__(54146);
var isArray = __webpack_require__(81708);
var isBuf = __webpack_require__(24787);

/**
 * Protocol version.
 *
 * @api public
 */

exports.protocol = 4;

/**
 * Packet types.
 *
 * @api public
 */

exports.types = [
  'CONNECT',
  'DISCONNECT',
  'EVENT',
  'ACK',
  'ERROR',
  'BINARY_EVENT',
  'BINARY_ACK'
];

/**
 * Packet type `connect`.
 *
 * @api public
 */

exports.CONNECT = 0;

/**
 * Packet type `disconnect`.
 *
 * @api public
 */

exports.DISCONNECT = 1;

/**
 * Packet type `event`.
 *
 * @api public
 */

exports.EVENT = 2;

/**
 * Packet type `ack`.
 *
 * @api public
 */

exports.ACK = 3;

/**
 * Packet type `error`.
 *
 * @api public
 */

exports.ERROR = 4;

/**
 * Packet type 'binary event'
 *
 * @api public
 */

exports.BINARY_EVENT = 5;

/**
 * Packet type `binary ack`. For acks with binary arguments.
 *
 * @api public
 */

exports.BINARY_ACK = 6;

/**
 * Encoder constructor.
 *
 * @api public
 */

exports.Encoder = Encoder;

/**
 * Decoder constructor.
 *
 * @api public
 */

exports.Decoder = Decoder;

/**
 * A socket.io Encoder instance
 *
 * @api public
 */

function Encoder() {}

var ERROR_PACKET = exports.ERROR + '"encode error"';

/**
 * Encode a packet as a single string if non-binary, or as a
 * buffer sequence, depending on packet type.
 *
 * @param {Object} obj - packet object
 * @param {Function} callback - function to handle encodings (likely engine.write)
 * @return Calls callback with Array of encodings
 * @api public
 */

Encoder.prototype.encode = function(obj, callback){
  debug('encoding packet %j', obj);

  if (exports.BINARY_EVENT === obj.type || exports.BINARY_ACK === obj.type) {
    encodeAsBinary(obj, callback);
  } else {
    var encoding = encodeAsString(obj);
    callback([encoding]);
  }
};

/**
 * Encode packet as string.
 *
 * @param {Object} packet
 * @return {String} encoded
 * @api private
 */

function encodeAsString(obj) {

  // first is type
  var str = '' + obj.type;

  // attachments if we have them
  if (exports.BINARY_EVENT === obj.type || exports.BINARY_ACK === obj.type) {
    str += obj.attachments + '-';
  }

  // if we have a namespace other than `/`
  // we append it followed by a comma `,`
  if (obj.nsp && '/' !== obj.nsp) {
    str += obj.nsp + ',';
  }

  // immediately followed by the id
  if (null != obj.id) {
    str += obj.id;
  }

  // json data
  if (null != obj.data) {
    var payload = tryStringify(obj.data);
    if (payload !== false) {
      str += payload;
    } else {
      return ERROR_PACKET;
    }
  }

  debug('encoded %j as %s', obj, str);
  return str;
}

function tryStringify(str) {
  try {
    return JSON.stringify(str);
  } catch(e){
    return false;
  }
}

/**
 * Encode packet as 'buffer sequence' by removing blobs, and
 * deconstructing packet into object with placeholders and
 * a list of buffers.
 *
 * @param {Object} packet
 * @return {Buffer} encoded
 * @api private
 */

function encodeAsBinary(obj, callback) {

  function writeEncoding(bloblessData) {
    var deconstruction = binary.deconstructPacket(bloblessData);
    var pack = encodeAsString(deconstruction.packet);
    var buffers = deconstruction.buffers;

    buffers.unshift(pack); // add packet info to beginning of data list
    callback(buffers); // write all the buffers
  }

  binary.removeBlobs(obj, writeEncoding);
}

/**
 * A socket.io Decoder instance
 *
 * @return {Object} decoder
 * @api public
 */

function Decoder() {
  this.reconstructor = null;
}

/**
 * Mix in `Emitter` with Decoder.
 */

Emitter(Decoder.prototype);

/**
 * Decodes an encoded packet string into packet JSON.
 *
 * @param {String} obj - encoded packet
 * @return {Object} packet
 * @api public
 */

Decoder.prototype.add = function(obj) {
  var packet;
  if (typeof obj === 'string') {
    packet = decodeString(obj);
    if (exports.BINARY_EVENT === packet.type || exports.BINARY_ACK === packet.type) { // binary packet's json
      this.reconstructor = new BinaryReconstructor(packet);

      // no attachments, labeled binary but no binary data to follow
      if (this.reconstructor.reconPack.attachments === 0) {
        this.emit('decoded', packet);
      }
    } else { // non-binary full packet
      this.emit('decoded', packet);
    }
  } else if (isBuf(obj) || obj.base64) { // raw binary data
    if (!this.reconstructor) {
      throw new Error('got binary data when not reconstructing a packet');
    } else {
      packet = this.reconstructor.takeBinaryData(obj);
      if (packet) { // received final buffer
        this.reconstructor = null;
        this.emit('decoded', packet);
      }
    }
  } else {
    throw new Error('Unknown type: ' + obj);
  }
};

/**
 * Decode a packet String (JSON data)
 *
 * @param {String} str
 * @return {Object} packet
 * @api private
 */

function decodeString(str) {
  var i = 0;
  // look up type
  var p = {
    type: Number(str.charAt(0))
  };

  if (null == exports.types[p.type]) {
    return error('unknown packet type ' + p.type);
  }

  // look up attachments if type binary
  if (exports.BINARY_EVENT === p.type || exports.BINARY_ACK === p.type) {
    var buf = '';
    while (str.charAt(++i) !== '-') {
      buf += str.charAt(i);
      if (i == str.length) break;
    }
    if (buf != Number(buf) || str.charAt(i) !== '-') {
      throw new Error('Illegal attachments');
    }
    p.attachments = Number(buf);
  }

  // look up namespace (if any)
  if ('/' === str.charAt(i + 1)) {
    p.nsp = '';
    while (++i) {
      var c = str.charAt(i);
      if (',' === c) break;
      p.nsp += c;
      if (i === str.length) break;
    }
  } else {
    p.nsp = '/';
  }

  // look up id
  var next = str.charAt(i + 1);
  if ('' !== next && Number(next) == next) {
    p.id = '';
    while (++i) {
      var c = str.charAt(i);
      if (null == c || Number(c) != c) {
        --i;
        break;
      }
      p.id += str.charAt(i);
      if (i === str.length) break;
    }
    p.id = Number(p.id);
  }

  // look up json data
  if (str.charAt(++i)) {
    var payload = tryParse(str.substr(i));
    var isPayloadValid = payload !== false && (p.type === exports.ERROR || isArray(payload));
    if (isPayloadValid) {
      p.data = payload;
    } else {
      return error('invalid payload');
    }
  }

  debug('decoded %s as %j', str, p);
  return p;
}

function tryParse(str) {
  try {
    return JSON.parse(str);
  } catch(e){
    return false;
  }
}

/**
 * Deallocates a parser's resources
 *
 * @api public
 */

Decoder.prototype.destroy = function() {
  if (this.reconstructor) {
    this.reconstructor.finishedReconstruction();
  }
};

/**
 * A manager of a binary event's 'buffer sequence'. Should
 * be constructed whenever a packet of type BINARY_EVENT is
 * decoded.
 *
 * @param {Object} packet
 * @return {BinaryReconstructor} initialized reconstructor
 * @api private
 */

function BinaryReconstructor(packet) {
  this.reconPack = packet;
  this.buffers = [];
}

/**
 * Method to be called when binary data received from connection
 * after a BINARY_EVENT packet.
 *
 * @param {Buffer | ArrayBuffer} binData - the raw binary data received
 * @return {null | Object} returns null if more binary data is expected or
 *   a reconstructed packet object if all buffers have been received.
 * @api private
 */

BinaryReconstructor.prototype.takeBinaryData = function(binData) {
  this.buffers.push(binData);
  if (this.buffers.length === this.reconPack.attachments) { // done with buffer list
    var packet = binary.reconstructPacket(this.reconPack, this.buffers);
    this.finishedReconstruction();
    return packet;
  }
  return null;
};

/**
 * Cleans up binary packet reconstruction variables.
 *
 * @api private
 */

BinaryReconstructor.prototype.finishedReconstruction = function() {
  this.reconPack = null;
  this.buffers = [];
};

function error(msg) {
  return {
    type: exports.ERROR,
    data: 'parser error: ' + msg
  };
}


/***/ }),

/***/ 24787:
/***/ (function(module) {


module.exports = isBuf;

var withNativeBuffer = typeof Buffer === 'function' && typeof Buffer.isBuffer === 'function';
var withNativeArrayBuffer = typeof ArrayBuffer === 'function';

var isView = function (obj) {
  return typeof ArrayBuffer.isView === 'function' ? ArrayBuffer.isView(obj) : (obj.buffer instanceof ArrayBuffer);
};

/**
 * Returns true if obj is a buffer or an arraybuffer.
 *
 * @api private
 */

function isBuf(obj) {
  return (withNativeBuffer && Buffer.isBuffer(obj)) ||
          (withNativeArrayBuffer && (obj instanceof ArrayBuffer || isView(obj)));
}


/***/ }),

/***/ 2679:
/***/ (function(module) {


/**
 * Expose `Emitter`.
 */

if (true) {
  module.exports = Emitter;
}

/**
 * Initialize a new `Emitter`.
 *
 * @api public
 */

function Emitter(obj) {
  if (obj) return mixin(obj);
};

/**
 * Mixin the emitter properties.
 *
 * @param {Object} obj
 * @return {Object}
 * @api private
 */

function mixin(obj) {
  for (var key in Emitter.prototype) {
    obj[key] = Emitter.prototype[key];
  }
  return obj;
}

/**
 * Listen on the given `event` with `fn`.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Emitter}
 * @api public
 */

Emitter.prototype.on =
Emitter.prototype.addEventListener = function(event, fn){
  this._callbacks = this._callbacks || {};
  (this._callbacks['$' + event] = this._callbacks['$' + event] || [])
    .push(fn);
  return this;
};

/**
 * Adds an `event` listener that will be invoked a single
 * time then automatically removed.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Emitter}
 * @api public
 */

Emitter.prototype.once = function(event, fn){
  function on() {
    this.off(event, on);
    fn.apply(this, arguments);
  }

  on.fn = fn;
  this.on(event, on);
  return this;
};

/**
 * Remove the given callback for `event` or all
 * registered callbacks.
 *
 * @param {String} event
 * @param {Function} fn
 * @return {Emitter}
 * @api public
 */

Emitter.prototype.off =
Emitter.prototype.removeListener =
Emitter.prototype.removeAllListeners =
Emitter.prototype.removeEventListener = function(event, fn){
  this._callbacks = this._callbacks || {};

  // all
  if (0 == arguments.length) {
    this._callbacks = {};
    return this;
  }

  // specific event
  var callbacks = this._callbacks['$' + event];
  if (!callbacks) return this;

  // remove all handlers
  if (1 == arguments.length) {
    delete this._callbacks['$' + event];
    return this;
  }

  // remove specific handler
  var cb;
  for (var i = 0; i < callbacks.length; i++) {
    cb = callbacks[i];
    if (cb === fn || cb.fn === fn) {
      callbacks.splice(i, 1);
      break;
    }
  }
  return this;
};

/**
 * Emit `event` with the given args.
 *
 * @param {String} event
 * @param {Mixed} ...
 * @return {Emitter}
 */

Emitter.prototype.emit = function(event){
  this._callbacks = this._callbacks || {};
  var args = [].slice.call(arguments, 1)
    , callbacks = this._callbacks['$' + event];

  if (callbacks) {
    callbacks = callbacks.slice(0);
    for (var i = 0, len = callbacks.length; i < len; ++i) {
      callbacks[i].apply(this, args);
    }
  }

  return this;
};

/**
 * Return array of callbacks for `event`.
 *
 * @param {String} event
 * @return {Array}
 * @api public
 */

Emitter.prototype.listeners = function(event){
  this._callbacks = this._callbacks || {};
  return this._callbacks['$' + event] || [];
};

/**
 * Check if this emitter has `event` handlers.
 *
 * @param {String} event
 * @return {Boolean}
 * @api public
 */

Emitter.prototype.hasListeners = function(event){
  return !! this.listeners(event).length;
};


/***/ }),

/***/ 81708:
/***/ (function(module) {

var toString = {}.toString;

module.exports = Array.isArray || function (arr) {
  return toString.call(arr) == '[object Array]';
};


/***/ }),

/***/ 73160:
/***/ (function(module) {

/**
 * Helpers.
 */

var s = 1000;
var m = s * 60;
var h = m * 60;
var d = h * 24;
var y = d * 365.25;

/**
 * Parse or format the given `val`.
 *
 * Options:
 *
 *  - `long` verbose formatting [false]
 *
 * @param {String|Number} val
 * @param {Object} [options]
 * @throws {Error} throw an error if val is not a non-empty string or a number
 * @return {String|Number}
 * @api public
 */

module.exports = function(val, options) {
  options = options || {};
  var type = typeof val;
  if (type === 'string' && val.length > 0) {
    return parse(val);
  } else if (type === 'number' && isNaN(val) === false) {
    return options.long ? fmtLong(val) : fmtShort(val);
  }
  throw new Error(
    'val is not a non-empty string or a valid number. val=' +
      JSON.stringify(val)
  );
};

/**
 * Parse the given `str` and return milliseconds.
 *
 * @param {String} str
 * @return {Number}
 * @api private
 */

function parse(str) {
  str = String(str);
  if (str.length > 100) {
    return;
  }
  var match = /^((?:\d+)?\.?\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|years?|yrs?|y)?$/i.exec(
    str
  );
  if (!match) {
    return;
  }
  var n = parseFloat(match[1]);
  var type = (match[2] || 'ms').toLowerCase();
  switch (type) {
    case 'years':
    case 'year':
    case 'yrs':
    case 'yr':
    case 'y':
      return n * y;
    case 'days':
    case 'day':
    case 'd':
      return n * d;
    case 'hours':
    case 'hour':
    case 'hrs':
    case 'hr':
    case 'h':
      return n * h;
    case 'minutes':
    case 'minute':
    case 'mins':
    case 'min':
    case 'm':
      return n * m;
    case 'seconds':
    case 'second':
    case 'secs':
    case 'sec':
    case 's':
      return n * s;
    case 'milliseconds':
    case 'millisecond':
    case 'msecs':
    case 'msec':
    case 'ms':
      return n;
    default:
      return undefined;
  }
}

/**
 * Short format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function fmtShort(ms) {
  if (ms >= d) {
    return Math.round(ms / d) + 'd';
  }
  if (ms >= h) {
    return Math.round(ms / h) + 'h';
  }
  if (ms >= m) {
    return Math.round(ms / m) + 'm';
  }
  if (ms >= s) {
    return Math.round(ms / s) + 's';
  }
  return ms + 'ms';
}

/**
 * Long format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function fmtLong(ms) {
  return plural(ms, d, 'day') ||
    plural(ms, h, 'hour') ||
    plural(ms, m, 'minute') ||
    plural(ms, s, 'second') ||
    ms + ' ms';
}

/**
 * Pluralization helper.
 */

function plural(ms, n, name) {
  if (ms < n) {
    return;
  }
  if (ms < n * 1.5) {
    return Math.floor(ms / n) + ' ' + name;
  }
  return Math.ceil(ms / n) + ' ' + name + 's';
}


/***/ }),

/***/ 23729:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var engine = __webpack_require__(98595)

var storages = __webpack_require__(88120)
var plugins = [__webpack_require__(30225)]

module.exports = engine.createStore(storages, plugins)


/***/ }),

/***/ 30225:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

module.exports = json2Plugin

function json2Plugin() {
	__webpack_require__(35414)
	return {}
}


/***/ }),

/***/ 35414:
/***/ (function() {

/* eslint-disable */

//  json2.js
//  2016-10-28
//  Public Domain.
//  NO WARRANTY EXPRESSED OR IMPLIED. USE AT YOUR OWN RISK.
//  See http://www.JSON.org/js.html
//  This code should be minified before deployment.
//  See http://javascript.crockford.com/jsmin.html

//  USE YOUR OWN COPY. IT IS EXTREMELY UNWISE TO LOAD CODE FROM SERVERS YOU DO
//  NOT CONTROL.

//  This file creates a global JSON object containing two methods: stringify
//  and parse. This file provides the ES5 JSON capability to ES3 systems.
//  If a project might run on IE8 or earlier, then this file should be included.
//  This file does nothing on ES5 systems.

//      JSON.stringify(value, replacer, space)
//          value       any JavaScript value, usually an object or array.
//          replacer    an optional parameter that determines how object
//                      values are stringified for objects. It can be a
//                      function or an array of strings.
//          space       an optional parameter that specifies the indentation
//                      of nested structures. If it is omitted, the text will
//                      be packed without extra whitespace. If it is a number,
//                      it will specify the number of spaces to indent at each
//                      level. If it is a string (such as "\t" or "&nbsp;"),
//                      it contains the characters used to indent at each level.
//          This method produces a JSON text from a JavaScript value.
//          When an object value is found, if the object contains a toJSON
//          method, its toJSON method will be called and the result will be
//          stringified. A toJSON method does not serialize: it returns the
//          value represented by the name/value pair that should be serialized,
//          or undefined if nothing should be serialized. The toJSON method
//          will be passed the key associated with the value, and this will be
//          bound to the value.

//          For example, this would serialize Dates as ISO strings.

//              Date.prototype.toJSON = function (key) {
//                  function f(n) {
//                      // Format integers to have at least two digits.
//                      return (n < 10)
//                          ? "0" + n
//                          : n;
//                  }
//                  return this.getUTCFullYear()   + "-" +
//                       f(this.getUTCMonth() + 1) + "-" +
//                       f(this.getUTCDate())      + "T" +
//                       f(this.getUTCHours())     + ":" +
//                       f(this.getUTCMinutes())   + ":" +
//                       f(this.getUTCSeconds())   + "Z";
//              };

//          You can provide an optional replacer method. It will be passed the
//          key and value of each member, with this bound to the containing
//          object. The value that is returned from your method will be
//          serialized. If your method returns undefined, then the member will
//          be excluded from the serialization.

//          If the replacer parameter is an array of strings, then it will be
//          used to select the members to be serialized. It filters the results
//          such that only members with keys listed in the replacer array are
//          stringified.

//          Values that do not have JSON representations, such as undefined or
//          functions, will not be serialized. Such values in objects will be
//          dropped; in arrays they will be replaced with null. You can use
//          a replacer function to replace those with JSON values.

//          JSON.stringify(undefined) returns undefined.

//          The optional space parameter produces a stringification of the
//          value that is filled with line breaks and indentation to make it
//          easier to read.

//          If the space parameter is a non-empty string, then that string will
//          be used for indentation. If the space parameter is a number, then
//          the indentation will be that many spaces.

//          Example:

//          text = JSON.stringify(["e", {pluribus: "unum"}]);
//          // text is '["e",{"pluribus":"unum"}]'

//          text = JSON.stringify(["e", {pluribus: "unum"}], null, "\t");
//          // text is '[\n\t"e",\n\t{\n\t\t"pluribus": "unum"\n\t}\n]'

//          text = JSON.stringify([new Date()], function (key, value) {
//              return this[key] instanceof Date
//                  ? "Date(" + this[key] + ")"
//                  : value;
//          });
//          // text is '["Date(---current time---)"]'

//      JSON.parse(text, reviver)
//          This method parses a JSON text to produce an object or array.
//          It can throw a SyntaxError exception.

//          The optional reviver parameter is a function that can filter and
//          transform the results. It receives each of the keys and values,
//          and its return value is used instead of the original value.
//          If it returns what it received, then the structure is not modified.
//          If it returns undefined then the member is deleted.

//          Example:

//          // Parse the text. Values that look like ISO date strings will
//          // be converted to Date objects.

//          myData = JSON.parse(text, function (key, value) {
//              var a;
//              if (typeof value === "string") {
//                  a =
//   /^(\d{4})-(\d{2})-(\d{2})T(\d{2}):(\d{2}):(\d{2}(?:\.\d*)?)Z$/.exec(value);
//                  if (a) {
//                      return new Date(Date.UTC(+a[1], +a[2] - 1, +a[3], +a[4],
//                          +a[5], +a[6]));
//                  }
//              }
//              return value;
//          });

//          myData = JSON.parse('["Date(09/09/2001)"]', function (key, value) {
//              var d;
//              if (typeof value === "string" &&
//                      value.slice(0, 5) === "Date(" &&
//                      value.slice(-1) === ")") {
//                  d = new Date(value.slice(5, -1));
//                  if (d) {
//                      return d;
//                  }
//              }
//              return value;
//          });

//  This is a reference implementation. You are free to copy, modify, or
//  redistribute.

/*jslint
    eval, for, this
*/

/*property
    JSON, apply, call, charCodeAt, getUTCDate, getUTCFullYear, getUTCHours,
    getUTCMinutes, getUTCMonth, getUTCSeconds, hasOwnProperty, join,
    lastIndex, length, parse, prototype, push, replace, slice, stringify,
    test, toJSON, toString, valueOf
*/


// Create a JSON object only if one does not already exist. We create the
// methods in a closure to avoid creating global variables.

if (typeof JSON !== "object") {
    JSON = {};
}

(function () {
    "use strict";

    var rx_one = /^[\],:{}\s]*$/;
    var rx_two = /\\(?:["\\\/bfnrt]|u[0-9a-fA-F]{4})/g;
    var rx_three = /"[^"\\\n\r]*"|true|false|null|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?/g;
    var rx_four = /(?:^|:|,)(?:\s*\[)+/g;
    var rx_escapable = /[\\"\u0000-\u001f\u007f-\u009f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g;
    var rx_dangerous = /[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g;

    function f(n) {
        // Format integers to have at least two digits.
        return n < 10
            ? "0" + n
            : n;
    }

    function this_value() {
        return this.valueOf();
    }

    if (typeof Date.prototype.toJSON !== "function") {

        Date.prototype.toJSON = function () {

            return isFinite(this.valueOf())
                ? this.getUTCFullYear() + "-" +
                        f(this.getUTCMonth() + 1) + "-" +
                        f(this.getUTCDate()) + "T" +
                        f(this.getUTCHours()) + ":" +
                        f(this.getUTCMinutes()) + ":" +
                        f(this.getUTCSeconds()) + "Z"
                : null;
        };

        Boolean.prototype.toJSON = this_value;
        Number.prototype.toJSON = this_value;
        String.prototype.toJSON = this_value;
    }

    var gap;
    var indent;
    var meta;
    var rep;


    function quote(string) {

// If the string contains no control characters, no quote characters, and no
// backslash characters, then we can safely slap some quotes around it.
// Otherwise we must also replace the offending characters with safe escape
// sequences.

        rx_escapable.lastIndex = 0;
        return rx_escapable.test(string)
            ? "\"" + string.replace(rx_escapable, function (a) {
                var c = meta[a];
                return typeof c === "string"
                    ? c
                    : "\\u" + ("0000" + a.charCodeAt(0).toString(16)).slice(-4);
            }) + "\""
            : "\"" + string + "\"";
    }


    function str(key, holder) {

// Produce a string from holder[key].

        var i;          // The loop counter.
        var k;          // The member key.
        var v;          // The member value.
        var length;
        var mind = gap;
        var partial;
        var value = holder[key];

// If the value has a toJSON method, call it to obtain a replacement value.

        if (value && typeof value === "object" &&
                typeof value.toJSON === "function") {
            value = value.toJSON(key);
        }

// If we were called with a replacer function, then call the replacer to
// obtain a replacement value.

        if (typeof rep === "function") {
            value = rep.call(holder, key, value);
        }

// What happens next depends on the value's type.

        switch (typeof value) {
        case "string":
            return quote(value);

        case "number":

// JSON numbers must be finite. Encode non-finite numbers as null.

            return isFinite(value)
                ? String(value)
                : "null";

        case "boolean":
        case "null":

// If the value is a boolean or null, convert it to a string. Note:
// typeof null does not produce "null". The case is included here in
// the remote chance that this gets fixed someday.

            return String(value);

// If the type is "object", we might be dealing with an object or an array or
// null.

        case "object":

// Due to a specification blunder in ECMAScript, typeof null is "object",
// so watch out for that case.

            if (!value) {
                return "null";
            }

// Make an array to hold the partial results of stringifying this object value.

            gap += indent;
            partial = [];

// Is the value an array?

            if (Object.prototype.toString.apply(value) === "[object Array]") {

// The value is an array. Stringify every element. Use null as a placeholder
// for non-JSON values.

                length = value.length;
                for (i = 0; i < length; i += 1) {
                    partial[i] = str(i, value) || "null";
                }

// Join all of the elements together, separated with commas, and wrap them in
// brackets.

                v = partial.length === 0
                    ? "[]"
                    : gap
                        ? "[\n" + gap + partial.join(",\n" + gap) + "\n" + mind + "]"
                        : "[" + partial.join(",") + "]";
                gap = mind;
                return v;
            }

// If the replacer is an array, use it to select the members to be stringified.

            if (rep && typeof rep === "object") {
                length = rep.length;
                for (i = 0; i < length; i += 1) {
                    if (typeof rep[i] === "string") {
                        k = rep[i];
                        v = str(k, value);
                        if (v) {
                            partial.push(quote(k) + (
                                gap
                                    ? ": "
                                    : ":"
                            ) + v);
                        }
                    }
                }
            } else {

// Otherwise, iterate through all of the keys in the object.

                for (k in value) {
                    if (Object.prototype.hasOwnProperty.call(value, k)) {
                        v = str(k, value);
                        if (v) {
                            partial.push(quote(k) + (
                                gap
                                    ? ": "
                                    : ":"
                            ) + v);
                        }
                    }
                }
            }

// Join all of the member texts together, separated with commas,
// and wrap them in braces.

            v = partial.length === 0
                ? "{}"
                : gap
                    ? "{\n" + gap + partial.join(",\n" + gap) + "\n" + mind + "}"
                    : "{" + partial.join(",") + "}";
            gap = mind;
            return v;
        }
    }

// If the JSON object does not yet have a stringify method, give it one.

    if (typeof JSON.stringify !== "function") {
        meta = {    // table of character substitutions
            "\b": "\\b",
            "\t": "\\t",
            "\n": "\\n",
            "\f": "\\f",
            "\r": "\\r",
            "\"": "\\\"",
            "\\": "\\\\"
        };
        JSON.stringify = function (value, replacer, space) {

// The stringify method takes a value and an optional replacer, and an optional
// space parameter, and returns a JSON text. The replacer can be a function
// that can replace values, or an array of strings that will select the keys.
// A default replacer method can be provided. Use of the space parameter can
// produce text that is more easily readable.

            var i;
            gap = "";
            indent = "";

// If the space parameter is a number, make an indent string containing that
// many spaces.

            if (typeof space === "number") {
                for (i = 0; i < space; i += 1) {
                    indent += " ";
                }

// If the space parameter is a string, it will be used as the indent string.

            } else if (typeof space === "string") {
                indent = space;
            }

// If there is a replacer, it must be a function or an array.
// Otherwise, throw an error.

            rep = replacer;
            if (replacer && typeof replacer !== "function" &&
                    (typeof replacer !== "object" ||
                    typeof replacer.length !== "number")) {
                throw new Error("JSON.stringify");
            }

// Make a fake root object containing our value under the key of "".
// Return the result of stringifying the value.

            return str("", {"": value});
        };
    }


// If the JSON object does not yet have a parse method, give it one.

    if (typeof JSON.parse !== "function") {
        JSON.parse = function (text, reviver) {

// The parse method takes a text and an optional reviver function, and returns
// a JavaScript value if the text is a valid JSON text.

            var j;

            function walk(holder, key) {

// The walk method is used to recursively walk the resulting structure so
// that modifications can be made.

                var k;
                var v;
                var value = holder[key];
                if (value && typeof value === "object") {
                    for (k in value) {
                        if (Object.prototype.hasOwnProperty.call(value, k)) {
                            v = walk(value, k);
                            if (v !== undefined) {
                                value[k] = v;
                            } else {
                                delete value[k];
                            }
                        }
                    }
                }
                return reviver.call(holder, key, value);
            }


// Parsing happens in four stages. In the first stage, we replace certain
// Unicode characters with escape sequences. JavaScript handles many characters
// incorrectly, either silently deleting them, or treating them as line endings.

            text = String(text);
            rx_dangerous.lastIndex = 0;
            if (rx_dangerous.test(text)) {
                text = text.replace(rx_dangerous, function (a) {
                    return "\\u" +
                            ("0000" + a.charCodeAt(0).toString(16)).slice(-4);
                });
            }

// In the second stage, we run the text against regular expressions that look
// for non-JSON patterns. We are especially concerned with "()" and "new"
// because they can cause invocation, and "=" because it can cause mutation.
// But just to be safe, we want to reject all unexpected forms.

// We split the second stage into 4 regexp operations in order to work around
// crippling inefficiencies in IE's and Safari's regexp engines. First we
// replace the JSON backslash pairs with "@" (a non-JSON character). Second, we
// replace all simple value tokens with "]" characters. Third, we delete all
// open brackets that follow a colon or comma or that begin the text. Finally,
// we look to see that the remaining characters are only whitespace or "]" or
// "," or ":" or "{" or "}". If that is so, then the text is safe for eval.

            if (
                rx_one.test(
                    text
                        .replace(rx_two, "@")
                        .replace(rx_three, "]")
                        .replace(rx_four, "")
                )
            ) {

// In the third stage we use the eval function to compile the text into a
// JavaScript structure. The "{" operator is subject to a syntactic ambiguity
// in JavaScript: it can begin a block or an object literal. We wrap the text
// in parens to eliminate the ambiguity.

                j = eval("(" + text + ")");

// In the optional fourth stage, we recursively walk the new structure, passing
// each name/value pair to a reviver function for possible transformation.

                return (typeof reviver === "function")
                    ? walk({"": j}, "")
                    : j;
            }

// If the text is not JSON parseable, then a SyntaxError is thrown.

            throw new SyntaxError("JSON.parse");
        };
    }
}());

/***/ }),

/***/ 98595:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var util = __webpack_require__(49511)
var slice = util.slice
var pluck = util.pluck
var each = util.each
var bind = util.bind
var create = util.create
var isList = util.isList
var isFunction = util.isFunction
var isObject = util.isObject

module.exports = {
	createStore: createStore
}

var storeAPI = {
	version: '2.0.12',
	enabled: false,
	
	// get returns the value of the given key. If that value
	// is undefined, it returns optionalDefaultValue instead.
	get: function(key, optionalDefaultValue) {
		var data = this.storage.read(this._namespacePrefix + key)
		return this._deserialize(data, optionalDefaultValue)
	},

	// set will store the given value at key and returns value.
	// Calling set with value === undefined is equivalent to calling remove.
	set: function(key, value) {
		if (value === undefined) {
			return this.remove(key)
		}
		this.storage.write(this._namespacePrefix + key, this._serialize(value))
		return value
	},

	// remove deletes the key and value stored at the given key.
	remove: function(key) {
		this.storage.remove(this._namespacePrefix + key)
	},

	// each will call the given callback once for each key-value pair
	// in this store.
	each: function(callback) {
		var self = this
		this.storage.each(function(val, namespacedKey) {
			callback.call(self, self._deserialize(val), (namespacedKey || '').replace(self._namespaceRegexp, ''))
		})
	},

	// clearAll will remove all the stored key-value pairs in this store.
	clearAll: function() {
		this.storage.clearAll()
	},

	// additional functionality that can't live in plugins
	// ---------------------------------------------------

	// hasNamespace returns true if this store instance has the given namespace.
	hasNamespace: function(namespace) {
		return (this._namespacePrefix == '__storejs_'+namespace+'_')
	},

	// createStore creates a store.js instance with the first
	// functioning storage in the list of storage candidates,
	// and applies the the given mixins to the instance.
	createStore: function() {
		return createStore.apply(this, arguments)
	},
	
	addPlugin: function(plugin) {
		this._addPlugin(plugin)
	},
	
	namespace: function(namespace) {
		return createStore(this.storage, this.plugins, namespace)
	}
}

function _warn() {
	var _console = (typeof console == 'undefined' ? null : console)
	if (!_console) { return }
	var fn = (_console.warn ? _console.warn : _console.log)
	fn.apply(_console, arguments)
}

function createStore(storages, plugins, namespace) {
	if (!namespace) {
		namespace = ''
	}
	if (storages && !isList(storages)) {
		storages = [storages]
	}
	if (plugins && !isList(plugins)) {
		plugins = [plugins]
	}

	var namespacePrefix = (namespace ? '__storejs_'+namespace+'_' : '')
	var namespaceRegexp = (namespace ? new RegExp('^'+namespacePrefix) : null)
	var legalNamespaces = /^[a-zA-Z0-9_\-]*$/ // alpha-numeric + underscore and dash
	if (!legalNamespaces.test(namespace)) {
		throw new Error('store.js namespaces can only have alphanumerics + underscores and dashes')
	}
	
	var _privateStoreProps = {
		_namespacePrefix: namespacePrefix,
		_namespaceRegexp: namespaceRegexp,

		_testStorage: function(storage) {
			try {
				var testStr = '__storejs__test__'
				storage.write(testStr, testStr)
				var ok = (storage.read(testStr) === testStr)
				storage.remove(testStr)
				return ok
			} catch(e) {
				return false
			}
		},

		_assignPluginFnProp: function(pluginFnProp, propName) {
			var oldFn = this[propName]
			this[propName] = function pluginFn() {
				var args = slice(arguments, 0)
				var self = this

				// super_fn calls the old function which was overwritten by
				// this mixin.
				function super_fn() {
					if (!oldFn) { return }
					each(arguments, function(arg, i) {
						args[i] = arg
					})
					return oldFn.apply(self, args)
				}

				// Give mixing function access to super_fn by prefixing all mixin function
				// arguments with super_fn.
				var newFnArgs = [super_fn].concat(args)

				return pluginFnProp.apply(self, newFnArgs)
			}
		},

		_serialize: function(obj) {
			return JSON.stringify(obj)
		},

		_deserialize: function(strVal, defaultVal) {
			if (!strVal) { return defaultVal }
			// It is possible that a raw string value has been previously stored
			// in a storage without using store.js, meaning it will be a raw
			// string value instead of a JSON serialized string. By defaulting
			// to the raw string value in case of a JSON parse error, we allow
			// for past stored values to be forwards-compatible with store.js
			var val = ''
			try { val = JSON.parse(strVal) }
			catch(e) { val = strVal }

			return (val !== undefined ? val : defaultVal)
		},
		
		_addStorage: function(storage) {
			if (this.enabled) { return }
			if (this._testStorage(storage)) {
				this.storage = storage
				this.enabled = true
			}
		},

		_addPlugin: function(plugin) {
			var self = this

			// If the plugin is an array, then add all plugins in the array.
			// This allows for a plugin to depend on other plugins.
			if (isList(plugin)) {
				each(plugin, function(plugin) {
					self._addPlugin(plugin)
				})
				return
			}

			// Keep track of all plugins we've seen so far, so that we
			// don't add any of them twice.
			var seenPlugin = pluck(this.plugins, function(seenPlugin) {
				return (plugin === seenPlugin)
			})
			if (seenPlugin) {
				return
			}
			this.plugins.push(plugin)

			// Check that the plugin is properly formed
			if (!isFunction(plugin)) {
				throw new Error('Plugins must be function values that return objects')
			}

			var pluginProperties = plugin.call(this)
			if (!isObject(pluginProperties)) {
				throw new Error('Plugins must return an object of function properties')
			}

			// Add the plugin function properties to this store instance.
			each(pluginProperties, function(pluginFnProp, propName) {
				if (!isFunction(pluginFnProp)) {
					throw new Error('Bad plugin property: '+propName+' from plugin '+plugin.name+'. Plugins should only return functions.')
				}
				self._assignPluginFnProp(pluginFnProp, propName)
			})
		},
		
		// Put deprecated properties in the private API, so as to not expose it to accidential
		// discovery through inspection of the store object.
		
		// Deprecated: addStorage
		addStorage: function(storage) {
			_warn('store.addStorage(storage) is deprecated. Use createStore([storages])')
			this._addStorage(storage)
		}
	}

	var store = create(_privateStoreProps, storeAPI, {
		plugins: []
	})
	store.raw = {}
	each(store, function(prop, propName) {
		if (isFunction(prop)) {
			store.raw[propName] = bind(store, prop)			
		}
	})
	each(storages, function(storage) {
		store._addStorage(storage)
	})
	each(plugins, function(plugin) {
		store._addPlugin(plugin)
	})
	return store
}


/***/ }),

/***/ 49511:
/***/ (function(module) {

var assign = make_assign()
var create = make_create()
var trim = make_trim()
var Global = (typeof window !== 'undefined' ? window : window)

module.exports = {
	assign: assign,
	create: create,
	trim: trim,
	bind: bind,
	slice: slice,
	each: each,
	map: map,
	pluck: pluck,
	isList: isList,
	isFunction: isFunction,
	isObject: isObject,
	Global: Global
}

function make_assign() {
	if (Object.assign) {
		return Object.assign
	} else {
		return function shimAssign(obj, props1, props2, etc) {
			for (var i = 1; i < arguments.length; i++) {
				each(Object(arguments[i]), function(val, key) {
					obj[key] = val
				})
			}			
			return obj
		}
	}
}

function make_create() {
	if (Object.create) {
		return function create(obj, assignProps1, assignProps2, etc) {
			var assignArgsList = slice(arguments, 1)
			return assign.apply(this, [Object.create(obj)].concat(assignArgsList))
		}
	} else {
		function F() {} // eslint-disable-line no-inner-declarations
		return function create(obj, assignProps1, assignProps2, etc) {
			var assignArgsList = slice(arguments, 1)
			F.prototype = obj
			return assign.apply(this, [new F()].concat(assignArgsList))
		}
	}
}

function make_trim() {
	if (String.prototype.trim) {
		return function trim(str) {
			return String.prototype.trim.call(str)
		}
	} else {
		return function trim(str) {
			return str.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g, '')
		}
	}
}

function bind(obj, fn) {
	return function() {
		return fn.apply(obj, Array.prototype.slice.call(arguments, 0))
	}
}

function slice(arr, index) {
	return Array.prototype.slice.call(arr, index || 0)
}

function each(obj, fn) {
	pluck(obj, function(val, key) {
		fn(val, key)
		return false
	})
}

function map(obj, fn) {
	var res = (isList(obj) ? [] : {})
	pluck(obj, function(v, k) {
		res[k] = fn(v, k)
		return false
	})
	return res
}

function pluck(obj, fn) {
	if (isList(obj)) {
		for (var i=0; i<obj.length; i++) {
			if (fn(obj[i], i)) {
				return obj[i]
			}
		}
	} else {
		for (var key in obj) {
			if (obj.hasOwnProperty(key)) {
				if (fn(obj[key], key)) {
					return obj[key]
				}
			}
		}
	}
}

function isList(val) {
	return (val != null && typeof val != 'function' && typeof val.length == 'number')
}

function isFunction(val) {
	return val && {}.toString.call(val) === '[object Function]'
}

function isObject(val) {
	return val && {}.toString.call(val) === '[object Object]'
}


/***/ }),

/***/ 88120:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

module.exports = [
	// Listed in order of usage preference
	__webpack_require__(19367),
	__webpack_require__(50026),
	__webpack_require__(70240),
	__webpack_require__(65362),
	__webpack_require__(90109),
	__webpack_require__(71884)
]


/***/ }),

/***/ 65362:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

// cookieStorage is useful Safari private browser mode, where localStorage
// doesn't work but cookies do. This implementation is adopted from
// https://developer.mozilla.org/en-US/docs/Web/API/Storage/LocalStorage

var util = __webpack_require__(49511)
var Global = util.Global
var trim = util.trim

module.exports = {
	name: 'cookieStorage',
	read: read,
	write: write,
	each: each,
	remove: remove,
	clearAll: clearAll,
}

var doc = Global.document

function read(key) {
	if (!key || !_has(key)) { return null }
	var regexpStr = "(?:^|.*;\\s*)" +
		escape(key).replace(/[\-\.\+\*]/g, "\\$&") +
		"\\s*\\=\\s*((?:[^;](?!;))*[^;]?).*"
	return unescape(doc.cookie.replace(new RegExp(regexpStr), "$1"))
}

function each(callback) {
	var cookies = doc.cookie.split(/; ?/g)
	for (var i = cookies.length - 1; i >= 0; i--) {
		if (!trim(cookies[i])) {
			continue
		}
		var kvp = cookies[i].split('=')
		var key = unescape(kvp[0])
		var val = unescape(kvp[1])
		callback(val, key)
	}
}

function write(key, data) {
	if(!key) { return }
	doc.cookie = escape(key) + "=" + escape(data) + "; expires=Tue, 19 Jan 2038 03:14:07 GMT; path=/"
}

function remove(key) {
	if (!key || !_has(key)) {
		return
	}
	doc.cookie = escape(key) + "=; expires=Thu, 01 Jan 1970 00:00:00 GMT; path=/"
}

function clearAll() {
	each(function(_, key) {
		remove(key)
	})
}

function _has(key) {
	return (new RegExp("(?:^|;\\s*)" + escape(key).replace(/[\-\.\+\*]/g, "\\$&") + "\\s*\\=")).test(doc.cookie)
}


/***/ }),

/***/ 19367:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var util = __webpack_require__(49511)
var Global = util.Global

module.exports = {
	name: 'localStorage',
	read: read,
	write: write,
	each: each,
	remove: remove,
	clearAll: clearAll,
}

function localStorage() {
	return Global.localStorage
}

function read(key) {
	return localStorage().getItem(key)
}

function write(key, data) {
	return localStorage().setItem(key, data)
}

function each(fn) {
	for (var i = localStorage().length - 1; i >= 0; i--) {
		var key = localStorage().key(i)
		fn(read(key), key)
	}
}

function remove(key) {
	return localStorage().removeItem(key)
}

function clearAll() {
	return localStorage().clear()
}


/***/ }),

/***/ 71884:
/***/ (function(module) {

// memoryStorage is a useful last fallback to ensure that the store
// is functions (meaning store.get(), store.set(), etc will all function).
// However, stored values will not persist when the browser navigates to
// a new page or reloads the current page.

module.exports = {
	name: 'memoryStorage',
	read: read,
	write: write,
	each: each,
	remove: remove,
	clearAll: clearAll,
}

var memoryStorage = {}

function read(key) {
	return memoryStorage[key]
}

function write(key, data) {
	memoryStorage[key] = data
}

function each(callback) {
	for (var key in memoryStorage) {
		if (memoryStorage.hasOwnProperty(key)) {
			callback(memoryStorage[key], key)
		}
	}
}

function remove(key) {
	delete memoryStorage[key]
}

function clearAll(key) {
	memoryStorage = {}
}


/***/ }),

/***/ 50026:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

// oldFF-globalStorage provides storage for Firefox
// versions 6 and 7, where no localStorage, etc
// is available.

var util = __webpack_require__(49511)
var Global = util.Global

module.exports = {
	name: 'oldFF-globalStorage',
	read: read,
	write: write,
	each: each,
	remove: remove,
	clearAll: clearAll,
}

var globalStorage = Global.globalStorage

function read(key) {
	return globalStorage[key]
}

function write(key, data) {
	globalStorage[key] = data
}

function each(fn) {
	for (var i = globalStorage.length - 1; i >= 0; i--) {
		var key = globalStorage.key(i)
		fn(globalStorage[key], key)
	}
}

function remove(key) {
	return globalStorage.removeItem(key)
}

function clearAll() {
	each(function(key, _) {
		delete globalStorage[key]
	})
}


/***/ }),

/***/ 70240:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

// oldIE-userDataStorage provides storage for Internet Explorer
// versions 6 and 7, where no localStorage, sessionStorage, etc
// is available.

var util = __webpack_require__(49511)
var Global = util.Global

module.exports = {
	name: 'oldIE-userDataStorage',
	write: write,
	read: read,
	each: each,
	remove: remove,
	clearAll: clearAll,
}

var storageName = 'storejs'
var doc = Global.document
var _withStorageEl = _makeIEStorageElFunction()
var disable = (Global.navigator ? Global.navigator.userAgent : '').match(/ (MSIE 8|MSIE 9|MSIE 10)\./) // MSIE 9.x, MSIE 10.x

function write(unfixedKey, data) {
	if (disable) { return }
	var fixedKey = fixKey(unfixedKey)
	_withStorageEl(function(storageEl) {
		storageEl.setAttribute(fixedKey, data)
		storageEl.save(storageName)
	})
}

function read(unfixedKey) {
	if (disable) { return }
	var fixedKey = fixKey(unfixedKey)
	var res = null
	_withStorageEl(function(storageEl) {
		res = storageEl.getAttribute(fixedKey)
	})
	return res
}

function each(callback) {
	_withStorageEl(function(storageEl) {
		var attributes = storageEl.XMLDocument.documentElement.attributes
		for (var i=attributes.length-1; i>=0; i--) {
			var attr = attributes[i]
			callback(storageEl.getAttribute(attr.name), attr.name)
		}
	})
}

function remove(unfixedKey) {
	var fixedKey = fixKey(unfixedKey)
	_withStorageEl(function(storageEl) {
		storageEl.removeAttribute(fixedKey)
		storageEl.save(storageName)
	})
}

function clearAll() {
	_withStorageEl(function(storageEl) {
		var attributes = storageEl.XMLDocument.documentElement.attributes
		storageEl.load(storageName)
		for (var i=attributes.length-1; i>=0; i--) {
			storageEl.removeAttribute(attributes[i].name)
		}
		storageEl.save(storageName)
	})
}

// Helpers
//////////

// In IE7, keys cannot start with a digit or contain certain chars.
// See https://github.com/marcuswestin/store.js/issues/40
// See https://github.com/marcuswestin/store.js/issues/83
var forbiddenCharsRegex = new RegExp("[!\"#$%&'()*+,/\\\\:;<=>?@[\\]^`{|}~]", "g")
function fixKey(key) {
	return key.replace(/^\d/, '___$&').replace(forbiddenCharsRegex, '___')
}

function _makeIEStorageElFunction() {
	if (!doc || !doc.documentElement || !doc.documentElement.addBehavior) {
		return null
	}
	var scriptTag = 'script',
		storageOwner,
		storageContainer,
		storageEl

	// Since #userData storage applies only to specific paths, we need to
	// somehow link our data to a specific path.  We choose /favicon.ico
	// as a pretty safe option, since all browsers already make a request to
	// this URL anyway and being a 404 will not hurt us here.  We wrap an
	// iframe pointing to the favicon in an ActiveXObject(htmlfile) object
	// (see: http://msdn.microsoft.com/en-us/library/aa752574(v=VS.85).aspx)
	// since the iframe access rules appear to allow direct access and
	// manipulation of the document element, even for a 404 page.  This
	// document can be used instead of the current document (which would
	// have been limited to the current path) to perform #userData storage.
	try {
		/* global ActiveXObject */
		storageContainer = new ActiveXObject('htmlfile')
		storageContainer.open()
		storageContainer.write('<'+scriptTag+'>document.w=window</'+scriptTag+'><iframe src="/favicon.ico"></iframe>')
		storageContainer.close()
		storageOwner = storageContainer.w.frames[0].document
		storageEl = storageOwner.createElement('div')
	} catch(e) {
		// somehow ActiveXObject instantiation failed (perhaps some special
		// security settings or otherwse), fall back to per-path storage
		storageEl = doc.createElement('div')
		storageOwner = doc.body
	}

	return function(storeFunction) {
		var args = [].slice.call(arguments, 0)
		args.unshift(storageEl)
		// See http://msdn.microsoft.com/en-us/library/ms531081(v=VS.85).aspx
		// and http://msdn.microsoft.com/en-us/library/ms531424(v=VS.85).aspx
		storageOwner.appendChild(storageEl)
		storageEl.addBehavior('#default#userData')
		storageEl.load(storageName)
		storeFunction.apply(this, args)
		storageOwner.removeChild(storageEl)
		return
	}
}


/***/ }),

/***/ 90109:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var util = __webpack_require__(49511)
var Global = util.Global

module.exports = {
	name: 'sessionStorage',
	read: read,
	write: write,
	each: each,
	remove: remove,
	clearAll: clearAll
}

function sessionStorage() {
	return Global.sessionStorage
}

function read(key) {
	return sessionStorage().getItem(key)
}

function write(key, data) {
	return sessionStorage().setItem(key, data)
}

function each(fn) {
	for (var i = sessionStorage().length - 1; i >= 0; i--) {
		var key = sessionStorage().key(i)
		fn(read(key), key)
	}
}

function remove(key) {
	return sessionStorage().removeItem(key)
}

function clearAll() {
	return sessionStorage().clear()
}


/***/ }),

/***/ 49830:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Tannin; }
/* harmony export */ });
/* harmony import */ var _tannin_plural_forms__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(11184);


/**
 * Tannin constructor options.
 *
 * @typedef {Object} TanninOptions
 *
 * @property {string}   [contextDelimiter] Joiner in string lookup with context.
 * @property {Function} [onMissingKey]     Callback to invoke when key missing.
 */

/**
 * Domain metadata.
 *
 * @typedef {Object} TanninDomainMetadata
 *
 * @property {string}            [domain]       Domain name.
 * @property {string}            [lang]         Language code.
 * @property {(string|Function)} [plural_forms] Plural forms expression or
 *                                              function evaluator.
 */

/**
 * Domain translation pair respectively representing the singular and plural
 * translation.
 *
 * @typedef {[string,string]} TanninTranslation
 */

/**
 * Locale data domain. The key is used as reference for lookup, the value an
 * array of two string entries respectively representing the singular and plural
 * translation.
 *
 * @typedef {{[key:string]:TanninDomainMetadata|TanninTranslation,'':TanninDomainMetadata|TanninTranslation}} TanninLocaleDomain
 */

/**
 * Jed-formatted locale data.
 *
 * @see http://messageformat.github.io/Jed/
 *
 * @typedef {{[domain:string]:TanninLocaleDomain}} TanninLocaleData
 */

/**
 * Default Tannin constructor options.
 *
 * @type {TanninOptions}
 */
var DEFAULT_OPTIONS = {
	contextDelimiter: '\u0004',
	onMissingKey: null,
};

/**
 * Given a specific locale data's config `plural_forms` value, returns the
 * expression.
 *
 * @example
 *
 * ```
 * getPluralExpression( 'nplurals=2; plural=(n != 1);' ) === '(n != 1)'
 * ```
 *
 * @param {string} pf Locale data plural forms.
 *
 * @return {string} Plural forms expression.
 */
function getPluralExpression( pf ) {
	var parts, i, part;

	parts = pf.split( ';' );

	for ( i = 0; i < parts.length; i++ ) {
		part = parts[ i ].trim();
		if ( part.indexOf( 'plural=' ) === 0 ) {
			return part.substr( 7 );
		}
	}
}

/**
 * Tannin constructor.
 *
 * @class
 *
 * @param {TanninLocaleData} data      Jed-formatted locale data.
 * @param {TanninOptions}    [options] Tannin options.
 */
function Tannin( data, options ) {
	var key;

	/**
	 * Jed-formatted locale data.
	 *
	 * @name Tannin#data
	 * @type {TanninLocaleData}
	 */
	this.data = data;

	/**
	 * Plural forms function cache, keyed by plural forms string.
	 *
	 * @name Tannin#pluralForms
	 * @type {Object<string,Function>}
	 */
	this.pluralForms = {};

	/**
	 * Effective options for instance, including defaults.
	 *
	 * @name Tannin#options
	 * @type {TanninOptions}
	 */
	this.options = {};

	for ( key in DEFAULT_OPTIONS ) {
		this.options[ key ] = options !== undefined && key in options
			? options[ key ]
			: DEFAULT_OPTIONS[ key ];
	}
}

/**
 * Returns the plural form index for the given domain and value.
 *
 * @param {string} domain Domain on which to calculate plural form.
 * @param {number} n      Value for which plural form is to be calculated.
 *
 * @return {number} Plural form index.
 */
Tannin.prototype.getPluralForm = function( domain, n ) {
	var getPluralForm = this.pluralForms[ domain ],
		config, plural, pf;

	if ( ! getPluralForm ) {
		config = this.data[ domain ][ '' ];

		pf = (
			config[ 'Plural-Forms' ] ||
			config[ 'plural-forms' ] ||
			// Ignore reason: As known, there's no way to document the empty
			// string property on a key to guarantee this as metadata.
			// @ts-ignore
			config.plural_forms
		);

		if ( typeof pf !== 'function' ) {
			plural = getPluralExpression(
				config[ 'Plural-Forms' ] ||
				config[ 'plural-forms' ] ||
				// Ignore reason: As known, there's no way to document the empty
				// string property on a key to guarantee this as metadata.
				// @ts-ignore
				config.plural_forms
			);

			pf = (0,_tannin_plural_forms__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)( plural );
		}

		getPluralForm = this.pluralForms[ domain ] = pf;
	}

	return getPluralForm( n );
};

/**
 * Translate a string.
 *
 * @param {string}      domain   Translation domain.
 * @param {string|void} context  Context distinguishing terms of the same name.
 * @param {string}      singular Primary key for translation lookup.
 * @param {string=}     plural   Fallback value used for non-zero plural
 *                               form index.
 * @param {number=}     n        Value to use in calculating plural form.
 *
 * @return {string} Translated string.
 */
Tannin.prototype.dcnpgettext = function( domain, context, singular, plural, n ) {
	var index, key, entry;

	if ( n === undefined ) {
		// Default to singular.
		index = 0;
	} else {
		// Find index by evaluating plural form for value.
		index = this.getPluralForm( domain, n );
	}

	key = singular;

	// If provided, context is prepended to key with delimiter.
	if ( context ) {
		key = context + this.options.contextDelimiter + singular;
	}

	entry = this.data[ domain ][ key ];

	// Verify not only that entry exists, but that the intended index is within
	// range and non-empty.
	if ( entry && entry[ index ] ) {
		return entry[ index ];
	}

	if ( this.options.onMissingKey ) {
		this.options.onMissingKey( singular, domain );
	}

	// If entry not found, fall back to singular vs. plural with zero index
	// representing the singular value.
	return index === 0 ? singular : plural;
};


/***/ }),

/***/ 77879:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "c": function() { return /* binding */ whatsNewQueryClient; }
/* harmony export */ });
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(82066);

const whatsNewQueryClient = new react_query__WEBPACK_IMPORTED_MODULE_0__.QueryClient();

/***/ }),

/***/ 44966:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ CalypsoStateProvider; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_polyfills__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(88691);
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(11481);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(4792);
/* harmony import */ var redux__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(18717);
/* harmony import */ var redux_thunk__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(43292);
/* harmony import */ var calypso_components_data_query_sites__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(38606);
/* harmony import */ var calypso_lib_analytics_init__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(70858);
/* harmony import */ var calypso_lib_analytics_super_props__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(21058);
/* harmony import */ var calypso_lib_user_shared_utils__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(59852);
/* harmony import */ var calypso_lib_user_shared_utils__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(29726);
/* harmony import */ var calypso_state_analytics_middleware__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(15223);
/* harmony import */ var calypso_state_console_dispatch__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(6255);
/* harmony import */ var calypso_state_current_user_actions__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(91668);
/* harmony import */ var calypso_state_current_user_reducer__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(18724);
/* harmony import */ var calypso_state_happychat_middleware__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(76693);
/* harmony import */ var calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(9044);
/* harmony import */ var calypso_state_sites_reducer__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(82139);
/* harmony import */ var calypso_state_ui_actions__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(71799);
/* harmony import */ var calypso_state_ui_section_actions__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(9817);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(95884);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(90924);


/**
 * Global polyfills
 */



















const rootReducer = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_12__/* .combineReducers */ .U)({
  currentUser: calypso_state_current_user_reducer__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .ZP,
  sites: calypso_state_sites_reducer__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .ZP
});
const store = (0,redux__WEBPACK_IMPORTED_MODULE_13__/* .createStore */ .MT)(rootReducer, (0,redux__WEBPACK_IMPORTED_MODULE_13__/* .compose */ .qC)(calypso_state_console_dispatch__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .Z, calypso_state_utils__WEBPACK_IMPORTED_MODULE_15__/* .addReducerEnhancer */ .f, (0,redux__WEBPACK_IMPORTED_MODULE_13__/* .applyMiddleware */ .md)(redux_thunk__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z, calypso_state_analytics_middleware__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z, calypso_state_happychat_middleware__WEBPACK_IMPORTED_MODULE_16__/* ["default"] */ .Z)));
(0,calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_10__/* .setStore */ .P)(store); // For the moment we have the help center only in the editor

store.dispatch((0,calypso_state_ui_section_actions__WEBPACK_IMPORTED_MODULE_17__/* .setSection */ .z)({
  name: 'gutenberg-editor'
}));
store.dispatch((0,calypso_state_ui_actions__WEBPACK_IMPORTED_MODULE_18__/* .setSelectedSiteId */ .B)(window._currentSiteId));
i18n_calypso__WEBPACK_IMPORTED_MODULE_19__/* ["default"].configure */ .ZP.configure({
  defaultLocaleSlug: window.helpCenterLocale
});
(0,calypso_lib_user_shared_utils__WEBPACK_IMPORTED_MODULE_20__/* .rawCurrentUserFetch */ .G)().then(calypso_lib_user_shared_utils__WEBPACK_IMPORTED_MODULE_21__/* .filterUserObject */ .v).then(user => {
  if (user) {
    store.dispatch((0,calypso_state_current_user_actions__WEBPACK_IMPORTED_MODULE_8__/* .setCurrentUser */ .lx)(user));
  }

  (0,calypso_lib_analytics_init__WEBPACK_IMPORTED_MODULE_5__/* .initializeAnalytics */ .M)(user || undefined, (0,calypso_lib_analytics_super_props__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(store));
});
function CalypsoStateProvider(_ref) {
  let {
    children
  } = _ref;
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_redux__WEBPACK_IMPORTED_MODULE_2__/* .Provider */ .zt, {
    store: store
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(calypso_components_data_query_sites__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, {
    siteId: window._currentSiteId
  }), children));
}

/***/ }),

/***/ 36707:
/***/ (function() {

window.configData = {
  env_id: 'development',
  i18n_default_locale_slug: 'en',
  google_analytics_key: 'UA-10673494-15',
  client_slug: 'browser',
  twemoji_cdn_url: 'https://s0.wp.com/wp-content/mu-plugins/wpcom-smileys/twemoji/2/',
  happychat_url: 'https://happychat.io/customer',
  site_filter: [],
  sections: {},
  enable_all_sections: false,
  livechat_support_locales: ['en'],
  upwork_support_locales: ['de'],
  jetpack_support_blog: 'jetpackme.wordpress.com',
  wpcom_support_blog: 'en.support.wordpress.com',
  gutenboarding_url: '/new',
  features: {
    happychat: true
  },
  signup_url: '/',
  discover_blog_id: 53424024,
  discover_feed_id: 41325786,
  directly_rtm_widget_environment: 'production',
  directly_rtm_widget_ids: {
    sandbox: '8a2968fc57d1e2f40157f42bf2d43160',
    production: '8a12a3ca5a21a619015a47e492b02cfc'
  }
};
window.process = {
  env: {
    NODE_DEBUG: 'dev'
  }
};

/***/ }),

/***/ 99477:
/***/ (function(__unused_webpack_module, __unused_webpack___webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36115);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(53762);
/* harmony import */ var _automattic_help_center__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(92421);
/* harmony import */ var _automattic_help_center__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(55213);
/* harmony import */ var _automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(30849);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(55609);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _wordpress_compose__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(94333);
/* harmony import */ var _wordpress_compose__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(_wordpress_compose__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _wordpress_interface__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(85192);
/* harmony import */ var _wordpress_plugins__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(98817);
/* harmony import */ var _wordpress_plugins__WEBPACK_IMPORTED_MODULE_6___default = /*#__PURE__*/__webpack_require__.n(_wordpress_plugins__WEBPACK_IMPORTED_MODULE_6__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_7___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_7__);
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(82066);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(4792);
/* harmony import */ var calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(83377);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(73041);
/* harmony import */ var _common_what_new_query_client__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(77879);
/* harmony import */ var _CalypsoStateProvider__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(44966);
/* harmony import */ var _help_center_scss__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(39142);




















function HelpCenterContent() {
  const isDesktop = (0,_wordpress_compose__WEBPACK_IMPORTED_MODULE_3__.useMediaQuery)('(min-width: 480px)');
  const sectionName = (0,react_redux__WEBPACK_IMPORTED_MODULE_9__/* .useSelector */ .v9)(calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .Z);
  const show = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_4__.useSelect)(select => select('automattic/help-center').isHelpCenterShown());
  const [showHelpIcon, setShowHelpIcon] = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useState)(false);
  const {
    setShowHelpCenter
  } = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_4__.useDispatch)('automattic/help-center');
  const [showHelpIconDot, setShowHelpIconDot] = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useState)(false);
  const isSimpleSite = (0,react_redux__WEBPACK_IMPORTED_MODULE_9__/* .useSelector */ .v9)(calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .Z) || false;
  const {
    data,
    isLoading
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_15__/* .useHasSeenWhatsNewModalQuery */ .R)(window._currentSiteId, isSimpleSite);
  (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    if (!isLoading && data) {
      setShowHelpIconDot(!data.has_seen_whats_new_modal);
    }
  }, [data, isLoading]);

  const handleToggleHelpCenter = () => {
    (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)(`calypso_inlinehelp_${show ? 'close' : 'show'}`, {
      location: 'help-center',
      section: sectionName
    });
    setShowHelpCenter(!show);
  };

  (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    const timeout = setTimeout(() => setShowHelpIcon(true), 0);
    return () => clearTimeout(timeout);
  }, []);
  const content = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__.Button, {
    className: classnames__WEBPACK_IMPORTED_MODULE_7___default()('entry-point-button', 'help-center', {
      'is-active': show
    }),
    onClick: handleToggleHelpCenter,
    icon: (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_help_center__WEBPACK_IMPORTED_MODULE_16__/* ["default"] */ .Z, {
      newItems: showHelpIconDot
    }),
    label: "Help",
    "aria-pressed": show ? true : false,
    "aria-expanded": show ? true : false
  });
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, isDesktop && showHelpIcon && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_interface__WEBPACK_IMPORTED_MODULE_5__/* .PinnedItems */ .Ox, {
    scope: "core/edit-post"
  }, content), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_interface__WEBPACK_IMPORTED_MODULE_5__/* .PinnedItems */ .Ox, {
    scope: "core/edit-site"
  }, content), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_interface__WEBPACK_IMPORTED_MODULE_5__/* .PinnedItems */ .Ox, {
    scope: "core/edit-widgets"
  }, content)), show && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_help_center__WEBPACK_IMPORTED_MODULE_17__/* ["default"] */ .Z, {
    handleClose: () => setShowHelpCenter(false)
  }));
}

(0,_wordpress_plugins__WEBPACK_IMPORTED_MODULE_6__.registerPlugin)('etk-help-center', {
  render: () => {
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_query__WEBPACK_IMPORTED_MODULE_8__.QueryClientProvider, {
      client: _common_what_new_query_client__WEBPACK_IMPORTED_MODULE_10__/* .whatsNewQueryClient */ .c
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_CalypsoStateProvider__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_18__/* .LocaleProvider */ .Iw, {
      localeSlug: window.helpCenterLocale
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(HelpCenterContent, null))));
  }
});

/***/ }),

/***/ 67459:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "p": function() { return /* binding */ getAdminSections; },
/* harmony export */   "x": function() { return /* binding */ filterListBySearchTerm; }
/* harmony export */ });
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(85694);
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_lib_gsuite__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(96598);
/* harmony import */ var calypso_lib_i18n_utils__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(26991);
/* harmony import */ var calypso_lib_paths__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(26347);
/* harmony import */ var calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(64802);
/* harmony import */ var calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(20336);






/**
 * Returns admin section items with site-based urls.
 *
 * @param   {number} siteId   - The current site ID.
 * @param   {string} siteSlug - The current site slug.
 * @param   {object} state    - Global state
 * @returns {Array}             An array of admin sections with site-specific URLs.
 */

const getAdminSections = (0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .createSelector */ .P1)((state, siteId) => {
  const siteSlug = (0,calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId);
  const sections = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_3__/* .generateAdminSections */ ._)(siteSlug, {
    root: (0,calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(state, siteId),
    homepage: (0,calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(state, siteId, 'homepage'),
    identity: (0,calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(state, siteId, 'identity'),
    menus: (0,calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(state, siteId, 'menus')
  }, (0,calypso_lib_gsuite__WEBPACK_IMPORTED_MODULE_5__/* .getGoogleMailServiceFamily */ .H)(), (0,calypso_lib_paths__WEBPACK_IMPORTED_MODULE_1__/* .onboardingUrl */ .Nf)());
  return sections;
}, (state, siteId) => [(0,calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId)]);
/**
 * Returns a filtered site admin collection.
 *
 * @param   {string} searchTerm The search term
 * @param   {Array}  collection A collection of site admin objects
 * @param   {number} limit      The maximum number of filtered results to return
 * @returns {Array}             A filtered (or empty) array
 */

function filterListBySearchTerm() {
  let searchTerm = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  let collection = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  let limit = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 4;

  // Early return if search term is empty.
  if (!searchTerm.length) {
    return [];
  }

  const searchTermWords = searchTerm // Split to words.
  .split(/[\W_]+/g) // Eliminate any empty string results.
  .filter(Boolean) // Lowercase all words.
  .map(word => word.toLowerCase());

  if (!searchTermWords.length) {
    return [];
  }

  const searchRegex = new RegExp( // Join a series of look aheads
  // matching full and partial works
  // Example: "Add a dom" => /(?=.*\badd\b)(?=.*\ba\b)(?=.*\bdom).+/gi
  searchTermWords.map((word, i) => // if it's the last word, don't look for a end word boundary
  // otherwise
  i + 1 === searchTermWords.length ? `(?=.*\\b${word})` : `(?=.*\\b${word}\\b)`).join('') + '.+', 'gi');
  const exactMatches = [];
  const partialMatches = [];
  const synonymMatches = [];
  collection.forEach(item => {
    var _item$synonyms;

    if (item.title.toLowerCase() === searchTerm.toLowerCase()) {
      exactMatches.push(item);
    } else if (searchRegex.test(item.title)) {
      partialMatches.push(item);
    } else if ('en' === (0,calypso_lib_i18n_utils__WEBPACK_IMPORTED_MODULE_6__/* .getLocaleSlug */ .Y)() && (_item$synonyms = item.synonyms) !== null && _item$synonyms !== void 0 && _item$synonyms.some(s => searchTermWords.includes(s))) {
      synonymMatches.push(item);
    }
  });
  return [...exactMatches, ...partialMatches, ...synonymMatches].slice(0, limit);
}

/***/ }),

/***/ 91040:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Di": function() { return /* binding */ SUPPORT_BLOG_ID; }
/* harmony export */ });
/* unused harmony exports RESULT_ARTICLE, RESULT_TOUR, RESULT_VIDEO, VIEW_CONTACT, VIEW_RICH_RESULT, VIEW_FORUM, SUPPORT_TYPE_CONTEXTUAL_HELP, SUPPORT_TYPE_API_HELP, SUPPORT_TYPE_ADMIN_SECTION, SELL_INTENT */
const RESULT_ARTICLE = 'article';
const RESULT_TOUR = 'tour';
const RESULT_VIDEO = 'video';
const VIEW_CONTACT = 'contact';
const VIEW_RICH_RESULT = 'richresult';
const VIEW_FORUM = 'forums';
const SUPPORT_BLOG_ID = 9619154;
const SUPPORT_TYPE_CONTEXTUAL_HELP = 'contextual_help';
const SUPPORT_TYPE_API_HELP = 'api_help';
const SUPPORT_TYPE_ADMIN_SECTION = 'admin_section';
const SELL_INTENT = 'sell_intent';

/***/ }),

/***/ 71688:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36115);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(10975);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(13980);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_8___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_8__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(4792);
/* harmony import */ var calypso_components_search_card__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(57925);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(73041);


/* eslint-disable no-restricted-imports */








/**
 * Module variables
 */

const debug = debug__WEBPACK_IMPORTED_MODULE_2___default()('calypso:inline-help');

const InlineHelpSearchCard = _ref => {
  let {
    searchQuery = '',
    location = 'inline-help-popover',
    isVisible = true,
    placeholder,
    onSearch
  } = _ref;
  const cardRef = (0,react__WEBPACK_IMPORTED_MODULE_3__.useRef)();
  const translate = (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)();
  const sectionName = (0,react_redux__WEBPACK_IMPORTED_MODULE_4__/* .useSelector */ .v9)(calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z); // Focus in the input element.

  (0,react__WEBPACK_IMPORTED_MODULE_3__.useEffect)(() => {
    var _cardRef$current;

    const inputElement = (_cardRef$current = cardRef.current) === null || _cardRef$current === void 0 ? void 0 : _cardRef$current.searchInput; // Focuses only in the popover.

    if (location !== 'inline-help-popover' || !inputElement || !isVisible) {
      return;
    }

    const timerId = setTimeout(() => inputElement.focus(), 0);
    return () => window.clearTimeout(timerId);
  }, [cardRef, location, isVisible]);

  const searchHelperHandler = query => {
    const inputQuery = query.trim();

    if (location === 'help-center') {
      if ((inputQuery === null || inputQuery === void 0 ? void 0 : inputQuery.length) > 2) {
        (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_inlinehelp_search', {
          search_query: searchQuery,
          location: location,
          section: sectionName
        });
      }
    } else if (inputQuery !== null && inputQuery !== void 0 && inputQuery.length) {
      debug('search query received: ', searchQuery);
      (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_inlinehelp_search', {
        search_query: searchQuery,
        location: location,
        section: sectionName
      });
    } // Set the query search


    onSearch === null || onSearch === void 0 ? void 0 : onSearch(query);
  };

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(calypso_components_search_card__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z, {
    ref: cardRef,
    initialValue: searchQuery,
    onSearch: searchHelperHandler,
    placeholder: placeholder || translate('Search for help…'),
    delaySearch: true
  });
};

InlineHelpSearchCard.propTypes = {
  searchQuery: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string),
  onSearch: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().func),
  placeholder: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string),
  location: (prop_types__WEBPACK_IMPORTED_MODULE_8___default().string)
};
/* harmony default export */ __webpack_exports__["Z"] = (InlineHelpSearchCard);

/***/ }),

/***/ 85774:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(13980);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var calypso_components_external_link__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(38782);




const SupportArticleHeader = _ref => {
  let {
    post,
    isLoading
  } = _ref;
  return isLoading || !post ? (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "support-article-dialog__header is-placeholder"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("h1", {
    className: "support-article-dialog__header-title is-placeholder"
  }, "Post loading\u2026")) : (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "support-article-dialog__header"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("h1", {
    className: "support-article-dialog__header-title"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(calypso_components_external_link__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, {
    className: "support-article-dialog__header-title-link",
    href: post.URL,
    target: "_blank",
    icon: false
  }, post.title)));
};

SupportArticleHeader.propTypes = {
  post: (prop_types__WEBPACK_IMPORTED_MODULE_2___default().object),
  isLoading: (prop_types__WEBPACK_IMPORTED_MODULE_2___default().bool)
};
/* harmony default export */ __webpack_exports__["Z"] = (SupportArticleHeader);

/***/ }),

/***/ 56077:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(56666);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(13980);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4792);
/* harmony import */ var calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(77327);
/* harmony import */ var calypso_state_reader_posts_actions__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(93125);
/* harmony import */ var calypso_state_reader_posts_selectors__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(6712);
/* harmony import */ var calypso_state_sites_selectors_is_simple_site__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(83377);









class QueryReaderPost extends react__WEBPACK_IMPORTED_MODULE_0__.Component {
  constructor() {
    super(...arguments);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "maybeFetch", () => {
      const {
        post,
        postKey,
        isHelpCenter,
        isSimpleSite
      } = this.props;

      if ((0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .isPostKeyLike */ .J0)(postKey) && (!post || post._state === 'minimal')) {
        this.props.fetchPost(postKey, isHelpCenter, isSimpleSite);
      }
    });
  }

  componentDidMount() {
    this.maybeFetch();
  }

  componentDidUpdate() {
    this.maybeFetch();
  }

  render() {
    return null;
  }

}

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(QueryReaderPost, "propTypes", {
  postKey: (prop_types__WEBPACK_IMPORTED_MODULE_4___default().object.isRequired),
  isHelpCenter: (prop_types__WEBPACK_IMPORTED_MODULE_4___default().bool)
});

/* harmony default export */ __webpack_exports__["Z"] = ((0,react_redux__WEBPACK_IMPORTED_MODULE_1__/* .connect */ .$j)((state, ownProps) => ({
  post: (0,calypso_state_reader_posts_selectors__WEBPACK_IMPORTED_MODULE_5__/* .getPostByKey */ .UK)(state, ownProps.postKey),
  isHelpCenter: ownProps.isHelpCenter,
  isSimpleSite: (0,calypso_state_sites_selectors_is_simple_site__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(state)
}), {
  fetchPost: calypso_state_reader_posts_actions__WEBPACK_IMPORTED_MODULE_7__/* .fetchPost */ .SD
})(QueryReaderPost));

/***/ }),

/***/ 9232:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(13980);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4792);
/* harmony import */ var calypso_state_reader_sites_actions__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(63262);
/* harmony import */ var calypso_state_reader_sites_selectors__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(58311);






function QueryReaderSite(_ref) {
  let {
    siteId
  } = _ref;
  const dispatch = (0,react_redux__WEBPACK_IMPORTED_MODULE_1__/* .useDispatch */ .I0)();
  const shouldFetch = (0,react_redux__WEBPACK_IMPORTED_MODULE_1__/* .useSelector */ .v9)(state => (0,calypso_state_reader_sites_selectors__WEBPACK_IMPORTED_MODULE_2__/* .shouldSiteBeFetched */ ._g)(state, siteId));
  (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    if (siteId && shouldFetch) {
      dispatch((0,calypso_state_reader_sites_actions__WEBPACK_IMPORTED_MODULE_3__/* .requestSite */ .LV)(siteId));
    }
  }, [dispatch, siteId, shouldFetch]);
  return null;
}

QueryReaderSite.propTypes = {
  siteId: (prop_types__WEBPACK_IMPORTED_MODULE_4___default().number)
};
/* harmony default export */ __webpack_exports__["Z"] = (QueryReaderSite);

/***/ }),

/***/ 38606:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ QuerySites; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(13980);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(4792);
/* harmony import */ var calypso_state_preferences_selectors__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(85300);
/* harmony import */ var calypso_state_selectors_get_primary_site_id__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(87720);
/* harmony import */ var calypso_state_sites_actions__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(40540);
/* harmony import */ var calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(52239);
/* harmony import */ var calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(58863);
/* harmony import */ var calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(79791);









const getRecentSites = state => (0,calypso_state_preferences_selectors__WEBPACK_IMPORTED_MODULE_5__/* .getPreference */ .Oz)(state, 'recentSites');

const requestAll = () => (dispatch, getState) => {
  if (!(0,calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(getState())) {
    dispatch((0,calypso_state_sites_actions__WEBPACK_IMPORTED_MODULE_4__/* .requestSites */ .BU)());
  }
};

function QueryAll() {
  const dispatch = (0,react_redux__WEBPACK_IMPORTED_MODULE_2__/* .useDispatch */ .I0)();
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    dispatch(requestAll());
  }, [dispatch]);
  return null;
}

const requestSingle = siteId => (dispatch, getState) => {
  if (siteId && !(0,calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(getState(), siteId)) {
    dispatch((0,calypso_state_sites_actions__WEBPACK_IMPORTED_MODULE_4__/* .requestSite */ .LV)(siteId));
  }
};

function QuerySingle(_ref) {
  let {
    siteId
  } = _ref;
  const dispatch = (0,react_redux__WEBPACK_IMPORTED_MODULE_2__/* .useDispatch */ .I0)();
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    if (siteId) {
      dispatch(requestSingle(siteId));
    }
  }, [dispatch, siteId]);
  return null;
}

const requestPrimaryAndRecent = siteIds => (dispatch, getState) => {
  const state = getState();

  if ((0,calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)(state)) {
    return;
  }

  siteIds.forEach(siteId => dispatch(requestSingle(siteId)));
};

function QueryPrimaryAndRecent() {
  const primarySiteId = (0,react_redux__WEBPACK_IMPORTED_MODULE_2__/* .useSelector */ .v9)(calypso_state_selectors_get_primary_site_id__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z); // This should return the same reference every time, so we can compare by reference.

  const recentSiteIds = (0,react_redux__WEBPACK_IMPORTED_MODULE_2__/* .useSelector */ .v9)(getRecentSites);
  const dispatch = (0,react_redux__WEBPACK_IMPORTED_MODULE_2__/* .useDispatch */ .I0)();
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    const siteIds = [...(primarySiteId ? [primarySiteId] : []), ...(recentSiteIds ?? [])];

    if (siteIds.length) {
      dispatch(requestPrimaryAndRecent(siteIds));
    }
  }, [dispatch, primarySiteId, recentSiteIds]);
  return null;
}

function QuerySites(_ref2) {
  let {
    siteId,
    allSites = false,
    primaryAndRecent = false
  } = _ref2;
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react__WEBPACK_IMPORTED_MODULE_1__.Fragment, null, allSites && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(QueryAll, null), siteId && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(QuerySingle, {
    siteId: siteId
  }), primaryAndRecent && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(QueryPrimaryAndRecent, null));
}
QuerySites.propTypes = {
  allSites: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),
  primaryAndRecent: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),
  siteId: prop_types__WEBPACK_IMPORTED_MODULE_9___default().oneOfType([(prop_types__WEBPACK_IMPORTED_MODULE_9___default().number), // The actions and selectors we use also work with site slugs.
  (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string)])
};

/***/ }),

/***/ 66525:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4792);
/* harmony import */ var calypso_state_current_user_selectors__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(36747);
/* harmony import */ var calypso_state_purchases_actions__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(86169);
/* harmony import */ var calypso_state_purchases_selectors__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(12726);






const request = (dispatch, getState) => {
  const state = getState();
  const userId = (0,calypso_state_current_user_selectors__WEBPACK_IMPORTED_MODULE_2__/* .getCurrentUserId */ .rc)(state);
  const isFetching = (0,calypso_state_purchases_selectors__WEBPACK_IMPORTED_MODULE_3__/* .isFetchingUserPurchases */ .Mo)(state);
  const hasLoaded = (0,calypso_state_purchases_selectors__WEBPACK_IMPORTED_MODULE_3__/* .hasLoadedUserPurchasesFromServer */ .iJ)(state);

  if (userId && !isFetching && !hasLoaded) {
    dispatch((0,calypso_state_purchases_actions__WEBPACK_IMPORTED_MODULE_4__/* .fetchUserPurchases */ .Y9)(userId));
  }
};

function QueryUserPurchases() {
  const dispatch = (0,react_redux__WEBPACK_IMPORTED_MODULE_1__/* .useDispatch */ .I0)();
  (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    dispatch(request);
  });
  return null;
}

/* harmony default export */ __webpack_exports__["Z"] = (QueryUserPurchases);

/***/ }),

/***/ 22169:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ EmbedContainer; }
/* harmony export */ });
/* harmony import */ var _automattic_load_script__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(84898);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(91850);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var calypso_lib_load_jquery_dependent_script_desktop_wrapper__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(16771);







const noop = () => {};

const debug = debug__WEBPACK_IMPORTED_MODULE_1___default()('calypso:components:embed-container');
const embedsToLookFor = {
  'blockquote[class^="instagram-"]': embedInstagram,
  'blockquote[class^="twitter-"], a[class^="twitter-"]': embedTwitter,
  'fb\\:post, [class^=fb-]': embedFacebook,
  '[class^=tumblr-]': embedTumblr,
  '.jetpack-slideshow': embedSlideshow,
  '.wp-block-jetpack-story': embedStory,
  '.embed-reddit': embedReddit
};
const cacheBustQuery = `?v=${Math.floor(new Date().getTime() / (1000 * 60 * 60 * 24 * 10))}`; // A new query every 10 days

const SLIDESHOW_URLS = {
  CSS: `https://s0.wp.com/wp-content/mu-plugins/shortcodes/css/slideshow-shortcode.css${cacheBustQuery}`,
  CYCLE_JS: `https://s0.wp.com/wp-content/mu-plugins/shortcodes/js/jquery.cycle.min.js${cacheBustQuery}`,
  JS: `https://s0.wp.com/wp-content/mu-plugins/shortcodes/js/slideshow-shortcode.js${cacheBustQuery}`,
  SPINNER: `https://s0.wp.com/wp-content/mu-plugins/shortcodes/img/slideshow-loader.gif${cacheBustQuery}`
};

function processEmbeds(domNode) {
  Object.entries(embedsToLookFor).forEach(_ref => {
    let [embedSelector, fn] = _ref;
    const nodes = domNode.querySelectorAll(embedSelector);
    (0,lodash__WEBPACK_IMPORTED_MODULE_2__.forEach)((0,lodash__WEBPACK_IMPORTED_MODULE_2__.filter)(nodes, nodeNeedsProcessing), fn);
  });
}

function nodeNeedsProcessing(domNode) {
  if (domNode.hasAttribute('data-wpcom-embed-processed')) {
    return false; // already marked for processing
  }

  domNode.setAttribute('data-wpcom-embed-processed', '1');
  return true;
}

function loadCSS(cssUrl) {
  const link = document.createElement('link');
  link.rel = 'stylesheet';
  link.type = 'text/css';
  link.href = cssUrl;
  document.head.appendChild(link);
}

const loaders = {};

function loadAndRun(scriptUrl, callback) {
  let loader = loaders[scriptUrl];

  if (!loader) {
    loader = new Promise(function (resolve, reject) {
      (0,_automattic_load_script__WEBPACK_IMPORTED_MODULE_0__/* .loadScript */ .ve)(scriptUrl, function (err) {
        if (err) {
          reject(err);
        } else {
          resolve();
        }
      });
    });
    loaders[scriptUrl] = loader;
  }

  loader.then(callback, function (err) {
    debug('error loading ' + scriptUrl, err);
    loaders[scriptUrl] = null;
  });
}

function embedInstagram(domNode) {
  debug('processing instagram for', domNode);

  if (typeof instgrm !== 'undefined') {
    try {
      window.instgrm.Embeds.process();
    } catch (e) {}

    return;
  }

  loadAndRun('https://platform.instagram.com/en_US/embeds.js', embedInstagram.bind(null, domNode));
}

function embedTwitter(domNode) {
  debug('processing twitter for', domNode);

  if (typeof twttr !== 'undefined') {
    try {
      window.twttr.widgets.load(domNode);
    } catch (e) {}

    return;
  }

  loadAndRun('https://platform.twitter.com/widgets.js', embedTwitter.bind(null, domNode));
}

function embedFacebook(domNode) {
  debug('processing facebook for', domNode);

  if (typeof fb !== 'undefined') {
    return;
  }

  loadAndRun('https://connect.facebook.net/en_US/sdk.js#xfbml=1&version=v2.2', noop);
}

function embedReddit(domNode) {
  debug('processing reddit for ', domNode);
  loadAndRun('https://embed.redditmedia.com/widgets/platform.js', noop);
}

let tumblrLoader;

function embedTumblr(domNode) {
  debug('processing tumblr for', domNode);

  if (tumblrLoader) {
    return;
  } // tumblr just wants us to load this script, over and over and over


  tumblrLoader = true;

  function removeScript() {
    (0,lodash__WEBPACK_IMPORTED_MODULE_2__.forEach)(document.querySelectorAll('script[src="https://secure.assets.tumblr.com/post.js"]'), function (el) {
      el.parentNode.removeChild(el);
    });
    tumblrLoader = false;
  }

  setTimeout(function () {
    (0,_automattic_load_script__WEBPACK_IMPORTED_MODULE_0__/* .loadScript */ .ve)('https://secure.assets.tumblr.com/post.js', removeScript);
  }, 30);
}

function triggerJQueryLoadEvent() {
  // force JetpackSlideshow to initialize, in case navigation hasn't caused ready event on document
  window.jQuery('body').trigger('post-load');
}

function createSlideshow() {
  if (window.JetpackSlideshow) {
    triggerJQueryLoadEvent();
  }

  loadAndRun(SLIDESHOW_URLS.JS, () => {
    triggerJQueryLoadEvent();
  });
}

function embedSlideshow(domNode) {
  debug('processing slideshow for', domNode);
  let slideshowCSSPresent = document.head.querySelector(`link[href="${SLIDESHOW_URLS.CSS}"]`); // set global variable required by JetpackSlideshow

  window.jetpackSlideshowSettings = {
    spinner: SLIDESHOW_URLS.SPINNER
  };

  if (!slideshowCSSPresent) {
    slideshowCSSPresent = true;
    loadCSS(SLIDESHOW_URLS.CSS);
  } // Remove no JS warning so user doesn't have to look at it while several scripts load


  const warningElements = domNode.parentNode.getElementsByClassName('jetpack-slideshow-noscript');
  (0,lodash__WEBPACK_IMPORTED_MODULE_2__.forEach)(warningElements, el => {
    el.classList.add('hidden');
  });

  if (window.jQuery && window.jQuery.prototype.cycle) {
    // jQuery and cylcejs exist
    createSlideshow();
  } else if (window.jQuery && !window.jQuery.prototype.cycle) {
    // Only jQuery exists
    loadAndRun(SLIDESHOW_URLS.CYCLE_JS, () => {
      createSlideshow();
    });
  } else {
    // Neither exist
    (0,calypso_lib_load_jquery_dependent_script_desktop_wrapper__WEBPACK_IMPORTED_MODULE_5__/* .loadjQueryDependentScriptDesktopWrapper */ .t)(SLIDESHOW_URLS.CYCLE_JS, () => {
      createSlideshow();
    });
  }
}

function embedStory(domNode) {
  debug('processing story for ', domNode); // wp-story-overlay is here for backwards compatiblity with Stories on Jetpack 9.7 and below.

  const storyLink = domNode.querySelector('a.wp-story-container, a.wp-story-overlay'); // Open story in a new tab

  if (storyLink) {
    storyLink.setAttribute('target', '_blank');
  }
}
/**
 * A component that notices when the content has embeds that require outside JS. Load the outside JS and process the embeds
 */


class EmbedContainer extends react__WEBPACK_IMPORTED_MODULE_3__.PureComponent {
  componentDidMount() {
    processEmbeds(react_dom__WEBPACK_IMPORTED_MODULE_4___default().findDOMNode(this));
  }

  componentDidUpdate() {
    processEmbeds(react_dom__WEBPACK_IMPORTED_MODULE_4___default().findDOMNode(this));
  }

  render() {
    return react__WEBPACK_IMPORTED_MODULE_3__.Children.only(this.props.children);
  }

}

/***/ }),

/***/ 38782:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(56666);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(56399);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(97493);
/* harmony import */ var _automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(47498);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(11481);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(13980);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_9___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_9__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);











class ExternalLink extends react__WEBPACK_IMPORTED_MODULE_3__.Component {
  render() {
    const classes = classnames__WEBPACK_IMPORTED_MODULE_1___default()('external-link', this.props.className, {
      'icon-first': this.props.showIconFirst,
      'has-icon': this.props.icon
    });
    const props = { ...(0,lodash__WEBPACK_IMPORTED_MODULE_2__.omit)(this.props, 'icon', 'iconSize', 'showIconFirst', 'iconClassName'),
      className: classes,
      rel: 'external'
    };

    if (this.props.icon) {
      props.target = '_blank';
    }

    if (props.target) {
      props.rel = props.rel.concat(' noopener noreferrer');
    }

    if (props.href) {
      props.href = (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_4__/* .localizeUrl */ .aq)(props.href);
    }

    const iconComponent = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z, {
      className: this.props.iconClassName,
      icon: "external",
      size: this.props.iconSize
    });
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("a", props, this.props.icon && this.props.showIconFirst && iconComponent, this.props.children, this.props.icon && !this.props.showIconFirst && iconComponent, this.props.icon && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, null, (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_7__/* .translate */ .Iu)('(opens in a new tab)', {
      comment: 'accessibility label for an external link'
    })));
  }

}

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)(ExternalLink, "defaultProps", {
  iconSize: 18,
  showIconFirst: false
});

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)(ExternalLink, "propTypes", {
  className: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),
  href: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().func),
  icon: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),
  iconSize: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().number),
  target: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string),
  showIconFirst: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().bool),
  iconClassName: (prop_types__WEBPACK_IMPORTED_MODULE_9___default().string)
});

/* harmony default export */ __webpack_exports__["Z"] = (ExternalLink);

/***/ }),

/***/ 66753:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ FormTextInput; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(7896);
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(56666);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(13980);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);







class FormTextInput extends react__WEBPACK_IMPORTED_MODULE_2__.PureComponent {
  constructor() {
    super(...arguments);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(this, "state", {
      value: this.props.value || ''
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(this, "currentTextField", undefined);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(this, "textFieldRef", element => {
      this.currentTextField = element;
      const {
        inputRef
      } = this.props;

      if (!inputRef) {
        return;
      }

      if (typeof inputRef === 'function') {
        inputRef(element);
      } else {
        inputRef.current = element;
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(this, "selectOnFocus", event => {
      if (this.props.selectOnFocus) {
        event.target.select();
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(this, "onChange", event => {
      var _this$props$onChange, _this$props;

      this.setState({
        value: event.target.value
      });
      (_this$props$onChange = (_this$props = this.props).onChange) === null || _this$props$onChange === void 0 ? void 0 : _this$props$onChange.call(_this$props, event);
    });
  }

  componentDidUpdate(oldProps) {
    this.updateValueIfNeeded(oldProps.value);
  }

  updateValueIfNeeded(oldValue) {
    const {
      value
    } = this.props;

    if (oldValue !== value || value !== this.state.value) {
      this.setState({
        value
      });
    }
  }

  focus() {
    if (this.currentTextField) {
      this.currentTextField.focus();
    }
  }

  render() {
    const {
      isError,
      isValid,
      selectOnFocus,
      inputRef,
      onChange,
      value,
      ...rest
    } = this.props;
    const classes = classnames__WEBPACK_IMPORTED_MODULE_1___default()('form-text-input', this.props.className, {
      'is-error': this.props.isError,
      'is-valid': this.props.isValid
    });
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("input", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)({
      type: "text"
    }, rest, {
      value: this.state.value,
      ref: this.textFieldRef,
      className: classes,
      onClick: this.selectOnFocus,
      onChange: this.onChange
    }));
  }

}

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(FormTextInput, "propTypes", {
  isError: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().bool),
  isValid: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().bool),
  selectOnFocus: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().bool),
  className: (prop_types__WEBPACK_IMPORTED_MODULE_5___default().string)
});

/***/ }),

/***/ 57925:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(7896);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(98148);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var calypso_components_search__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(12982);








const SearchCard = (_ref, ref) => {
  let {
    className,
    ...props
  } = _ref;
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, {
    className: classnames__WEBPACK_IMPORTED_MODULE_1___default()('search-card', className)
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(calypso_components_search__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({
    ref: ref
  }, props)));
};

/* harmony default export */ __webpack_exports__["Z"] = (/*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_2__.forwardRef)(SearchCard));

/***/ }),

/***/ 12982:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(7896);
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(56666);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(6010);
/* harmony import */ var _automattic_viewport__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(79321);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(5869);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(17108);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(60199);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(11481);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(13980);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_16___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_16__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(88767);
/* harmony import */ var calypso_components_forms_form_text_input__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(66753);
/* harmony import */ var calypso_components_translatable_proptype__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(28816);
/* harmony import */ var calypso_lib_analytics_ga__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(44567);
















/**
 * Internal variables
 */

const SEARCH_DEBOUNCE_MS = 300;

const noop = () => {};

function keyListener(methodToCall, event) {
  switch (event.key) {
    case ' ':
    case 'Enter':
      this[methodToCall](event);
      break;
  }
}

class Search extends react__WEBPACK_IMPORTED_MODULE_3__.Component {
  constructor(props) {
    super(props);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "setOpenIconRef", openIcon => this.openIcon = openIcon);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "setSearchInputRef", input => this.searchInput = input);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "setOverlayRef", overlay => this.overlay = overlay);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "scrollOverlay", () => {
      this.overlay && window.requestAnimationFrame(() => {
        if (this.overlay && this.searchInput) {
          this.overlay.scrollLeft = this.getScrollLeft(this.searchInput);
        }
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "getScrollLeft", inputElement => {
      //TextRange is IE11 specific so this checks if we are not on IE11.
      if (!inputElement.createTextRange) {
        return inputElement.scrollLeft;
      }

      const range = inputElement.createTextRange();
      const inputStyle = window.getComputedStyle(inputElement, undefined);
      const paddingLeft = parseFloat(inputStyle.paddingLeft);
      const rangeRect = range.getBoundingClientRect();
      const scrollLeft = inputElement.getBoundingClientRect().left + inputElement.clientLeft + paddingLeft - rangeRect.left;
      return scrollLeft;
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "focus", () => {
      // if we call focus before the element has been entirely synced up with the DOM, we stand a decent chance of
      // causing the browser to scroll somewhere odd. Instead, defer the focus until a future turn of the event loop.
      setTimeout(() => this.searchInput && this.searchInput.focus(), 0);
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "blur", () => this.searchInput.blur());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "clear", () => this.setState({
      keyword: ''
    }));

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "onBlur", event => {
      if (this.props.onBlur) {
        this.props.onBlur(event);
      }

      this.setState({
        hasFocus: false
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "onChange", event => {
      this.setState({
        keyword: event.target.value
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "openSearch", event => {
      event.preventDefault();
      this.setState({
        keyword: '',
        isOpen: true
      });
      (0,calypso_lib_analytics_ga__WEBPACK_IMPORTED_MODULE_6__/* .gaRecordEvent */ .Yh)(this.props.analyticsGroup, 'Clicked Open Search');
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "closeSearch", event => {
      event.preventDefault();

      if (this.props.disabled) {
        return;
      }

      this.setState({
        keyword: '',
        isOpen: this.props.isOpen || false
      });
      this.searchInput.value = ''; // will not trigger onChange

      if (this.props.pinned) {
        this.searchInput.blur();
        this.openIcon.focus();
      } else {
        this.searchInput.focus();
      }

      this.props.onSearchClose(event);
      (0,calypso_lib_analytics_ga__WEBPACK_IMPORTED_MODULE_6__/* .gaRecordEvent */ .Yh)(this.props.analyticsGroup, 'Clicked Close Search');
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "keyUp", event => {
      if (event.key === 'Enter' && (0,_automattic_viewport__WEBPACK_IMPORTED_MODULE_8__/* .isMobile */ .tq)()) {
        //dismiss soft keyboards
        this.blur();
      }

      if (!this.props.pinned) {
        return;
      }

      if (event.key === 'Escape') {
        this.closeSearch(event);
      }

      this.scrollOverlay();
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "keyDown", event => {
      this.scrollOverlay();

      if (event.key === 'Escape' && event.target.value === '') {
        this.closeSearch(event);
      }

      this.props.onKeyDown(event);
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(this, "onFocus", () => {
      if (!this.searchInput) {
        return;
      }

      const setValue = this.searchInput.value;

      if (setValue) {
        // Firefox needs clear or won't move cursor to end
        this.searchInput.value = '';
        this.searchInput.value = setValue;
      }

      this.setState({
        hasFocus: true
      });
      this.props.onSearchOpen();
    });

    this.instanceId = (0,uuid__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z)();
    this.state = {
      keyword: props.initialValue || '',
      isOpen: !!props.isOpen,
      hasFocus: props.autoFocus
    };
    this.closeListener = keyListener.bind(this, 'closeSearch');
    this.openListener = keyListener.bind(this, 'openSearch');
  }

  // @TODO: Please update https://github.com/Automattic/wp-calypso/issues/58453 if you are refactoring away from UNSAFE_* lifecycle methods!
  UNSAFE_componentWillReceiveProps(nextProps) {
    if (nextProps.onSearch !== this.props.onSearch || nextProps.delaySearch !== this.props.delaySearch) {
      this.onSearch = this.props.delaySearch ? (0,lodash__WEBPACK_IMPORTED_MODULE_2__.debounce)(this.props.onSearch, this.props.delayTimeout) : this.props.onSearch;
    }

    if (this.props.isOpen !== nextProps.isOpen) {
      this.setState({
        isOpen: nextProps.isOpen
      });
    }

    if (this.props.value !== nextProps.value && (nextProps.value || nextProps.value === '') && nextProps.value !== this.state.keyword) {
      this.setState({
        keyword: nextProps.value
      });
    }
  }

  componentDidUpdate(prevProps, prevState) {
    this.scrollOverlay(); // Focus if the search box was opened or the autoFocus prop has changed

    if (this.state.isOpen && !prevState.isOpen || this.props.autoFocus && !prevProps.autoFocus) {
      this.focus();
    }

    if (this.state.keyword === prevState.keyword) {
      return;
    } // if there's a keyword change: trigger search


    if (this.state.keyword) {
      // this.onSearch is debounced when this.props.delaySearch === true
      // this avoids unnecessary fetches while user types
      this.onSearch(this.state.keyword);
    } else {
      // this.props.onSearch is _not_ debounced
      // no need to debounce if ! this.state.keyword
      if (this.props.delaySearch) {
        // Cancel any pending debounce
        this.onSearch.cancel();
      }

      this.props.onSearch(this.state.keyword);
    }

    this.props.onSearchChange(this.state.keyword);
  }

  componentDidMount() {
    this.onSearch = this.props.delaySearch ? (0,lodash__WEBPACK_IMPORTED_MODULE_2__.debounce)(this.props.onSearch, this.props.delayTimeout) : this.props.onSearch;
  }

  render() {
    const searchValue = this.state.keyword;
    const placeholder = this.props.placeholder || i18n_calypso__WEBPACK_IMPORTED_MODULE_10__/* ["default"].translate */ .ZP.translate('Search…', {
      textOnly: true
    });
    const inputLabel = this.props.inputLabel;
    const enableOpenIcon = this.props.pinned && !this.state.isOpen;
    const isOpenUnpinnedOrQueried = this.state.isOpen || !this.props.pinned || this.props.initialValue;
    const autocorrect = this.props.disableAutocorrect && {
      autoComplete: 'off',
      autoCorrect: 'off',
      spellCheck: 'false'
    };
    const searchClass = classnames__WEBPACK_IMPORTED_MODULE_1___default()(this.props.additionalClasses, this.props.dir, {
      'is-expanded-to-container': this.props.fitsContainer,
      'is-open': isOpenUnpinnedOrQueried,
      'is-searching': this.props.searching,
      'is-compact': this.props.compact,
      'has-focus': !this.props.hideFocus && this.state.hasFocus,
      'has-open-icon': !this.props.hideOpenIcon,
      search: true
    });
    const fadeDivClass = classnames__WEBPACK_IMPORTED_MODULE_1___default()('search__input-fade', this.props.dir);
    const inputClass = classnames__WEBPACK_IMPORTED_MODULE_1___default()('search__input', this.props.dir);
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      dir: this.props.dir || null,
      className: searchClass,
      role: "search"
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_11__/* .Spinner */ .$, null), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      role: "button",
      className: "search__icon-navigation",
      ref: this.setOpenIconRef,
      onClick: enableOpenIcon ? this.openSearch : this.focus,
      tabIndex: enableOpenIcon ? '0' : null,
      onKeyDown: enableOpenIcon ? this.openListener : null,
      "aria-controls": 'search-component-' + this.instanceId,
      "aria-label": i18n_calypso__WEBPACK_IMPORTED_MODULE_10__/* ["default"].translate */ .ZP.translate('Open Search', {
        context: 'button label'
      })
    }, !this.props.hideOpenIcon && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
      icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .Z,
      className: "search__open-icon"
    })), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      className: fadeDivClass
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(calypso_components_forms_form_text_input__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .Z)({
      type: "search",
      id: 'search-component-' + this.instanceId,
      autoFocus: this.props.autoFocus // eslint-disable-line jsx-a11y/no-autofocus
      ,
      "aria-describedby": this.props.describedBy,
      "aria-label": inputLabel ? inputLabel : i18n_calypso__WEBPACK_IMPORTED_MODULE_10__/* ["default"].translate */ .ZP.translate('Search'),
      "aria-hidden": !isOpenUnpinnedOrQueried,
      className: inputClass,
      placeholder: placeholder,
      role: "searchbox",
      value: searchValue,
      inputRef: this.setSearchInputRef,
      onChange: this.onChange,
      onKeyUp: this.keyUp,
      onKeyDown: this.keyDown,
      onMouseUp: this.props.onClick,
      onFocus: this.onFocus,
      onBlur: this.onBlur,
      disabled: this.props.disabled,
      autoCapitalize: "none",
      dir: this.props.dir,
      maxLength: this.props.maxLength,
      minLength: this.props.minLength
    }, autocorrect)), this.props.overlayStyling && this.renderStylingDiv()), this.closeButton(), this.props.children);
  }

  renderStylingDiv() {
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      className: "search__text-overlay",
      ref: this.setOverlayRef
    }, this.props.overlayStyling(this.state.keyword));
  }

  closeButton() {
    if (!this.props.hideClose && (this.state.keyword || this.state.isOpen)) {
      return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
        role: "button",
        className: "search__icon-navigation",
        onClick: this.closeSearch,
        tabIndex: "0",
        onKeyDown: this.closeListener,
        "aria-controls": 'search-component-' + this.instanceId,
        "aria-label": i18n_calypso__WEBPACK_IMPORTED_MODULE_10__/* ["default"].translate */ .ZP.translate('Close Search', {
          context: 'button label'
        })
      }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
        icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_15__/* ["default"] */ .Z,
        className: "search__close-icon"
      }));
    }

    return null;
  }

}

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(Search, "propTypes", {
  additionalClasses: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),
  initialValue: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),
  value: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),
  placeholder: calypso_components_translatable_proptype__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z,
  pinned: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),
  delaySearch: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),
  delayTimeout: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number),
  describedBy: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),
  onSearch: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func.isRequired),
  onSearchChange: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),
  onSearchOpen: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),
  onSearchClose: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),
  analyticsGroup: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string),
  overlayStyling: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),
  autoFocus: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),
  disabled: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),
  onKeyDown: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),
  onClick: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),
  disableAutocorrect: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),
  onBlur: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().func),
  searching: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),
  isOpen: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),
  dir: prop_types__WEBPACK_IMPORTED_MODULE_16___default().oneOf(['ltr', 'rtl']),
  fitsContainer: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),
  maxLength: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number),
  minLength: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().number),
  hideClose: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),
  hideFocus: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),
  compact: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),
  hideOpenIcon: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().bool),
  inputLabel: (prop_types__WEBPACK_IMPORTED_MODULE_16___default().string)
});

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(Search, "defaultProps", {
  pinned: false,
  delaySearch: false,
  delayTimeout: SEARCH_DEBOUNCE_MS,
  autoFocus: false,
  disabled: false,
  describedBy: null,
  onSearchChange: noop,
  onSearchOpen: noop,
  onSearchClose: noop,
  onKeyDown: noop,
  onClick: noop,
  //undefined value for overlayStyling is an optimization that will
  //disable overlay scrolling calculation when no overlay is provided.
  overlayStyling: undefined,
  disableAutocorrect: false,
  searching: false,
  isOpen: false,
  dir: undefined,
  fitsContainer: false,
  hideClose: false,
  hideFocus: false,
  compact: false,
  hideOpenIcon: false
});

/* harmony default export */ __webpack_exports__["Z"] = (Search);

/***/ }),

/***/ 28816:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
function translatableStringChecker(props, propName, componentName) {
  componentName = componentName || 'ANONYMOUS';
  const value = props[propName];

  if (value !== undefined && value !== null) {
    if ('string' === typeof value) {
      return null;
    } // Translator Jumpstart old-style


    if ('object' === typeof value && 'data' === value.type) {
      return null;
    } // Translator Jumpstart after #21591


    if ('object' === typeof value && ['object', 'function'].includes(typeof value.type) && ('Translatable' === value.type.name || // Accept HOC wrappings (e.g. `localize( Translatable )`)
    String(value.type.displayName).match(/\(Translatable\)/))) {
      return null;
    }

    return new Error('Invalid value for Translatable string in `' + componentName + '`. Please pass a translate() call.');
  } // assume all ok


  return null;
}

function createChainableTypeChecker(validate) {
  function checkType(isRequired, props, propName, componentName, location) {
    componentName = componentName || 'ANONYMOUS';

    if (props[propName] === undefined) {
      if (isRequired) {
        return new Error('Required ' + location + ' `' + propName + '` was not specified in ' + ('`' + componentName + '`.'));
      }

      return null;
    }

    return validate(props, propName, componentName, location);
  }

  const chainedCheckType = checkType.bind(null, false);
  chainedCheckType.isRequired = checkType.bind(null, true);
  return chainedCheckType;
}

/* harmony default export */ __webpack_exports__["Z"] = (createChainableTypeChecker(translatableStringChecker));

/***/ }),

/***/ 1230:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(6339);
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(82066);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4792);
/* harmony import */ var calypso_lib_wp__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(72429);
/* harmony import */ var calypso_state_selectors_get_current_locale_slug__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(30963);






function useSupportArticleAlternatesQuery(blogId, postId) {
  let queryOptions = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  const locale = (0,react_redux__WEBPACK_IMPORTED_MODULE_1__/* .useSelector */ .v9)(calypso_state_selectors_get_current_locale_slug__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z);
  return (0,react_query__WEBPACK_IMPORTED_MODULE_0__.useQuery)(['support-article-alternates', blogId, postId], () => calypso_lib_wp__WEBPACK_IMPORTED_MODULE_2__/* ["default"].req.get */ .Z.req.get(`/support/alternates/${blogId}/posts/${postId}`), { ...queryOptions,
    enabled: !(0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_4__/* .isDefaultLocale */ .TF)(locale) && !!(blogId && postId),
    refetchOnMount: false,
    refetchOnWindowFocus: false,
    select: data => {
      return data[locale];
    }
  });
}

/* harmony default export */ __webpack_exports__["Z"] = (useSupportArticleAlternatesQuery);

/***/ }),

/***/ 36190:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "wZ": function() { return /* binding */ isGoogleAnalyticsEnabled; },
/* harmony export */   "ZK": function() { return /* binding */ isFloodlightEnabled; },
/* harmony export */   "_O": function() { return /* binding */ isFacebookEnabled; },
/* harmony export */   "n_": function() { return /* binding */ isBingEnabled; },
/* harmony export */   "CO": function() { return /* binding */ isGeminiEnabled; },
/* harmony export */   "xb": function() { return /* binding */ isWpcomGoogleAdsGtagEnabled; },
/* harmony export */   "kL": function() { return /* binding */ isQuantcastEnabled; },
/* harmony export */   "GL": function() { return /* binding */ isOutbrainEnabled; },
/* harmony export */   "eG": function() { return /* binding */ isPinterestEnabled; },
/* harmony export */   "hR": function() { return /* binding */ isIconMediaEnabled; },
/* harmony export */   "Mf": function() { return /* binding */ isTwitterEnabled; },
/* harmony export */   "Q1": function() { return /* binding */ isLinkedinEnabled; },
/* harmony export */   "az": function() { return /* binding */ isCriteoEnabled; },
/* harmony export */   "S$": function() { return /* binding */ isQuoraEnabled; },
/* harmony export */   "nF": function() { return /* binding */ isAdRollEnabled; },
/* harmony export */   "fF": function() { return /* binding */ debug; },
/* harmony export */   "lB": function() { return /* binding */ FACEBOOK_TRACKING_SCRIPT_URL; },
/* harmony export */   "n5": function() { return /* binding */ GOOGLE_GTAG_SCRIPT_URL; },
/* harmony export */   "Dt": function() { return /* binding */ BING_TRACKING_SCRIPT_URL; },
/* harmony export */   "j_": function() { return /* binding */ CRITEO_TRACKING_SCRIPT_URL; },
/* harmony export */   "EV": function() { return /* binding */ YAHOO_GEMINI_AUDIENCE_BUILDING_PIXEL_URL; },
/* harmony export */   "y2": function() { return /* binding */ ICON_MEDIA_RETARGETING_PIXEL_URL; },
/* harmony export */   "yf": function() { return /* binding */ ICON_MEDIA_SIGNUP_PIXEL_URL; },
/* harmony export */   "xV": function() { return /* binding */ ADROLL_PAGEVIEW_PIXEL_URL_1; },
/* harmony export */   "E9": function() { return /* binding */ ADROLL_PAGEVIEW_PIXEL_URL_2; },
/* harmony export */   "O5": function() { return /* binding */ ADROLL_PURCHASE_PIXEL_URL_1; },
/* harmony export */   "pP": function() { return /* binding */ ADROLL_PURCHASE_PIXEL_URL_2; },
/* harmony export */   "Ai": function() { return /* binding */ TWITTER_TRACKING_SCRIPT_URL; },
/* harmony export */   "zR": function() { return /* binding */ LINKED_IN_SCRIPT_URL; },
/* harmony export */   "Uk": function() { return /* binding */ QUORA_SCRIPT_URL; },
/* harmony export */   "L": function() { return /* binding */ OUTBRAIN_SCRIPT_URL; },
/* harmony export */   "cf": function() { return /* binding */ PINTEREST_SCRIPT_URL; },
/* harmony export */   "Hb": function() { return /* binding */ TRACKING_IDS; },
/* harmony export */   "zv": function() { return /* binding */ DCM_FLOODLIGHT_SESSION_COOKIE_NAME; },
/* harmony export */   "oh": function() { return /* binding */ DCM_FLOODLIGHT_SESSION_LENGTH_IN_SECONDS; }
/* harmony export */ });
/* unused harmony exports isGoogleAnalyticsEnhancedEcommerceEnabled, isJetpackGoogleAdsGtagEnabled, isExperianEnabled, isPandoraEnabled, YAHOO_GEMINI_CONVERSION_PIXEL_URL, PANDORA_CONVERSION_PIXEL_URL, EXPERIAN_CONVERSION_PIXEL_URL, ICON_MEDIA_ORDER_PIXEL_URL, GA_PRODUCT_BRAND_WPCOM, GA_PRODUCT_BRAND_JETPACK */
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_1__);

 // Enable/disable ad-tracking
// These should not be put in the json config as they must not differ across environments

const isGoogleAnalyticsEnabled = true;
const isGoogleAnalyticsEnhancedEcommerceEnabled = true;
const isFloodlightEnabled = true;
const isFacebookEnabled = true;
const isBingEnabled = true;
const isGeminiEnabled = false;
const isWpcomGoogleAdsGtagEnabled = true;
const isJetpackGoogleAdsGtagEnabled = true;
const isQuantcastEnabled = false;
const isExperianEnabled = true;
const isOutbrainEnabled = true;
const isPinterestEnabled = true;
const isIconMediaEnabled = false;
const isTwitterEnabled = true;
const isLinkedinEnabled = false;
const isCriteoEnabled = false;
const isPandoraEnabled = false;
const isQuoraEnabled = false;
const isAdRollEnabled = false;
/**
 * Module variables
 */

const debug = debug__WEBPACK_IMPORTED_MODULE_1___default()('calypso:analytics:ad-tracking');
const FACEBOOK_TRACKING_SCRIPT_URL = 'https://connect.facebook.net/en_US/fbevents.js';
const GOOGLE_GTAG_SCRIPT_URL = 'https://www.googletagmanager.com/gtag/js?id=';
const BING_TRACKING_SCRIPT_URL = 'https://bat.bing.com/bat.js';
const CRITEO_TRACKING_SCRIPT_URL = 'https://static.criteo.net/js/ld/ld.js';
const YAHOO_GEMINI_CONVERSION_PIXEL_URL = 'https://sp.analytics.yahoo.com/spp.pl?a=10000&.yp=10014088&ec=wordpresspurchase';
const YAHOO_GEMINI_AUDIENCE_BUILDING_PIXEL_URL = 'https://sp.analytics.yahoo.com/spp.pl?a=10000&.yp=10014088';
const PANDORA_CONVERSION_PIXEL_URL = 'https://data.adxcel-ec2.com/pixel/?ad_log=referer&action=purchase&pixid=7efc5994-458b-494f-94b3-31862eee9e26';
const EXPERIAN_CONVERSION_PIXEL_URL = 'https://d.turn.com/r/dd/id/L21rdC84MTYvY2lkLzE3NDc0MzIzNDgvdC8yL2NhdC8zMjE4NzUwOQ';
const ICON_MEDIA_RETARGETING_PIXEL_URL = 'https://tags.w55c.net/rs?id=cab35a3a79dc4173b8ce2c47adad2cea&t=marketing';
const ICON_MEDIA_SIGNUP_PIXEL_URL = 'https://tags.w55c.net/rs?id=d239e9cb6d164f7299d2dbf7298f930a&t=marketing';
const ICON_MEDIA_ORDER_PIXEL_URL = 'https://tags.w55c.net/rs?id=d299eef42f2d4135a96d0d40ace66f3a&t=checkout';
const ADROLL_PAGEVIEW_PIXEL_URL_1 = 'https://d.adroll.com/ipixel/PEJHFPIHPJC2PD3IMTCWTT/WV6A5O5PBJBIBDYGZHVBM5?name=ded132f8';
const ADROLL_PAGEVIEW_PIXEL_URL_2 = 'https://d.adroll.com/fb/ipixel/PEJHFPIHPJC2PD3IMTCWTT/WV6A5O5PBJBIBDYGZHVBM5?name=ded132f8';
const ADROLL_PURCHASE_PIXEL_URL_1 = 'https://d.adroll.com/ipixel/PEJHFPIHPJC2PD3IMTCWTT/WV6A5O5PBJBIBDYGZHVBM5?name=8eb337b5';
const ADROLL_PURCHASE_PIXEL_URL_2 = 'https://d.adroll.com/fb/ipixel/PEJHFPIHPJC2PD3IMTCWTT/WV6A5O5PBJBIBDYGZHVBM5?name=8eb337b5';
const TWITTER_TRACKING_SCRIPT_URL = 'https://static.ads-twitter.com/uwt.js';
const LINKED_IN_SCRIPT_URL = 'https://snap.licdn.com/li.lms-analytics/insight.min.js';
const QUORA_SCRIPT_URL = 'https://a.quora.com/qevents.js';
const OUTBRAIN_SCRIPT_URL = 'https://amplify.outbrain.com/cp/obtp.js';
const PINTEREST_SCRIPT_URL = 'https://s.pinimg.com/ct/core.js';
const TRACKING_IDS = {
  bingInit: '4074038',
  criteo: '31321',
  dcmFloodlightAdvertiserId: '6355556',
  facebookInit: '823166884443641',
  facebookJetpackInit: '919484458159593',
  fullStory: '120RG4',
  fullStoryJetpack: '181XXV',
  linkedInPartnerId: '195308',
  outbrainAdvId: '00f0f5287433c2851cc0cb917c7ff0465e',
  pinterestInit: '2613194105266',
  quantcast: 'p-3Ma3jHaQMB_bS',
  quoraPixelId: '420845cb70e444938cf0728887a74ca1',
  twitterPixelId: 'nvzbs',
  wpcomGoogleAnalyticsGtag: (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('google_analytics_key'),
  wpcomFloodlightGtag: 'DC-6355556',
  wpcomGoogleAdsGtag: 'AW-946162814',
  wpcomGoogleAdsGtagSignupStart: 'AW-946162814/baDICKzQiq4BEP6YlcMD',
  // "WordPress.com Signup Start"
  wpcomGoogleAdsGtagRegistration: 'AW-946162814/_6cKCK6miZYBEP6YlcMD',
  // "WordPress.com Registration"
  wpcomGoogleAdsGtagSignup: 'AW-946162814/5-NnCKy3xZQBEP6YlcMD',
  // "All Calypso Signups (WordPress.com)"
  wpcomGoogleAdsGtagAddToCart: 'AW-946162814/MF4yCNi_kZYBEP6YlcMD',
  // "WordPress.com AddToCart"
  wpcomGoogleAdsGtagPurchase: 'AW-946162814/taG8CPW8spQBEP6YlcMD',
  // "WordPress.com Purchase Gtag"
  jetpackGoogleAnalyticsGtag: 'UA-52447-43',
  // Jetpack Gtag (Analytics) for use in Jetpack x WordPress.com Flows
  jetpackGoogleGA4Gtag: 'G-YELRMVV4YG',
  jetpackGoogleAdsGtagPurchase: 'AW-946162814/kIF1CL3ApfsBEP6YlcMD'
}; // This name is something we created to store a session id for DCM Floodlight session tracking

const DCM_FLOODLIGHT_SESSION_COOKIE_NAME = 'dcmsid';
const DCM_FLOODLIGHT_SESSION_LENGTH_IN_SECONDS = 1800;
const GA_PRODUCT_BRAND_WPCOM = 'WordPress.com';
const GA_PRODUCT_BRAND_JETPACK = 'Jetpack';

/***/ }),

/***/ 33675:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "j": function() { return /* binding */ recordParamsInFloodlightGtag; },
/* harmony export */   "I": function() { return /* binding */ recordPageViewInFloodlight; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(36115);
/* harmony import */ var cookie__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(13421);
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(88767);
/* harmony import */ var calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(1444);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(36190);
/* harmony import */ var _setup__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(28122);




 // Ensure setup has run.


/**
 * Records Floodlight events using Gtag and automatically adds `u4`, `u5`, and `allow_custom_scripts: true`.
 *
 * @param {object} params An object of Floodlight params.
 */

function recordParamsInFloodlightGtag(params) {
  if (!(0,calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)() || !_constants__WEBPACK_IMPORTED_MODULE_4__/* .isFloodlightEnabled */ .ZK) {
    return;
  } // Adds u4 (user id) and u5 (anonymous user id) parameters


  const defaults = { ...floodlightUserParams(),
    // See: https://support.google.com/searchads/answer/7566546?hl=en
    allow_custom_scripts: true
  };
  const finalParams = ['event', 'conversion', { ...defaults,
    ...params
  }];
  (0,_constants__WEBPACK_IMPORTED_MODULE_4__/* .debug */ .fF)('recordParamsInFloodlightGtag:', finalParams);
  window.gtag(...finalParams);
}
/**
 * Returns an object with DCM Floodlight user params
 *
 * @returns {object} With the WordPress.com user id and/or the logged out Tracks id
 */

function floodlightUserParams() {
  const params = {};
  const currentUser = (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .getCurrentUser */ .ts)();
  const anonymousUserId = (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .getTracksAnonymousUserId */ .di)();

  if (currentUser) {
    params.u4 = currentUser.hashedPii.ID;
  }

  if (anonymousUserId) {
    params.u5 = anonymousUserId;
  }

  return params;
}
/**
 * Returns the DCM Floodlight session id, generating a new one if there's not already one
 *
 * @returns {string} The session id
 */


function floodlightSessionId() {
  const cookies = cookie__WEBPACK_IMPORTED_MODULE_1__.parse(document.cookie);
  const existingSessionId = cookies[_constants__WEBPACK_IMPORTED_MODULE_4__/* .DCM_FLOODLIGHT_SESSION_COOKIE_NAME */ .zv];

  if (existingSessionId) {
    (0,_constants__WEBPACK_IMPORTED_MODULE_4__/* .debug */ .fF)('Floodlight: Existing session: ' + existingSessionId);
    return existingSessionId;
  } // Generate a 32-byte random session id


  const newSessionId = (0,uuid__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)().replace(new RegExp('-', 'g'), '');
  (0,_constants__WEBPACK_IMPORTED_MODULE_4__/* .debug */ .fF)('Floodlight: New session: ' + newSessionId);
  return newSessionId;
}
/**
 * Track a page view in DCM Floodlight
 *
 * @param {string} urlPath - The URL path
 * @returns {void}
 */


function recordPageViewInFloodlight(urlPath) {
  if (!(0,calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)() || !_constants__WEBPACK_IMPORTED_MODULE_4__/* .isFloodlightEnabled */ .ZK) {
    return;
  }

  const sessionId = floodlightSessionId(); // Set or bump the cookie's expiration date to maintain the session

  document.cookie = cookie__WEBPACK_IMPORTED_MODULE_1__.serialize(_constants__WEBPACK_IMPORTED_MODULE_4__/* .DCM_FLOODLIGHT_SESSION_COOKIE_NAME */ .zv, sessionId, {
    maxAge: _constants__WEBPACK_IMPORTED_MODULE_4__/* .DCM_FLOODLIGHT_SESSION_LENGTH_IN_SECONDS */ .oh
  });
  (0,_constants__WEBPACK_IMPORTED_MODULE_4__/* .debug */ .fF)('retarget: recordPageViewInFloodlight: wpvisit');
  recordParamsInFloodlightGtag({
    session_id: sessionId,
    u6: urlPath,
    u7: sessionId,
    send_to: 'DC-6355556/wordp0/wpvisit+per_session'
  });
  (0,_constants__WEBPACK_IMPORTED_MODULE_4__/* .debug */ .fF)('retarget: recordPageViewInFloodlight: wppv');
  recordParamsInFloodlightGtag({
    u6: urlPath,
    u7: sessionId,
    send_to: 'DC-6355556/wordp0/wppv+standard'
  });
}

/***/ }),

/***/ 98565:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "cY": function() { return /* binding */ setup; },
/* harmony export */   "$Q": function() { return /* binding */ firePageView; }
/* harmony export */ });
/* unused harmony exports fireJetpackEcommercePurchase, fireJetpackEcommerceAddToCart */
/* harmony import */ var calypso_lib_jetpack_is_jetpack_cloud__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9415);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(36190);
/* harmony import */ var _setup__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(28122);

 // Ensure setup has run.


function setup(params) {
  // TODO: GA4 properties for WPCOM will be here
  if ((0,calypso_lib_jetpack_is_jetpack_cloud__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)()) {
    window.gtag('config', _constants__WEBPACK_IMPORTED_MODULE_2__/* .TRACKING_IDS.jetpackGoogleGA4Gtag */ .Hb.jetpackGoogleGA4Gtag, params);
  }
}
function fireJetpackEcommercePurchase(purchase) {
  window.gtag('event', 'purchase', {
    send_to: TRACKING_IDS.jetpackGoogleGA4Gtag,
    ...purchase
  });
}
function fireJetpackEcommerceAddToCart(item) {
  window.gtag('event', 'add_to_cart', {
    send_to: TRACKING_IDS.jetpackGoogleGA4Gtag,
    value: item.price,
    currency: 'USD',
    items: [item]
  });
}
function firePageView(title, location) {
  let shouldSendToJetpack = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

  if (shouldSendToJetpack) {
    window.gtag('event', 'page_view', {
      send_to: _constants__WEBPACK_IMPORTED_MODULE_2__/* .TRACKING_IDS.jetpackGoogleGA4Gtag */ .Hb.jetpackGoogleGA4Gtag,
      page_title: title,
      page_location: location
    });
  }
}

/***/ }),

/***/ 95157:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "LT": function() { return /* binding */ setupGoogleAnalyticsGtag; },
/* harmony export */   "mf": function() { return /* binding */ isGoogleAnalyticsAllowed; },
/* harmony export */   "Uk": function() { return /* binding */ getGoogleAnalyticsDefaultConfig; },
/* harmony export */   "vL": function() { return /* binding */ fireGoogleAnalyticsPageView; },
/* harmony export */   "Zf": function() { return /* binding */ fireGoogleAnalyticsEvent; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(36115);
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(20899);
/* harmony import */ var calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(32486);
/* harmony import */ var calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(43621);
/* harmony import */ var calypso_lib_jetpack_is_jetpack_cloud__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9415);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(36190);
/* harmony import */ var _google_analytics_4__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(98565);
/* harmony import */ var _setup__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(28122);





 // Ensure setup has run.


function setupGoogleAnalyticsGtag(params) {
  _google_analytics_4__WEBPACK_IMPORTED_MODULE_4__/* .setup */ .cY(params);
  window.gtag('config', _constants__WEBPACK_IMPORTED_MODULE_5__/* .TRACKING_IDS.wpcomGoogleAnalyticsGtag */ .Hb.wpcomGoogleAnalyticsGtag, params);

  if ((0,calypso_lib_jetpack_is_jetpack_cloud__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)()) {
    window.gtag('config', _constants__WEBPACK_IMPORTED_MODULE_5__/* .TRACKING_IDS.jetpackGoogleAnalyticsGtag */ .Hb.jetpackGoogleAnalyticsGtag, params);
  }
}
/**
 * Returns whether Google Analytics is allowed.
 *
 * This function returns false if:
 *
 * 1. `isGoogleAnalyticsEnabled` is `true`
 * 2. `ad-tracking` feature is disabled
 * 3. `Do Not Track` is enabled
 * 4. the current user could be in the GDPR zone and hasn't consented to tracking
 * 5. `document.location.href` may contain personally identifiable information
 *
 * Note that getDoNotTrack() and isPiiUrl() can change at any time which is why we do not cache them.
 *
 * @returns {boolean} true if GA is allowed.
 */

function isGoogleAnalyticsAllowed() {
  return _constants__WEBPACK_IMPORTED_MODULE_5__/* .isGoogleAnalyticsEnabled */ .wZ && _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* ["default"].isEnabled */ .ZP.isEnabled('ad-tracking') && !(0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .getDoNotTrack */ .vX)() && !(0,calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)() && (0,calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)();
}
/**
 * Returns the default configuration for Google Analytics
 *
 * @returns {object} GA's default config
 */

function getGoogleAnalyticsDefaultConfig() {
  const currentUser = (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .getCurrentUser */ .ts)();
  return { ...(currentUser && {
      user_id: currentUser.hashedPii.ID
    }),
    anonymize_ip: true,
    transport_type: 'function' === typeof window.navigator.sendBeacon ? 'beacon' : 'xhr',
    use_amp_client_id: true,
    custom_map: {
      dimension3: 'client_id'
    },
    linker: (0,calypso_lib_jetpack_is_jetpack_cloud__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)() ? {
      domains: ['wordpress.com']
    } : {
      accept_incoming: true
    }
  };
}
/**
 * Fires Google Analytics page view event
 *
 * @param {string} urlPath The path of the current page
 * @param {string} pageTitle The title of the current page
 * @param {boolean} useJetpackGoogleAnalytics send the page view to Jetpack Google Analytics
 */

function fireGoogleAnalyticsPageView(urlPath, pageTitle) {
  let useJetpackGoogleAnalytics = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  _google_analytics_4__WEBPACK_IMPORTED_MODULE_4__/* .firePageView */ .$Q(pageTitle, urlPath, useJetpackGoogleAnalytics);
  const params = { ...getGoogleAnalyticsDefaultConfig(),
    page_path: urlPath,
    page_title: pageTitle
  };
  window.gtag('config', _constants__WEBPACK_IMPORTED_MODULE_5__/* .TRACKING_IDS.wpcomGoogleAnalyticsGtag */ .Hb.wpcomGoogleAnalyticsGtag, params);

  if (useJetpackGoogleAnalytics) {
    window.gtag('config', _constants__WEBPACK_IMPORTED_MODULE_5__/* .TRACKING_IDS.jetpackGoogleAnalyticsGtag */ .Hb.jetpackGoogleAnalyticsGtag, params);
  }
}
/**
 * Fires a generic Google Analytics event
 *
 * @param {string} category Is the string that will appear as the event category.
 * @param {string} action Is the string that will appear as the event action in Google Analytics Event reports.
 * @param {string} label Is the string that will appear as the event label.
 * @param {number} value Is a non-negative integer that will appear as the event value.
 */

function fireGoogleAnalyticsEvent(category, action, label, value) {
  window.gtag('event', action, {
    event_category: category,
    event_label: label,
    value: value
  });
}

/***/ }),

/***/ 30214:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_": function() { return /* binding */ loadTrackingScripts; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(36115);
/* harmony import */ var _automattic_load_script__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(84898);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(36190);
/* harmony import */ var _setup__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(28122);


 // Ensure setup has run.


const loadTrackingScripts = attemptLoad(async () => {
  const scripts = getTrackingScriptsToLoad();
  let hasError = false;

  for (const src of scripts) {
    try {
      // We use `await` to load each script one by one and allow the GUI to load and be responsive while
      // the trackers get loaded in a user friendly manner.
      await (0,_automattic_load_script__WEBPACK_IMPORTED_MODULE_1__/* .loadScript */ .ve)(src);
    } catch (error) {
      hasError = true;
      (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('loadTrackingScripts: [Load Error] a tracking script failed to load: ', error);
    }

    (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('loadTrackingScripts: [Loaded]', src);
  }

  if (hasError) {
    throw new Error('One or more tracking scripts failed to load');
  }

  (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('loadTrackingScripts: load done');
  initLoadedTrackingScripts(); // uses JSON.stringify for consistency with recordOrder()

  (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('loadTrackingScripts: dataLayer:', JSON.stringify(window.dataLayer, null, 2));
});

function getTrackingScriptsToLoad() {
  const scripts = [];

  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isFacebookEnabled */ ._O) {
    scripts.push(_constants__WEBPACK_IMPORTED_MODULE_3__/* .FACEBOOK_TRACKING_SCRIPT_URL */ .lB);
  } // The Gtag script needs to be loaded with an ID in the URL so we search for the first available one.


  const enabledGtags = [_constants__WEBPACK_IMPORTED_MODULE_3__/* .isGoogleAnalyticsEnabled */ .wZ && _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.wpcomGoogleAnalyticsGtag */ .Hb.wpcomGoogleAnalyticsGtag, _constants__WEBPACK_IMPORTED_MODULE_3__/* .isWpcomGoogleAdsGtagEnabled */ .xb && _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.wpcomGoogleAdsGtag */ .Hb.wpcomGoogleAdsGtag, _constants__WEBPACK_IMPORTED_MODULE_3__/* .isFloodlightEnabled */ .ZK && _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.wpcomFloodlightGtag */ .Hb.wpcomFloodlightGtag].filter(id => false !== id);

  if (enabledGtags.length > 0) {
    scripts.push(_constants__WEBPACK_IMPORTED_MODULE_3__/* .GOOGLE_GTAG_SCRIPT_URL */ .n5 + enabledGtags[0]);
  }

  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isBingEnabled */ .n_) {
    scripts.push(_constants__WEBPACK_IMPORTED_MODULE_3__/* .BING_TRACKING_SCRIPT_URL */ .Dt);
  }

  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isCriteoEnabled */ .az) {
    scripts.push(_constants__WEBPACK_IMPORTED_MODULE_3__/* .CRITEO_TRACKING_SCRIPT_URL */ .j_);
  }

  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isQuantcastEnabled */ .kL) {
    scripts.push(quantcastAsynchronousTagURL());
  }

  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isTwitterEnabled */ .Mf) {
    scripts.push(_constants__WEBPACK_IMPORTED_MODULE_3__/* .TWITTER_TRACKING_SCRIPT_URL */ .Ai);
  }

  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isLinkedinEnabled */ .Q1) {
    scripts.push(_constants__WEBPACK_IMPORTED_MODULE_3__/* .LINKED_IN_SCRIPT_URL */ .zR);
  }

  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isQuoraEnabled */ .S$) {
    scripts.push(_constants__WEBPACK_IMPORTED_MODULE_3__/* .QUORA_SCRIPT_URL */ .Uk);
  }

  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isOutbrainEnabled */ .GL) {
    scripts.push(_constants__WEBPACK_IMPORTED_MODULE_3__/* .OUTBRAIN_SCRIPT_URL */ .L);
  }

  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isPinterestEnabled */ .eG) {
    scripts.push(_constants__WEBPACK_IMPORTED_MODULE_3__/* .PINTEREST_SCRIPT_URL */ .cf);
  }

  return scripts;
}

function initLoadedTrackingScripts() {
  // init Facebook
  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isFacebookEnabled */ ._O) {
    initFacebook();
  } // init Bing


  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isBingEnabled */ .n_) {
    const bingConfig = {
      ti: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.bingInit */ .Hb.bingInit,
      q: window.uetq
    };

    if (typeof UET !== 'undefined') {
      // bing's script creates the UET global for us
      window.uetq = new UET(bingConfig); // eslint-disable-line
    }
  } // init Twitter


  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isTwitterEnabled */ .Mf) {
    window.twq('init', _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.twitterPixelId */ .Hb.twitterPixelId);
  } // init Quora


  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isQuoraEnabled */ .S$) {
    window.qp('init', _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.quoraPixelId */ .Hb.quoraPixelId);
  } // init Pinterest


  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isPinterestEnabled */ .eG) {
    const currentUser = (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .getCurrentUser */ .ts)();
    const params = currentUser ? {
      em: currentUser.hashedPii.email
    } : {};
    window.pintrk('load', _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.pinterestInit */ .Hb.pinterestInit, params);
  }

  (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('loadTrackingScripts: init done');
} // Returns a function that has the following behavior:
// - when called, tries to call `loader` and returns a promise that resolves when load is finished
// - when `loader` is already in progress, don't issue two concurrent calls: wait for the first to finish
// - when `loader` fails, DON'T return a rejected promise. Instead, leave it unresolved and let the caller
//   wait, potentially forever. Next call to the loader function has a chance to succeed and resolve the
//   promise, for the current and all previous callers. That effectively implements a queue.


function attemptLoad(loader) {
  let setLoadResult;
  let status = 'not-loading';
  const loadResult = new Promise(resolve => {
    setLoadResult = resolve;
  });
  return () => {
    if (status === 'not-loading') {
      status = 'loading';
      loader().then(result => {
        status = 'loaded';
        setLoadResult(result);
      }, () => {
        status = 'not-loading';
      });
    }

    return loadResult;
  };
}
/**
 * Returns the URL for Quantcast's Purchase Confirmation Tag
 *
 * @see https://www.quantcast.com/help/guides/using-the-quantcast-asynchronous-tag/
 * @returns {string} The URL
 */


function quantcastAsynchronousTagURL() {
  const protocolAndSubdomain = document.location.protocol === 'https:' ? 'https://secure' : 'http://edge';
  return protocolAndSubdomain + '.quantserve.com/quant.js';
}
/**
 * Initializes the Facebook pixel.
 *
 * When the user is logged in, additional hashed data is being forwarded.
 * See https://developers.facebook.com/docs/facebook-pixel/pixel-with-ads/conversion-tracking#advanced_match
 */


function initFacebook() {
  let advancedMatching = {};
  const currentUser = (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .getCurrentUser */ .ts)();

  if (currentUser) {
    advancedMatching = {
      em: currentUser.hashedPii.email
    };
  }

  (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('initFacebook', advancedMatching); // WP Facebook pixel

  window.fbq('init', _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.facebookInit */ .Hb.facebookInit, advancedMatching); // Jetpack Facebook pixel
  // Also initialize the FB pixel for Jetpack.
  // However, disable auto-config for this secondary pixel ID.
  // See: <https://developers.facebook.com/docs/facebook-pixel/api-reference#automatic-configuration>

  window.fbq('set', 'autoConfig', false, _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.facebookJetpackInit */ .Hb.facebookJetpackInit);
  window.fbq('init', _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.facebookJetpackInit */ .Hb.facebookJetpackInit, advancedMatching);
}

/***/ }),

/***/ 32985:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "a": function() { return /* binding */ retarget; }
/* harmony export */ });
/* harmony import */ var calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(7369);
/* harmony import */ var calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(1444);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(36190);
/* harmony import */ var _floodlight__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(33675);
/* harmony import */ var _load_tracking_scripts__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(30214);
/* harmony import */ var _setup__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(28122);



 // Ensure setup has run.

 // Retargeting events are fired once every `retargetingPeriod` seconds.

const retargetingPeriod = 60 * 60 * 24; // Last time the retarget() function effectively fired (Unix time in seconds).

let lastRetargetTime = 0;
/**
 * Fire tracking events for the purposes of retargeting on all Calypso pages
 *
 * @param {string} urlPath The URL path we should report to the ad-trackers which may be different from the actual one
 * for privacy reasons.
 * @returns {void}
 */

async function retarget(urlPath) {
  await (0,calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)();

  if (!(0,calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)()) {
    (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: [Skipping] ad tracking is not allowed', urlPath);
    return;
  }

  await (0,_load_tracking_scripts__WEBPACK_IMPORTED_MODULE_4__/* .loadTrackingScripts */ ._)();
  (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget:', urlPath); // Non rate limited retargeting (main trackers)
  // Quantcast

  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isQuantcastEnabled */ .kL) {
    const params = {
      qacct: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.quantcast */ .Hb.quantcast,
      event: 'refresh'
    };
    (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: [Quantcast]', params);

    window._qevents.push(params);
  } // Facebook


  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isFacebookEnabled */ ._O) {
    const params = ['trackSingle', _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.facebookInit */ .Hb.facebookInit, 'PageView'];
    (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: [Facebook]', params);
    window.fbq(...params);
  } // Bing


  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isBingEnabled */ .n_) {
    (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: [Bing]');
    window.uetq.push('pageLoad');
  } // Wordpress.com Google Ads Gtag


  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isWpcomGoogleAdsGtagEnabled */ .xb) {
    const params = ['config', _constants__WEBPACK_IMPORTED_MODULE_3__/* .TRACKING_IDS.wpcomGoogleAdsGtag */ .Hb.wpcomGoogleAdsGtag, {
      page_path: urlPath
    }];
    (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: [Google Ads] WPCom', params);
    window.gtag(...params);
  } // Floodlight


  (0,_floodlight__WEBPACK_IMPORTED_MODULE_5__/* .recordPageViewInFloodlight */ .I)(urlPath); // Pinterest

  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isPinterestEnabled */ .eG) {
    (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: [Pinterest]');
    window.pintrk('page');
  } // AdRoll


  if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isAdRollEnabled */ .nF) {
    (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: [AdRoll]');
    window.adRoll.trackPageview();
  } // Rate limited retargeting (secondary trackers)


  const nowTimestamp = Date.now() / 1000;

  if (nowTimestamp >= lastRetargetTime + retargetingPeriod) {
    lastRetargetTime = nowTimestamp; // Outbrain

    if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isOutbrainEnabled */ .GL) {
      const params = ['track', 'PAGE_VIEW'];
      (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: [Outbrain] [rate limited]', params);
      window.obApi(...params);
    } // Icon Media


    if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isIconMediaEnabled */ .hR) {
      const params = _constants__WEBPACK_IMPORTED_MODULE_3__/* .ICON_MEDIA_RETARGETING_PIXEL_URL */ .y2;
      (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: [Icon Media] [rate limited]', params);
      new window.Image().src = params;
    } // Twitter


    if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isTwitterEnabled */ .Mf) {
      const params = ['track', 'PageView'];
      (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: [Twitter] [rate limited]', params);
      window.twq(...params);
    } // Yahoo Gemini


    if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isGeminiEnabled */ .CO) {
      const params = _constants__WEBPACK_IMPORTED_MODULE_3__/* .YAHOO_GEMINI_AUDIENCE_BUILDING_PIXEL_URL */ .EV;
      (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: [Yahoo Gemini] [rate limited]', params);
      new window.Image().src = params;
    } // Quora


    if (_constants__WEBPACK_IMPORTED_MODULE_3__/* .isQuoraEnabled */ .S$) {
      const params = ['track', 'ViewContent'];
      (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: [Quora] [rate limited]', params);
      window.qp(...params);
    }
  } // uses JSON.stringify for consistency with recordOrder()


  (0,_constants__WEBPACK_IMPORTED_MODULE_3__/* .debug */ .fF)('retarget: dataLayer:', JSON.stringify(window.dataLayer, null, 2));
}

/***/ }),

/***/ 28122:
/***/ (function(__unused_webpack_module, __unused_webpack___webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(36190);


if (typeof window !== 'undefined') {
  setupGtag(); // Facebook

  if (_constants__WEBPACK_IMPORTED_MODULE_0__/* .isFacebookEnabled */ ._O) {
    setupFacebookGlobal();
  } // Bing


  if (_constants__WEBPACK_IMPORTED_MODULE_0__/* .isBingEnabled */ .n_ && !window.uetq) {
    window.uetq = [];
  } // Criteo


  if (_constants__WEBPACK_IMPORTED_MODULE_0__/* .isCriteoEnabled */ .az && !window.criteo_q) {
    window.criteo_q = [];
  } // Quantcast


  if (_constants__WEBPACK_IMPORTED_MODULE_0__/* .isQuantcastEnabled */ .kL && !window._qevents) {
    window._qevents = [];
  } // Google Ads Gtag for wordpress.com


  if (_constants__WEBPACK_IMPORTED_MODULE_0__/* .isWpcomGoogleAdsGtagEnabled */ .xb) {
    setupWpcomGoogleAdsGtag();
  }

  if (_constants__WEBPACK_IMPORTED_MODULE_0__/* .isFloodlightEnabled */ .ZK) {
    setupWpcomFloodlightGtag();
  } // Twitter


  if (_constants__WEBPACK_IMPORTED_MODULE_0__/* .isTwitterEnabled */ .Mf) {
    setupTwitterGlobal();
  } // Linkedin


  if (_constants__WEBPACK_IMPORTED_MODULE_0__/* .isLinkedinEnabled */ .Q1) {
    setupLinkedinGlobal();
  } // Quora


  if (_constants__WEBPACK_IMPORTED_MODULE_0__/* .isQuoraEnabled */ .S$) {
    setupQuoraGlobal();
  } // Outbrain


  if (_constants__WEBPACK_IMPORTED_MODULE_0__/* .isOutbrainEnabled */ .GL) {
    setupOutbrainGlobal();
  } // Pinterest


  if (_constants__WEBPACK_IMPORTED_MODULE_0__/* .isPinterestEnabled */ .eG) {
    setupPinterestGlobal();
  } // AdRoll


  if (_constants__WEBPACK_IMPORTED_MODULE_0__/* .isAdRollEnabled */ .nF) {
    setupAdRollGlobal();
  }
}
/**
 * Initializes Linkedin tracking.
 */


function setupLinkedinGlobal() {
  if (!window._linkedin_data_partner_id) {
    window._linkedin_data_partner_id = _constants__WEBPACK_IMPORTED_MODULE_0__/* .TRACKING_IDS.linkedInPartnerId */ .Hb.linkedInPartnerId;
  }
}
/**
 * Initializes Quora tracking.
 * This is a rework of the obfuscated tracking code provided by Quora.
 */


function setupQuoraGlobal() {
  if (window.qp) {
    return;
  }

  const quoraPixel = window.qp = function () {
    quoraPixel.qp ? quoraPixel.qp.apply(quoraPixel, arguments) : quoraPixel.queue.push(arguments);
  };

  quoraPixel.queue = [];
}
/**
 * This sets up the globals that the Facebook event library expects.
 * More info here: https://www.facebook.com/business/help/952192354843755
 */


function setupFacebookGlobal() {
  if (window.fbq) {
    return;
  }

  const facebookEvents = window.fbq = function () {
    if (facebookEvents.callMethod) {
      facebookEvents.callMethod.apply(facebookEvents, arguments);
    } else {
      facebookEvents.queue.push(arguments);
    }
  };

  if (!window._fbq) {
    window._fbq = facebookEvents;
  }
  /*
   * Disable automatic PageView pushState tracking. It causes problems when we're using multiple FB pixel IDs.
   * The objective here is to avoid firing a PageView against multiple FB pixel IDs. By disabling pushState tracking,
   * we can do PageView tracking for FB on our own. See: `retarget()` in this file.
   *
   * There's more about the `disablePushState` flag here:
   * <https://developers.facebook.com/ads/blog/post/2017/05/29/tagging-a-single-page-application-facebook-pixel/>
   */


  window._fbq.disablePushState = true;
  facebookEvents.push = facebookEvents;
  facebookEvents.loaded = true;
  facebookEvents.version = '2.0';
  facebookEvents.queue = [];
}
/**
 * This sets up the global `twq` function that Twitter expects.
 * More info here: https://github.com/Automattic/wp-calypso/pull/10235
 */


function setupTwitterGlobal() {
  if (window.twq) {
    return;
  }

  const twq = window.twq = function () {
    twq.exe ? twq.exe.apply(twq, arguments) : twq.queue.push(arguments);
  };

  twq.version = '1.1';
  twq.queue = [];
}

function setupOutbrainGlobal() {
  const api = window.obApi = function () {
    api.dispatch ? api.dispatch.apply(api, arguments) : api.queue.push(arguments);
  };

  api.version = '1.0';
  api.loaded = true;
  api.marketerId = _constants__WEBPACK_IMPORTED_MODULE_0__/* .TRACKING_IDS.outbrainAdvId */ .Hb.outbrainAdvId;
  api.queue = [];
}

function setupPinterestGlobal() {
  if (!window.pintrk) {
    window.pintrk = function () {
      window.pintrk.queue.push(Array.prototype.slice.call(arguments));
    };

    const n = window.pintrk;
    n.queue = [];
    n.version = '3.0';
  }
}

function setupAdRollGlobal() {
  if (!window.adRoll) {
    window.adRoll = {
      trackPageview: function () {
        new window.Image().src = _constants__WEBPACK_IMPORTED_MODULE_0__/* .ADROLL_PAGEVIEW_PIXEL_URL_1 */ .xV;
        new window.Image().src = _constants__WEBPACK_IMPORTED_MODULE_0__/* .ADROLL_PAGEVIEW_PIXEL_URL_2 */ .E9;
      },
      trackPurchase: function () {
        new window.Image().src = _constants__WEBPACK_IMPORTED_MODULE_0__/* .ADROLL_PURCHASE_PIXEL_URL_1 */ .O5;
        new window.Image().src = _constants__WEBPACK_IMPORTED_MODULE_0__/* .ADROLL_PURCHASE_PIXEL_URL_2 */ .pP;
      }
    };
  }
}

function setupGtag() {
  if (window.dataLayer && window.gtag) {
    return;
  }

  window.dataLayer = window.dataLayer || [];

  window.gtag = function () {
    window.dataLayer.push(arguments);
  };

  window.gtag('js', new Date());
}

function setupWpcomGoogleAdsGtag() {
  window.gtag('config', _constants__WEBPACK_IMPORTED_MODULE_0__/* .TRACKING_IDS.wpcomGoogleAdsGtag */ .Hb.wpcomGoogleAdsGtag);
}

function setupWpcomFloodlightGtag() {
  window.gtag('config', _constants__WEBPACK_IMPORTED_MODULE_0__/* .TRACKING_IDS.wpcomFloodlightGtag */ .Hb.wpcomFloodlightGtag);
}

/***/ }),

/***/ 25394:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "K": function() { return /* binding */ trackCustomFacebookConversionEvent; },
/* harmony export */   "w": function() { return /* binding */ trackCustomAdWordsRemarketingEvent; }
/* harmony export */ });
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36190);
/* harmony import */ var _setup__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(28122);
 // Ensure setup has run.


/**
 * Fire custom facebook conversion tracking event.
 *
 * @param {string} name - The name of the custom event.
 * @param {object} properties - The custom event attributes.
 * @returns {void}
 */

function trackCustomFacebookConversionEvent(name, properties) {
  window.fbq && window.fbq('trackSingleCustom', _constants__WEBPACK_IMPORTED_MODULE_1__/* .TRACKING_IDS.facebookInit */ .Hb.facebookInit, name, properties);
}
/**
 * Fire custom adwords conversation tracking event.
 *
 * @param {object} properties - The custom event attributes.
 * @returns {void}
 */

function trackCustomAdWordsRemarketingEvent(properties) {
  (0,_constants__WEBPACK_IMPORTED_MODULE_1__/* .debug */ .fF)('trackCustomAdWordsRemarketingEvent:', properties); // Not sure this is currently serving any purpose and whether we can convert it to use Gtag.
  // Refactoring the middleware for analytics is outside the scope of this PR so I'll leave the function stub for now.

  /*
  window.google_trackConversion &&
  	window.google_trackConversion( {
  		google_conversion_id: ADWORDS_CONVERSION_ID,
  		google_custom_params: properties,
  		google_remarketing_only: true,
  	} );
  */
}

/***/ }),

/***/ 46272:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "U": function() { return /* binding */ retargetFullStory; },
/* harmony export */   "K": function() { return /* binding */ recordFullStoryEvent; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(36115);
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(20899);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var calypso_lib_e2e__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(94776);
/* harmony import */ var calypso_lib_jetpack_is_jetpack_cloud__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(9415);
/* harmony import */ var _ad_tracking_constants__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(36190);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(32486);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(43621);







const fullStoryDebug = debug__WEBPACK_IMPORTED_MODULE_2___default()('calypso:analytics:fullstory');
let fullStoryScriptLoaded = false;
function retargetFullStory() {
  maybeAddFullStoryScript();

  if (!window.FS) {
    return;
  }

  fullStoryDebug('retargetFullStory');
  window.FS.restart();
  maybeIdentifyUser();
}
function recordFullStoryEvent(name, _props) {
  maybeAddFullStoryScript();

  if (!window.FS || !name) {
    return;
  }

  const props = suffixPropsAccordingToSpec(_props);
  fullStoryDebug('recordFullStoryEvent:', {
    name,
    props
  });
  window.FS.event(name, props);
  maybeIdentifyUser();
}

function maybeAddFullStoryScript() {
  if (fullStoryScriptLoaded || !_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* ["default"].isEnabled */ .ZP.isEnabled('fullstory') || (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .getDoNotTrack */ .vX)() || (0,calypso_lib_e2e__WEBPACK_IMPORTED_MODULE_4__/* .isE2ETest */ .b)() || (0,_utils__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)() || !(0,_utils__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)()) {
    if (!fullStoryScriptLoaded) {
      fullStoryDebug('maybeAddFullStoryScript:', false);
    }

    return;
  }

  fullStoryScriptLoaded = true;
  fullStoryDebug('maybeAddFullStoryScript:', true);
  window._fs_debug = 'development' === "production";
  window._fs_host = 'fullstory.com';
  window._fs_script = 'edge.fullstory.com/s/fs.js';
  window._fs_org = (0,calypso_lib_jetpack_is_jetpack_cloud__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)() ? _ad_tracking_constants__WEBPACK_IMPORTED_MODULE_7__/* .TRACKING_IDS.fullStoryJetpack */ .Hb.fullStoryJetpack : _ad_tracking_constants__WEBPACK_IMPORTED_MODULE_7__/* .TRACKING_IDS.fullStory */ .Hb.fullStory;
  window._fs_namespace = 'FS';

  (function (m, n, e, t, l, o, g, y) {
    fullStoryDebug('maybeAddFullStoryScript:', 'script loading');

    if (e in m) {
      if (m.console && m.console.log) {
        m.console.log('FullStory namespace conflict. Please set window._fs_namespace.');
      }

      return;
    }

    g = m[e] = function (a, b, s) {
      g.q ? g.q.push([a, b, s]) : g._api(a, b, s);
    };

    g.q = [];
    o = n.createElement(t);
    o.async = 1;
    o.crossOrigin = 'anonymous';
    o.src = 'https://' + window._fs_script;
    y = n.getElementsByTagName(t)[0];
    y.parentNode.insertBefore(o, y);

    g.identify = function (i, v, s) {
      g(l, {
        uid: i
      }, s);
      if (v) g(l, v, s);
    };

    g.setUserVars = function (v, s) {
      g(l, v, s);
    };

    g.event = function (i, v, s) {
      g('event', {
        n: i,
        p: v
      }, s);
    };

    g.anonymize = function () {
      g.identify(!!0);
    };

    g.shutdown = function () {
      g('rec', !1);
    };

    g.restart = function () {
      g('rec', !0);
    };

    g.log = function (a, b) {
      g('log', [a, b]);
    };

    g.consent = function (a) {
      g('consent', !arguments.length || a);
    };

    g.identifyAccount = function (i, v) {
      o = 'account';
      v = v || {};
      v.acctId = i;
      g(o, v);
    };

    g.clearUserCookie = function () {};

    g.setVars = function (_n, p) {
      g('setVars', [_n, p]);
    };

    g._w = {};
    y = 'XMLHttpRequest';
    g._w[y] = m[y];
    y = 'fetch';
    g._w[y] = m[y];
    if (m[y]) m[y] = function () {
      return g._w[y].apply(this, arguments);
    };
    g._v = '1.3.0';
  })(window, document, window._fs_namespace, 'script', 'user');
}

function maybeIdentifyUser() {
  if (!window.FS) {
    return;
  }

  const currentUser = (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .getCurrentUser */ .ts)();

  if (currentUser) {
    fullStoryDebug('maybeIdentifyUser:', currentUser);
    window.FS.identify(currentUser.hashedPii.ID);
  }
}

function suffixPropsAccordingToSpec(_props) {
  const props = {};
  _props = typeof _props === 'object' ? _props : {};

  for (const [key, value] of Object.entries(_props)) {
    const type = typeof value;

    if (type === 'string') {
      props[key + '_str'] = value;
    } else if (type === 'boolean') {
      props[key + '_bool'] = value;
    } else if (type === 'number' || type === 'bigint') {
      if (String(value).indexOf('.') !== -1) {
        props[key + '_real'] = value;
      } else {
        props[key + '_int'] = value;
      }
    } else if (type === 'object') {
      props[key] = suffixPropsAccordingToSpec(value);
    }
  }

  return props;
}

/***/ }),

/***/ 44567:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "eK": function() { return /* binding */ gaRecordPageView; },
/* harmony export */   "Yh": function() { return /* binding */ gaRecordEvent; }
/* harmony export */ });
/* unused harmony export makeGoogleAnalyticsTrackingFunction */
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_lib_analytics_ad_tracking__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(95157);


const gaDebug = debug__WEBPACK_IMPORTED_MODULE_0___default()('calypso:analytics:ga');
let initialized = false;

function initialize() {
  if (!initialized) {
    const params = {
      send_page_view: false,
      ...(0,calypso_lib_analytics_ad_tracking__WEBPACK_IMPORTED_MODULE_1__/* .getGoogleAnalyticsDefaultConfig */ .Uk)()
    };
    gaDebug('parameters:', params);
    (0,calypso_lib_analytics_ad_tracking__WEBPACK_IMPORTED_MODULE_1__/* .setupGoogleAnalyticsGtag */ .LT)(params);
    initialized = true;
  }
}

const gaRecordPageView = makeGoogleAnalyticsTrackingFunction(function recordPageView(urlPath, pageTitle) {
  let useJetpackGoogleAnalytics = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  gaDebug('Recording Page View ~ [URL: ' + urlPath + '] [Title: ' + pageTitle + '] [useJetpackGoogleAnalytics: ' + useJetpackGoogleAnalytics + ']');
  (0,calypso_lib_analytics_ad_tracking__WEBPACK_IMPORTED_MODULE_1__/* .fireGoogleAnalyticsPageView */ .vL)(urlPath, pageTitle, useJetpackGoogleAnalytics);
});
/**
 * Fires a generic Google Analytics event
 *
 * {string} category Is the string that will appear as the event category.
 * {string} action Is the string that will appear as the event action in Google Analytics Event reports.
 * {string} label Is the string that will appear as the event label.
 * {string} value Is a non-negative integer that will appear as the event value.
 */

const gaRecordEvent = makeGoogleAnalyticsTrackingFunction(function recordEvent(category, action, label, value) {
  if ('undefined' !== typeof value && !isNaN(Number(String(value)))) {
    value = Math.round(Number(String(value))); // GA requires an integer value.
    // https://developers.google.com/analytics/devguides/collection/analyticsjs/field-reference#eventValue
  }

  let debugText = 'Recording Event ~ [Category: ' + category + '] [Action: ' + action + ']';

  if ('undefined' !== typeof label) {
    debugText += ' [Option Label: ' + label + ']';
  }

  if ('undefined' !== typeof value) {
    debugText += ' [Option Value: ' + value + ']';
  }

  gaDebug(debugText);
  (0,calypso_lib_analytics_ad_tracking__WEBPACK_IMPORTED_MODULE_1__/* .fireGoogleAnalyticsEvent */ .Zf)(category, action, label, value);
});
/**
 * Wrap Google Analytics with debugging, possible analytics supression, and initialization
 *
 * This method will display debug output if Google Analytics is suppresed, otherwise it will
 * initialize and call the Google Analytics function it is passed.
 *
 * @see isGoogleAnalyticsAllowed
 * @param  {Function} func Google Analytics tracking function
 * @returns {Function} Wrapped function
 */

function makeGoogleAnalyticsTrackingFunction(func) {
  return function () {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    if (!(0,calypso_lib_analytics_ad_tracking__WEBPACK_IMPORTED_MODULE_1__/* .isGoogleAnalyticsAllowed */ .mf)()) {
      gaDebug('[Disallowed] analytics %s( %o )', func.name, args);
      return;
    }

    initialize();
    func(...args);
  };
}

/***/ }),

/***/ 80252:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "o": function() { return /* binding */ addHotJarScript; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(36115);
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(20899);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var calypso_lib_e2e__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(94776);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(32486);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(43621);





const hotjarDebug = debug__WEBPACK_IMPORTED_MODULE_2___default()('calypso:analytics:hotjar');
let hotJarScriptLoaded = false;
function addHotJarScript() {
  if (hotJarScriptLoaded || !(0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP)('hotjar_enabled') || (0,calypso_lib_e2e__WEBPACK_IMPORTED_MODULE_3__/* .isE2ETest */ .b)() || (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .getDoNotTrack */ .vX)() || (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)() || !(0,_utils__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)()) {
    hotjarDebug('Not loading HotJar script');
    return;
  }

  (function (h, o, t, j, a, r) {
    hotjarDebug('Loading HotJar script');

    h.hj = h.hj || function () {
      (h.hj.q = h.hj.q || []).push(arguments);
    };

    h._hjSettings = {
      hjid: 227769,
      hjsv: 5
    };
    a = o.getElementsByTagName('head')[0];
    r = o.createElement('script');
    r.async = 1;
    r.src = t + h._hjSettings.hjid + j + h._hjSettings.hjsv;
    a.appendChild(r);
  })(window, document, '//static.hotjar.com/c/hotjar-', '.js?sv=');

  hotJarScriptLoaded = true;
}

/***/ }),

/***/ 70858:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "M": function() { return /* binding */ initializeAnalytics; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(36115);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_1__);


/**
 * Module variables
 */

const debug = debug__WEBPACK_IMPORTED_MODULE_1___default()('calypso:analytics:init');
async function initializeAnalytics(currentUser, superProps) {
  await (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .initializeAnalytics */ .MB)(currentUser, superProps);
  const user = (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .getCurrentUser */ .ts)(); // This block is necessary because calypso-analytics/initializeAnalytics no longer calls out to ad-tracking

  if ('object' === typeof currentUser && user && (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .getTracksAnonymousUserId */ .di)()) {
    const mod = await __webpack_require__.e(/* import() | lib-analytics-ad-tracking-record-alias-in-floodlight */ 474).then(__webpack_require__.bind(__webpack_require__, 11209));
    const {
      recordAliasInFloodlight
    } = mod;
    debug('recordAliasInFloodlight', user);
    recordAliasInFloodlight();
  }
}

/***/ }),

/***/ 7689:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "P": function() { return /* binding */ bumpStat; },
/* harmony export */   "S": function() { return /* binding */ bumpStatWithPageView; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_1__);


const mcDebug = debug__WEBPACK_IMPORTED_MODULE_1___default()('calypso:analytics:mc');

function buildQuerystring(group, name) {
  let uriComponent = '';

  if ('object' === typeof group) {
    for (const key in group) {
      uriComponent += '&x_' + encodeURIComponent(key) + '=' + encodeURIComponent(group[key]);
    }
  } else {
    uriComponent = '&x_' + encodeURIComponent(group) + '=' + encodeURIComponent(name);
  }

  return uriComponent;
}

function buildQuerystringNoPrefix(group, name) {
  let uriComponent = '';

  if ('object' === typeof group) {
    for (const key in group) {
      uriComponent += '&' + encodeURIComponent(key) + '=' + encodeURIComponent(group[key]);
    }
  } else {
    uriComponent = '&' + encodeURIComponent(group) + '=' + encodeURIComponent(name);
  }

  return uriComponent;
}

function bumpStat(group, name) {
  if ('object' === typeof group) {
    mcDebug('Bumping stats %o', group);
  } else {
    mcDebug('Bumping stat %s:%s', group, name);
  }

  if ('undefined' !== typeof window && (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('mc_analytics_enabled')) {
    const uriComponent = buildQuerystring(group, name);
    new window.Image().src = document.location.protocol + '//pixel.wp.com/g.gif?v=wpcom-no-pv' + uriComponent + '&t=' + Math.random();
  }
}
function bumpStatWithPageView(group, name) {
  // this function is fairly dangerous, as it bumps page views for wpcom and should only be called in very specific cases.
  if ('object' === typeof group) {
    mcDebug('Bumping page view with props %o', group);
  } else {
    mcDebug('Bumping page view %s:%s', group, name);
  }

  if ('undefined' !== typeof window && (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('mc_analytics_enabled')) {
    const uriComponent = buildQuerystringNoPrefix(group, name);
    new window.Image().src = document.location.protocol + '//pixel.wp.com/g.gif?v=wpcom' + uriComponent + '&t=' + Math.random();
  }
}

/***/ }),

/***/ 66610:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "A": function() { return /* binding */ recordPageView; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(36115);
/* harmony import */ var _automattic_viewport__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(79321);
/* harmony import */ var calypso_lib_analytics_ad_tracking__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(32985);
/* harmony import */ var calypso_lib_analytics_fullstory__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(46272);
/* harmony import */ var calypso_lib_analytics_sem__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(93513);
/* harmony import */ var calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(11915);
/* harmony import */ var calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(7369);
/* harmony import */ var _ga__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(44567);
/* harmony import */ var _queue__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(38602);
/* harmony import */ var _refer__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(5323);
// pageView is a wrapper for pageview events across Tracks and GA.









function recordPageView(urlPath, pageTitle) {
  let params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  let options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  // Add delay to avoid stale `_dl` in recorded calypso_page_view event details.
  // `_dl` (browserdocumentlocation) is read from the current URL by external JavaScript.
  setTimeout(() => {
    // Add device type to Tracks page view event.
    params.device_type = (0,_automattic_viewport__WEBPACK_IMPORTED_MODULE_6__/* .resolveDeviceTypeByViewPort */ .jv)(); // Tracks, Google Analytics, Refer platform.

    (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .recordTracksPageViewWithPageParams */ .w2)(urlPath, params);
    safeGoogleAnalyticsPageView(urlPath, pageTitle, options === null || options === void 0 ? void 0 : options.useJetpackGoogleAnalytics);
    (0,_refer__WEBPACK_IMPORTED_MODULE_5__/* .referRecordPageView */ .G)(); // Retargeting.

    (0,calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)();
    (0,calypso_lib_analytics_sem__WEBPACK_IMPORTED_MODULE_2__/* .updateQueryParamsTracking */ .n)();
    (0,calypso_lib_analytics_ad_tracking__WEBPACK_IMPORTED_MODULE_8__/* .retarget */ .a)(urlPath); // FullStory.

    (0,calypso_lib_analytics_fullstory__WEBPACK_IMPORTED_MODULE_1__/* .retargetFullStory */ .U)(); // Process queue.

    (0,_queue__WEBPACK_IMPORTED_MODULE_4__/* .processQueue */ .V)();
  }, 0);
}

async function safeGoogleAnalyticsPageView(urlPath, pageTitle) {
  let useJetpackGoogleAnalytics = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  await (0,calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z)();
  (0,_ga__WEBPACK_IMPORTED_MODULE_3__/* .gaRecordPageView */ .eK)(urlPath, pageTitle, useJetpackGoogleAnalytics);
}

/***/ }),

/***/ 38602:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "x": function() { return /* binding */ addToQueue; },
/* harmony export */   "V": function() { return /* binding */ processQueue; }
/* harmony export */ });
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
// This is a `localStorage` queue for delayed event triggers.

/**
 * Module variables
 */

const queueDebug = debug__WEBPACK_IMPORTED_MODULE_0___default()('calypso:analytics:queue'); // The supported modules for which queue triggers can be set up.
// We use a layer of indirection to avoid loading the modules until they're needed.

const modules = {
  signup: () => __webpack_require__.e(/* import() | lib-analytics-signup */ 874).then(__webpack_require__.bind(__webpack_require__, 48528))
};

const lsKey = () => 'analyticsQueue';

function clear() {
  if (!window.localStorage) {
    return; // Not possible.
  }

  window.localStorage.removeItem(lsKey());
}

function get() {
  if (!window.localStorage) {
    return []; // Not possible.
  }

  let items = window.localStorage.getItem(lsKey());
  items = items ? JSON.parse(items) : [];
  items = Array.isArray(items) ? items : [];
  return items;
}

function runTrigger(moduleName, trigger) {
  for (var _len = arguments.length, args = new Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
    args[_key - 2] = arguments[_key];
  }

  if ('string' === typeof trigger && 'function' === typeof modules[moduleName]) {
    modules[moduleName]().then(mod => {
      if ('function' === typeof mod[trigger]) {
        mod[trigger].apply(null, args || undefined);
      }
    });
  }

  return; // Not possible.
}
/**
 * Add an item to the analytics queue.
 *
 * @param {string} moduleName the name of the module where the queued method exists, e.g. `signup`.
 * See the `modules` constant at the top of this file (`lib/analytics/queue.js`).
 * @param {string} trigger the exported function in the chosen module to be run, e.g. `recordSignupStart` in `signup`.
 * @param  {...any} args the arguments to be passed to the chosen function. Optional.
 */


function addToQueue(moduleName, trigger) {
  for (var _len2 = arguments.length, args = new Array(_len2 > 2 ? _len2 - 2 : 0), _key2 = 2; _key2 < _len2; _key2++) {
    args[_key2 - 2] = arguments[_key2];
  }

  if (!window.localStorage) {
    // If unable to queue, trigger it now.
    return runTrigger(moduleName, trigger, ...args);
  }

  let items = get();
  const newItem = {
    moduleName,
    trigger,
    args
  };
  items.push(newItem);
  items = items.slice(-100); // Upper limit.

  queueDebug('Adding new item to queue.', newItem);
  window.localStorage.setItem(lsKey(), JSON.stringify(items));
}
/**
 * Process the existing analytics queue, by running any pending triggers and clearing it.
 */

function processQueue() {
  if (!window.localStorage) {
    return; // Not possible.
  }

  const items = get();
  clear();
  queueDebug('Processing items in queue.', items);
  items.forEach(item => {
    if ('object' === typeof item && 'string' === typeof item.trigger) {
      queueDebug('Processing item in queue.', item);
      runTrigger(item.moduleName, item.trigger, ...item.args);
    }
  });
}

/***/ }),

/***/ 5323:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "G": function() { return /* binding */ referRecordPageView; }
/* harmony export */ });
/* harmony import */ var calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(78920);
/* harmony import */ var _track_affiliate_referral__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(39297);
/* harmony import */ var _tracks__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(17032);
// Refer platform tracking.



function referRecordPageView() {
  if (!window || !window.location) {
    return; // Not possible.
  }

  const referrer = window.location.href;
  const parsedUrl = (0,calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(referrer);
  const affiliateId = (parsedUrl === null || parsedUrl === void 0 ? void 0 : parsedUrl.searchParams.get('aff')) || (parsedUrl === null || parsedUrl === void 0 ? void 0 : parsedUrl.searchParams.get('affiliate'));
  const campaignId = parsedUrl === null || parsedUrl === void 0 ? void 0 : parsedUrl.searchParams.get('cid');
  const subId = parsedUrl === null || parsedUrl === void 0 ? void 0 : parsedUrl.searchParams.get('sid');

  if (affiliateId && !isNaN(affiliateId)) {
    (0,_tracks__WEBPACK_IMPORTED_MODULE_1__.recordTracksEvent)('calypso_refer_visit', {
      page: parsedUrl.host + parsedUrl.pathname
    });
    (0,_track_affiliate_referral__WEBPACK_IMPORTED_MODULE_0__/* .trackAffiliateReferral */ .l)({
      affiliateId,
      campaignId,
      subId,
      referrer
    });
  }
}

/***/ }),

/***/ 93513:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "n": function() { return /* binding */ updateQueryParamsTracking; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(36115);
/* harmony import */ var cookie__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(13421);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(78920);




/**
 * Const variables.
 */

const debug = debug__WEBPACK_IMPORTED_MODULE_2___default()('calypso:analytics:sem');
const UTM_COOKIE_MAX_AGE = 60 * 60 * 24 * 365;
const MAX_UTM_LENGTH = 128;
const MAX_URL_PARAM_VALUE_LENGTH = 50;
const MAX_KEYWORD_PARAM_VALUE_LENGTH = 80;
const MAX_GCLID_PARAM_VALUE_LENGTH = 100; // These are the URL params that end up in the `ad_details` cookie

const ALLOWED_URL_PARAMS = ['adgroupid', 'campaignid', 'device', 'gclid', 'gclsrc', 'fbclid', 'keyword', 'matchtype', 'network', 'type', 'term', 'utm_campaign', 'utm_content', 'utm_medium', 'utm_source', 'utm_term', 'targetid', // QuanticMind
'locationid', // QuanticMind
'ref', 'format' // amp/non-amp
];
const VALID_UTM_SOURCE_CAMPAIGN = new RegExp('^[a-zA-Z\\d_\\-]{1,' + MAX_UTM_LENGTH + '}$');

function isValidUtmSourceOrCampaign(value) {
  return VALID_UTM_SOURCE_CAMPAIGN.test(value);
}

function isValidOtherUrlParamValue(key, value) {
  if ('gclid' === key) {
    return value.length <= MAX_GCLID_PARAM_VALUE_LENGTH;
  } else if ('keyword' === key) {
    return value.length <= MAX_KEYWORD_PARAM_VALUE_LENGTH;
  }

  return value.length <= MAX_URL_PARAM_VALUE_LENGTH;
}

function isValidAndAllowedUrlParamValue(key, value) {
  if (-1 === ALLOWED_URL_PARAMS.indexOf(key)) {
    return false;
  } else if ('utm_source' === key || 'utm_campaign' === value) {
    return isValidUtmSourceOrCampaign(value);
  }

  return isValidOtherUrlParamValue(key, value);
}

function setUtmCookie(name, value) {
  document.cookie = cookie__WEBPACK_IMPORTED_MODULE_1__.serialize(name, value, {
    path: '/',
    maxAge: UTM_COOKIE_MAX_AGE,
    // NOTE: Domains having more than a single extension (e.g., example.us.com)
    // would require additional custom logic to work out the root domain name.
    domain: '.' + document.location.hostname.split('.').slice(-2).join('.')
  });
}
/**
 * Updates tracking based on URL query parameters.
 */


function updateQueryParamsTracking() {
  var _urlParseAmpCompatibl;

  if (!document.location.search) {
    debug('No query data in URL.');
    return;
  }

  const searchParams = (_urlParseAmpCompatibl = (0,calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(document.location.href)) === null || _urlParseAmpCompatibl === void 0 ? void 0 : _urlParseAmpCompatibl.searchParams; // Sanitize query params

  let sanitizedQuery = new URLSearchParams();

  if (searchParams) {
    const validEntries = Array.from(searchParams.entries()).filter(_ref => {
      let [key, value] = _ref;
      return isValidAndAllowedUrlParamValue(key, value);
    });
    sanitizedQuery = new URLSearchParams(validEntries); // Cross domain tracking for AMP.

    if (searchParams.get('amp_client_id')) {
      (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .pushEventToTracksQueue */ .lH)(['identifyAnonUser', searchParams.get('amp_client_id')]);
    }
  } // Drop SEM cookie update if either of these is missing


  if (!sanitizedQuery.get('utm_source') || !sanitizedQuery.get('utm_campaign')) {
    debug('Missing utm_source or utm_campaign.');
    return;
  } // Regenerate sanitized query string


  const sanitizedQueryString = sanitizedQuery.toString();

  if (sanitizedQueryString) {
    debug('ad_details: ' + sanitizedQueryString);
    setUtmCookie('ad_details', sanitizedQueryString);
    setUtmCookie('ad_timestamp', Math.floor(new Date().getTime() / 1000));
  }
}

/***/ }),

/***/ 21058:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(35899);
/* harmony import */ var calypso_state_current_user_selectors__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36747);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(17014);





const getSuperProps = reduxStore => eventProperties => {
  const state = reduxStore.getState();
  const superProps = {
    environment: "production",
    environment_id: (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('env_id'),
    site_count: (0,calypso_state_current_user_selectors__WEBPACK_IMPORTED_MODULE_1__/* .getCurrentUserSiteCount */ .bo)(state) || 0,
    site_id_label: 'wpcom',
    client: (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('client_slug')
  };
  const omitSelectedSite = (0,calypso_lib_analytics_utils__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(eventProperties.path);
  const selectedSite = omitSelectedSite ? null : (0,calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(state);

  if (selectedSite) {
    Object.assign(superProps, {
      // Tracks expects a blog_id property to identify the blog which is
      // why we use it here instead of calling the property site_id
      blog_id: selectedSite.ID,
      // Tracks expects a blog_lang property to identify the blog language which is
      // why we use it here instead of calling the property site_language
      blog_lang: selectedSite.lang,
      site_id_label: selectedSite.jetpack ? 'jetpack' : 'wpcom',
      site_plan_id: selectedSite.plan ? selectedSite.plan.product_id : null
    });
  }

  return superProps;
};

/* harmony default export */ __webpack_exports__["Z"] = (getSuperProps);

/***/ }),

/***/ 39297:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "l": function() { return /* binding */ trackAffiliateReferral; }
/* harmony export */ });
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var calypso_lib_analytics_tracks__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(17032);



const referDebug = debug__WEBPACK_IMPORTED_MODULE_0___default()('calypso:analytics:refer');
const allowedEventProps = ['status', 'success', 'duplicate', 'description', 'cookie_id', 'vendor_id', 'affiliate_id', 'campaign_id', 'sub_id', 'referrer'];
async function trackAffiliateReferral(_ref) {
  let {
    affiliateId,
    campaignId,
    subId,
    referrer
  } = _ref;
  referDebug('Recording affiliate referral.', {
    affiliateId,
    campaignId,
    subId,
    referrer
  });
  const headers = {
    'Content-Type': 'application/x-www-form-urlencoded; charset=UTF-8',
    Accept: 'application/json'
  };
  const body = new URLSearchParams({
    affiliate_id: affiliateId,
    campaign_id: campaignId || '',
    sub_id: subId || '',
    referrer: referrer || ''
  }).toString();
  referDebug('Fetching Refer platform response.');

  try {
    const response = await window.fetch('https://refer.wordpress.com/clicks/67402', {
      credentials: 'include',
      // Needed to check and set the 'wp-affiliate-tracker' cookie.
      method: 'POST',
      headers,
      body
    });
    const json = await response.json();

    if (response.ok) {
      referDebug('Recording Refer platform success response.', json);
      (0,calypso_lib_analytics_tracks__WEBPACK_IMPORTED_MODULE_2__.recordTracksEvent)('calypso_refer_visit_response', { ...(0,lodash__WEBPACK_IMPORTED_MODULE_1__.pick)(json.data, allowedEventProps),
        status: response.status || '',
        success: json.success || true,
        description: json.message || 'success'
      });
      return;
    }

    referDebug('Recording Refer platform error response.', json);
    (0,calypso_lib_analytics_tracks__WEBPACK_IMPORTED_MODULE_2__.recordTracksEvent)('calypso_refer_visit_response', { ...(0,lodash__WEBPACK_IMPORTED_MODULE_1__.pick)(json.data, allowedEventProps),
      status: response.status || '',
      success: json.success || false,
      description: json.message || 'error'
    });
  } catch (error) {
    // Exception from `fetch` usually means network error. Don't report these to Tracks.
    referDebug('Failed to fetch Refer platform response.', error);
  }
}

/***/ }),

/***/ 17032:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "tracksEvents": function() { return /* binding */ tracksEvents; },
/* harmony export */   "recordTracksEvent": function() { return /* binding */ recordTracksEvent; },
/* harmony export */   "recordTracksPageView": function() { return /* binding */ recordTracksPageView; },
/* harmony export */   "setTracksOptOut": function() { return /* binding */ setTracksOptOut; }
/* harmony export */ });
/* harmony import */ var events__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(22699);
/* harmony import */ var events__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(events__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36115);


const tracksEvents = new events__WEBPACK_IMPORTED_MODULE_0__.EventEmitter();
function recordTracksEvent(eventName, eventProperties) {
  _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .analyticsEvents.once */ .MR.once('record-event', (_eventName, _eventProperties) => {
    tracksEvents.emit('record-event', _eventName, _eventProperties);
  });
  (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)(eventName, eventProperties);
}
function recordTracksPageView(urlPath, params) {
  (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksPageView */ .P6)(urlPath, params);
}
function setTracksOptOut(isOptingOut) {
  (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .pushEventToTracksQueue */ .lH)(['setOptOut', isOptingOut]);
}

/***/ }),

/***/ 87360:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Module variables
 */

/* harmony default export */ __webpack_exports__["Z"] = (debug__WEBPACK_IMPORTED_MODULE_0___default()('calypso:analytics:utils'));

/***/ }),

/***/ 1444:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ isAdTrackingAllowed; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(36115);
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(20899);
/* harmony import */ var _debug__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(87360);
/* harmony import */ var _is_pii_url__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(32486);
/* harmony import */ var _is_url_excluded_for_performance__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(69874);
/* harmony import */ var _may_we_track_current_user_gdpr__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(43621);






/**
 * Returns whether ad tracking is allowed.
 *
 * This function returns false if:
 *
 * 1. 'ad-tracking' is disabled
 * 2. `Do Not Track` is enabled
 * 3. the current user could be in the GDPR zone and hasn't consented to tracking
 * 4. `document.location.href` may contain personally identifiable information
 *
 * @returns {boolean} Is ad tracking is allowed?
 */

function isAdTrackingAllowed() {
  const result = _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* ["default"].isEnabled */ .ZP.isEnabled('ad-tracking') && !(0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_0__/* .getDoNotTrack */ .vX)() && !(0,_is_url_excluded_for_performance__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)() && !(0,_is_pii_url__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)() && (0,_may_we_track_current_user_gdpr__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)();
  (0,_debug__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(`isAdTrackingAllowed: ${result}`);
  return result;
}

/***/ }),

/***/ 76814:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ isCountryInGdprZone; }
/* harmony export */ });
const GDPR_COUNTRIES = [// European Member countries
'AT', // Austria
'BE', // Belgium
'BG', // Bulgaria
'CY', // Cyprus
'CZ', // Czech Republic
'DE', // Germany
'DK', // Denmark
'EE', // Estonia
'ES', // Spain
'FI', // Finland
'FR', // France
'GR', // Greece
'HR', // Croatia
'HU', // Hungary
'IE', // Ireland
'IT', // Italy
'LT', // Lithuania
'LU', // Luxembourg
'LV', // Latvia
'MT', // Malta
'NL', // Netherlands
'PL', // Poland
'PT', // Portugal
'RO', // Romania
'SE', // Sweden
'SI', // Slovenia
'SK', // Slovakia
'GB', // United Kingdom
// Single Market Countries that GDPR applies to
'CH', // Switzerland
'IS', // Iceland
'LI', // Liechtenstein
'NO' // Norway
];
/**
 * Returns a boolean telling whether a country is in the GDPR zone.
 *
 * @param countryCode The country code to look for.
 * @returns Whether the country is in the GDPR zone
 */

function isCountryInGdprZone(countryCode) {
  return countryCode !== undefined && GDPR_COUNTRIES.includes(countryCode);
}

/***/ }),

/***/ 32486:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ isPiiUrl; }
/* harmony export */ });
/* harmony import */ var _debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(87360);
 // If this list catches things that are not necessarily forbidden we're ok with
// a little bit of approximation as long as we do catch the ones that we have to.
// We need to be quite aggressive with how we filter candiate pages as failing
// to protect our users' privacy puts us in breach of our own TOS and our
// retargeting partners' TOS. We also see personally identifiable information in
// unexpected places like email addresses in users' posts URLs and titles for
// various (usually accidental) reasons. We also pass PII in URLs like
// `wordpress.com/jetpack/connect` and `wordpress.com/error-report`.

const forbiddenPiiPatterns = ['@', 'email=', 'email_address=', 'first=', 'last=', 'first-name=', 'last-name=', 'address-1=', 'phone='];
const forbiddenPiiPatternsEnc = forbiddenPiiPatterns.map(pattern => {
  return encodeURIComponent(pattern);
});
/**
 * Whether the current URL can potentially contain personally identifiable info.
 *
 * @returns {boolean} true if the current URL can potentially contain personally identifiable info.
 */

function isPiiUrl() {
  const href = document.location.href;

  const match = pattern => href.indexOf(pattern) !== -1;

  const result = forbiddenPiiPatterns.some(match) || forbiddenPiiPatternsEnc.some(match);
  (0,_debug__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(`Is PII URL: ${result}`);
  return result;
}

/***/ }),

/***/ 69874:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ isUrlExcludedForPerformance; }
/* harmony export */ });
/* harmony import */ var _debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(87360);
 // For better load performance, these routes are excluded from loading ads.

const excludedRoutes = ['/log-in'];
/**
 * Are tracking pixels forbidden from the given URL for better performance (except for Google Analytics)?
 *
 * @returns {boolean} true if the current URL is excluded.
 */

function isUrlExcludedForPerformance() {
  const {
    href
  } = document.location;

  const match = pattern => href.indexOf(pattern) !== -1;

  const result = excludedRoutes.some(match);
  (0,_debug__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(`Is URL Excluded for Performance: ${result}`);
  return result;
}

/***/ }),

/***/ 81653:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/**
 * `localStorage` key for marketing coupons.
 *
 * @type {string} `localStorage` key.
 */
const MARKETING_COUPONS_KEY = 'marketing-coupons';
/* harmony default export */ __webpack_exports__["Z"] = (MARKETING_COUPONS_KEY);

/***/ }),

/***/ 43621:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ mayWeTrackCurrentUserGdpr; }
/* harmony export */ });
/* harmony import */ var cookie__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(13421);
/* harmony import */ var _debug__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(87360);
/* harmony import */ var _is_country_in_gdpr_zone__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(76814);



/**
 * Returns a boolean telling whether we may track the current user.
 *
 * WARNING: this function only works on the client side.
 *
 * @returns Whether we may track the current user
 */

function mayWeTrackCurrentUserGdpr() {
  let result = false;
  const cookies = cookie__WEBPACK_IMPORTED_MODULE_0__.parse(document.cookie);

  if (cookies.sensitive_pixel_option === 'yes') {
    result = true;
  } else if (cookies.sensitive_pixel_option === 'no') {
    result = false;
  } else {
    const countryCode = cookies.country_code;
    result = countryCode !== undefined && countryCode !== 'unknown' && !(0,_is_country_in_gdpr_zone__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(countryCode);
  }

  (0,_debug__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(`mayWeTrackCurrentUserGdpr: ${result}`);
  return result;
}

/***/ }),

/***/ 7369:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ refreshCountryCodeCookieGdpr; }
/* harmony export */ });
/* harmony import */ var cookie__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(13421);
/* harmony import */ var _debug__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(87360);


let refreshCountryCodeCookieGdprRequest = null;
/**
 * Refreshes the GDPR `country_code` cookie every 6 hours (like A8C_Analytics wpcom plugin).
 *
 * @returns {Promise<void>} Promise that resolves when the refreshing is done (or immediately)
 */

async function refreshCountryCodeCookieGdpr() {
  const cookies = cookie__WEBPACK_IMPORTED_MODULE_0__.parse(document.cookie);

  if (cookies.country_code) {
    (0,_debug__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)('refreshCountryCodeCookieGdpr: country_code cookie is fresh: %s', cookies.country_code);
    return;
  }

  if (refreshCountryCodeCookieGdprRequest === null) {
    refreshCountryCodeCookieGdprRequest = requestCountryCode().then(countryCode => setCountryCodeCookie(countryCode));
  }

  await refreshCountryCodeCookieGdprRequest;
  refreshCountryCodeCookieGdprRequest = null;
}

function requestCountryCode() {
  // cache buster
  const v = new Date().getTime();
  return fetch('https://public-api.wordpress.com/geo/?v=' + v).then(res => {
    if (!res.ok) {
      return res.body().then(body => {
        throw new Error(body);
      });
    }

    return res.json();
  }).then(json => {
    return json.country_short;
  }).catch(err => {
    (0,_debug__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)('refreshCountryCodeCookieGdpr: error: ', err);
    return 'unknown';
  });
}

function setCountryCodeCookie(countryCode) {
  const maxAge = 6 * 60 * 60; // 6 hours in seconds

  document.cookie = cookie__WEBPACK_IMPORTED_MODULE_0__.serialize('country_code', countryCode, {
    path: '/',
    maxAge
  });
  (0,_debug__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)('refreshCountryCodeCookieGdpr: country_code cookie set to %s', countryCode);
}

/***/ }),

/***/ 11915:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ saveCouponQueryArgument; }
/* harmony export */ });
/* harmony import */ var _debug__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(87360);
/* harmony import */ var _marketing_coupons_key__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(81653);
/* harmony import */ var _url_parse_amp_compatible__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(78920);



/**
 * Remembers `?coupon` query argument via `localStorage`.
 */

function saveCouponQueryArgument() {
  // Read coupon query argument, return early if there is none.
  const parsedUrl = (0,_url_parse_amp_compatible__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(window.location.href);
  const couponCode = parsedUrl === null || parsedUrl === void 0 ? void 0 : parsedUrl.searchParams.get('coupon');

  if (!couponCode) {
    return;
  } // Read coupon list from localStorage, create new if it's not there yet, refresh existing.


  let coupons = null;

  try {
    const couponsJson = window.localStorage.getItem(_marketing_coupons_key__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z);
    coupons = JSON.parse(couponsJson);
  } catch (err) {}

  if (!coupons) {
    coupons = {};
  }

  const THIRTY_DAYS_MILLISECONDS = 7 * 24 * 60 * 60 * 1000;
  const now = Date.now();
  (0,_debug__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)('Found coupons in localStorage: ', coupons);
  coupons[couponCode] = now; // Delete coupons if they're older than 30 days.

  Object.keys(coupons).forEach(key => {
    if (now > coupons[key] + THIRTY_DAYS_MILLISECONDS) {
      delete coupons[key];
    }
  }); // Write remembered coupons back to localStorage.

  try {
    (0,_debug__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)('Storing coupons in localStorage: ', coupons);
    window.localStorage.setItem(_marketing_coupons_key__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, JSON.stringify(coupons));
  } catch (err) {}
}

/***/ }),

/***/ 35899:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
const SITE_FRAGMENT_REGEX = /\/(:site|:site_id|:siteid|:blogid|:blog_id|:siteslug)(\/|$|\?)/i;
/**
 * Check if a path should report the currently selected site ID.
 *
 * Some paths should never report it because it's used
 * to tell general admin and site-specific activities apart.
 *
 * @param {string} path The tracked path.
 * @returns {boolean} If the report should null `blog_id`.
 */

/* harmony default export */ __webpack_exports__["Z"] = (path => {
  if (!path) {
    return true;
  }

  return !SITE_FRAGMENT_REGEX.test(path);
});

/***/ }),

/***/ 78920:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ urlParseAmpCompatible; }
/* harmony export */ });
/* harmony import */ var _debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(87360);

/**
 * Decodes a url-safe base64 encoded string.
 *
 * @param {string} str The url-safe base64 encoded string
 * @returns {string} The decoded string
 */

function urlSafeBase64DecodeString(str) {
  const decodeMap = {
    '-': '+',
    _: '/',
    '.': '='
  };
  return window.atob(str.replace(/[-_.]/g, ch => decodeMap[ch]));
}
/**
 * Decodes a URL param encoded by AMP's linker.js
 * See also https://github.com/ampproject/amphtml/blob/HEAD/extensions/amp-analytics/linker-id-receiving.md
 *
 * @param {string} value Value to be decoded
 * @returns {null|object} null or and object containing key/value pairs
 */


function parseAmpEncodedParams(value) {
  value = value.split('*').filter(val => val.length).slice(2); // return null if empty or we have an odd number of elements

  if (0 === value.length || 0 !== value.length % 2) {
    return null;
  }

  const keyValMap = {};

  for (let i = 0; i < value.length; i += 2) {
    keyValMap[value[i]] = urlSafeBase64DecodeString(value[i + 1]);
  }

  return keyValMap;
}
/**
 * Returns a URL instance with the original data plus the data extracted from `tk_amp`. Null if not a valid absolute URL.
 * URL parameters explicitly present in the URL take precedence over the ones extracted from `tk_amp`.
 * This function is used to support AMP-compatible tracking.
 *
 * @param {string} url URL to be parsed like `document.location.href`.
 * @returns {object} A URL instance with the original data plus the data extracted from `tk_amp`. Null if not a valid absolute URL.
 */


function urlParseAmpCompatible(url) {
  try {
    const parsedUrl = new URL(url);
    (0,_debug__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)('urlParseAmpCompatible: original query:', parsedUrl.search);

    if (parsedUrl.searchParams.has('tk_amp')) {
      const tk_amp = parseAmpEncodedParams(parsedUrl.searchParams.get('tk_amp'));
      (0,_debug__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)('urlParseAmpCompatible: tk_amp:', tk_amp);

      for (const key of Object.keys(tk_amp)) {
        if (!parsedUrl.searchParams.has(key)) {
          parsedUrl.searchParams.set(key, tk_amp[key]);
        }
      }
    }

    (0,_debug__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)('urlParseAmpCompatible: merged query:', parsedUrl.search);
    return parsedUrl;
  } catch {
    return null;
  }
}

/***/ }),

/***/ 32919:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "B$": function() { return /* binding */ clearStorage; }
/* harmony export */ });
/* unused harmony exports getAllStoredItems, getStoredItem, setStoredItem, activate */
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);

const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('calypso:support-user'); // This module defines a series of methods which bypasse all persistent storage.
// Any calls to read/write data using browser-storage instead access a temporary
// in-memory store which is lost on page reload. This driver is used to sandbox
// a user's data while support-user is active, ensuring it does not contaminate
// the original user, and vice versa.

const memoryStore = new Map();
async function getAllStoredItems(pattern) {
  debug('browser-storage bypass', 'getAllStoredItems'); // Return everything.

  if (!pattern) {
    return Object.fromEntries(memoryStore.entries());
  } // Return only the entries that match the pattern.


  const entries = Array.from(memoryStore.entries());
  return Object.fromEntries(entries.filter(_ref => {
    let [key] = _ref;
    return pattern.test(key);
  }));
}
async function getStoredItem(key) {
  debug('browser-storage bypass', 'getStoredItem', key);

  if (memoryStore.has(key)) {
    return memoryStore.get(key);
  }

  return undefined;
}
async function setStoredItem(key, value) {
  debug('browser-storage bypass', 'setStoredItem', key);
  memoryStore.set(key, value);
}
async function clearStorage() {
  debug('browser-storage bypass', 'clearStorage');
  memoryStore.clear();
}
function activate() {
  memoryStore.clear();
}

/***/ }),

/***/ 66651:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "B$": function() { return /* binding */ clearStorage; }
/* harmony export */ });
/* unused harmony exports supportsIDB, bypassPersistentStorage, getStoredItem, getAllStoredItems, setStoredItem */
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var calypso_lib_analytics_mc__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(7689);
/* harmony import */ var calypso_lib_memoize_last__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(47824);
/* harmony import */ var _bypass__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(32919);
var _window$IDBKeyRange;







const debug = debug__WEBPACK_IMPORTED_MODULE_1___default()('calypso:browser-storage');
let shouldBypass = false;
let shouldDisableIDB = false;
const DB_NAME = 'calypso';
const DB_VERSION = 2; // Match versioning of the previous localforage-based implementation.

const STORE_NAME = 'calypso_store';
const SANITY_TEST_KEY = 'browser-storage-sanity-test'; // eslint-disable-next-line @typescript-eslint/no-explicit-any

const isAffectedSafari = _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"].isEnabled */ .ZP.isEnabled('safari-idb-mitigation') && typeof window !== 'undefined' && !!((_window$IDBKeyRange = window.IDBKeyRange) !== null && _window$IDBKeyRange !== void 0 && _window$IDBKeyRange.lowerBound(0).includes) && !!window.webkitAudioContext && !!window.PointerEvent;
debug('Safari IDB mitigation active: %s', isAffectedSafari);
const supportsIDB = (0,calypso_lib_memoize_last__WEBPACK_IMPORTED_MODULE_5__/* .once */ .I)(async () => {
  if (typeof window === 'undefined' || !window.indexedDB) {
    debug('IDB not found in host');
    return false;
  }

  if (shouldDisableIDB) {
    debug('IDB disabled');
    return false;
  }

  try {
    const testValue = Date.now().toString();
    await idbSet(SANITY_TEST_KEY, testValue);
    await idbGet(SANITY_TEST_KEY);
    return true;
  } catch (error) {
    // IDB sanity test failed. Fall back to alternative method.
    return false;
  }
});
const getDB = (0,calypso_lib_memoize_last__WEBPACK_IMPORTED_MODULE_5__/* .once */ .I)(() => {
  const request = window.indexedDB.open(DB_NAME, DB_VERSION);
  return new Promise((resolve, reject) => {
    try {
      if (request) {
        request.onerror = event => {
          // InvalidStateError is special in Firefox.
          // We need to `preventDefault` to stop it from reaching the console.
          if (request.error && request.error.name === 'InvalidStateError') {
            event.preventDefault();
          }

          reject(request.error);
        };

        request.onsuccess = () => {
          const db = request.result; // Add a general error handler for any future requests made against this db handle.
          // See https://developer.mozilla.org/en-US/docs/Web/API/IndexedDB_API/Using_IndexedDB#Handling_Errors for
          // more information on how error events bubble with IndexedDB

          db.onerror = function (errorEvent) {
            var _errorEvent$target, _errorEvent$target$er;

            debug('IDB Error', errorEvent);

            if ((_errorEvent$target = errorEvent.target) !== null && _errorEvent$target !== void 0 && (_errorEvent$target$er = _errorEvent$target.error) !== null && _errorEvent$target$er !== void 0 && _errorEvent$target$er.name) {
              (0,calypso_lib_analytics_mc__WEBPACK_IMPORTED_MODULE_3__/* .bumpStat */ .P)('calypso-browser-storage', (0,lodash__WEBPACK_IMPORTED_MODULE_2__.kebabCase)(errorEvent.target.error.name));

              if (errorEvent.target.error.name === 'QuotaExceededError') {
                // we've blown through the quota. Turn off IDB for this page load
                shouldDisableIDB = true;
                supportsIDB.clear();
                debug('disabling IDB because we saw a QuotaExceededError');
              }
            }
          };

          db.onversionchange = () => {
            // This fires when the database gets upgraded or when it gets deleted.
            // We need to close our handle to allow the change to proceed
            db.close();
          };

          resolve(db);
        };

        request.onupgradeneeded = () => request.result.createObjectStore(STORE_NAME);
      }
    } catch (error) {
      reject(error);
    }
  });
});

function idbGet(key) {
  return new Promise((resolve, reject) => {
    getDB().then(db => {
      const transaction = db.transaction(STORE_NAME, 'readonly');
      const get = transaction.objectStore(STORE_NAME).get(key);

      const success = () => resolve(get.result);

      const error = () => reject(transaction.error);

      transaction.oncomplete = success;
      transaction.onabort = error;
      transaction.onerror = error;
    }).catch(err => reject(err));
  });
}

function idbGetAll(pattern) {
  return getDB().then(db => new Promise((resolve, reject) => {
    const results = {};
    const transaction = db.transaction(STORE_NAME, 'readonly');
    const getAll = transaction.objectStore(STORE_NAME).openCursor();

    const success = event => {
      const cursor = event.target.result;

      if (cursor) {
        const {
          primaryKey: key,
          value
        } = cursor;

        if (key && typeof key === 'string' && key !== SANITY_TEST_KEY && (!pattern || pattern.test(key))) {
          results[key] = value;
        }

        cursor.continue();
      } else {
        // No more results.
        resolve(results);
      }
    };

    const error = () => reject(transaction.error);

    getAll.onsuccess = success;
    transaction.onabort = error;
    transaction.onerror = error;
  }));
}

let idbWriteCount = 0;
let idbWriteBlock = null;

async function idbSet(key, value) {
  // if there's a write lock, wait on it
  if (idbWriteBlock) {
    await idbWriteBlock;
  } // if we're on safari 13, we need to clear out the object store every
  // so many writes to make sure we don't chew up the transaction log


  if (isAffectedSafari && ++idbWriteCount % 20 === 0) {
    await idbSafariReset();
  }

  return new Promise((resolve, reject) => {
    getDB().then(async db => {
      const transaction = db.transaction(STORE_NAME, 'readwrite');
      transaction.objectStore(STORE_NAME).put(value, key);

      const success = () => resolve();

      const error = () => reject(transaction.error);

      transaction.oncomplete = success;
      transaction.onabort = error;
      transaction.onerror = error;
    }).catch(err => reject(err));
  });
}

function idbClear() {
  return new Promise((resolve, reject) => {
    getDB().then(db => {
      const transaction = db.transaction(STORE_NAME, 'readwrite');
      transaction.objectStore(STORE_NAME).clear();

      const success = () => resolve();

      const error = () => reject(transaction.error);

      transaction.oncomplete = success;
      transaction.onabort = error;
      transaction.onerror = error;
    }).catch(err => reject(err));
  });
}

function idbRemove() {
  return new Promise((resolve, reject) => {
    const deleteRequest = window.indexedDB.deleteDatabase(DB_NAME);

    deleteRequest.onsuccess = () => {
      getDB.clear();
      resolve();
    };

    deleteRequest.onerror = event => reject(event);
  });
}

async function idbSafariReset() {
  if (idbWriteBlock) {
    return idbWriteBlock;
  }

  debug('performing safari idb mitigation');
  idbWriteBlock = _idbSafariReset();
  idbWriteBlock.finally(() => {
    idbWriteBlock = null;
    debug('idb mitigation complete');
  });
  return idbWriteBlock;
}

async function _idbSafariReset() {
  const items = await idbGetAll();
  await idbRemove();
  return new Promise((resolve, reject) => {
    getDB().then(db => {
      const transaction = db.transaction(STORE_NAME, 'readwrite');
      const oStore = transaction.objectStore(STORE_NAME); // eslint-disable-next-line prefer-const

      for (let [key, value] of Object.entries(items)) {
        oStore.put(value, key);
      }

      const success = () => resolve();

      const error = () => reject(transaction.error);

      transaction.oncomplete = success;
      transaction.onabort = error;
      transaction.onerror = error;
    }, err => reject(err));
  });
}
/**
 * Whether persistent storage should be bypassed, using a memory store instead.
 *
 * @param shouldBypassPersistentStorage Whether persistent storage should be bypassed.
 */


function bypassPersistentStorage(shouldBypassPersistentStorage) {
  shouldBypass = shouldBypassPersistentStorage;

  if (shouldBypass) {
    activateBypass();
  }
}
/**
 * Get a stored item.
 *
 * @param key The stored item key.
 * @returns A promise with the stored value. `undefined` if missing.
 */

async function getStoredItem(key) {
  if (shouldBypass) {
    return await bypassGet(key);
  }

  const idbSupported = await supportsIDB();

  if (!idbSupported) {
    const valueString = window.localStorage.getItem(key);

    if (valueString === undefined || valueString === null) {
      return undefined;
    }

    return JSON.parse(valueString);
  }

  return await idbGet(key);
}
/**
 * Get all stored items.
 *
 * @param pattern The pattern to match on returned item keys.
 * @returns A promise with the stored key/value pairs as an object. Empty if none.
 */

async function getAllStoredItems(pattern) {
  if (shouldBypass) {
    return await bypassGetAll(pattern);
  }

  const idbSupported = await supportsIDB();

  if (!idbSupported) {
    const entries = Object.entries(window.localStorage).map(_ref => {
      let [key, value] = _ref;
      return [key, value !== undefined ? JSON.parse(value) : undefined];
    });

    if (!pattern) {
      return Object.fromEntries(entries);
    }

    return Object.fromEntries(entries.filter(_ref2 => {
      let [key] = _ref2;
      return pattern.test(key);
    }));
  }

  return await idbGetAll(pattern);
}
/**
 * Set an item in storage.
 *
 * @param key The key to store the item under.
 * @param value The value of the item to be stored.
 * @returns A promise that gets resolved when the item is successfully stored.
 */

async function setStoredItem(key, value) {
  if (shouldBypass) {
    return await bypassSet(key, value);
  }

  const idbSupported = await supportsIDB();

  if (!idbSupported) {
    window.localStorage.setItem(key, JSON.stringify(value));
    return;
  }

  return await idbSet(key, value);
}
/**
 * Clear all stored items.
 *
 * @returns A promise that gets resolved when all items are successfully cleared.
 */

async function clearStorage() {
  if (shouldBypass) {
    return await (0,_bypass__WEBPACK_IMPORTED_MODULE_4__/* .clearStorage */ .B$)();
  }

  const idbSupported = await supportsIDB();

  if (!idbSupported) {
    window.localStorage.clear();
    return;
  }

  return await idbClear();
}

/***/ }),

/***/ 94776:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "b": function() { return /* binding */ isE2ETest; }
/* harmony export */ });
// All end-to-end tests use a custom user agent containing this string.
const E2E_USER_AGENT = 'wp-e2e-tests';
function isE2ETest() {
  return typeof navigator !== 'undefined' && navigator.userAgent.includes(E2E_USER_AGENT);
}

/***/ }),

/***/ 50118:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "S": function() { return /* binding */ decodeEntities; }
/* harmony export */ });
/* harmony import */ var _decode__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(24050);

function decodeEntities(text) {
  // Bypass decode if text doesn't include entities
  if ('string' !== typeof text || -1 === text.indexOf('&')) {
    return text;
  }

  return (0,_decode__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(text);
}

/***/ }),

/***/ 24050:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ decodeEntities; }
/* harmony export */ });
const element = (() => {
  if (document.implementation && document.implementation.createHTMLDocument) {
    return document.implementation.createHTMLDocument('').createElement('textarea');
  }

  return document.createElement('textarea');
})();

function decodeEntities(text) {
  element.innerHTML = text;
  const decoded = element.textContent;
  element.innerHTML = '';
  return decoded;
}

/***/ }),

/***/ 93345:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "R": function() { return /* binding */ preventWidows; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Prevent widows by replacing spaces between the last `wordsToKeep` words in the text with non-breaking spaces
 *
 * @param  {string|@i18n-calypso/TranslateResult} text the text to work on
 * @param  {number} wordsToKeep the number of words to keep together
 * @returns {string}             the widow-prevented string
 */

function preventWidows(text) {
  let wordsToKeep = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 2;
  return preventWidowsInPart('string' === typeof text ? text.trim() : text, Math.max(1, wordsToKeep - 1)).part;
}
const reverseSpaceRegex = /\s+(\S*)$/;
/**
 * The helper function to preventWidows that calls itself recursively searching for spaces to substitute with
 * non-breaking spaces.
 *
 * @param {string|@i18n-calypso/TranslateResult} part The section of the content to search, a string or a component
 *     or an array of strings and components
 * @param {number} spacesToSubstitute The number of spaces to substitute with non-breaking spaces. This is one less than the preventWidows wordsToKeep
 * @returns object Contains two keys `part` the possibly modified `part` parameter passed in, and `substituted` the number of spaces substituted.
 */

function preventWidowsInPart(part, spacesToSubstitute) {
  let substituted = 0;

  if ('string' === typeof part && part.length > 0) {
    let text = part;
    let retVal = ''; // If the part is a string, work from the right looking for spaces
    // TODO Work out if we can tell that this is a RTL language, and if it's appropriate to join words in this way

    while (substituted < spacesToSubstitute && reverseSpaceRegex.test(text)) {
      const match = reverseSpaceRegex.exec(text);
      retVal = '\xA0' + match[1] + retVal;
      text = text.replace(reverseSpaceRegex, '');
      substituted++;
    }

    retVal = text + retVal; // Return the modified string and the number of spaces substituted

    return {
      part: retVal,
      substituted
    };
  }
  /* If we're called with an array construct a copy of the array by calling
   * ourself on each element until we have substituted enough spaces. Then
   * concatentate the rest of the array
   */


  if (Array.isArray(part) && part.length > 0) {
    let elements = [];
    let idx = part.length - 1;

    while (substituted < spacesToSubstitute && idx >= 0) {
      const result = preventWidowsInPart(part[idx], spacesToSubstitute - substituted);
      elements.unshift(result.part);
      substituted += result.substituted;
      idx--;
    }

    elements = part.slice(0, idx + 1).concat(elements);
    return {
      part: elements,
      substituted
    };
  }
  /* If we're called with a component, and it has children
   * then call ourself with the value of the children prop
   * (an array that will be handled above)
   *
   * Then return a cloned component with the possibly modified
   * children, along with the tally of substituted spaces.
   */


  if ( /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.isValidElement)(part) && part.props.children) {
    const result = preventWidowsInPart(part.props.children, spacesToSubstitute);

    if (result.substituted > 0) {
      // pass children as spread arguments to prevent missing array key warnings
      const partArray = Array.isArray(result.part) ? result.part : [result.part];
      return {
        part: /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.cloneElement)(part, part.props, ...partArray),
        substituted: result.substituted
      };
    }

    return {
      part,
      substituted
    };
  } // For anything else e.g. an element without children, there's nothing to do.


  return {
    part,
    substituted
  };
}

/***/ }),

/***/ 8165:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "C": function() { return /* binding */ stripHTML; }
/* harmony export */ });
/* harmony import */ var striptags__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(33927);
/* harmony import */ var striptags__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(striptags__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Strips HTML from a string. Does not handle tags nested in attribute strings.
 *
 * @param  {string} string The string to strip tags from
 * @returns {string}        The stripped string
 */

function stripHTML(string) {
  return striptags__WEBPACK_IMPORTED_MODULE_0___default()(string);
}

/***/ }),

/***/ 284:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "HX": function() { return /* binding */ GSUITE_PRODUCT_FAMILY; },
/* harmony export */   "fh": function() { return /* binding */ GOOGLE_WORKSPACE_PRODUCT_FAMILY; }
/* harmony export */ });
/* unused harmony exports GOOGLE_WORKSPACE_PRODUCT_TYPE, GSUITE_PRODUCT_TYPE, GOOGLE_PROVIDER_NAME */
/**
 * We'll use the following constants to do the switchover from
 * G Suite -> Google Workspace.
 * The product name is never translated in the translation strings
 * so we won't translate them here either.
 */
const GSUITE_PRODUCT_FAMILY = 'G Suite';
const GOOGLE_WORKSPACE_PRODUCT_FAMILY = 'Google Workspace';
/**
 * Defines product types to use as slugs in urls.
 *
 * @see emailManagementAddGSuiteUsers() in client/my-sites/email/paths.js
 */

const GOOGLE_WORKSPACE_PRODUCT_TYPE = 'google-workspace';
const GSUITE_PRODUCT_TYPE = 'gsuite';
const GOOGLE_PROVIDER_NAME = 'google';

/***/ }),

/***/ 96598:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "H": function() { return /* binding */ getGoogleMailServiceFamily; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_products__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(10128);
/* harmony import */ var calypso_lib_gsuite_constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(284);


/**
 * @param {string|null} productSlug - optional product slug
 * @returns {string}
 */

function getGoogleMailServiceFamily() {
  let productSlug = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;

  if ((0,_automattic_calypso_products__WEBPACK_IMPORTED_MODULE_0__/* .isGSuiteProductSlug */ .M)(productSlug)) {
    return calypso_lib_gsuite_constants__WEBPACK_IMPORTED_MODULE_1__/* .GSUITE_PRODUCT_FAMILY */ .HX;
  }

  return calypso_lib_gsuite_constants__WEBPACK_IMPORTED_MODULE_1__/* .GOOGLE_WORKSPACE_PRODUCT_FAMILY */ .fh;
}

/***/ }),

/***/ 26991:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Y": function() { return /* binding */ getLocaleSlug; }
/* harmony export */ });
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(11481);

const getLocaleSlug = () => i18n_calypso__WEBPACK_IMPORTED_MODULE_0__/* ["default"].getLocaleSlug */ .ZP.getLocaleSlug();

/***/ }),

/***/ 9415:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);

const jetpackCloudEnvironments = ['jetpack-cloud-development', 'jetpack-cloud-stage', 'jetpack-cloud-horizon', 'jetpack-cloud-production'];

const isJetpackCloud = () => jetpackCloudEnvironments.includes((0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('env_id'));

/* harmony default export */ __webpack_exports__["Z"] = (isJetpackCloud);

/***/ }),

/***/ 16771:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "t": function() { return /* binding */ loadjQueryDependentScriptDesktopWrapper; }
/* harmony export */ });
/* harmony import */ var _automattic_load_script__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(84898);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_1__);
/**
 * A wrapper for loadjQueryDependentScript that handles the desktop app
 * It is not possible to expose jQuery globally in Electron App: https://github.com/atom/electron/issues/254.
 * It needs to be loaded using require and npm package.
 */


const debug = debug__WEBPACK_IMPORTED_MODULE_1___default()('lib/load-jquery-dependent-script-desktop-wrapper');
function loadjQueryDependentScriptDesktopWrapper(url, callback) {
  debug(`Loading a jQuery dependent script from "${url}"`);
  (0,_automattic_load_script__WEBPACK_IMPORTED_MODULE_0__/* .loadjQueryDependentScript */ .D1)(url, callback);
}

/***/ }),

/***/ 47824:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "I": function() { return /* binding */ once; }
/* harmony export */ });
/* unused harmony export default */
/**
 * Wraps a function in a utility method that remembers the last invocation's
 * arguments and results, and returns the latter if the former match.
 *
 * @param fn The function to be wrapped.
 * @returns The wrapped function.
 */
function memoizeLast(fn) {
  let lastArgs;
  let lastResult;

  const func = function () {
    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    const isSame = lastArgs && args.length === lastArgs.length && args.every((arg, index) => arg === lastArgs[index]);

    if (!isSame) {
      lastArgs = args;
      lastResult = fn(...args);
    }

    return lastResult;
  };

  func.clear = () => {
    lastArgs = undefined;
    lastResult = undefined;
  };

  return func;
}
/**
 * A stricter-typed alias of `memoizeLast`, for functions without arguments.
 * Since it only accepts functions without arguments, it effectively guarantees
 * that the provided function will only be run once, as the check for whether
 * the arguments have not changed will always pass.
 *
 * @param fn The function to be wrapped.
 * @returns The wrapped function.
 */

function once(fn) {
  // Runtime validation. Useful when static validation is unavailable.
  if (false) {}

  return memoizeLast(fn);
}

/***/ }),

/***/ 7268:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "LP": function() { return /* binding */ getToken; }
/* harmony export */ });
/* unused harmony exports setToken, clearToken */
/* harmony import */ var cookie__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(13421);
/* harmony import */ var store__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(23729);
/* harmony import */ var store__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(store__WEBPACK_IMPORTED_MODULE_1__);


/**
 * Module variables
 */

const TOKEN_NAME = 'wpcom_token';
const MAX_AGE = (/* unused pure expression or super */ null && (365 * 24 * 60 * 60 * 1000)); // How long to store the OAuth cookie

function getToken() {
  const cookies = cookie__WEBPACK_IMPORTED_MODULE_0__.parse(document.cookie);

  if (typeof cookies[TOKEN_NAME] !== 'undefined') {
    return cookies[TOKEN_NAME];
  }

  const token = store__WEBPACK_IMPORTED_MODULE_1___default().get(TOKEN_NAME);

  if (token) {
    return token;
  }

  return false;
}
function setToken(token) {
  // TODO: Support secure cookies if this is ever used outside of the desktop app
  document.cookie = cookie.serialize(TOKEN_NAME, token, {
    maxAge: MAX_AGE
  });
}
function clearToken() {
  const cookies = cookie.parse(document.cookie);

  if (typeof cookies[TOKEN_NAME] !== 'undefined') {
    document.cookie = cookie.serialize(TOKEN_NAME, false, {
      maxAge: -1
    });
  }
}

/***/ }),

/***/ 26347:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Nf": function() { return /* reexport safe */ _onboarding_url__WEBPACK_IMPORTED_MODULE_0__.N; }
/* harmony export */ });
/* unused harmony export newPost */
/* harmony import */ var _onboarding_url__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(65337);




function editorPathFromSite(site) {
  if (!site) {
    return '';
  }

  const siteSlug = typeof site === 'object' ? site.slug : site;
  return '/' + siteSlug;
}
/**
 * Returns a URL to the post editor for a new post on a given site.
 *
 * @param  {object|string} site Site object or site slug
 * @returns {string}      URL to post editor
 */


function newPost(site) {
  const sitePath = editorPathFromSite(site);
  return '/post' + sitePath;
}

/***/ }),

/***/ 65337:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "N": function() { return /* binding */ onboardingUrl; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var calypso_lib_jetpack_is_jetpack_cloud__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9415);


/**
 * Returns the onboarding URL.
 *
 * @returns {string}  URL of the onboarding flow for existing users.
 */

function onboardingUrl() {
  if ((0,calypso_lib_jetpack_is_jetpack_cloud__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)()) {
    return (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('jetpack_connect_url');
  }

  return (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('signup_url');
}

/***/ }),

/***/ 77804:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* export default binding */ __WEBPACK_DEFAULT_EXPORT__; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);

const DISCOVER_BLOG_ID = 53424024;
/**
 * Add discover properties to a post
 *
 * @param  {object} post - the post to extend
 * @returns {object}      - the post with discover properties
 */

/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(post) {
  const isDiscover = !!((0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(post, 'discover_metadata') || DISCOVER_BLOG_ID === (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(post, 'site_ID'));
  let discoverFormat;

  if (isDiscover) {
    const formats = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(post, 'discover_metadata.discover_fp_post_formats');
    const pickFormat = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.find)(formats, format => format.slug !== 'pick'); // if there is no pick format the post is a discover feature

    discoverFormat = pickFormat ? pickFormat.slug : 'feature';
  }

  post.is_discover = isDiscover;
  post.discover_format = discoverFormat;
  return post;
}

/***/ }),

/***/ 53544:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ detectMedia; }
/* harmony export */ });
/* harmony import */ var get_video_id__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(17451);
/* harmony import */ var get_video_id__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(get_video_id__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var calypso_state_reader_posts_sizes__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(99891);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(59755);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(54855);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(95822);
/* eslint-disable jsdoc/no-undefined-types */




/**
 * Checks whether or not an image is a tracking pixel
 *
 * @param {Node} image - DOM node for an img
 * @returns {boolean} isTrackingPixel - returns true if image is probably a tracking pixel
 */

function isTrackingPixel(image) {
  if (!image || !image.src) {
    return false;
  }

  const edgeLength = image.height + image.width;
  return edgeLength === 1 || edgeLength === 2;
}
/**
 * Returns true if image should be considered
 *
 * @param {Node} image - DOM node for an image
 * @returns {boolean} true/false depending on if it should be included as a potential featured image
 */


function isCandidateForContentImage(image) {
  if (!image || !image.getAttribute('src')) {
    return false;
  }

  const ineligibleCandidateUrlParts = ['gravatar.com', '/wpcom-smileys/'];
  const imageUrl = image.getAttribute('src');
  const imageShouldBeExcludedFromCandidacy = (0,lodash__WEBPACK_IMPORTED_MODULE_1__.some)(ineligibleCandidateUrlParts, urlPart => (0,lodash__WEBPACK_IMPORTED_MODULE_1__.includes)(imageUrl.toLowerCase(), urlPart));
  return !(isTrackingPixel(image) || imageShouldBeExcludedFromCandidacy);
}
/**
 * Detects and returns metadata if it should be considered as a content image
 *
 * @param {image} image - the image
 * @returns {object} metadata - regarding the image or null
 */


const detectImage = image => {
  if (isCandidateForContentImage(image)) {
    const {
      width,
      height
    } = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .deduceImageWidthAndHeight */ .H)(image) || {
      width: 0,
      height: 0
    };
    return {
      src: (0,_utils__WEBPACK_IMPORTED_MODULE_3__/* .maxWidthPhotonishURL */ .E)(image.getAttribute('src'), calypso_state_reader_posts_sizes__WEBPACK_IMPORTED_MODULE_4__/* .READER_CONTENT_WIDTH */ .fY),
      width: width,
      height: height,
      mediaType: 'image'
    };
  }

  return false;
};
/**
 *  For an iframe we know how to process, return a string for an autoplaying iframe
 *
 * @param {Node} iframe - DOM node for an iframe
 * @returns {string} html src for an iframe that autoplays if from a source we understand.  else null;
 */


const getAutoplayIframe = iframe => {
  const KNOWN_SERVICES = ['youtube', 'vimeo', 'videopress'];
  const metadata = get_video_id__WEBPACK_IMPORTED_MODULE_0___default()(iframe.src);

  if (metadata && (0,lodash__WEBPACK_IMPORTED_MODULE_1__.includes)(KNOWN_SERVICES, metadata.service)) {
    const autoplayIframe = iframe.cloneNode();

    if (autoplayIframe.src.indexOf('?') === -1) {
      autoplayIframe.src += '?autoplay=1';
    } else {
      autoplayIframe.src += '&autoplay=1';
    }

    return autoplayIframe.outerHTML;
  }

  return null;
};

const getEmbedType = iframe => {
  let node = iframe;
  let matches;

  do {
    if (!node.className) {
      continue;
    }

    matches = node.className.match(/\bembed-([-a-zA-Z0-9_]+)\b/);

    if (matches) {
      return matches[1];
    }
  } while (node = node.parentNode);

  return null;
};
/**
 * Detects and returns metadata if it should be considered as a content iframe
 *
 * @param {Node} iframe - a DOM node for an iframe
 * @returns {metadata} metadata - metadata for an embed
 */


const detectEmbed = iframe => {
  if (!(0,_utils__WEBPACK_IMPORTED_MODULE_5__/* .iframeIsAllowed */ .p)(iframe)) {
    return false;
  }

  const width = Number(iframe.width);
  const height = Number(iframe.height);
  const aspectRatio = width / height;
  return {
    type: getEmbedType(iframe),
    src: iframe.src,
    iframe: iframe.outerHTML,
    aspectRatio: aspectRatio,
    width: width,
    height: height,
    mediaType: 'video',
    autoplayIframe: getAutoplayIframe(iframe)
  };
};
/**
 * Adds an ordered list of all of the content_media to the post
 *
 * @param {post} post - the post object to add content_media to
 * @param {dom} dom - the dom of the post to scan for media
 * @returns {PostMetadata} post - the post object mutated to also have content_media
 */


function detectMedia(post, dom) {
  const imageSelector = 'img[src]';
  const embedSelector = 'iframe';
  const media = dom.querySelectorAll(`${imageSelector}, ${embedSelector}`);
  const contentMedia = (0,lodash__WEBPACK_IMPORTED_MODULE_1__.map)(media, element => {
    const nodeName = element.nodeName.toLowerCase();

    if (nodeName === 'iframe') {
      return detectEmbed(element);
    } else if (nodeName === 'img') {
      return detectImage(element);
    }

    return false;
  });
  post.content_media = (0,lodash__WEBPACK_IMPORTED_MODULE_1__.compact)(contentMedia);
  post.content_embeds = (0,lodash__WEBPACK_IMPORTED_MODULE_1__.filter)(post.content_media, m => m.mediaType === 'video');
  post.content_images = (0,lodash__WEBPACK_IMPORTED_MODULE_1__.filter)(post.content_media, m => m.mediaType === 'image'); // TODO: figure out a more sane way of combining featured_image + content media
  // so that changes to logic don't need to exist in multiple places

  if (post.featured_image) {
    post.featured_image = (0,_utils__WEBPACK_IMPORTED_MODULE_3__/* .maxWidthPhotonishURL */ .E)(post.featured_image, calypso_state_reader_posts_sizes__WEBPACK_IMPORTED_MODULE_4__/* .READER_CONTENT_WIDTH */ .fY);
  }

  return post;
}

/***/ }),

/***/ 10363:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ detectPolls; }
/* harmony export */ });
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(11481);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(6964);



const pollLinkSelectors = ['a[href^="http://polldaddy.com/poll/"]', 'a[href^="https://polldaddy.com/poll/"]', 'a[href^="http://poll.fm/"]', 'a[href^="https://poll.fm/"]', 'a[href^="http://survey.fm/"]', 'a[href^="https://survey.fm/"]'];
function detectPolls(post, dom) {
  if (!dom) {
    throw new Error('this transform must be used as part of withContentDOM');
  } // Crowdsignal embed markup isn't very helpfully structured, but we can look for the noscript tag,
  // which contains the information we need, and replace it with a paragraph.


  const noscripts = dom.querySelectorAll('noscript');
  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(noscripts, noscript => {
    if (!noscript.firstChild) {
      return;
    } // some browsers don't require this and let us query the dom inside a noscript. some do not. maybe just jsdom.


    const noscriptDom = (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .domForHtml */ .j)(noscript.innerHTML);
    const pollLink = noscriptDom.querySelector(pollLinkSelectors.join(', '));

    if (pollLink) {
      const matches = pollLink.href.match(/https?:\/\/(polldaddy\.com\/poll|poll\.fm|survey\.fm)\/([0-9]+)/) || [];
      const pollId = matches[2];

      if (pollId) {
        const p = document.createElement('p');
        p.innerHTML = '<a target="_blank" rel="external noopener noreferrer" href="https://poll.fm/' + pollId + '">' + i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Take our poll') + '</a>';
        noscript.parentNode.replaceChild(p, noscript);
      }
    }
  });
  return post;
}

/***/ }),

/***/ 37183:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ detectSurveys; }
/* harmony export */ });
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(11481);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);


function detectSurveys(post, dom) {
  if (!dom) {
    throw new Error('this transform must be used as part of withContentDOM');
  }

  const surveys = dom.querySelectorAll('.pd-embed, .cs-embed');

  if (!surveys) {
    return post;
  }

  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(surveys, survey => {
    // Get survey details
    let surveyDetails = null;

    try {
      surveyDetails = JSON.parse(survey.getAttribute('data-settings'));
    } catch (e) {
      return;
    }

    const {
      domain: surveyDomain,
      id: surveySlug
    } = surveyDetails;

    if (!surveyDomain || !surveySlug) {
      return;
    } // Construct a survey link


    const p = document.createElement('p');
    p.innerHTML = '<a target="_blank" rel="external noopener noreferrer" href="https://' + surveyDomain + surveySlug + '">' + i18n_calypso__WEBPACK_IMPORTED_MODULE_1__/* ["default"].translate */ .ZP.translate('Take our survey') + '</a>'; // Replace the .pd-embed div with the new paragraph

    survey.parentNode.replaceChild(p, survey);
  });
  return post;
}

/***/ }),

/***/ 40691:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Y": function() { return /* binding */ disableAutoPlayOnMedia; },
/* harmony export */   "b": function() { return /* binding */ disableAutoPlayOnEmbeds; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(6261);


function stripAutoPlays(searchParams) {
  const returnVal = new URLSearchParams(searchParams);
  const keys = Array.from(searchParams.keys()).filter(k => /^auto_?play$/i.test(k)) || [];
  keys.forEach(key => {
    // In the rare case that we're handed an array of values, we use the first one
    const val = searchParams.get(key).toLowerCase();

    if (val === '1') {
      returnVal.set(key, '0');
    } else if (val === 'true') {
      returnVal.set(key, 'false');
    } else {
      // force a singular value
      returnVal.set(key, val);
    }
  });
  return returnVal;
}

function disableAutoPlayOnMedia(post, dom) {
  if (!dom) {
    throw new Error('this transform must be used as part of withContentDOM');
  }

  dom.querySelectorAll('audio, video').forEach(el => el.autoplay = false);
  return post;
}
function disableAutoPlayOnEmbeds(post, dom) {
  if (!dom) {
    throw new Error('this transform must be used as part of withContentDOM');
  }

  dom.querySelectorAll('iframe').forEach(embed => {
    const urlParts = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__/* .getUrlParts */ .A)(embed.src);

    if (urlParts.search) {
      urlParts.searchParams = stripAutoPlays(urlParts.searchParams);
      delete urlParts.search;
      embed.src = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__/* .getUrlFromParts */ .C)(urlParts).href;
    }
  });
  return post;
}

/***/ }),

/***/ 17431:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ linkJetpackCarousels; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);

/**
 * The linkJetpackCarousels rule modifies all of the WordPress galleries in the content
 * to link you to their host website's carousel instead of the permalink for that specific image.
 * Based on the DOM layout for Jetpack Galleries, which are used by Jetpack sites and WordPress.com sites
 * For example,
 * Before: https://example.com/2017/03/25/my-family/img_1/
 * After: https://example.com/2017/03/25/my-family/#jp-carousel-1234
 *
 * @param  {object} post The post
 * @param  {object} dom  The DOM for the post's content
 * @returns {object}      The post, with any additions
 */

function linkJetpackCarousels(post, dom) {
  const galleries = dom.querySelectorAll('.tiled-gallery');
  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(galleries, gallery => {
    let extra = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(gallery, ['dataset', 'carouselExtra'], false);

    if (!extra) {
      // this only really exists for jsdom. See https://github.com/tmpvar/jsdom/issues/961
      extra = gallery.getAttribute('data-carousel-extra');

      if (!extra) {
        // We couldn't find the extra for this gallery. While we could pull it from the post, this makes it
        // suspect that we really found a jetpack gallery. Just bail.
        return post;
      }
    }

    let permalink;

    try {
      permalink = JSON.parse(extra).permalink;
    } catch (e) {
      // doesn't look like the extra was valid JSON. Maybe this isn't really a gallery? Bail.
      return post;
    } // find all the links and rewrite them to point to the carousel instead of the permalink


    const links = gallery.querySelectorAll('.tiled-gallery-item > a');
    (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(links, link => {
      const img = link.querySelector('img');
      const attachmentId = img && img.getAttribute('data-attachment-id');

      if (attachmentId) {
        link.href = permalink + '#jp-carousel-' + attachmentId;
        link.setAttribute('target', '_blank');
      }
    });
  });
  return post;
}

/***/ }),

/***/ 50917:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ makeEmbedsSafe; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(6261);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(95822);



/**
 * Given an iframe, is it okay to have it run without a sandbox?
 *
 * @param {object} iframe - the iframe to check
 * @returns {boolean} true/false if we trust the source and we know they don't work in a sandbox
 */

function doesNotNeedSandbox(iframe) {
  const trustedHosts = ['spotify.com', 'kickstarter.com', 'soundcloud.com', 'embed.ted.com', 'player.twitch.tv'];
  const hostName = iframe.src && (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .getUrlParts */ .A)(iframe.src).hostname;
  const iframeHost = hostName && hostName.toLowerCase();
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.some)(trustedHosts, trustedHost => `.${iframeHost}`.endsWith('.' + trustedHost));
}

function makeEmbedsSafe(post, dom) {
  if (!dom) {
    throw new Error('this transform must be used as part of withContentDOM');
  }

  const iframes = dom.querySelectorAll('iframe');
  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(iframes, function (iframe) {
    if (!(0,lodash__WEBPACK_IMPORTED_MODULE_0__.startsWith)(iframe.src, 'http')) {
      iframe.parentNode.removeChild(iframe);
      return;
    }

    iframe.src = iframe.src.replace(/^http:/, 'https:');

    if (doesNotNeedSandbox(iframe)) {
      iframe.removeAttribute('sandbox');
    } else if ((0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .iframeIsAllowed */ .p)(iframe)) {
      iframe.setAttribute('sandbox', 'allow-same-origin allow-scripts allow-popups');
    } else {
      iframe.setAttribute('sandbox', 'allow-scripts');
    }
  });

  if (post.is_external || post.is_jetpack) {
    const embeds = dom.querySelectorAll('embed,object');
    (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(embeds, function (embed) {
      embed.parentNode.removeChild(embed);
    });
  }

  return post;
}

/***/ }),

/***/ 30757:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(6261);
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(94668);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_lib_url__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(70353);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(54855);




const TRANSPARENT_GIF = 'data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7';
/**
 * @param {window.Node} node - Takes in a DOM Node and mutates it so that it no longer has an 'on*' event handlers e.g. onClick
 */

const removeUnwantedAttributes = node => {
  if (!node || !node.hasAttributes()) {
    return;
  }

  const inlineEventHandlerAttributes = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.filter)(node.attributes, attr => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.startsWith)(attr.name, 'on'));
  inlineEventHandlerAttributes.forEach(a => node.removeAttribute(a.name)); // always remove srcset because they are very difficult to make safe and may not be worth the trouble

  node.removeAttribute('srcset');
};
/**
 * Checks whether or not imageUrl should be removed from the dom
 *
 * @param {string} imageUrl - the url of the image
 * @returns {boolean} whether or not it should be removed from the dom
 */


const imageShouldBeRemovedFromContent = imageUrl => {
  if (!imageUrl) {
    return;
  }

  const bannedUrlParts = ['feeds.feedburner.com', 'feeds.wordpress.com/', '.feedsportal.com', 'wp-includes', 'wp-content/themes', 'wp-content/plugins', 'stats.wordpress.com', 'pixel.wp.com'];
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.some)(bannedUrlParts, part => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.includes)(imageUrl.toLowerCase(), part));
};

function provideProtocol(post, url) {
  const postUrlParts = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .getUrlParts */ .A)(post.URL); // The image on the relative-protocol URL will have the same protocol with the post

  if (url.startsWith('//')) {
    return `${postUrlParts.protocol || 'https:'}${url}`;
  }

  return url;
}

function makeImageSafe(post, image, maxWidth) {
  let imgSource = image.getAttribute('src');
  const imgSourceParts = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .getUrlParts */ .A)(imgSource);
  const hostName = imgSourceParts.hostname; // if imgSource is relative, prepend post domain so it isn't relative to calypso

  if (!hostName) {
    const postUrlParts = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .getUrlParts */ .A)(post.URL);
    imgSource = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .getUrlFromParts */ .C)({
      protocol: postUrlParts.protocol,
      host: postUrlParts.host,
      pathname: (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(postUrlParts.pathname, imgSourceParts.pathname)
    }).href;
  }

  let safeSource = maxWidth ? (0,_utils__WEBPACK_IMPORTED_MODULE_3__/* .maxWidthPhotonishURL */ .E)((0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_4__/* .safeImageUrl */ .F)(imgSource), maxWidth) : (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_4__/* .safeImageUrl */ .F)(imgSource); // When the image URL is not photoned, try providing protocol

  if (!safeSource) {
    imgSource = provideProtocol(post, imgSource);
  } // allow https sources through even if we can't make them 'safe'
  // helps images that use querystring params and are from secure sources


  if (!safeSource && (0,lodash__WEBPACK_IMPORTED_MODULE_0__.startsWith)(imgSource, 'https://')) {
    safeSource = imgSource;
  }

  removeUnwantedAttributes(image); // trickery to remove it from the dom / not load the image
  // TODO: test if this is necessary

  if (!safeSource || imageShouldBeRemovedFromContent(imgSource)) {
    image.parentNode.removeChild(image); // fun fact: removing the node from the DOM will not prevent it from loading. You actually have to
    // change out the src to change what loads. The following is a 1x1 transparent gif as a data URL

    image.setAttribute('src', TRANSPARENT_GIF);
    return;
  }

  image.setAttribute('src', safeSource);
}

const makeImagesSafe = maxWidth => (post, dom) => {
  if (!dom) {
    throw new Error('this transform must be used as part of withContentDOM');
  }

  const images = dom.querySelectorAll('img[src]');
  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(images, image => makeImageSafe(post, image, maxWidth));
  return post;
};

/* harmony default export */ __webpack_exports__["Z"] = (makeImagesSafe);

/***/ }),

/***/ 51088:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ makeContentLinksSafe; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(48265);


function makeContentLinksSafe(post, dom) {
  const links = Array.from(dom.querySelectorAll('a[href]'));
  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(links, link => {
    // only accept links that are to http or https sites
    if (!_utils__WEBPACK_IMPORTED_MODULE_1__/* .safeLinkRe.test */ .G.test(link.href)) {
      link.removeAttribute('href');
    }
  });
  return post;
}

/***/ }),

/***/ 64000:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ sanitizeContent; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);

const thingsToRemove = ['.sharedaddy', // share daddy
'script', // might be too late for these at this point...
'.jp-relatedposts', // jetpack related posts
'.jp-relatedposts-headline', // same
'.mc4wp-form', // mailchimp 4 wp
'.wpcnt', // wordads?
'.OUTBRAIN', '.adsbygoogle', 'form', // no form elements
'input', 'select', 'button', 'textarea'].join(', '); // make them all into one big selector

function removeElement(element) {
  element.parentNode && element.parentNode.removeChild(element);
}

function sanitizeContent(post, dom) {
  if (!dom) {
    throw new Error('this transform must be used as part of withContentDOM');
  }

  const elements = dom.querySelectorAll(thingsToRemove); // using forEach because qsa doesn't return a real array

  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(elements, removeElement);
  return post;
}

/***/ }),

/***/ 42347:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ removeContentStyles; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);


function matches(element, selector) {
  const ep = Element.prototype; // modern browsers support `matches` but IE11 and older safari support it as `matchesSelector` with a prefix

  const matcher = ep.matches || ep.webkitMatchesSelector || ep.mozMatchesSelector || ep.msMatchesSelector;

  if (!matcher) {
    return false;
  }

  return matcher.call(element, selector);
}

function removeContentStyles(post, dom) {
  if (!dom) {
    throw new Error('this transform must be used as part of withContentDOM');
  } // Allow the markup for galleries, Instagram, and Twitter. Styling will be allowed on elements that match this selector.


  const allowedMarkupSelector = '.gallery, .gallery *, .gallery-row, .gallery-row *, .gallery-group, .gallery-group *, ' + 'blockquote[class^="instagram-"], blockquote[class^="instagram-"] *, ' + 'blockquote[class^="twitter-"], blockquote[class^="twitter-"] *'; // remove most style attributes

  const styled = dom.querySelectorAll('[style]');
  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(styled, function (element) {
    if (!matches(element, allowedMarkupSelector)) {
      element.removeAttribute('style');
    }
  }); // remove all style elements outside of galleries and embeds

  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(dom.querySelectorAll('style'), function (element) {
    if (!matches(element, allowedMarkupSelector)) {
      element.parentNode && element.parentNode.removeChild(element);
    }
  }); // remove align from non images. Unlike above, img align is permitted anywhere.

  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(dom.querySelectorAll('[align]'), element => {
    if (element.tagName !== 'IMG') {
      element.removeAttribute('align');
    }
  });
  return post;
}

/***/ }),

/***/ 47401:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ createBetterExcerpt; }
/* harmony export */ });
/* unused harmony export formatExcerpt */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var striptags__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(33927);
/* harmony import */ var striptags__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(striptags__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(6964);



/**
 * Removes an HTML element from the DOM
 *
 * @param {Node} element DOM element to remove
 */

function removeElement(element) {
  element.parentNode && element.parentNode.removeChild(element);
}
/**
 *  Trims any empty starting `br` tags.  Recurses into non-empty tags.
 *  will remove all of the leading `br`s it can find.
 *
 * @param {Node} dom DOM element to remove br tags from.
 */


function stripLeadingBreaklines(dom) {
  if (!dom) {
    return;
  } // first element is breakline actually returns the node in case of success


  while (firstElementIsBreakline(dom)) {
    removeElement(firstElementIsBreakline(dom));
  }
}
/**
 *  Returns the node if first element ( checking nested ) is a `br`
 *  else returns falsy
 *
 * @param {Node} dom DOM element to check
 */


function firstElementIsBreakline(dom) {
  if (dom.childNodes.length === 0) {
    return dom.nodeName === 'BR' && dom;
  }

  return firstElementIsBreakline(dom.firstChild);
}

function buildStrippedDom(content) {
  // Spin up a new DOM for the linebreak markup
  const dom = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .domForHtml */ .j)(content); // Ditch any photo captions, styles, scripts

  const stripSelectors = '.wp-caption, style, script, blockquote[class^="instagram-"], figure, .tiled-gallery';
  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(dom.querySelectorAll(stripSelectors), removeElement);
  return dom.innerHTML;
}

function formatExcerpt(content) {
  if (!content) {
    return '';
  }

  const dom = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .domForHtml */ .j)(striptags__WEBPACK_IMPORTED_MODULE_1___default()(content, ['p', 'br', 'sup', 'sub']));
  dom.id = '__better_excerpt__'; // strip any p's that are empty

  Array.from(dom.querySelectorAll('p')).filter(element => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.trim)(element.textContent).length === 0).forEach(removeElement); // remove styles for all p's that remain

  Array.from(dom.querySelectorAll('p')).forEach(element => {
    element.removeAttribute('style');
    element.removeAttribute('align');
  });
  stripLeadingBreaklines(dom); // now limit it to the first three elements

  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(dom.querySelectorAll('#__better_excerpt__ > p, #__better_excerpt__ > br'), function (element, index) {
    if (index >= 3) {
      element.parentNode && element.parentNode.removeChild(element);
    }
  }); // trim and replace &nbsp; entities

  const betterExcerpt = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.trim)(dom.innerHTML.replace(/&nbsp;/g, ' '));
  dom.innerHTML = '';
  return betterExcerpt;
}
function createBetterExcerpt(post) {
  if (!post || !post.content) {
    return post;
  }

  const strippedDom = buildStrippedDom(post.content);
  post.content_no_html = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.trim)(striptags__WEBPACK_IMPORTED_MODULE_1___default()(strippedDom));
  post.better_excerpt = formatExcerpt(strippedDom);
  post.better_excerpt_no_html = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.trim)(striptags__WEBPACK_IMPORTED_MODULE_1___default()(post.better_excerpt)); // also make a shorter excerpt...

  if (post.better_excerpt_no_html) {
    // replace any trailing [...] with an actual ellipsis
    let shorterExcerpt = post.better_excerpt_no_html.replace(/\[...\]\w*$/, '…'); // limit to 160 characters

    if (shorterExcerpt.length > 160) {
      const lastSpace = shorterExcerpt.lastIndexOf(' ', 160);
      shorterExcerpt = shorterExcerpt.substring(0, lastSpace) + '…';
    }

    post.short_excerpt = shorterExcerpt;
  }

  return post;
}

/***/ }),

/***/ 12800:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ decodeEntities; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(94668);
/* harmony import */ var calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(50118);


const DEFAULT_FIELDS = ['excerpt', 'title', 'site_name'];
function decodeEntities(post) {
  let fields = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : DEFAULT_FIELDS;
  fields.forEach(function (prop) {
    if (post[prop]) {
      post[prop] = (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_0__/* .decodeEntities */ .S)(post[prop]);
    }
  }); // Sometimes titles are double-encoded, so run again to be sure

  post.title = (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_0__/* .decodeEntities */ .S)(post.title);

  if (post.parent && post.parent.title) {
    post.parent.title = (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_0__/* .decodeEntities */ .S)(post.parent.title);
  }

  if (post.author) {
    if (post.author.name) {
      post.author.name = (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_0__/* .decodeEntities */ .S)(post.author.name);
    }

    if (post.author.avatar_URL) {
      post.author.avatar_URL = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .safeImageUrl */ .F)(post.author.avatar_URL);
    }
  }

  if (post.tags) {
    // tags is an object
    Object.values(post.tags).forEach(function (tag) {
      tag.name = (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_0__/* .decodeEntities */ .S)(tag.name);
    });
  }

  return post;
}

/***/ }),

/***/ 31564:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ keepValidImages; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(94668);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);



function isValidImage(width, height) {
  return function (image) {
    return image.width >= width && image.height >= height && (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .safeImageUrl */ .F)(image.src);
  };
}

function keepValidImages(minWidth, minHeight) {
  return function keepValidImagesForWidthAndHeight(post) {
    const imageFilter = isValidImage(minWidth, minHeight);

    if (post.images) {
      post.images = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.filter)(post.images, imageFilter);
    }

    if (post.content_images) {
      post.content_images = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.filter)(post.content_images, imageFilter);
    }

    return post;
  };
}

/***/ }),

/***/ 91410:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ makeLinksSafe; }
/* harmony export */ });
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(48265);
/**
 */

function makeLinksSafe(post) {
  if (post && post.URL && !_utils__WEBPACK_IMPORTED_MODULE_0__/* .safeLinkRe.test */ .G.test(post.URL)) {
    post.URL = '';
  }

  if (post && post.short_URL && !_utils__WEBPACK_IMPORTED_MODULE_0__/* .safeLinkRe.test */ .G.test(post.short_URL)) {
    post.short_URL = '';
  }

  return post;
}

/***/ }),

/***/ 21036:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ makeSiteIDSafeForAPI; }
/* harmony export */ });
function makeSiteIDSafeForAPI(post) {
  if (post.site_id) {
    post.normalized_site_id = ('' + post.site_id).replace(/::/g, '/');
  }

  return post;
}

/***/ }),

/***/ 53317:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ pickCanonicalImage; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(15721);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(75209);


function pickCanonicalImage(post) {
  let canonicalImage;

  if ((0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .thumbIsLikelyImage */ .J)(post.post_thumbnail)) {
    const {
      URL: url,
      width,
      height
    } = post.post_thumbnail;
    canonicalImage = {
      uri: url,
      width,
      height
    };
  } else if (post.content_images && post.content_images.length) {
    const candidateImage = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.find)(post.content_images, _utils__WEBPACK_IMPORTED_MODULE_2__/* .isCandidateForCanonicalImage */ .O);

    if (candidateImage) {
      canonicalImage = {
        uri: candidateImage.src,
        width: candidateImage.width,
        height: candidateImage.height
      };
    }
  }

  if (canonicalImage) {
    post.canonical_image = canonicalImage;
  }

  return post;
}

/***/ }),

/***/ 66184:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ pickCanonicalMedia; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(94668);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(48098);



/**
 * Returns true if an image is large enough to be a featured asset
 *
 * @param {object} image - image must have a width and height property
 * @returns {boolean} true if large enough, false if image undefined or too small
 */

function isImageLargeEnoughForFeature(image) {
  if (!image) {
    return false;
  }

  const imageIsTallEnough = 100 <= image.width;
  const imageIsWideEnough = 75 <= image.height;
  return imageIsTallEnough && imageIsWideEnough;
}

function isCandidateForFeature(media) {
  if (!media) {
    return false;
  }

  if (media.mediaType === 'image') {
    return isImageLargeEnoughForFeature(media) && (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .safeImageUrl */ .F)(media.src);
  } else if (media.mediaType === 'video') {
    // we need to know how to autoplay it which probably means we know how to get a thumbnail
    return media.autoplayIframe;
  }

  return false;
}
/*
 * Given a post:
 *  1. prefer to return the post's featured image ( post.post_thumbnail )
 *  2. if there is no usable featured image, use the media that appears first in the content of the post
 *  3. if there is no eligible asset, return null
 */


function pickCanonicalMedia(post) {
  if (!post) {
    return post;
  } // jetpack lies about thumbnails/featured_images so we need to make sure its actually an image


  if ((0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .isUrlLikelyAnImage */ .E)(post.featured_image) && (!post.post_thumbnail && post.is_jetpack || // some jetpack sites dont create post_thumbnail
  isImageLargeEnoughForFeature(post.post_thumbnail)) && (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .safeImageUrl */ .F)(post.featured_image)) {
    post.canonical_media = {
      src: post.featured_image,
      height: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(post, 'post_thumbnail.height'),
      width: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(post, 'post_thumbnail.width'),
      mediaType: 'image'
    };
    return post;
  }

  const canonicalMedia = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.find)(post.content_media, isCandidateForFeature);

  if (canonicalMedia) {
    post.canonical_media = canonicalMedia;
  }

  return post;
}

/***/ }),

/***/ 49147:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ pickPrimaryTag; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);

function pickPrimaryTag(post) {
  // if we hand max an invalid or empty array, it returns -Infinity
  const primary_tag = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.maxBy)((0,lodash__WEBPACK_IMPORTED_MODULE_0__.values)(post.tags), function (tag) {
    return tag.post_count;
  });

  if (primary_tag !== undefined) {
    post.primary_tag = primary_tag;
  }

  return post;
}

/***/ }),

/***/ 59654:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ preventWidows; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(93345);


function preventWidows(post) {
  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(['excerpt'], function (prop) {
    if (post[prop]) {
      post[prop] = (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_1__/* .preventWidows */ .R)(post[prop], 2);
    }
  });
  return post;
}

/***/ }),

/***/ 36003:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ safeImagePropertiesForWidth; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(65956);


function safeImagePropertiesForWidth(maxWidth) {
  return function safeImageProperties(post) {
    (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .makeImageURLSafe */ .O)(post.author, 'avatar_URL', maxWidth);
    (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .makeImageURLSafe */ .O)(post, 'featured_image', maxWidth, post.URL);

    if (post.post_thumbnail) {
      (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .makeImageURLSafe */ .O)(post.post_thumbnail, 'URL', maxWidth, post.URL);
    }

    if (post.featured_media && post.featured_media.type === 'image') {
      (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .makeImageURLSafe */ .O)(post.featured_media, 'uri', maxWidth, post.URL);
    }

    if (post.canonical_image && post.canonical_image.uri) {
      (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .makeImageURLSafe */ .O)(post.canonical_image, 'uri', maxWidth, post.URL);
    }

    if (post.attachments) {
      Object.values(post.attachments).forEach(function (attachment) {
        if ((0,lodash__WEBPACK_IMPORTED_MODULE_0__.startsWith)(attachment.mime_type, 'image/')) {
          (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .makeImageURLSafe */ .O)(attachment, 'URL', maxWidth, post.URL);
        }
      });
    }

    return post;
  };
}

/***/ }),

/***/ 60566:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ stripHtml; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(8165);


function stripHtml(post) {
  (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(['excerpt', 'title', 'site_name'], function (prop) {
    if (post[prop]) {
      post[prop] = (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_1__/* .stripHTML */ .C)(post[prop]);
    }
  });

  if (post.author && post.author.name) {
    post.author.name = (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_1__/* .stripHTML */ .C)(post.author.name);
  }

  return post;
}

/***/ }),

/***/ 75659:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ waitForImagesToLoad; }
/* harmony export */ });
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(59755);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(15721);



const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('calypso:post-normalizer:wait-for-images-to-load');

function convertImageToObject(image) {
  const returnObj = {
    src: image.src,
    // use natural height and width
    width: image.naturalWidth,
    height: image.naturalHeight
  };

  if (image instanceof Image && image.complete) {
    returnObj.fetched = true;
  }

  return returnObj;
}

function imageForURL(imageUrl) {
  const img = new Image();
  img.src = imageUrl;
  return img;
}

function promiseForImage(image) {
  if (image.complete && image.naturalWidth > 0) {
    return Promise.resolve(image);
  }

  return new Promise((resolve, reject) => {
    image.onload = () => resolve(image);

    image.onerror = () => reject(image);
  });
}

function waitForImagesToLoad(post) {
  return new Promise(resolve => {
    function acceptLoadedImages(images) {
      if (post.featured_image) {
        if (!images.some(img => img.src === post.featured_image)) {
          // featured image didn't load, nix it
          post.featured_image = null;
        }
      }

      post.images = images.map(convertImageToObject);
      post.content_images = (0,lodash__WEBPACK_IMPORTED_MODULE_1__.map)(post.content_images, image => post.images.find(img => img.src === image.src)).filter(Boolean); // this adds adds height/width to images

      post.content_media = (0,lodash__WEBPACK_IMPORTED_MODULE_1__.map)(post.content_media, media => {
        if (media.mediaType === 'image') {
          const img = post.images.find(image => image.src === media.src);
          return { ...media,
            ...img
          };
        }

        return media;
      });
      resolve(post);
    }

    const knownImages = {};
    const imagesToCheck = [];

    function checkAndRememberDimensions(image, url) {
      // Check provided image (if any) for dimension info first.
      let knownDimensions = image && (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .deduceImageWidthAndHeight */ .H)(image); // If we still don't know the dimension info, check attachments.

      if (!knownDimensions && post.attachments) {
        const attachment = Object.values(post.attachments).find(att => att.URL === post.featured_image);

        if (attachment) {
          knownDimensions = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .deduceImageWidthAndHeight */ .H)(attachment);
        }
      } // Remember dimensions if we have them.


      if (knownDimensions) {
        knownImages[url] = {
          src: url,
          naturalWidth: knownDimensions.width,
          naturalHeight: knownDimensions.height
        };
      }

      imagesToCheck.push(url);
    }

    if ((0,_utils__WEBPACK_IMPORTED_MODULE_3__/* .thumbIsLikelyImage */ .J)(post.post_thumbnail)) {
      checkAndRememberDimensions(post.post_thumbnail, post.post_thumbnail.URL);
    } else if (post.featured_image) {
      checkAndRememberDimensions(null, post.featured_image);
    }

    (0,lodash__WEBPACK_IMPORTED_MODULE_1__.forEach)(post.content_images, image => checkAndRememberDimensions(image, image.src));

    if (imagesToCheck.length === 0) {
      resolve(post);
      return;
    }

    const imagesLoaded = {}; // convert to image objects to start the load process
    // only check the first x images

    const NUMBER_OF_IMAGES_TO_CHECK = 10;
    let promises = imagesToCheck.slice(0, NUMBER_OF_IMAGES_TO_CHECK).map(imageUrl => {
      if (imageUrl in knownImages) {
        return Promise.resolve(knownImages[imageUrl]);
      }

      return promiseForImage(imageForURL(imageUrl));
    });
    promises.forEach(promise => {
      promise.then(image => {
        // keep track of what loaded successfully. Note these will be out of order.
        imagesLoaded[image.src] = image;
      }).catch(err => {
        // ignore what did not, but return the promise chain to success
        debug('failed to load image', err, post);
        return null;
      }).then(() => {
        // check to see if all of the promises have settled
        // if so, accept what loaded and resolve the main promise
        promises = promises.filter(p => p !== promise);

        if (promises.length === 0) {
          const imagesInOrder = imagesToCheck.map(src => imagesLoaded[src]).filter(Boolean);
          acceptLoadedImages(imagesInOrder);
        }
      }).catch(err => {
        debug('Fulfilling promise failed', err);
      });
    });
  });
}

/***/ }),

/***/ 55454:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ createDomTransformRunner; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(6964);


function createDomTransformRunner(transforms) {
  return function withContentDOM(post) {
    if (!post || !post.content || !transforms) {
      return post;
    }

    const dom = (0,_utils__WEBPACK_IMPORTED_MODULE_1__/* .domForHtml */ .j)(post.content);
    post = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(transforms, (memo, transform) => {
      return transform(memo, dom);
    }, post);
    post.content = dom.innerHTML;
    dom.innerHTML = '';
    return post;
  };
}

/***/ }),

/***/ 59755:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "H": function() { return /* binding */ deduceImageWidthAndHeight; }
/* harmony export */ });
function deduceImageWidthAndHeight(image) {
  if (image.height && image.width) {
    return {
      height: image.height,
      width: image.width
    };
  }

  if (image.naturalHeight && image.naturalWidth) {
    return {
      height: image.naturalHeight,
      width: image.naturalWidth
    };
  }

  if (image.dataset && image.dataset.origSize) {
    const [width, height] = image.dataset.origSize.split(',').map(Number);
    return {
      width,
      height
    };
  }

  return null;
}

/***/ }),

/***/ 6964:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "j": function() { return /* binding */ domForHtml; }
/* harmony export */ });
function domForHtml(html) {
  if (typeof DOMParser !== 'undefined' && window.DOMParser.prototype.parseFromString) {
    const parser = new window.DOMParser();
    const parsed = parser.parseFromString(html, 'text/html');

    if (parsed && parsed.body) {
      return parsed.body;
    }
  } // DOMParser support is not present or non-standard


  const newDoc = document.implementation.createHTMLDocument('processing doc');
  const dom = newDoc.createElement('div');
  dom.innerHTML = html;
  return dom;
}

/***/ }),

/***/ 95822:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "p": function() { return /* binding */ iframeIsAllowed; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(6261);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);


/**
 * Determines if an iframe is from a source we trust. We allow these to be the featured media and also give
 * them a freer sandbox
 *
 * @param  {object} iframe the iframe to check
 * @returns {boolean} true if allowed
 */

function iframeIsAllowed(iframe) {
  const allowedIframeHosts = ['youtube.com', 'youtube-nocookie.com', 'videopress.com', 'video.wordpress.com', 'vimeo.com', 'cloudup.com', 'soundcloud.com', '8tracks.com', 'spotify.com', 'me.sh', 'bandcamp.com', 'kickstarter.com', 'facebook.com', 'embed.itunes.apple.com', 'nyt.com', 'google.com', 'mixcloud.com', 'players.brightcove.net', 'embed.ted.com', 'fast.wistia.net', 'player.twitch.tv', 'archive.org', 'codepen.io', 'www.audiomack.com', 'player.theplatform.com', 'embed.radiopublic.com', 'gfycat.com', 'scribd.com', 'megaphone.fm', 'icloud.com', 'read.amazon.com', 'loom.com'];
  const hostName = iframe.src && (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .getUrlParts */ .A)(iframe.src).hostname;
  const iframeSrc = hostName && hostName.toLowerCase();
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.some)(allowedIframeHosts, function (allowedHost) {
    return `.${iframeSrc}`.endsWith('.' + allowedHost);
  });
}

/***/ }),

/***/ 75209:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "O": function() { return /* binding */ isCandidateForCanonicalImage; }
/* harmony export */ });
function isCandidateForCanonicalImage(image) {
  if (!image) {
    return false;
  }

  if (image.width < 100) {
    return false;
  }

  if (image.width * image.height < 100 * 75) {
    return false;
  }

  return true;
}

/***/ }),

/***/ 48098:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "E": function() { return /* binding */ isUrlLikelyAnImage; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(6261);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);


/**
 * Determine if url is likely pointed to an image
 *
 * @param {string} uri - a url
 * @returns {boolean} - true or false depending on if it is probably an image (has the right extension)
 */

function isUrlLikelyAnImage(uri) {
  if (!uri) {
    return false;
  }

  const withoutQuery = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .getUrlParts */ .A)(uri).pathname;
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.some)(['.jpg', '.jpeg', '.png', '.gif'], ext => withoutQuery.endsWith(ext));
}

/***/ }),

/***/ 65956:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "O": function() { return /* binding */ makeImageURLSafe; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(6261);
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(94668);
/* harmony import */ var calypso_lib_post_normalizer_utils_max_width_photonish_url__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(54855);
/* harmony import */ var calypso_lib_url__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70353);



function makeImageURLSafe(object, propName, maxWidth, baseURL) {
  if (object && object[propName]) {
    const urlParts = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__/* .getUrlParts */ .A)(object[propName]);

    if (baseURL && !urlParts.hostname) {
      const {
        pathname: basePath
      } = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__/* .getUrlParts */ .A)(baseURL);
      const resolvedPath = (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(basePath, object[propName]);
      object[propName] = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__/* .getUrlFromParts */ .C)({ ...urlParts,
        protocol: baseURL.protocol,
        hostname: baseURL.hostname,
        pathname: resolvedPath
      }).href;
    }

    object[propName] = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_2__/* .safeImageUrl */ .F)(object[propName]);

    if (maxWidth) {
      object[propName] = (0,calypso_lib_post_normalizer_utils_max_width_photonish_url__WEBPACK_IMPORTED_MODULE_3__/* .maxWidthPhotonishURL */ .E)(object[propName], maxWidth);
    }
  }
}

/***/ }),

/***/ 54855:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "E": function() { return /* binding */ maxWidthPhotonishURL; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(6261);
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4174);
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(78038);

const IMAGE_SCALE_FACTOR = typeof window !== 'undefined' && window.devicePixelRatio && window.devicePixelRatio > 1 ? 2 : 1;
const DEFAULT_PHOTON_QUALITY = 80; // 80 was chosen after some heuristic testing as the best blend of size and quality

const SERVICE_HOSTNAME_PATTERNS = {
  photon: /(^[is]\d\.wp\.com|(^|\.)wordpress\.com)$/,
  gravatar: /(^|\.)gravatar\.com$/
};
function maxWidthPhotonishURL(imageURL, width) {
  if (!imageURL) {
    return imageURL;
  }

  const urlParts = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__/* .getUrlParts */ .A)(imageURL);
  const urlType = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .determineUrlType */ .D)(imageURL); // Return the unformatted imageURL for path-relative or path-absolute URLs.

  if (!urlParts.host) {
    return imageURL;
  }

  const service = Object.keys(SERVICE_HOSTNAME_PATTERNS).find(key => urlParts.hostname.match(SERVICE_HOSTNAME_PATTERNS[key])); // From this point on, we should only have absolute and scheme-relative URLs.

  delete urlParts.search; // strip other sizing params

  for (const param of ['h', 'crop', 'resize', 'fit']) {
    urlParts.searchParams.delete(param);
  }

  const sizeParam = 'gravatar' === service ? 's' : 'w';
  urlParts.searchParams.set(sizeParam, width * IMAGE_SCALE_FACTOR);

  if ('gravatar' !== service) {
    // gravatar doesn't support these, only photon / files.wordpress
    urlParts.searchParams.set('quality', DEFAULT_PHOTON_QUALITY);
    urlParts.searchParams.set('strip', 'info'); // strip all exif data, leave ICC intact
  } // make a new query object with keys in a known order


  const sortedKeys = Array.from(urlParts.searchParams.keys()).sort();
  const sortedParams = new URLSearchParams();
  sortedKeys.forEach(key => sortedParams.set(key, urlParts.searchParams.get(key)));
  const extendedUrl = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__/* .getUrlFromParts */ .C)({ ...urlParts,
    // Provide a protocol if one is missing. This is the case for some image ads.
    protocol: urlParts.protocol || 'https:',
    // Override original search params.
    searchParams: sortedParams
  }).href;

  try {
    // Format back to original URL type (e.g. scheme-relative).
    return (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(extendedUrl, urlType);
  } catch {
    // Something failed in the formatting, so return just return the full extended URL.
    return extendedUrl;
  }
}

/***/ }),

/***/ 48265:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "G": function() { return /* binding */ safeLinkRe; },
/* harmony export */   "m": function() { return /* binding */ safeLink; }
/* harmony export */ });
const safeLinkRe = /^https?:\/\//;
/**
 * Only accept links that start with http or https. Reject others.
 *
 * @param {string} link the link to check
 * @returns {string|undefined} the safe link or undefined
 */

function safeLink(link) {
  if (safeLinkRe.test(link)) {
    return link;
  }

  return undefined;
}

/***/ }),

/***/ 15721:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "J": function() { return /* binding */ thumbIsLikelyImage; }
/* harmony export */ });
/* harmony import */ var calypso_lib_post_normalizer_utils_is_url_likely_an_image__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(48098);

/**
 * Determine if a post thumbnail is likely an image
 *
 * @param  {object} thumb the thumbnail object from a post
 * @returns {boolean}       whether or not we think this is an image
 */

function thumbIsLikelyImage(thumb) {
  if (!thumb || !thumb.URL) {
    return false;
  } // this doesn't work because jetpack 4.2 lies
  // normally I wouldn't leave commented code in, but it's the best way to explain what not to do
  //if ( startsWith( thumb.mime_type, 'image/' ) ) {
  //	return true;
  // }


  return (0,calypso_lib_post_normalizer_utils_is_url_likely_an_image__WEBPACK_IMPORTED_MODULE_0__/* .isUrlLikelyAnImage */ .E)(thumb.URL);
}

/***/ }),

/***/ 29950:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "W": function() { return /* binding */ createPurchasesArray; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);


function createPurchaseObject(purchase) {
  const object = {
    id: Number(purchase.ID),
    active: Boolean(purchase.active),
    amount: Number(purchase.amount),
    attachedToPurchaseId: Number(purchase.attached_to_purchase_id),
    billPeriodDays: Number(purchase.bill_period_days),
    billPeriodLabel: purchase.bill_period_label,
    mostRecentRenewDate: purchase.most_recent_renew_date,
    canDisableAutoRenew: Boolean(purchase.can_disable_auto_renew),
    canReenableAutoRenewal: Boolean(purchase.can_reenable_auto_renewal),
    canExplicitRenew: Boolean(purchase.can_explicit_renew),
    costToUnbundle: purchase.cost_to_unbundle ? Number(purchase.cost_to_unbundle) : Number(purchase.amount),
    costToUnbundleText: purchase.cost_to_unbundle_display ? purchase.cost_to_unbundle_display : purchase.price_text,
    currencyCode: purchase.currency_code,
    currencySymbol: purchase.currency_symbol,
    description: purchase.description,
    domain: purchase.domain,
    domainRegistrationAgreementUrl: purchase.domain_registration_agreement_url || null,
    error: null,
    blogCreatedDate: purchase.blog_created_date,
    expiryDate: purchase.expiry_date,
    expiryStatus: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.camelCase)(purchase.expiry_status),
    iapPurchaseManagementLink: purchase.iap_purchase_management_link,
    includedDomain: purchase.included_domain,
    includedDomainPurchaseAmount: purchase.included_domain_purchase_amount,
    introductoryOffer: purchase.introductory_offer ? {
      costPerInterval: Number(purchase.introductory_offer.cost_per_interval),
      endDate: String(purchase.introductory_offer.end_date),
      intervalCount: Number(purchase.introductory_offer.interval_count),
      intervalUnit: String(purchase.introductory_offer.interval_unit),
      isWithinPeriod: Boolean(purchase.introductory_offer.is_within_period),
      transitionAfterRenewalCount: Number(purchase.introductory_offer.transition_after_renewal_count),
      isNextRenewalUsingOffer: Boolean(purchase.introductory_offer.is_next_renewal_using_offer),
      remainingRenewalsUsingOffer: Number(purchase.introductory_offer.remaining_renewals_using_offer),
      shouldProrateWhenOfferEnds: Boolean(purchase.introductory_offer.should_prorate_when_offer_ends),
      isNextRenewalProrated: Boolean(purchase.introductory_offer.is_next_renewal_prorated)
    } : null,
    isCancelable: Boolean(purchase.is_cancelable),
    isDomainRegistration: Boolean(purchase.is_domain_registration),
    isLocked: Boolean(purchase.is_locked),
    isInAppPurchase: Boolean(purchase.is_iap_purchase),
    isRechargeable: Boolean(purchase.is_rechargable),
    isRefundable: Boolean(purchase.is_refundable),
    isRenewable: Boolean(purchase.is_renewable),
    isRenewal: Boolean(purchase.is_renewal),
    meta: purchase.meta,
    priceText: purchase.price_text,
    partnerName: purchase.partner_name,
    partnerSlug: purchase.partner_slug,
    partnerKeyId: purchase.partner_key_id,
    payment: {
      name: purchase.payment_name,
      type: purchase.payment_type,
      countryCode: purchase.payment_country_code,
      countryName: purchase.payment_country_name,
      storedDetailsId: purchase.stored_details_id
    },
    pendingTransfer: Boolean(purchase.pending_transfer),
    productId: Number(purchase.product_id),
    productName: purchase.product_name,
    productSlug: purchase.product_slug,
    productDisplayPrice: purchase.product_display_price,
    totalRefundAmount: Number(purchase.total_refund_amount),
    totalRefundText: purchase.total_refund_text,
    refundAmount: Number(purchase.refund_amount),
    refundOptions: purchase.refund_options,
    refundText: purchase.refund_text,
    refundPeriodInDays: purchase.refund_period_in_days,
    regularPriceText: purchase.regular_price_text,
    renewDate: purchase.renew_date,
    saleAmount: purchase.sale_amount,
    siteId: Number(purchase.blog_id),
    siteName: purchase.blogname,
    subscribedDate: purchase.subscribed_date,
    subscriptionStatus: purchase.subscription_status,
    tagLine: purchase.tag_line,
    taxAmount: purchase.tax_amount,
    taxText: purchase.tax_text,
    purchaseRenewalQuantity: purchase.renewal_price_tier_usage_quantity || null,
    userId: Number(purchase.user_id),
    isAutoRenewEnabled: purchase.auto_renew === '1'
  };

  if ('credit_card' === purchase.payment_type) {
    object.payment.creditCard = {
      id: Number(purchase.payment_card_id),
      type: purchase.payment_card_type,
      processor: purchase.payment_card_processor,
      number: purchase.payment_details,
      expiryDate: purchase.payment_expiry
    };
  }

  if ('paypal_direct' === purchase.payment_type) {
    object.payment.expiryDate = purchase.payment_expiry;
  }

  return object;
}

function createPurchasesArray(dataTransferObject) {
  if (!Array.isArray(dataTransferObject)) {
    return [];
  }

  return dataTransferObject.map(createPurchaseObject);
}

/***/ }),

/***/ 2623:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ QueryManager; }
/* harmony export */ });
/* unused harmony export DELETE_PATCH_KEY */
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(56666);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _key__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(37754);



/**
 * Constants
 */

/**
 * Object key name for property used in indicating that an item is intended to
 * be removed during patched `mergeItem`.
 *
 * @type {string}
 */

const DELETE_PATCH_KEY = '__DELETE';
/*
 * Construct an array of items from an array of keys and a map of key/item pairs.
 * There is a two-level memoization cache for the `items` and `itemKeys` params.
 * `itemKeys` can also be `null`, which means a request to return an array of all items.
 */

const itemsCache = new WeakMap();
const ALL_ITEMS_KEY = [];

function getItemsForKeys(items, itemKeys) {
  // Get the cache record for the `items` instance, construct a new one if doesn't exist yet.
  let cacheForItems = itemsCache.get(items);

  if (!cacheForItems) {
    cacheForItems = new WeakMap();
    itemsCache.set(items, cacheForItems);
  } // `itemKeys == null` means a request for array of all items. Cache them with a special key.


  if (itemKeys == null) {
    let resultForAllKeys = cacheForItems.get(ALL_ITEMS_KEY);

    if (!resultForAllKeys) {
      resultForAllKeys = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.values)(items);
      cacheForItems.set(ALL_ITEMS_KEY, resultForAllKeys);
    }

    return resultForAllKeys;
  } // compute result from `items` and `itemKeys`, cached for unique `itemKeys` instances


  let resultForItemKeys = cacheForItems.get(itemKeys);

  if (!resultForItemKeys) {
    resultForItemKeys = itemKeys.map(itemKey => items[itemKey]);
    cacheForItems.set(itemKeys, resultForItemKeys);
  }

  return resultForItemKeys;
}
/**
 * QueryManager manages items which can be queried and change over time. It is
 * intended to be extended by a more specific implementation which is
 * responsible for implementing its matching, merging, and sorting behaviors.
 */


class QueryManager {
  /**
   * Constructs a new instance of QueryManager
   *
   * @param {object} data            Initial data
   * @param {object} options         Manager options
   * @param {string} options.itemKey Field to key items by
   */
  constructor(data, options) {
    this.data = Object.assign({
      items: {},
      queries: {}
    }, data);
    this.options = Object.assign({
      itemKey: 'ID'
    }, options);
  }
  /**
   * Returns a new item after consideration of incoming revision of that
   * item. The item can be undefined in the case that the revision is
   * new. Optionally patch the item to merge, not replace. Returning
   * undefined indicates that item should be removed from known set.
   *
   * @param  {?object} item        Existing item, if exists
   * @param  {object}  revisedItem Incoming revision of item
   * @param  {boolean} patch       Use patching application
   * @returns {?object}             Item to track, or undefined to omit
   */


  static mergeItem(item, revisedItem) {
    let patch = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;

    if (patch) {
      if (revisedItem[DELETE_PATCH_KEY]) {
        return undefined;
      }

      return Object.assign({}, item, revisedItem);
    }

    return revisedItem;
  }
  /**
   * Returns true if the item matches the given query, or false otherwise.
   *
   * @param  {object}  query Query object
   * @param  {object}  item  Item to consider
   * @returns {boolean}       Whether item matches query
   */


  static matches(query, item) {
    return !!item;
  }
  /**
   * A sort comparison function that defines the sort order of items under
   * consideration of the specified query.
   *
   * @param  {object} query Query object
   * @param  {object} itemA First item
   * @param  {object} itemB Second item
   * @returns {number}       0 if equal, less than 0 if itemA is first,
   *                        greater than 0 if itemB is first.
   */


  static compare(query, itemA, itemB) {
    if (itemA === itemB) {
      return 0;
    }

    return itemB - itemA;
  }
  /**
   * A sorting function that defines the sort order of items under
   * consideration of the specified query. This mutates the keys argument and
   * doesn't have a return value (because that's how Array.prototype.sort works, see
   * https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/sort ).
   *
   * @param  {Array}  keys  Keys to be sorted
   * @param  {Array}  items Items by which to sort
   * @param  {object} query Query object
   */


  static sort(keys, items, query) {
    keys.sort((keyA, keyB) => {
      if (!items[keyA] || !items[keyB]) {
        // One of the items has yet to be removed from the
        // set at this point in iteration, so don't bother
        // trying to sort.
        // This is just an optimization, so implementers of an extending class's `sort`
        // method aren't required to implement this check.
        return 0;
      }

      return this.compare(query, items[keyA], items[keyB]);
    });
  }
  /**
   * Returns a single item by key.
   *
   * @param  {string} itemKey Item key
   * @returns {object}         Item
   */


  getItem(itemKey) {
    return this.data.items[itemKey];
  }
  /**
   * Returns items tracked by the instance. If a query is specified, returns
   * items specific to that query, or null if no items have been received for
   * the query.
   *
   * @param  {?object}       query Optional query object
   * @returns {object[]|null}       Items tracked, if known
   */


  getItems(query) {
    let itemKeys = null;

    if (query) {
      var _this$data$queries$qu;

      const queryKey = this.constructor.QueryKey.stringify(query);
      itemKeys = (_this$data$queries$qu = this.data.queries[queryKey]) === null || _this$data$queries$qu === void 0 ? void 0 : _this$data$queries$qu.itemKeys;

      if (!itemKeys) {
        return null;
      }
    }

    return getItemsForKeys(this.data.items, itemKeys);
  }
  /**
   * Returns the number of total known items for the specified query, as
   * included in the REST API posts response. Returns null if the query is
   * not known.
   *
   * @param  {object}  query Query object
   * @returns {?number}       Found items for query
   */


  getFound(query) {
    const queryKey = this.constructor.QueryKey.stringify(query);
    return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(this.data.queries, [queryKey, 'found'], null);
  }
  /**
   * Removes a single item given its item key, returning a new instance of
   * QueryManager if the tracked items have changed, or the current instance
   * otherwise.
   *
   * @param  {string}       itemKey Key of item to remove
   * @returns {QueryManager}         New instance if changed, or same instance
   *                                otherwise
   */


  removeItem(itemKey) {
    return this.removeItems([itemKey]);
  }
  /**
   * Removes multiple items given an array of item keys, returning a new
   * instance of QueryManager if the tracked items have changed, or the
   * current instance otherwise.
   *
   * @param  {string[]}     itemKeys Keys of items to remove
   * @returns {QueryManager}          New instance if changed, or same
   *                                 instance otherwise
   */


  removeItems() {
    let itemKeys = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    return this.receive(itemKeys.map(itemKey => {
      return {
        [this.options.itemKey]: itemKey,
        [DELETE_PATCH_KEY]: true
      };
    }), {
      patch: true
    });
  }
  /**
   * Signal that an item(s) has been received for tracking. Optionally
   * specify that items received are intended for patch application, or that
   * they are associated with a query. This function does not mutate the
   * instance state. Instead, it returns a new instance of QueryManager if
   * the tracked items have been modified, or the current instance otherwise.
   *
   * @param  {(Array|object)} items              Item(s) to be received
   * @param  {object}         options            Options for receive
   * @param  {boolean}        options.patch      Apply changes as partial
   * @param  {object}         options.query      Query set to set or replace
   * @param  {boolean}        options.mergeQuery Add to existing query set
   * @param  {boolean}        options.dontShareQueryResultsWhenQueriesAreDifferent When storing results for one query, results for that query should not be shared with different queries
   * @param  {number}         options.found      Total found items for query
   * @returns {QueryManager}                      New instance if changed, or
   *                                             same instance otherwise
   */


  receive() {
    let items = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    // Coerce received single item to array
    if (!Array.isArray(items)) {
      items = [items];
    }

    const nextItems = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(items, (memo, receivedItem) => {
      const receivedItemKey = receivedItem[this.options.itemKey];
      const item = this.getItem(receivedItemKey);
      const mergedItem = this.constructor.mergeItem(item, receivedItem, options.patch);

      if (undefined === mergedItem) {
        if (item) {
          // `undefined` item is an intended omission from set
          return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(memo, receivedItemKey);
        } // Item never existed in set in the first place, skip and
        // return same memo


        return memo;
      }

      if (!item || !(0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEqual)(mergedItem, item)) {
        // Did not exist previously or has changed
        if (memo === this.data.items) {
          // Create a copy of memo, as we don't want to mutate the original items set
          memo = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.clone)(memo);
        }

        memo[receivedItemKey] = mergedItem;
      }

      return memo;
    }, this.data.items);
    let isModified = nextItems !== this.data.items;
    let nextQueries = this.data.queries;
    let isNewlyReceivedQueryKey = false;
    let receivedQueryKey; // Skip if no items have been updated, added, or removed. If query
    // specified with received items, we may need to update queries

    if (!isModified && !options.query) {
      return this;
    }

    if (options.query) {
      const receivedItemKeys = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.map)(items, this.options.itemKey);
      receivedQueryKey = this.constructor.QueryKey.stringify(options.query);
      isNewlyReceivedQueryKey = !this.data.queries[receivedQueryKey];
      let nextQueryReceivedItemKeys;

      if (isNewlyReceivedQueryKey || !(0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEqual)(this.data.queries[receivedQueryKey].itemKeys, receivedItemKeys)) {
        if (options.mergeQuery && !isNewlyReceivedQueryKey) {
          // When merging into a query where items already exist,
          // omit incoming keys from existing set. These keys will
          // be restored below during match testing.
          nextQueryReceivedItemKeys = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.difference)(this.data.queries[receivedQueryKey].itemKeys, receivedItemKeys);
        } else {
          // If not merging, assign incoming keys as next items
          nextQueryReceivedItemKeys = receivedItemKeys;
        }
      }

      let nextQueryFound;

      if (options.found >= 0 && options.found !== (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(nextQueries, [receivedQueryKey, 'found'])) {
        nextQueryFound = options.found;
      }

      if (nextQueryReceivedItemKeys || nextQueryFound >= 0) {
        // Consider modified if either the current query set is not
        // tracked or if the keys differ from currently known set
        isModified = true;
        const nextReceivedQuery = Object.assign({}, nextQueries[receivedQueryKey]);

        if (nextQueryReceivedItemKeys) {
          nextReceivedQuery.itemKeys = nextQueryReceivedItemKeys;
        }

        if (nextQueryFound >= 0) {
          nextReceivedQuery.found = nextQueryFound;
        }

        nextQueries = Object.assign({}, nextQueries, {
          [receivedQueryKey]: nextReceivedQuery
        });
      }
    }

    nextQueries = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(nextQueries, (memo, queryDetails, queryKey) => {
      memo[queryKey] = queryDetails;
      const isReceivedQueryKey = receivedQueryKey && receivedQueryKey === queryKey;

      if (isReceivedQueryKey && (isNewlyReceivedQueryKey || !options.mergeQuery)) {
        // We can save the effort testing against received items in
        // the current query, since we know they'll match
        return memo;
      }

      if (!isReceivedQueryKey && options.dontShareQueryResultsWhenQueriesAreDifferent) {
        return memo;
      } // Found counts should not be adjusted for the received query if
      // merging into existing items


      const shouldAdjustFoundCount = !isReceivedQueryKey;
      const query = this.constructor.QueryKey.parse(queryKey);
      let needsSort = false;
      items.forEach(receivedItem => {
        // Find item in known data for query
        const receivedItemKey = receivedItem[this.options.itemKey];
        const updatedItem = nextItems[receivedItemKey];
        const index = memo[queryKey].itemKeys.indexOf(receivedItemKey);

        if (-1 !== index) {
          // Item already exists in query, check to see whether the
          // updated item is being removed or no longer matches
          if (!updatedItem || !this.constructor.matches(query, updatedItem)) {
            // Create a copy of the original details to avoid mutating
            if (memo[queryKey] === queryDetails) {
              memo[queryKey] = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.clone)(queryDetails);
            } // Omit item by slicing previous and next


            memo[queryKey].itemKeys = [...memo[queryKey].itemKeys.slice(0, index), ...memo[queryKey].itemKeys.slice(index + 1)]; // Decrement found count for query

            if (shouldAdjustFoundCount && Number.isFinite(memo[queryKey].found)) {
              memo[queryKey].found--;
            }
          }
        } else if (updatedItem && this.constructor.matches(query, updatedItem)) {
          // Item doesn't currently exist in query but is a match, so
          // insert item into set
          // Create a copy of the original details to avoid mutating
          if (memo[queryKey] === queryDetails) {
            memo[queryKey] = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.clone)(queryDetails);
          } // Increment found count for query


          if (shouldAdjustFoundCount && Number.isFinite(memo[queryKey].found)) {
            memo[queryKey].found++;
          } // A matching item should be inserted into the query set


          memo[queryKey].itemKeys = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(memo, [queryKey, 'itemKeys'], []).concat(receivedItemKey); // The itemKeys will need to be re-sorted after all items are processed

          needsSort = true;
        }
      });

      if (needsSort) {
        this.constructor.sort(memo[queryKey].itemKeys, nextItems, query);
      }

      isModified = isModified || memo[queryKey] !== queryDetails;
      return memo;
    }, {});

    if (!isModified) {
      return this;
    }

    return new this.constructor(Object.assign({}, this.data, {
      items: nextItems,
      queries: nextQueries
    }), this.options);
  }

}

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(QueryManager, "QueryKey", _key__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z);

/***/ }),

/***/ 37754:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ QueryKey; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(56666);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);


/**
 * QueryKey manages the serialization and deserialization of a query key for
 * use in tracking query results in an instance of QueryManager.
 */

class QueryKey {
  /**
   * If defined in extending class, will omit all parameters where values
   * match that of the default query
   *
   * @type {?object}
   */

  /**
   * If defined in extending class as true, will omit all null values from
   * stringified or parsed query objects
   *
   * @type {boolean}
   */

  /**
   * Given a query object, determines which values of query are included in
   * stringification or parsed return value. The base class will omit only
   * undefined values, but can be extended to omit null values or values
   * matching those in a default query.
   *
   * @param  {object} query Query object
   * @returns {object}       Pruned query object
   */
  static omit(query) {
    const {
      OMIT_NULL_VALUES,
      DEFAULT_QUERY
    } = this;

    if (!OMIT_NULL_VALUES && !DEFAULT_QUERY) {
      return query;
    }

    return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omitBy)(query, (value, key) => {
      if (OMIT_NULL_VALUES && null === value) {
        return true;
      }

      if (DEFAULT_QUERY && DEFAULT_QUERY[key] === value) {
        return true;
      }

      return false;
    });
  }
  /**
   * Returns a serialized query, given a query object
   *
   * @param  {object} query Query object
   * @returns {string}       Serialized query
   */


  static stringify(query) {
    const prunedQuery = this.omit(query); // A stable query is one which produces the same result regardless of
    // key ordering in the original object, to ensure that:
    //
    // QueryKey.stringify( { a: 1, b: 2 } ) === QueryKey.stringify( { b: 2, a: 1 } )

    const stableQuery = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.sortBy)(Object.entries(prunedQuery), pair => pair[0]);
    return JSON.stringify(stableQuery);
  }
  /**
   * Returns a query object, given a serialized query
   *
   * @param  {string} key Serialized query
   * @returns {object}     Query object
   */


  static parse(key) {
    return this.omit(Object.fromEntries(JSON.parse(key)));
  }

}

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(QueryKey, "DEFAULT_QUERY", null);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(QueryKey, "OMIT_NULL_VALUES", false);

/***/ }),

/***/ 88425:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "t": function() { return /* binding */ DEFAULT_PAGINATED_QUERY; },
/* harmony export */   "H": function() { return /* binding */ PAGINATION_QUERY_KEYS; }
/* harmony export */ });
const DEFAULT_PAGINATED_QUERY = {
  number: 20,
  page: 1
};
const PAGINATION_QUERY_KEYS = ['number', 'offset', 'page'];

/***/ }),

/***/ 44550:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ PaginatedQueryManager; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(56666);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(2623);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(88425);
/* harmony import */ var _key__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(27866);





const pageCache = new WeakMap();
/*
 * Compute paginated slices of the `items` array, with memoization
 */

function getPaginatedItems(items, start, count) {
  // retrieve cache for the `items` array, create a new record if doesn't exist
  let itemsCache = pageCache.get(items);

  if (!itemsCache) {
    itemsCache = new Map();
    pageCache.set(items, itemsCache);
  } // cache the computed page slices


  const pageKey = `${start}/${count}`;
  let pageResult = itemsCache.get(pageKey);

  if (!pageResult) {
    pageResult = items.slice(start, start + count);
    itemsCache.set(pageKey, pageResult);
  }

  return pageResult;
}
/**
 * PaginatedQueryManager manages paginated data which can be queried and
 * change over time
 */


class PaginatedQueryManager extends ___WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z {
  /**
   * Returns true if the specified query is an object containing one or more
   * query pagination keys.
   *
   * @param  {object}  query Query object to check
   * @returns {boolean}       Whether query contains pagination key
   */
  static hasQueryPaginationKeys(query) {
    return !!query && _constants__WEBPACK_IMPORTED_MODULE_2__/* .PAGINATION_QUERY_KEYS.some */ .H.some(key => query.hasOwnProperty(key));
  }
  /**
   * Returns items tracked by the instance. If a query is specified, returns
   * items specific to that query.
   *
   * @param  {?object}  query Optional query object
   * @returns {object[]}       Items tracked
   */


  getItems(query) {
    if (!query) {
      return super.getItems(query);
    } // Get all items, ignoring page. Test as truthy to ensure that query is
    // in-fact being tracked, otherwise bail early.


    const dataIgnoringPage = this.getItemsIgnoringPage(query, true);

    if (!dataIgnoringPage) {
      return dataIgnoringPage;
    } // Slice the unpaginated set of data


    const page = query.page || this.constructor.DefaultQuery.page;
    const perPage = query.number || this.constructor.DefaultQuery.number;
    const startOffset = (page - 1) * perPage;
    return getPaginatedItems(dataIgnoringPage, startOffset, perPage);
  }
  /**
   * Returns items tracked by the instance, ignoring pagination for the given
   * query.
   *
   * @param  {object}   query         Query object
   * @param  {boolean}  includeFiller Whether page structure should be left
   *                                  intact to reflect found count, with
   *                                  items yet to be received as `undefined`
   * @returns {object[]}               Items tracked, ignoring page
   */


  getItemsIgnoringPage(query) {
    let includeFiller = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

    if (!query) {
      return null;
    }

    const items = super.getItems((0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(query, _constants__WEBPACK_IMPORTED_MODULE_2__/* .PAGINATION_QUERY_KEYS */ .H));

    if (!items || includeFiller) {
      return items;
    }

    return items.filter(item => undefined !== item);
  }
  /**
   * Returns the number of pages for the specified query, or null if the
   * query is not known.
   *
   * @param  {object}  query Query object
   * @returns {?number}       Pages for query
   */


  getNumberOfPages(query) {
    const found = this.getFound(query);

    if (null === found) {
      return found;
    }

    const perPage = query.number || this.constructor.DefaultQuery.number;
    return Math.ceil(found / perPage);
  }
  /**
   * Signal that an item(s) has been received for tracking. Optionally
   * specify that items received are intended for patch application, or that
   * they are associated with a query. This function does not mutate the
   * instance state. Instead, it returns a new instance of QueryManager if
   * the tracked items have been modified, or the current instance otherwise.
   *
   * @param  {(Array|object)} items              Item(s) to be received
   * @param  {object}         options            Options for receive
   * @param  {boolean}        options.patch      Apply changes as partial
   * @param  {object}         options.query      Query set to set or replace
   * @param  {boolean}        options.mergeQuery Add to existing query set
   * @param  {number}         options.found      Total found items for query
   * @returns {QueryManager}                      New instance if changed, or
   *                                             same instance otherwise
   */


  receive(items) {
    let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    // When tracking queries, remove pagination query arguments. These are
    // simulated in `PaginatedQueryManager.prototype.getItems`.
    let modifiedOptions = options;

    if (options.query) {
      modifiedOptions = Object.assign({
        mergeQuery: true
      }, options, {
        query: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(options.query, _constants__WEBPACK_IMPORTED_MODULE_2__/* .PAGINATION_QUERY_KEYS */ .H)
      });
    } // Receive the updated manager, passing a modified set of options to
    // exclude pagination keys, and to indicate appending query.


    const nextManager = super.receive(items, modifiedOptions); // If manager is the same instance, assume no changes have been made

    if (this === nextManager) {
      return nextManager;
    } // If original query does not have any pagination keys, we don't need
    // to update its item set


    if (!this.constructor.hasQueryPaginationKeys(options.query)) {
      return nextManager;
    }

    const queryKey = this.constructor.QueryKey.stringify(options.query);
    const page = options.query.page || this.constructor.DefaultQuery.page;
    const perPage = options.query.number || this.constructor.DefaultQuery.number;
    const startOffset = (page - 1) * perPage;
    const nextQuery = nextManager.data.queries[queryKey]; // Coerce received single item to array

    if (!Array.isArray(items)) {
      items = [items];
    } // If the item set for the queried page is identical, there are no
    // updates to be made


    const pageItemKeys = items.map(item => item[this.options.itemKey]); // If we've reached this point, we know that we've received a paged
    // set of data where our assumed item set is incorrect.

    const modifiedNextQuery = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.cloneDeep)(nextQuery); // Found count is not always reliable.  For example, if one or more
    // password-protected posts would appear in a page of API results, but
    // the current user doesn't have access to view them, then they will be
    // omitted from the results entirely.  There are also other situations
    // where this can occur, such as `status: 'inherit'`.
    //
    // Even worse, the WP.com API will decrement the found count in this
    // situation, but only for items missing from the currently requested
    // page.
    //
    // What should we do about all of this?  We decided that given the
    // limitations of this code, it's OK for a page of results to have less
    // than the expected number of items, and we should not try to
    // decrement the "found" count either because then we could end up
    // skipping pages from the end of a result set.
    //
    // Therefore, the only thing we need to do here is take the *maximum*
    // of the previous "found" count and the next "found" count.

    if (modifiedNextQuery.hasOwnProperty('found') && items.length < perPage) {
      const previousQuery = this.data.queries[queryKey];

      if (previousQuery && previousQuery.hasOwnProperty('found')) {
        modifiedNextQuery.found = Math.max(previousQuery.found, modifiedNextQuery.found);
      }
    } // Replace the assumed set with the received items.


    modifiedNextQuery.itemKeys = [...(0,lodash__WEBPACK_IMPORTED_MODULE_0__.range)(0, startOffset).map(index => {
      // Ensure that item set is comprised of all indices leading up
      // to received page, even if those items are not known.
      const itemKey = nextQuery.itemKeys[index];

      if (!pageItemKeys.includes(itemKey)) {
        return itemKey;
      }
    }), ...(0,lodash__WEBPACK_IMPORTED_MODULE_0__.range)(0, perPage).map(index => {
      // Fill page with items from the received set, or undefined to
      // at least ensure page matches expected range
      return pageItemKeys[index];
    }), ...nextQuery.itemKeys.slice(startOffset + perPage).filter(itemKey => {
      // Filter out any item keys which exist in the page set, as
      // this indicates that they've trickled down from later page
      return itemKey && !pageItemKeys.includes(itemKey);
    })]; // If found is known from options, ensure that we fill the end of the
    // array with undefined entries until found count

    if (modifiedNextQuery.hasOwnProperty('found')) {
      modifiedNextQuery.itemKeys = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.range)(0, modifiedNextQuery.found).map(index => {
        return modifiedNextQuery.itemKeys[index];
      });
    }

    return new this.constructor(Object.assign({}, nextManager.data, {
      queries: Object.assign({}, nextManager.data.queries, {
        [queryKey]: modifiedNextQuery
      })
    }), nextManager.options);
  }

}

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(PaginatedQueryManager, "QueryKey", _key__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(PaginatedQueryManager, "DefaultQuery", _constants__WEBPACK_IMPORTED_MODULE_2__/* .DEFAULT_PAGINATED_QUERY */ .t);

/***/ }),

/***/ 27866:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ PaginatedQueryKey; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _key__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(37754);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(88425);



/**
 * PaginatedQueryKey manages the serialization and deserialization of a query
 * key for use in tracking query results in an instance of PostQueryManager.
 */

class PaginatedQueryKey extends _key__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z {
  /**
   * Returns a serialized query, given a query object
   *
   * @param  {object} query Query object
   * @returns {string}       Serialized query
   */
  static stringify(query) {
    return super.stringify((0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(query, _constants__WEBPACK_IMPORTED_MODULE_2__/* .PAGINATION_QUERY_KEYS */ .H));
  }
  /**
   * Returns a query object, given a serialized query
   *
   * @param  {string} key Serialized query
   * @returns {object}     Query object
   */


  static parse(key) {
    return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(super.parse(key), _constants__WEBPACK_IMPORTED_MODULE_2__/* .PAGINATION_QUERY_KEYS */ .H);
  }

}

/***/ }),

/***/ 725:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "e": function() { return /* binding */ DEFAULT_POST_QUERY; }
/* harmony export */ });
const DEFAULT_POST_QUERY = {
  context: 'display',
  http_envelope: false,
  pretty: false,
  number: 20,
  offset: 0,
  page: 1,
  order: 'DESC',
  order_by: 'date',
  type: 'post',
  status: 'publish',
  sticky: 'include',
  search: ''
};

/***/ }),

/***/ 3982:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ PostQueryManager; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(56666);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var moment__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(76292);
/* harmony import */ var moment__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(moment__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _paginated__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(44550);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(725);
/* harmony import */ var _key__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(93039);






/**
 * PostQueryManager manages posts which can be queried and change over time
 */

class PostQueryManager extends _paginated__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z {
  /**
   * Returns true if the post matches the given query, or false otherwise.
   *
   * @param  {object}  query Query object
   * @param  {object}  post  Item to consider
   * @returns {boolean}       Whether post matches query
   */
  static matches(query, post) {
    const queryWithDefaults = Object.assign({}, this.DefaultQuery, query);
    return Object.entries(queryWithDefaults).every(_ref => {
      let [key, value] = _ref;

      switch (key) {
        case 'search':
          {
            if (!value) {
              return true;
            }

            const search = value.toLowerCase();
            return post.title && post.title.toLowerCase().includes(search) || post.content && post.content.toLowerCase().includes(search);
          }

        case 'after':
        case 'before':
        case 'modified_after':
        case 'modified_before':
          {
            const queryDate = moment__WEBPACK_IMPORTED_MODULE_1___default()(value, (moment__WEBPACK_IMPORTED_MODULE_1___default().ISO_8601));
            const comparison = /after$/.test(key) ? 'isAfter' : 'isBefore';
            const field = /^modified_/.test(key) ? 'modified' : 'date';
            return queryDate.isValid() && moment__WEBPACK_IMPORTED_MODULE_1___default()(post[field])[comparison](queryDate);
          }

        case 'term':
          return Object.entries(value).every(_ref2 => {
            let [taxonomy, slugs] = _ref2;
            slugs = slugs.split(',');
            return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.some)(post.terms[taxonomy], _ref3 => {
              let {
                slug
              } = _ref3;
              return slugs.includes(slug);
            });
          });

        case 'tag':
        case 'category':
          {
            if (!value) {
              return true;
            }

            const valueLowercase = value.toLowerCase();
            const field = 'tag' === key ? 'tags' : 'categories';
            return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.some)(post[field], _ref4 => {
              let {
                name,
                slug
              } = _ref4;
              return name && name.toLowerCase() === valueLowercase || slug && slug.toLowerCase() === valueLowercase;
            });
          }

        case 'type':
          return 'any' === value || value === post.type;

        case 'parent_id':
          return value === post.parent || post.parent && value === post.parent.ID;

        case 'exclude':
          if (Array.isArray(value)) {
            return !value.includes(post.ID);
          }

          return value !== post.ID;

        case 'sticky':
          if ('require' === value) {
            return post.sticky;
          } else if ('exclude' === value) {
            return !post.sticky;
          }

          return true;

        case 'author':
          return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(post, 'author.ID', post.author) === value;

        case 'status':
          return 'any' === value || String(value).split(',').some(status => {
            return status === post[key];
          });
      }

      return true;
    });
  }
  /**
   * A sort comparison function that defines the sort order of posts under
   * consideration of the specified query.
   *
   * @param  {object} query Query object
   * @param  {object} postA First post
   * @param  {object} postB Second post
   * @returns {number}       0 if equal, less than 0 if postA is first,
   *                        greater than 0 if postB is first.
   */


  static compare(query, postA, postB) {
    let order;

    switch (query.order_by) {
      case 'ID':
        order = postA.ID - postB.ID;
        break;

      case 'comment_count':
        order = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(postA.discussion, 'comment_count', 0) - (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(postB.discussion, 'comment_count', 0);
        break;

      case 'title':
        order = postA.title.localeCompare(postB.title);
        break;

      case 'modified':
        order = new Date(postA.modified) - new Date(postB.modified);
        break;

      case 'date':
      default:
        order = new Date(postA.date) - new Date(postB.date);
    } // Default to descending order, opposite sign of ordered result


    if (!query.order || /^desc$/i.test(query.order)) {
      order *= -1;
    }

    return order || 0;
  }

}

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(PostQueryManager, "QueryKey", _key__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z);

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(PostQueryManager, "DefaultQuery", _constants__WEBPACK_IMPORTED_MODULE_3__/* .DEFAULT_POST_QUERY */ .e);

/***/ }),

/***/ 93039:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ PostQueryKey; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _paginated_key__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(27866);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(725);



/**
 * Returns true if the specified key value query pair is identical to that of
 * the default post query, is null, or is undefined.
 *
 * @param  {*}       value Value to check
 * @param  {string}  key   Key to check
 * @returns {boolean}       Whether key value matches default query or is null
 */

function isDefaultOrNullQueryValue(value, key) {
  return null == value || _constants__WEBPACK_IMPORTED_MODULE_2__/* .DEFAULT_POST_QUERY */ .e[key] === value // Double-equals null checks undefined, null
  ;
}
/**
 * PostQueryKey manages the serialization and deserialization of a query key
 * for use in tracking query results in an instance of PostQueryManager.
 */


class PostQueryKey extends _paginated_key__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z {
  /**
   * Returns a serialized query, given a query object
   *
   * @param  {object} query Query object
   * @returns {string}       Serialized query
   */
  static stringify(query) {
    return super.stringify((0,lodash__WEBPACK_IMPORTED_MODULE_0__.omitBy)(query, isDefaultOrNullQueryValue));
  }
  /**
   * Returns a query object, given a serialized query
   *
   * @param  {string} key Serialized query
   * @returns {object}     Query object
   */


  static parse(key) {
    return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omitBy)(super.parse(key), isDefaultOrNullQueryValue);
  }

}

/***/ }),

/***/ 41900:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export withItemsSchema */
/* harmony import */ var deep_freeze__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(24869);
/* harmony import */ var deep_freeze__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(deep_freeze__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_1__);


const queryManagerSchema = deep_freeze__WEBPACK_IMPORTED_MODULE_0___default()({
  additionalProperties: false,
  required: ['data', 'options'],
  type: 'object',
  properties: {
    data: {
      additionalProperties: false,
      type: 'object',
      properties: {
        items: {
          type: 'object'
        },
        queries: {
          additionalProperties: false,
          type: 'object',
          patternProperties: {
            // Stringified query objects are the keys
            '^\\[.*\\]$': {
              required: ['itemKeys'],
              type: 'object',
              properties: {
                itemKeys: {
                  type: 'array',
                  items: {
                    // Typical valid object keys
                    // `null` is important for PagingQueryManager
                    // It fills array with undefined (matches null)
                    type: ['integer', 'null', 'string']
                  }
                },
                found: {
                  type: 'integer'
                }
              }
            }
          }
        }
      }
    },
    options: {
      additionalProperties: true,
      required: ['itemKey'],
      type: 'object',
      properties: {
        itemKey: {
          type: 'string'
        }
      }
    }
  }
});
/**
 * Get a queryManagerSchema with a customized items schema
 *
 * @param  {object} itemsSchema Schema that will be used for the items
 * @returns {object}            Customized schema
 */

function withItemsSchema(itemsSchema) {
  return cloneDeepWith(queryManagerSchema, value => {
    if (value === queryManagerSchema.properties.data.properties.items) {
      return itemsSchema;
    }
  });
}
/* harmony default export */ __webpack_exports__["Z"] = (queryManagerSchema);

/***/ }),

/***/ 96252:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ withQueryManager; }
/* harmony export */ });
/**
 * Apply a `callback` transformation to a `QueryManager` instance in `state[ siteId ]` and
 * return a state object updated with its result.
 * If the `state[ siteId ]` object doesn't exist, it's created with the `create` function.
 * If `create` is `false`, the `callback` will not be applied (there is no `QueryManager` to
 * apply it to after all) and unchanged state will be returned.
 *
 * @param {object} state State object
 * @param {string} siteId State key
 * @param {Function} callback Transformation callback
 * @param {Function} [create] Optional create callback
 * @returns {object} Updated state object
 */
function withQueryManager(state, siteId, callback, create) {
  if (!siteId) {
    return state;
  }

  const prevManager = state[siteId] || create && create();

  if (!prevManager) {
    return state;
  }

  const nextManager = callback(prevManager);

  if (nextManager === prevManager) {
    return state;
  }

  return { ...state,
    [siteId]: nextManager
  };
}

/***/ }),

/***/ 55347:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/* harmony default export */ __webpack_exports__["Z"] = (path => path === '/' ? path : path.replace(/\/$/, ''));

/***/ }),

/***/ 72537:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Cm": function() { return /* binding */ getJetpackSiteCollisions; }
/* harmony export */ });
/* unused harmony exports userCan, timezone, gmtOffset, getSiteFileModDisableReason, isMainNetworkSite, hasCustomDomain, isModuleActive, getUnmappedUrl */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_lib_url__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(47307);



function userCan(capability, site) {
  return site && site.capabilities && site.capabilities[capability];
}
/**
 * site's timezone getter
 *
 * @param   {object} site - site object
 * @returns {string} timezone
 */

function timezone(site) {
  return site && site.options ? site.options.timezone : null;
}
/**
 * site's gmt_offset getter
 *
 * @param   {object} site - site object
 * @returns {string} gmt_offset
 */

function gmtOffset(site) {
  return site && site.options ? site.options.gmt_offset : null;
}
function getSiteFileModDisableReason(site) {
  let action = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'modifyFiles';

  if (!site || !site.options || !site.options.file_mod_disabled) {
    return;
  }

  return site.options.file_mod_disabled.map(clue => {
    if (action === 'modifyFiles' || action === 'autoupdateFiles' || action === 'autoupdateCore') {
      if (clue === 'has_no_file_system_write_access') {
        return i18n.translate('The file permissions on this host prevent editing files.');
      }

      if (clue === 'disallow_file_mods') {
        return i18n.translate('File modifications are explicitly disabled by a site administrator.');
      }
    }

    if ((action === 'autoupdateFiles' || action === 'autoupdateCore') && clue === 'automatic_updater_disabled') {
      return i18n.translate('Any autoupdates are explicitly disabled by a site administrator.');
    }

    if (action === 'autoupdateCore' && clue === 'wp_auto_update_core_disabled') {
      return i18n.translate('Core autoupdates are explicitly disabled by a site administrator.');
    }

    return null;
  }).filter(reason => reason);
}
function isMainNetworkSite(site) {
  if (!site) {
    return false;
  }

  if (site.options && site.options.is_multi_network) {
    return false;
  }

  if (site.is_multisite === false) {
    return true;
  }

  if (site.is_multisite) {
    const unmappedUrl = get(site.options, 'unmapped_url', null);
    const mainNetworkSite = get(site.options, 'main_network_site', null);

    if (!unmappedUrl || !mainNetworkSite) {
      return false;
    } // Compare unmapped_url with the main_network_site to see if is the main network site.


    return !(withoutHttp(unmappedUrl) !== withoutHttp(mainNetworkSite));
  }

  return false;
}
/**
 * Checks whether a site has a custom mapped URL.
 *
 * @param   {object}   site Site object
 * @returns {?boolean}      Whether site has custom domain
 */

function hasCustomDomain(site) {
  if (!site || !site.domain || !site.wpcom_url) {
    return null;
  }

  return site.domain !== site.wpcom_url;
}
function isModuleActive(site, moduleId) {
  return site.options.active_modules && site.options.active_modules.indexOf(moduleId) > -1;
}
/**
 * Returns the WordPress.com URL of a site (simple or Atomic)
 *
 * @param {object} site Site object
 * @returns {?string} WordPress.com URL
 */

function getUnmappedUrl(site) {
  if (!site || !site.options) {
    return null;
  }

  return site.options.main_network_site || site.options.unmapped_url;
}
/**
 * Returns a filtered array of WordPress.com site IDs where a Jetpack site
 * exists in the set of sites with the same URL.
 *
 * @param {Array} siteList Array of site objects
 * @returns {number[]} Array of site IDs with URL collisions
 */

function getJetpackSiteCollisions(siteList) {
  return siteList.filter(siteItem => {
    const siteUrlSansProtocol = (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_1__/* .withoutHttp */ .ce)(siteItem.URL);
    return !siteItem.jetpack && siteList.some(jetpackSite => jetpackSite.jetpack && siteUrlSansProtocol === (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_1__/* .withoutHttp */ .ce)(jetpackSite.URL));
  }).map(siteItem => siteItem.ID);
}

/***/ }),

/***/ 40822:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ addQueryArgs; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(4174);
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(78038);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);


const BASE_URL = 'http://__domain__.invalid';
function addQueryArgs(args, url) {
  if ('object' !== typeof args) {
    throw new Error('addQueryArgs expects the first argument to be an object.');
  }

  if ('string' !== typeof url) {
    throw new Error('addQueryArgs expects the second argument to be a string.');
  }

  const urlType = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .determineUrlType */ .D)(url);

  if (urlType === _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .URL_TYPE.INVALID */ .a.INVALID) {
    throw new Error('addQueryArgs expects the second argument to be a valid URL.');
  } // Remove any undefined query args


  args = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.pickBy)(args, arg => arg != null);
  const parsed = new URL(url, BASE_URL);
  const newSearch = new URLSearchParams(parsed.search);

  for (const key of Object.keys(args)) {
    newSearch.set(key, String(args[key]));
  } // Path-relative URLs require special handling, because they cannot be transformed
  // into an absolute URL without potentially losing path information.
  // E.g. `../foo?bar=baz` becomes `<base>/foo?bar=baz` when fed to `new URL()`
  // with a base, losing the traversal into the parent directory.
  // We need to handle these with a string replace instead.


  if (urlType === _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_1__/* .URL_TYPE.PATH_RELATIVE */ .a.PATH_RELATIVE) {
    let serializedSearch = newSearch.toString();

    if (serializedSearch !== '') {
      serializedSearch = `?${serializedSearch}`;
    } // The URL had some params already.


    if (parsed.search !== '') {
      return url.replace(parsed.search, serializedSearch);
    } // The URL didn't have params, but it had a hash.


    if (parsed.hash) {
      return url.replace(parsed.hash, `${serializedSearch}${parsed.hash}`);
    } // The URL didn't have params nor a hash.


    return `${url}${serializedSearch}`;
  }

  parsed.search = newSearch.toString(); // Format the new URL into the same type the original had.

  return (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(parsed, urlType);
}

/***/ }),

/***/ 47307:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ce": function() { return /* binding */ withoutHttp; },
/* harmony export */   "nq": function() { return /* binding */ urlToSlug; }
/* harmony export */ });
/* unused harmony export urlToDomainAndPath */
const urlWithoutHttpRegex = /^https?:\/\//;
/**
 * Returns the supplied URL without the initial http(s).
 *
 * @param  url The URL to remove http(s) from
 * @returns     URL without the initial http(s)
 */

function withoutHttp(url) {
  if (url === '') {
    return '';
  }

  if (!url) {
    return null;
  }

  return url.replace(urlWithoutHttpRegex, '');
}
function urlToSlug(url) {
  if (!url) {
    return null;
  }

  return withoutHttp(url).replace(/\//g, '::');
}
/**
 * Removes the `http(s)://` part and the trailing slash from a URL.
 * "http://blog.wordpress.com" will be converted into "blog.wordpress.com".
 * "https://www.wordpress.com/blog/" will be converted into "www.wordpress.com/blog".
 *
 * @param  urlToConvert The URL to convert
 * @returns              The URL's domain and path
 */

function urlToDomainAndPath(urlToConvert) {
  return withoutHttp(urlToConvert).replace(/\/$/, '');
}

/***/ }),

/***/ 70353:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ resolveRelativePath; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4174);

const DUMMY_URL = 'http://__domain__.invalid/';
function resolveRelativePath(basePath, relativePath) {
  basePath = basePath || '/';
  const baseType = (0,_automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__/* .determineUrlType */ .D)(basePath);

  if (baseType !== _automattic_calypso_url__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.PATH_ABSOLUTE */ .a.PATH_ABSOLUTE) {
    throw new Error('`basePath` should be an absolute path');
  }

  const url = new URL(DUMMY_URL);
  url.pathname = basePath;

  if (!relativePath) {
    return url.pathname;
  }

  url.pathname = (url.pathname.endsWith('/') ? url.pathname.slice(0, -1) : url.pathname) + (relativePath.startsWith('/') ? '' : '/') + relativePath;
  return url.pathname;
}

/***/ }),

/***/ 29726:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "v": function() { return /* binding */ filterUserObject; }
/* harmony export */ });
/* harmony import */ var calypso_lib_formatting_decode_entities__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(50118);
/* harmony import */ var _get_computed_attributes__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(41333);


const allowedKeys = ['ID', 'display_name', 'username', 'avatar_URL', 'site_count', 'jetpack_site_count', 'visible_site_count', 'jetpack_visible_site_count', 'date', 'has_unseen_notes', 'newest_note_type', 'phone_account', 'email', 'email_verified', 'is_valid_google_apps_country', 'user_ip_country_code', 'logout_URL', 'primary_blog', 'primary_blog_is_jetpack', 'has_jetpack_partner_access', 'jetpack_partner_types', 'primary_blog_url', 'meta', 'is_new_reader', 'social_login_connections', 'abtests', 'lasagna_jwt', 'i18n_empathy_mode', 'use_fallback_for_incomplete_languages'];
const requiredKeys = ['ID'];
const decodedKeys = ['display_name', 'description', 'user_URL'];
function filterUserObject(obj) {
  if (typeof obj !== 'object') {
    throw new Error('the /me response is not an object');
  }

  for (const key of requiredKeys) {
    if (!obj.hasOwnProperty(key)) {
      throw new Error(`the /me response misses a required field '${key}'`);
    }
  }

  const user = {};

  for (const key of allowedKeys) {
    const value = obj[key];
    user[key] = value && decodedKeys.includes(key) ? (0,calypso_lib_formatting_decode_entities__WEBPACK_IMPORTED_MODULE_0__/* .decodeEntities */ .S)(value) : value;
  }

  return Object.assign(user, (0,_get_computed_attributes__WEBPACK_IMPORTED_MODULE_1__/* .getComputedAttributes */ .B)(obj));
}

/***/ }),

/***/ 41333:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "B": function() { return /* binding */ getComputedAttributes; }
/* harmony export */ });
/* harmony import */ var calypso_lib_url__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(47307);


function getSiteSlug(url) {
  const slug = (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_0__/* .withoutHttp */ .ce)(url);
  return slug.replace(/\//g, '::');
}

function getComputedAttributes(attributes) {
  const primaryBlogUrl = attributes.primary_blog_url || '';
  return {
    primarySiteSlug: getSiteSlug(primaryBlogUrl),
    localeSlug: attributes.language,
    localeVariant: attributes.locale_variant
  };
}

/***/ }),

/***/ 26935:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "K": function() { return /* binding */ getLogoutUrl; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);

function getLogoutUrl(userData, redirect) {
  let url;
  let subdomain = ''; // If logout_URL isn't set, then go ahead and return the logout URL
  // without a proper nonce as a fallback.
  // Note: we never want to use logout_URL in the desktop app

  if (!(userData !== null && userData !== void 0 && userData.logout_URL) || _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"].isEnabled */ .ZP.isEnabled('always_use_logout_url')) {
    // Use localized version of the homepage in the redirect
    if (userData !== null && userData !== void 0 && userData.localeSlug && userData.localeSlug !== '' && userData.localeSlug !== 'en') {
      subdomain = userData.localeSlug + '.';
    }

    url = (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('logout_url').replace('|subdomain|', subdomain);
  } else {
    url = userData.logout_URL;
  }

  if ('string' === typeof redirect) {
    redirect = '&redirect_to=' + encodeURIComponent(redirect);
    url += redirect;
  }

  return url;
}

/***/ }),

/***/ 59852:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "G": function() { return /* binding */ rawCurrentUserFetch; }
/* harmony export */ });
/* harmony import */ var calypso_lib_wp__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(72429);

function rawCurrentUserFetch() {
  return calypso_lib_wp__WEBPACK_IMPORTED_MODULE_0__/* ["default"].me */ .Z.me().get({
    meta: 'flags'
  });
}

/***/ }),

/***/ 65792:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "YF": function() { return /* binding */ clearStore; }
/* harmony export */ });
/* unused harmony exports getStoredUserId, setStoredUserId, disablePersistence, onDisablePersistence */
/* harmony import */ var store__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(23729);
/* harmony import */ var store__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(store__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_lib_browser_storage__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(66651);


/**
 * Empty localStorage cache to discard any user reference that the application may hold
 */

async function clearStore() {
  store__WEBPACK_IMPORTED_MODULE_0___default().clearAll();
  await (0,calypso_lib_browser_storage__WEBPACK_IMPORTED_MODULE_1__/* .clearStorage */ .B$)();
}
function getStoredUserId() {
  return store.get('wpcom_user_id');
}
function setStoredUserId(userId) {
  return store.set('wpcom_user_id', userId);
}
const disablePersistenceCallbacks = (/* unused pure expression or super */ null && ([]));
function disablePersistence() {
  for (const callback of disablePersistenceCallbacks) {
    callback();
  }
}
function onDisablePersistence(callback) {
  disablePersistenceCallbacks.push(callback);
}

/***/ }),

/***/ 72429:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export wpcomJetpackLicensing */
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(18552);
/* harmony import */ var calypso_lib_oauth_token__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(7268);
/* harmony import */ var calypso_lib_wp_support__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(33300);
/* harmony import */ var calypso_lib_wpcom_oauth_wrapper__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(12902);
/* harmony import */ var calypso_lib_wpcom_xhr_wrapper__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(54083);
/* harmony import */ var _handlers_guest_sandbox_ticket__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(78009);
/* harmony import */ var _localization__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(21286);









const debug = debug__WEBPACK_IMPORTED_MODULE_1___default()('calypso:wp');
let wpcom;

if (_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"].isEnabled */ .ZP.isEnabled('oauth')) {
  wpcom = (0,calypso_lib_wpcom_oauth_wrapper__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(calypso_lib_oauth_token__WEBPACK_IMPORTED_MODULE_2__/* .getToken */ .LP(), calypso_lib_wpcom_xhr_wrapper__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z);
} else {
  wpcom = (0,calypso_lib_wpcom_oauth_wrapper__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .ZP); // Upgrade to "access all users blogs" mode

  wpcom.request({
    metaAPI: {
      accessAllUsersBlogs: true
    }
  }, function (error) {
    if (error) {
      throw error;
    }

    debug('Proxy now running in "access all user\'s blogs" mode');
  });
}

wpcom = (0,calypso_lib_wp_support__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(wpcom);

if (false) {} // Inject localization helpers to `wpcom` instance


(0,_localization__WEBPACK_IMPORTED_MODULE_7__/* .injectLocalization */ .J)(wpcom);
(0,_handlers_guest_sandbox_ticket__WEBPACK_IMPORTED_MODULE_6__/* .injectGuestSandboxTicketHandler */ .rc)(wpcom);
/**
 * Expose `wpcom`
 */

/* harmony default export */ __webpack_exports__["Z"] = (wpcom);
/**
 * Expose `wpcomJetpackLicensing` which uses a different auth token than wpcom.
 */

const wpcomJetpackLicensing = (0,calypso_lib_wpcom_oauth_wrapper__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(calypso_lib_wpcom_xhr_wrapper__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z);

/***/ }),

/***/ 78009:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "rc": function() { return /* binding */ injectGuestSandboxTicketHandler; }
/* harmony export */ });
/* unused harmony exports GUEST_TICKET_LOCALFORAGE_KEY, GUEST_TICKET_VALIDITY_DURATION, deleteOldTicket */
/* harmony import */ var qs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(19126);
/* harmony import */ var qs__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(qs__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var store__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(23729);
/* harmony import */ var store__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(store__WEBPACK_IMPORTED_MODULE_1__);


const GUEST_TICKET_LOCALFORAGE_KEY = 'guest_sandbox_ticket';
const GUEST_TICKET_VALIDITY_DURATION = 1000 * 60 * 60 * 2; // two hours

const getTicket = () => store__WEBPACK_IMPORTED_MODULE_1___default().get(GUEST_TICKET_LOCALFORAGE_KEY);
/**
 * Deletes an old guest sandbox ticket from local storage if one exists.
 */


const deleteOldTicket = () => {
  const existingTicket = getTicket();

  if (existingTicket && existingTicket.createdDate < Date.now() - GUEST_TICKET_VALIDITY_DURATION) {
    store__WEBPACK_IMPORTED_MODULE_1___default().remove(GUEST_TICKET_LOCALFORAGE_KEY);
  }
};
/**
 * Updates `wpcom` to pass a store sandbox ticket if one is present.
 *
 * @param {object} wpcom Original WPCOM instance
 */

const injectGuestSandboxTicketHandler = wpcom => {
  const request = wpcom.request.bind(wpcom);
  Object.assign(wpcom, {
    request(params, callback) {
      const ticket = getTicket();

      if (ticket) {
        const query = (0,qs__WEBPACK_IMPORTED_MODULE_0__.parse)(params.query);
        params = Object.assign({}, params, {
          query: (0,qs__WEBPACK_IMPORTED_MODULE_0__.stringify)(Object.assign(query, {
            store_sandbox_ticket: ticket.value
          }))
        });
      }

      return request(params, callback);
    }

  });
};
/**
 * Deletes the old ticket and sets the new one from a `guest_ticket` querystring parameter.
 */

const initialize = () => {
  if (typeof window === 'undefined') {
    return;
  }

  deleteOldTicket();
  const queryObject = (0,qs__WEBPACK_IMPORTED_MODULE_0__.parse)(window.location.search.replace('?', ''));

  if (queryObject.guest_ticket) {
    store__WEBPACK_IMPORTED_MODULE_1___default().set(GUEST_TICKET_LOCALFORAGE_KEY, {
      createdDate: Date.now(),
      value: queryObject.guest_ticket
    });
  }
};

initialize();

/***/ }),

/***/ 21286:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "J": function() { return /* binding */ injectLocalization; }
/* harmony export */ });
/* unused harmony export addLocaleQueryParam */
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(11481);
/* harmony import */ var qs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(19126);
/* harmony import */ var qs__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(qs__WEBPACK_IMPORTED_MODULE_0__);


/**
 * Given a WPCOM parameter set, modifies the query such that a non-default
 * locale is added to the query parameter.
 *
 * @param  {object} params Original parameters
 * @returns {object}        Revised parameters, if non-default locale
 */

function addLocaleQueryParam(params) {
  const locale = i18n_calypso__WEBPACK_IMPORTED_MODULE_1__/* ["default"].getLocaleVariant */ .ZP.getLocaleVariant() || i18n_calypso__WEBPACK_IMPORTED_MODULE_1__/* ["default"].getLocaleSlug */ .ZP.getLocaleSlug();

  if (!locale || 'en' === locale) {
    return params;
  }

  let localeQueryParam;
  const query = (0,qs__WEBPACK_IMPORTED_MODULE_0__.parse)(params.query);

  if (params.apiNamespace) {
    // v2 api request
    localeQueryParam = {
      _locale: locale
    };
  } else {
    localeQueryParam = {
      locale
    };
  }

  return Object.assign(params, {
    query: (0,qs__WEBPACK_IMPORTED_MODULE_0__.stringify)(Object.assign(localeQueryParam, query))
  });
}
/**
 * Modifies a WPCOM instance, returning an updated instance with included
 * localization helpers. Specifically, this adds a locale query parameter
 * by default.
 *
 * @param {object} wpcom Original WPCOM instance
 * @returns {object} Modified WPCOM instance with localization helpers
 */

function injectLocalization(wpcom) {
  const originalRequest = wpcom.request.bind(wpcom);
  return Object.assign(wpcom, {
    localized: true,
    request: function (params, callback) {
      return originalRequest(addLocaleQueryParam(params), callback);
    }
  });
}

/***/ }),

/***/ 33300:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ wpcomSupport; }
/* harmony export */ });
/* harmony import */ var qs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(19126);
/* harmony import */ var qs__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(qs__WEBPACK_IMPORTED_MODULE_0__);

function wpcomSupport(wpcom) {
  let supportUser = '';
  let supportToken = '';
  let tokenErrorCallback = null;
  /**
   * Add the supportUser and supportToken to the query.
   *
   * @param {object}  params The original request params object
   * @returns {object}        The new query object with support data injected
   */

  const addSupportData = function (params) {
    // Unwind the query string
    const query = (0,qs__WEBPACK_IMPORTED_MODULE_0__.parse)(params.query); // Inject the credentials

    query.support_user = supportUser;
    query._support_token = supportToken;
    return Object.assign({}, params, {
      query: (0,qs__WEBPACK_IMPORTED_MODULE_0__.stringify)(query)
    });
  };
  /**
   * Add the supportUser and supportToken to the query.
   *
   * @param {object}  params The original request params object
   * @returns {object}        The new query object with support data injected
   */


  const addSupportParams = function (params) {
    return { ...params,
      support_user: supportUser,
      _support_token: supportToken
    };
  };

  const request = wpcom.request.bind(wpcom);
  return Object.assign(wpcom, {
    addSupportParams,

    /**
     * @param {string} newUser  Support username
     * @param {string} newToken Support token
     * @param {Function} newTokenErrorCallback Called when invalid support auth token is detected
     * @returns {boolean}  true if the user and token were changed, false otherwise
     */
    setSupportUserToken: function () {
      let newUser = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
      let newToken = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
      let newTokenErrorCallback = arguments.length > 2 ? arguments[2] : undefined;

      if (newUser === supportUser && newToken === supportToken) {
        return false;
      }

      supportUser = newUser;
      supportToken = newToken;
      tokenErrorCallback = newTokenErrorCallback;
      return true;
    },
    request: (params, callback) => {
      if (!(supportUser && supportToken)) {
        return request(params, callback);
      }

      return request(addSupportData(params), (error, response) => {
        if (tokenErrorCallback && (error === null || error === void 0 ? void 0 : error.error) === 'invalid_support_token') {
          tokenErrorCallback(error);
          return;
        } // Call the original response callback


        callback(error, response);
      });
    }
  });
}

/***/ }),

/***/ 12902:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var inherits__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(91285);
/* harmony import */ var inherits__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(inherits__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var wpcom__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(91202);


/**
 * Class inherited from `WPCOMUnpublished` class and adds
 * specific methods useful for wp-calypso.
 *
 * @param {string} [token] - oauth token
 * @param {Function} [reqHandler] - request handler
 * @returns {wpcomFactory} WPCOMOAuthWrapper instance
 */

function WPCOMOAuthWrapper(token, reqHandler) {
  if (!(this instanceof WPCOMOAuthWrapper)) {
    return new WPCOMOAuthWrapper(token, reqHandler);
  }

  if ('function' === typeof token) {
    reqHandler = token;
    token = null;
  } else if (token) {
    this.loadToken(token);
  }

  wpcom__WEBPACK_IMPORTED_MODULE_1__/* ["default"].call */ .Z.call(this, token, function (params, fn) {
    if (this.isTokenLoaded()) {
      // authToken is used in wpcom-xhr-request,
      // which is used for the signup flow in the REST Proxy
      params = { ...params,
        authToken: this._token,
        token: this._token
      };
    }

    return reqHandler(params, fn);
  });
}

inherits__WEBPACK_IMPORTED_MODULE_0___default()(WPCOMOAuthWrapper, wpcom__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z);
/**
 * Add a token to this instance of WPCOM.
 * When loaded, the token is applied to the param object of each subsequent request.
 *
 * @param {string} [token] - oauth token
 */

wpcom__WEBPACK_IMPORTED_MODULE_1__/* ["default"].prototype.loadToken */ .Z.prototype.loadToken = function (token) {
  this._token = token;
};
/**
 * Returns a boolean representing whether or not the token has been loaded.
 *
 * @returns {string} oauth token
 */


WPCOMOAuthWrapper.prototype.isTokenLoaded = function () {
  return this._token !== undefined;
};
/**
 * Expose `WPCOMOAuthWrapper`
 */


/* harmony default export */ __webpack_exports__["Z"] = (WPCOMOAuthWrapper);

/***/ }),

/***/ 54083:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* export default binding */ __WEBPACK_DEFAULT_EXPORT__; }
/* harmony export */ });
/* harmony import */ var calypso_lib_user_shared_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(26935);
/* harmony import */ var calypso_lib_user_store__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(65792);


/* harmony default export */ async function __WEBPACK_DEFAULT_EXPORT__(params, callback) {
  const xhr = (await __webpack_require__.e(/* import() | wpcom-xhr-request */ 361).then(__webpack_require__.bind(__webpack_require__, 3614))).default;
  return xhr(params, async function (error, response, headers) {
    if (error && error.name === 'InvalidTokenError') {
      await (0,calypso_lib_user_store__WEBPACK_IMPORTED_MODULE_0__/* .clearStore */ .YF)();
      window.location.href = (0,calypso_lib_user_shared_utils__WEBPACK_IMPORTED_MODULE_1__/* .getLogoutUrl */ .K)();
    }

    callback(error, response, headers);
  });
}

/***/ }),

/***/ 1422:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports purchasesRoot, addCreditCard, addNewPaymentMethod, billingHistory, paymentMethods, vatDetails, billingHistoryReceipt, managePurchase, cancelPurchase, confirmCancelDomain, addCardDetails, editCardDetails, addPaymentMethod, changePaymentMethod, deprecated */
const purchasesRoot = '/me/purchases';
const addCreditCard = purchasesRoot + '/add-credit-card';
const addNewPaymentMethod = purchasesRoot + '/add-payment-method';
const billingHistory = purchasesRoot + '/billing';
const paymentMethods = purchasesRoot + '/payment-methods';
const vatDetails = purchasesRoot + '/vat-details';
function billingHistoryReceipt(receiptId) {
  if (false) {}

  return billingHistory + `/${receiptId}`;
}
function managePurchase(siteName, purchaseId) {
  if (false) {}

  return purchasesRoot + `/${siteName}/${purchaseId}`;
}
function cancelPurchase(siteName, purchaseId) {
  if (false) {}

  return managePurchase(siteName, purchaseId) + '/cancel';
}
function confirmCancelDomain(siteName, purchaseId) {
  if (false) {}

  return managePurchase(siteName, purchaseId) + '/confirm-cancel-domain';
} // legacy path

function addCardDetails(siteName, purchaseId) {
  if (false) {}

  return managePurchase(siteName, purchaseId) + '/payment/add';
} // legacy path

function editCardDetails(siteName, purchaseId, cardId) {
  if (false) {}

  return managePurchase(siteName, purchaseId) + `/payment/edit/${cardId}`;
}
function addPaymentMethod(siteName, purchaseId) {
  if (false) {}

  return managePurchase(siteName, purchaseId) + '/payment-method/add';
}
function changePaymentMethod(siteName, purchaseId, cardId) {
  if (false) {}

  return managePurchase(siteName, purchaseId) + `/payment-method/change/${cardId}`;
}
const deprecated = {
  upcomingCharges: purchasesRoot + '/upcoming',
  otherPurchases: purchasesRoot + '/other'
};

/***/ }),

/***/ 77270:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "t": function() { return /* binding */ getCustomizerFocus; }
/* harmony export */ });
/* unused harmony export PANEL_MAPPINGS */
/**
 * Mapping from Calypso panel slug to tuple of focus key and value.
 *
 *
 * @type {object}
 */
const PANEL_MAPPINGS = {
  widgets: ['panel', 'widgets'],
  fonts: ['section', 'jetpack_fonts'],
  identity: ['section', 'title_tagline'],
  'custom-css': ['section', 'jetpack_custom_css'],
  amp: ['section', 'amp_design'],
  menus: ['panel', 'nav_menus'],
  homepage: ['section', 'static_front_page'],
  jetpack_search: ['section', 'jetpack_search']
};
/**
 * Given the name of a Calypso customizer panel, returns an object containing
 * the section or panel to be used in autofocus. Returns null if the panel is
 * not recognized.
 *
 * @param  {string}  panel Calypso panel slug
 * @returns {?object}       WordPress autofocus argument object
 */

function getCustomizerFocus(panel) {
  if (PANEL_MAPPINGS.hasOwnProperty(panel)) {
    const [key, value] = PANEL_MAPPINGS[panel];
    return {
      [`autofocus[${key}]`]: value
    };
  }

  return null;
}

/***/ }),

/***/ 83373:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports discoverBlogId, isDiscoverBlog, isDiscoverFeed, isDiscoverEnabled, isDiscoverPost, isDiscoverSitePick, isInternalDiscoverPost, getSiteUrl, getDiscoverBlogName, hasSource, getSourceData, getLinkProps, getSourceFollowUrl */
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var calypso_reader_route__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(7728);





function hasDiscoverSlug(post, searchSlug) {
  const metaData = get(post, 'discover_metadata.discover_fp_post_formats');
  return !!(metaData && find(metaData, {
    slug: searchSlug
  }));
}

const discoverBlogId = (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('discover_blog_id');
function isDiscoverBlog(blogId) {
  return +blogId === config('discover_blog_id');
}
function isDiscoverFeed(feedId) {
  return +feedId === config('discover_feed_id');
}
function isDiscoverEnabled() {
  return false;
}
function isDiscoverPost(post) {
  return !!(get(post, 'discover_metadata') || get(post, 'site_ID') === config('discover_blog_id'));
}
function isDiscoverSitePick(post) {
  return hasDiscoverSlug(post, 'site-pick');
}
function isInternalDiscoverPost(post) {
  return !!get(post, 'discover_metadata.featured_post_wpcom_data');
}
function getSiteUrl(post) {
  const blogId = get(post, 'discover_metadata.featured_post_wpcom_data.blog_id'); // If we have a blog ID, we want to send them to the site detail page

  return blogId ? readerRouteGetSiteUrl(blogId) : get(post, 'discover_metadata.permalink');
}
function getDiscoverBlogName(post) {
  return get(post, 'discover_metadata.attribution.blog_name');
}
function hasSource(post) {
  return isDiscoverPost(post) && !isDiscoverSitePick(post);
}
function getSourceData(post) {
  const sourceData = get(post, 'discover_metadata.featured_post_wpcom_data');

  if (sourceData) {
    return {
      blogId: get(sourceData, 'blog_id'),
      postId: get(sourceData, 'post_id')
    };
  }

  return {};
}
function getLinkProps(linkUrl) {
  const {
    hostname
  } = getUrlParts(linkUrl);
  const isExternal = hostname && hostname !== window.location.hostname;
  return {
    rel: isExternal ? 'external' : '',
    target: isExternal ? '_blank' : ''
  };
}
function getSourceFollowUrl(post) {
  let followUrl;

  if (!isDiscoverPost(post)) {
    return;
  }

  followUrl = get(post, 'discover_metadata.attribution.blog_url'); // If it's a site pick, try the permalink

  if (!followUrl && isDiscoverSitePick(post)) {
    followUrl = get(post, 'discover_metadata.permalink');
  }

  return followUrl || '';
}

/***/ }),

/***/ 58414:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ contentWidth; }
/* harmony export */ });
const PAGE_MARGIN_LARGE = 32 * 2;
const PAGE_MARGIN_MEDIUM = 24 * 2;
const PAGE_MARGIN_SMALL = 10 * 2;
const SIDEBAR_WIDTH = 240;
const MAX_CONTENT_WIDTH = 720;
/**
 * Returns the available content width in full post for the reader at the current viewport width
 */

function contentWidth() {
  if (typeof document === 'undefined') {
    return undefined;
  }

  const clientWidth = document.documentElement.clientWidth;

  if (clientWidth > 1040) {
    return MAX_CONTENT_WIDTH;
  }

  if (clientWidth > 928) {
    return clientWidth - (SIDEBAR_WIDTH + PAGE_MARGIN_LARGE);
  }

  if (clientWidth > 660) {
    return clientWidth - (SIDEBAR_WIDTH + PAGE_MARGIN_MEDIUM);
  }

  return clientWidth - PAGE_MARGIN_SMALL;
}

/***/ }),

/***/ 77327:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "WO": function() { return /* binding */ keyForPost; },
/* harmony export */   "NK": function() { return /* binding */ keysAreEqual; },
/* harmony export */   "C$": function() { return /* binding */ keyToString; },
/* harmony export */   "J0": function() { return /* binding */ isPostKeyLike; }
/* harmony export */ });
function keyForPost(post) {
  if (!post) {
    return;
  }

  if (post.feed_ID && post.feed_item_ID) {
    return {
      feedId: post.feed_ID,
      postId: post.feed_item_ID
    };
  }

  if (post.is_external) {
    return {
      feedId: post.feed_ID || post.site_ID,
      postId: post.feed_item_ID || post.ID
    };
  }

  return {
    blogId: post.site_ID,
    postId: post.ID
  };
}
function keysAreEqual(a, b) {
  if (a === b) {
    return true;
  }

  if (!a && b || a && !b || !a && !b && a !== b) {
    return false;
  }

  if (a.isGap && !b.isGap || !a.isGap && b.isGap) {
    return false;
  }

  if (a.isGap && b.isGap) {
    return a.from === b.from && a.to === b.to;
  }

  if (a.postId !== b.postId) {
    return false;
  }

  if (a.feedId) {
    return a.feedId === b.feedId;
  }

  return a.blogId === b.blogId;
}
function keyToString(postKey) {
  if (!postKey || postKey.isGap) {
    return null;
  }

  if (postKey.isCombination) {
    const feedId = postKey.feedId ? `&feedId=${postKey.feedId}` : '';
    const blogId = postKey.blogId ? `&feedId=${postKey.blogId}` : '';
    const postIds = postKey.postIds.join(',');
    return `postIds=[${postIds}, ]${feedId}${blogId} `;
  } else if (postKey.isRecommendationBlock) {
    return `rec-${postKey.index}`;
  } else if (postKey.feedId) {
    return `${postKey.postId}-${postKey.feedId}`;
  } else if (postKey.blogId) {
    return `${postKey.postId}-${postKey.blogId}`;
  }

  return null; // should never happen!
}
function isPostKeyLike(postKey) {
  return postKey && postKey.postId && (postKey.blogId || postKey.feedId);
}

/***/ }),

/***/ 7728:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports getPrettySiteUrl, getPrettyFeedUrl, getSiteUrl, getFeedUrl, getStreamUrl, getStreamUrlFromPost, getTagStreamUrl, getPostUrl */
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);

const FEED_URL_BASE = '/read/feeds/';
const SITE_URL_BASE = '/read/blogs/';
const DISCOVER_SITE_ID = (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('discover_blog_id');
const DISCOVER_FEED_ID = (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('discover_feed_id');
const prettyFeedUrls = {
  [DISCOVER_FEED_ID]: '/discover'
};
const prettySiteUrls = {
  [DISCOVER_SITE_ID]: '/discover'
};
function getPrettySiteUrl(siteID) {
  return prettySiteUrls[siteID];
}
function getPrettyFeedUrl(feedID) {
  return prettyFeedUrls[feedID];
}
function getSiteUrl(siteID) {
  return getPrettySiteUrl(siteID) || SITE_URL_BASE + siteID;
}
function getFeedUrl(feedID) {
  return getPrettyFeedUrl(feedID) || FEED_URL_BASE + feedID;
}
function getStreamUrl(feedID, siteID) {
  if (feedID) {
    return getFeedUrl(feedID);
  }

  return getSiteUrl(siteID);
}
function getStreamUrlFromPost(post) {
  if (post.feed_ID) {
    return getFeedUrl(post.feed_ID);
  }

  return getSiteUrl(post.site_ID);
}
function getTagStreamUrl(tag) {
  return `/tag/${tag}`;
}
function getPostUrl(post) {
  if (post.feed_ID && post.feed_item_ID) {
    return `/read/feeds/${post.feed_ID}/posts/${post.feed_item_ID}`;
  } else if (post.is_external) {
    return `/read/feeds/${post.feed_ID}/posts/${post.ID}`;
  }

  return `/read/blogs/${post.site_ID}/posts/${post.ID}`;
}

/***/ }),

/***/ 29789:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "yg": function() { return /* binding */ pageViewForPost; }
/* harmony export */ });
/* unused harmony exports recordAction, recordGaEvent, recordPermalinkClick, recordTrack, recordTracksRailcar, recordTracksRailcarRender, recordTracksRailcarInteract, recordTrackForPost, getTracksPropertiesForPost, recordRailcar, recordTrackWithRailcar, recordFollow, recordUnfollow */
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var calypso_lib_analytics_ga__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(44567);
/* harmony import */ var calypso_lib_analytics_mc__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(7689);
/* harmony import */ var calypso_lib_analytics_tracks__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(17032);





const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('calypso:reader:stats');
function recordAction(action) {
  debug('reader action', action);
  bumpStat('reader_actions', action);
}
function recordGaEvent(action, label, value) {
  debug('reader ga event', ...arguments);
  gaRecordEvent('Reader', action, label, value);
}
function recordPermalinkClick(source, post) {
  let eventProperties = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  bumpStat({
    reader_actions: 'visited_post_permalink',
    reader_permalink_source: source
  });
  recordGaEvent('Clicked Post Permalink', source);
  const trackEvent = 'calypso_reader_permalink_click'; // Add source as Tracks event property

  eventProperties = Object.assign({
    source
  }, eventProperties);

  if (post) {
    recordTrackForPost(trackEvent, post, eventProperties);
  } else {
    recordTrack(trackEvent, eventProperties);
  }
}

function getLocation(path) {
  if (path === undefined || path === '') {
    return 'unknown';
  }

  if (path === '/read') {
    return 'following';
  }

  if (path.indexOf('/read/a8c') === 0) {
    return 'following_a8c';
  }

  if (path.indexOf('/read/p2') === 0) {
    return 'following_p2';
  }

  if (path.indexOf('/tag/') === 0) {
    return 'topic_page';
  }

  if (path.match(/^\/read\/(blogs|feeds)\/([0-9]+)\/posts\/([0-9]+)$/i)) {
    return 'single_post';
  }

  if (path.match(/^\/read\/(blogs|feeds)\/([0-9]+)$/i)) {
    return 'blog_page';
  }

  if (path.indexOf('/read/list/') === 0) {
    return 'list';
  }

  if (path.indexOf('/activities/likes') === 0) {
    return 'postlike';
  }

  if (path.indexOf('/recommendations/mine') === 0) {
    return 'recommended_foryou';
  }

  if (path.indexOf('/following/edit') === 0) {
    return 'following_edit';
  }

  if (path.indexOf('/following/manage') === 0) {
    return 'following_manage';
  }

  if (path.indexOf('/discover') === 0) {
    return 'discover';
  }

  if (path.indexOf('/read/recommendations/posts') === 0) {
    return 'recommended_posts';
  }

  if (path.indexOf('/read/search') === 0) {
    return 'search';
  }

  if (path.indexOf('/read/conversations/a8c') === 0) {
    return 'conversations_a8c';
  }

  if (path.indexOf('/read/conversations') === 0) {
    return 'conversations';
  }

  return 'unknown';
}
/**
 * @param {*} eventName track event name
 * @param {*} eventProperties extra event props
 * @param {{pathnameOverride: string}} [pathnameOverride] Overwrites the location for ui_algo Useful for when
 *   recordTrack() is called after loading the next window.
 *   For example: opening an article (calypso_reader_article_opened) would call
 *   recordTrack after changing windows and would result in a `ui_algo: single_post`
 *   regardless of the stream the post was opened. This now allows the article_opened
 *   Tracks event to correctly specify which stream the post was opened.
 * @deprecated Use the recordReaderTracksEvent action instead.
 */


function recordTrack(eventName, eventProperties) {
  let {
    pathnameOverride
  } = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  debug('reader track', ...arguments);
  const location = getLocation(pathnameOverride || window.location.pathname);
  eventProperties = Object.assign({
    ui_algo: location
  }, eventProperties);

  if (false) {}

  recordTracksEvent(eventName, eventProperties);
}
const allowedTracksRailcarEventNames = new Set();
allowedTracksRailcarEventNames.add('calypso_reader_related_post_from_same_site_clicked').add('calypso_reader_related_post_from_other_site_clicked').add('calypso_reader_related_post_site_clicked').add('calypso_reader_article_liked').add('calypso_reader_article_commented_on').add('calypso_reader_article_opened').add('calypso_reader_searchcard_clicked').add('calypso_reader_author_link_clicked').add('calypso_reader_permalink_click').add('calypso_reader_recommended_post_clicked').add('calypso_reader_recommended_site_clicked').add('calypso_reader_recommended_post_dismissed');
function recordTracksRailcar(action, eventName, railcar) {
  let overrides = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  // flatten the railcar down into the event props
  recordTrack(action, Object.assign(eventName ? {
    action: eventName.replace('calypso_reader_', '')
  } : {}, railcar, overrides));
}
function recordTracksRailcarRender(eventName, railcar, overrides) {
  return recordTracksRailcar('calypso_traintracks_render', eventName, railcar, overrides);
}
function recordTracksRailcarInteract(eventName, railcar, overrides) {
  return recordTracksRailcar('calypso_traintracks_interact', eventName, railcar, overrides);
}
function recordTrackForPost(eventName) {
  let post = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  let additionalProps = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  let options = arguments.length > 3 ? arguments[3] : undefined;
  recordTrack(eventName, { ...getTracksPropertiesForPost(post),
    ...additionalProps
  }, options);

  if (post.railcar && allowedTracksRailcarEventNames.has(eventName)) {
    // check for overrides for the railcar
    recordTracksRailcarInteract(eventName, post.railcar, pick(additionalProps, ['ui_position', 'ui_algo']));
  } else if (false) {}
}
function getTracksPropertiesForPost() {
  let post = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return {
    blog_id: !post.is_external && post.site_ID > 0 ? post.site_ID : undefined,
    post_id: !post.is_external && post.ID > 0 ? post.ID : undefined,
    feed_id: post.feed_ID > 0 ? post.feed_ID : undefined,
    feed_item_id: post.feed_item_ID > 0 ? post.feed_item_ID : undefined,
    is_jetpack: post.is_jetpack
  };
}
function recordRailcar(eventName, railcar, eventProperties) {
  recordTracksRailcarInteract(eventName, railcar, pick(eventProperties, ['ui_position', 'ui_algo']));
}
function recordTrackWithRailcar(eventName, railcar, eventProperties) {
  recordTrack(eventName, eventProperties);
  recordRailcar(eventName, railcar, eventProperties);
}
function pageViewForPost(blogId, blogUrl, postId, isPrivate) {
  if (!blogId || !blogUrl || !postId) {
    return;
  }

  const params = {
    ref: 'http://wordpress.com/',
    reader: 1,
    host: blogUrl.replace(/.*?:\/\//g, ''),
    blog: blogId,
    post: postId
  };

  if (isPrivate) {
    params.priv = 1;
  }

  debug('reader page view for post', params);
  (0,calypso_lib_analytics_mc__WEBPACK_IMPORTED_MODULE_3__/* .bumpStatWithPageView */ .S)(params);
}
function recordFollow(url, railcar) {
  let additionalProps = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  const source = additionalProps.source || getLocation(window.location.pathname);
  bumpStat('reader_follows', source);
  recordAction('followed_blog');
  recordGaEvent('Clicked Follow Blog', source);
  recordTrack('calypso_reader_site_followed', {
    url,
    source,
    ...additionalProps
  });

  if (railcar) {
    recordTracksRailcarInteract('site_followed', railcar);
  }
}
function recordUnfollow(url, railcar) {
  let additionalProps = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  const source = getLocation(window.location.pathname);
  bumpStat('reader_unfollows', source);
  recordAction('unfollowed_blog');
  recordGaEvent('Clicked Unfollow Blog', source);
  recordTrack('calypso_reader_site_unfollowed', {
    url,
    source,
    ...additionalProps
  });

  if (railcar) {
    recordTracksRailcarInteract('site_unfollowed', railcar);
  }
}

/***/ }),

/***/ 46310:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "qb": function() { return /* binding */ sameXPost; }
/* harmony export */ });
/* unused harmony exports isDiscoverPostKey, RECS_PER_BLOCK, sameSite, sameDay, combine, combineCards, injectRecommendations, getDistanceBetweenRecs */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var moment__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(76292);
/* harmony import */ var moment__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(moment__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var calypso_reader_discover_helper__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(83373);



function isDiscoverPostKey(postKey) {
  return isDiscoverBlog(postKey.blogId) || isDiscoverFeed(postKey.feedId);
}
const RECS_PER_BLOCK = 2;
/**
 * Check if two postKeys are for the same siteId or feedId
 *
 * @param {object} postKey1 First post key
 * @param {object} postKey2 Second post key
 * @returns {boolean} Returns true if two postKeys are for the same siteId or feedId
 */

function sameSite(postKey1, postKey2) {
  return postKey1 && postKey2 && !postKey1.isRecommendationBlock && !postKey2.isRecommendationBlock && (postKey1.blogId && postKey1.blogId === postKey2.blogId || postKey1.feedId && postKey1.feedId === postKey2.feedId);
}
function sameDay(postKey1, postKey2) {
  return moment(postKey1.date).isSame(postKey2.date, 'day');
}
function sameXPost(postKey1, postKey2) {
  return postKey1 && postKey2 && postKey1.xPostMetadata && postKey2.xPostMetadata && postKey1.xPostMetadata.blogId && postKey1.xPostMetadata.blogId === postKey2.xPostMetadata.blogId && postKey1.xPostMetadata.postId && postKey1.xPostMetadata.postId === postKey2.xPostMetadata.postId;
}
/**
 * Takes two postKeys and combines them into a ReaderCombinedCard postKey.
 * Note: This only makes sense for postKeys from the same site
 *
 * @param {object} postKey1 must be either a ReaderCombinedCard postKey or a regular postKey
 * @param {object} postKey2 can only be a regular postKey. May not be a combinedCard postKey or a recommendations postKey
 * @returns {object} A ReaderCombinedCard postKey
 */

function combine(postKey1, postKey2) {
  if (!postKey1 || !postKey2) {
    return null;
  }

  const combined = {
    isCombination: true,
    date: postKey1.date && postKey1.date < postKey2.date // keep the earliest moment
    ? postKey1.date : postKey2.date,
    postIds: [...(postKey1.postIds || [postKey1.postId]), ...(postKey2.postIds || [postKey2.postId])]
  };
  postKey1.blogId && (combined.blogId = postKey1.blogId);
  postKey1.feedId && (combined.feedId = postKey1.feedId);
  return combined;
}
const combineCards = postKeys => postKeys.reduce((accumulator, postKey) => {
  const lastPostKey = last(accumulator);

  if (sameSite(lastPostKey, postKey) && sameDay(lastPostKey, postKey) && !isDiscoverPostKey(postKey)) {
    accumulator[accumulator.length - 1] = combine(last(accumulator), postKey);
  } else {
    accumulator.push(postKey);
  }

  return accumulator;
}, []);
function injectRecommendations(posts) {
  let recs = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  let itemsBetweenRecs = arguments.length > 2 ? arguments[2] : undefined;

  if (!recs || recs.length === 0) {
    return posts;
  }

  if (posts.length < itemsBetweenRecs) {
    return posts;
  }

  let recIndex = 0;
  return flatMap(posts, (post, index) => {
    if (index && index % itemsBetweenRecs === 0 && recIndex < recs.length) {
      const recBlock = {
        isRecommendationBlock: true,
        recommendations: recs.slice(recIndex, recIndex + RECS_PER_BLOCK),
        index: recIndex
      };
      recIndex += RECS_PER_BLOCK;
      return [recBlock, post];
    }

    return post;
  });
}
const MIN_DISTANCE_BETWEEN_RECS = 4; // page size is 7, so one in the middle of every page and one on page boundries, sometimes

const MAX_DISTANCE_BETWEEN_RECS = 30;
function getDistanceBetweenRecs(totalSubs) {
  // the distance between recs changes based on how many subscriptions the user has.
  // We cap it at MAX_DISTANCE_BETWEEN_RECS.
  // It grows at the natural log of the number of subs, times a multiplier, offset by a constant.
  // This lets the distance between recs grow quickly as you add subs early on, and slow down as you
  // become a common user of the reader.
  if (totalSubs <= 0) {
    // 0 means either we don't know yet, or the user actually has zero subs.
    // if a user has zero subs, we don't show posts at all, so just treat 0 as 'unknown' and
    // push recs to the max.
    return MAX_DISTANCE_BETWEEN_RECS;
  }

  return Math.min(Math.max(Math.floor(Math.log(totalSubs) * Math.LOG2E * 5 - 6), MIN_DISTANCE_BETWEEN_RECS), MAX_DISTANCE_BETWEEN_RECS);
}

/***/ }),

/***/ 40211:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "u2u": function() { return /* binding */ ANALYTICS_EVENT_RECORD; },
/* harmony export */   "Wj3": function() { return /* binding */ ANALYTICS_PAGE_VIEW_RECORD; },
/* harmony export */   "lAo": function() { return /* binding */ ANALYTICS_STAT_BUMP; },
/* harmony export */   "K5f": function() { return /* binding */ ANALYTICS_TRACKING_ON; },
/* harmony export */   "ti2": function() { return /* binding */ ANALYTICS_TRACKS_OPT_OUT; },
/* harmony export */   "Fux": function() { return /* binding */ APP_BANNER_TOGGLE_VISIBILITY; },
/* harmony export */   "JYg": function() { return /* binding */ APP_BANNER_DISMISSED; },
/* harmony export */   "gm2": function() { return /* binding */ APPLY_STORED_STATE; },
/* harmony export */   "uBM": function() { return /* binding */ CURRENT_USER_RECEIVE; },
/* harmony export */   "KAg": function() { return /* binding */ CURRENT_USER_SET_EMAIL_VERIFIED; },
/* harmony export */   "w6q": function() { return /* binding */ DOMAIN_CONTACT_INFO_DISCLOSE; },
/* harmony export */   "M5U": function() { return /* binding */ DOMAIN_CONTACT_INFO_DISCLOSE_FAILURE; },
/* harmony export */   "tGX": function() { return /* binding */ DOMAIN_CONTACT_INFO_DISCLOSE_SUCCESS; },
/* harmony export */   "K1T": function() { return /* binding */ DOMAIN_CONTACT_INFO_REDACT; },
/* harmony export */   "sQe": function() { return /* binding */ DOMAIN_CONTACT_INFO_REDACT_FAILURE; },
/* harmony export */   "HYG": function() { return /* binding */ DOMAIN_CONTACT_INFO_REDACT_SUCCESS; },
/* harmony export */   "HCR": function() { return /* binding */ DOMAIN_PRIVACY_DISABLE; },
/* harmony export */   "T6o": function() { return /* binding */ DOMAIN_PRIVACY_DISABLE_FAILURE; },
/* harmony export */   "ON1": function() { return /* binding */ DOMAIN_PRIVACY_DISABLE_SUCCESS; },
/* harmony export */   "sBg": function() { return /* binding */ DOMAIN_PRIVACY_ENABLE; },
/* harmony export */   "zVI": function() { return /* binding */ DOMAIN_PRIVACY_ENABLE_FAILURE; },
/* harmony export */   "DGo": function() { return /* binding */ DOMAIN_PRIVACY_ENABLE_SUCCESS; },
/* harmony export */   "gQI": function() { return /* binding */ EDITOR_START; },
/* harmony export */   "cnn": function() { return /* binding */ EDITOR_STOP; },
/* harmony export */   "G1W": function() { return /* binding */ EMAIL_VERIFY_REQUEST; },
/* harmony export */   "dAl": function() { return /* binding */ EMAIL_VERIFY_REQUEST_FAILURE; },
/* harmony export */   "YPU": function() { return /* binding */ EMAIL_VERIFY_REQUEST_SUCCESS; },
/* harmony export */   "iHL": function() { return /* binding */ EMAIL_VERIFY_STATE_RESET; },
/* harmony export */   "H6A": function() { return /* binding */ GUIDED_TOUR_UPDATE; },
/* harmony export */   "vQd": function() { return /* binding */ HAPPYCHAT_BLUR; },
/* harmony export */   "o9b": function() { return /* binding */ HAPPYCHAT_FOCUS; },
/* harmony export */   "Mei": function() { return /* binding */ HAPPYCHAT_IO_INIT; },
/* harmony export */   "nHy": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_ACCEPT; },
/* harmony export */   "oH7": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_CONNECT; },
/* harmony export */   "f5U": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_DISCONNECT; },
/* harmony export */   "AKl": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_ERROR; },
/* harmony export */   "M7f": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_INIT; },
/* harmony export */   "Sur": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_LOCALIZED_SUPPORT; },
/* harmony export */   "$Tb": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_MESSAGE; },
/* harmony export */   "IoY": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_MESSAGE_OPTIMISTIC; },
/* harmony export */   "Ylp": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_MESSAGE_UPDATE; },
/* harmony export */   "k_K": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_RECONNECTING; },
/* harmony export */   "myH": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_STATUS; },
/* harmony export */   "yGK": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_TOKEN; },
/* harmony export */   "IwF": function() { return /* binding */ HAPPYCHAT_IO_RECEIVE_UNAUTHORIZED; },
/* harmony export */   "R_D": function() { return /* binding */ HAPPYCHAT_IO_REQUEST_TRANSCRIPT; },
/* harmony export */   "kJ4": function() { return /* binding */ HAPPYCHAT_IO_REQUEST_TRANSCRIPT_RECEIVE; },
/* harmony export */   "Syf": function() { return /* binding */ HAPPYCHAT_IO_SEND_MESSAGE_EVENT; },
/* harmony export */   "vsK": function() { return /* binding */ HAPPYCHAT_IO_SEND_MESSAGE_LOG; },
/* harmony export */   "qjX": function() { return /* binding */ HAPPYCHAT_IO_SEND_MESSAGE_MESSAGE; },
/* harmony export */   "$tj": function() { return /* binding */ HAPPYCHAT_IO_SEND_MESSAGE_USERINFO; },
/* harmony export */   "Do$": function() { return /* binding */ HAPPYCHAT_IO_SEND_PREFERENCES; },
/* harmony export */   "ILV": function() { return /* binding */ HAPPYCHAT_IO_SEND_TYPING; },
/* harmony export */   "SgU": function() { return /* binding */ HAPPYCHAT_IO_SET_CUSTOM_FIELDS; },
/* harmony export */   "tyO": function() { return /* binding */ HAPPYCHAT_MINIMIZING; },
/* harmony export */   "eYx": function() { return /* binding */ HAPPYCHAT_OPEN; },
/* harmony export */   "c2t": function() { return /* binding */ HAPPYCHAT_SET_CURRENT_MESSAGE; },
/* harmony export */   "Xeb": function() { return /* binding */ HAPPYCHAT_SET_USER_CONFIG; },
/* harmony export */   "xm0": function() { return /* binding */ HELP_CENTER_VISIBLE; },
/* harmony export */   "Oh9": function() { return /* binding */ JETPACK_DISCONNECT_RECEIVE; },
/* harmony export */   "ftJ": function() { return /* binding */ JETPACK_SITE_DISCONNECT_REQUEST; },
/* harmony export */   "kUt": function() { return /* binding */ LAYOUT_FOCUS_SET; },
/* harmony export */   "XTm": function() { return /* binding */ LAYOUT_NEXT_FOCUS_ACTIVATE; },
/* harmony export */   "vO0": function() { return /* binding */ LAYOUT_NEXT_FOCUS_SET; },
/* harmony export */   "JqF": function() { return /* binding */ LOCALE_SET; },
/* harmony export */   "NnF": function() { return /* binding */ MASTERBAR_TOGGLE_VISIBILITY; },
/* harmony export */   "aqr": function() { return /* binding */ MEDIA_DELETE; },
/* harmony export */   "WkZ": function() { return /* binding */ MEDIA_MODAL_VIEW_SET; },
/* harmony export */   "hxz": function() { return /* binding */ NOTIFICATIONS_PANEL_TOGGLE; },
/* harmony export */   "C6k": function() { return /* binding */ POST_COUNTS_RECEIVE; },
/* harmony export */   "T3s": function() { return /* binding */ POST_COUNTS_REQUEST; },
/* harmony export */   "X5K": function() { return /* binding */ POST_COUNTS_REQUEST_FAILURE; },
/* harmony export */   "h2B": function() { return /* binding */ POST_COUNTS_REQUEST_SUCCESS; },
/* harmony export */   "Rp6": function() { return /* binding */ POST_COUNTS_RESET_INTERNAL_STATE; },
/* harmony export */   "LbL": function() { return /* binding */ POST_DELETE; },
/* harmony export */   "xkR": function() { return /* binding */ POST_DELETE_FAILURE; },
/* harmony export */   "kNW": function() { return /* binding */ POST_DELETE_SUCCESS; },
/* harmony export */   "oD3": function() { return /* binding */ POST_EDIT; },
/* harmony export */   "RFP": function() { return /* binding */ POST_LIKE; },
/* harmony export */   "rgA": function() { return /* binding */ POST_LIKES_ADD_LIKER; },
/* harmony export */   "AVO": function() { return /* binding */ POST_LIKES_RECEIVE; },
/* harmony export */   "a7F": function() { return /* binding */ POST_LIKES_REMOVE_LIKER; },
/* harmony export */   "PP1": function() { return /* binding */ POST_LIKES_REQUEST; },
/* harmony export */   "pgH": function() { return /* binding */ POST_REQUEST; },
/* harmony export */   "Ra4": function() { return /* binding */ POST_REQUEST_FAILURE; },
/* harmony export */   "nL0": function() { return /* binding */ POST_REQUEST_SUCCESS; },
/* harmony export */   "F1Z": function() { return /* binding */ POST_RESTORE; },
/* harmony export */   "JZv": function() { return /* binding */ POST_RESTORE_FAILURE; },
/* harmony export */   "R$r": function() { return /* binding */ POST_REVISION_AUTHORS_RECEIVE; },
/* harmony export */   "NYz": function() { return /* binding */ POST_REVISIONS_DIALOG_CLOSE; },
/* harmony export */   "gpX": function() { return /* binding */ POST_REVISIONS_DIALOG_OPEN; },
/* harmony export */   "Se1": function() { return /* binding */ POST_REVISIONS_DIFF_SPLIT_VIEW; },
/* harmony export */   "bE0": function() { return /* binding */ POST_REVISIONS_DIFF_UNIFY_VIEW; },
/* harmony export */   "vIA": function() { return /* binding */ POST_REVISIONS_RECEIVE; },
/* harmony export */   "N__": function() { return /* binding */ POST_REVISIONS_SELECT; },
/* harmony export */   "CNw": function() { return /* binding */ POST_SAVE; },
/* harmony export */   "hZH": function() { return /* binding */ POST_SAVE_SUCCESS; },
/* harmony export */   "KF6": function() { return /* binding */ POST_TYPE_LIST_SHARE_PANEL_HIDE; },
/* harmony export */   "WYe": function() { return /* binding */ POST_TYPE_LIST_SHARE_PANEL_TOGGLE; },
/* harmony export */   "vP0": function() { return /* binding */ POST_UNLIKE; },
/* harmony export */   "hYA": function() { return /* binding */ POSTS_RECEIVE; },
/* harmony export */   "XMF": function() { return /* binding */ POSTS_REQUEST; },
/* harmony export */   "LEp": function() { return /* binding */ POSTS_REQUEST_FAILURE; },
/* harmony export */   "A4M": function() { return /* binding */ POSTS_REQUEST_SUCCESS; },
/* harmony export */   "pSd": function() { return /* binding */ PREFERENCES_FETCH; },
/* harmony export */   "PD1": function() { return /* binding */ PREFERENCES_FETCH_FAILURE; },
/* harmony export */   "N8o": function() { return /* binding */ PREFERENCES_FETCH_SUCCESS; },
/* harmony export */   "XuD": function() { return /* binding */ PREFERENCES_RECEIVE; },
/* harmony export */   "lCo": function() { return /* binding */ PREFERENCES_SAVE_SUCCESS; },
/* harmony export */   "JPH": function() { return /* binding */ PREFERENCES_SET; },
/* harmony export */   "kLL": function() { return /* binding */ PREVIEW_URL_CLEAR; },
/* harmony export */   "dGx": function() { return /* binding */ PREVIEW_URL_SET; },
/* harmony export */   "WjV": function() { return /* binding */ PURCHASE_REMOVE_COMPLETED; },
/* harmony export */   "RIF": function() { return /* binding */ PURCHASE_REMOVE_FAILED; },
/* harmony export */   "gbe": function() { return /* binding */ PURCHASES_REMOVE; },
/* harmony export */   "pJb": function() { return /* binding */ PURCHASES_SITE_FETCH; },
/* harmony export */   "m58": function() { return /* binding */ PURCHASES_SITE_FETCH_COMPLETED; },
/* harmony export */   "_qM": function() { return /* binding */ PURCHASES_SITE_FETCH_FAILED; },
/* harmony export */   "Fsf": function() { return /* binding */ PURCHASES_SITE_RESET_STATE; },
/* harmony export */   "$5Y": function() { return /* binding */ PURCHASES_USER_FETCH; },
/* harmony export */   "XMH": function() { return /* binding */ PURCHASES_USER_FETCH_COMPLETED; },
/* harmony export */   "_MG": function() { return /* binding */ PURCHASES_USER_FETCH_FAILED; },
/* harmony export */   "RSp": function() { return /* binding */ ROUTE_SET; },
/* harmony export */   "Nq": function() { return /* binding */ SECTION_LOADING_SET; },
/* harmony export */   "IK5": function() { return /* binding */ SECTION_SET; },
/* harmony export */   "bgv": function() { return /* binding */ SELECTED_SITE_SET; },
/* harmony export */   "tvw": function() { return /* binding */ SITE_CONNECTION_STATUS_RECEIVE; },
/* harmony export */   "U5d": function() { return /* binding */ SITE_CONNECTION_STATUS_REQUEST; },
/* harmony export */   "QLz": function() { return /* binding */ SITE_CONNECTION_STATUS_REQUEST_FAILURE; },
/* harmony export */   "D5g": function() { return /* binding */ SITE_CONNECTION_STATUS_REQUEST_SUCCESS; },
/* harmony export */   "SYS": function() { return /* binding */ SITE_DELETE_RECEIVE; },
/* harmony export */   "t2O": function() { return /* binding */ SITE_DOMAINS_RECEIVE; },
/* harmony export */   "wOJ": function() { return /* binding */ SITE_DOMAINS_REQUEST; },
/* harmony export */   "dyA": function() { return /* binding */ SITE_DOMAINS_REQUEST_FAILURE; },
/* harmony export */   "RI4": function() { return /* binding */ SITE_DOMAINS_REQUEST_SUCCESS; },
/* harmony export */   "fa4": function() { return /* binding */ SITE_FEATURES_FETCH; },
/* harmony export */   "xNf": function() { return /* binding */ SITE_FEATURES_FETCH_COMPLETED; },
/* harmony export */   "YCt": function() { return /* binding */ SITE_FEATURES_FETCH_FAILED; },
/* harmony export */   "uvG": function() { return /* binding */ SITE_FRONT_PAGE_UPDATE; },
/* harmony export */   "Kmp": function() { return /* binding */ SITE_INTRO_OFFER_RECEIVE; },
/* harmony export */   "Frv": function() { return /* binding */ SITE_INTRO_OFFER_REQUEST; },
/* harmony export */   "Byq": function() { return /* binding */ SITE_INTRO_OFFER_REQUEST_FAILURE; },
/* harmony export */   "lfH": function() { return /* binding */ SITE_INTRO_OFFER_REQUEST_SUCCESS; },
/* harmony export */   "lTr": function() { return /* binding */ SITE_MIGRATION_STATUS_UPDATE; },
/* harmony export */   "gNn": function() { return /* binding */ SITE_PLANS_FETCH; },
/* harmony export */   "Rmh": function() { return /* binding */ SITE_PLANS_FETCH_COMPLETED; },
/* harmony export */   "$MQ": function() { return /* binding */ SITE_PLANS_FETCH_FAILED; },
/* harmony export */   "XLI": function() { return /* binding */ SITE_PLANS_REMOVE; },
/* harmony export */   "U0$": function() { return /* binding */ SITE_PLUGIN_UPDATED; },
/* harmony export */   "eO9": function() { return /* binding */ SITE_PRODUCTS_FETCH; },
/* harmony export */   "S3d": function() { return /* binding */ SITE_PRODUCTS_FETCH_COMPLETED; },
/* harmony export */   "whB": function() { return /* binding */ SITE_PRODUCTS_FETCH_FAILED; },
/* harmony export */   "UUJ": function() { return /* binding */ SITE_RECEIVE; },
/* harmony export */   "hJk": function() { return /* binding */ SITE_REQUEST; },
/* harmony export */   "uuM": function() { return /* binding */ SITE_REQUEST_FAILURE; },
/* harmony export */   "Mvd": function() { return /* binding */ SITE_REQUEST_SUCCESS; },
/* harmony export */   "KBY": function() { return /* binding */ SITE_SETTINGS_RECEIVE; },
/* harmony export */   "rZJ": function() { return /* binding */ SITE_SETTINGS_UPDATE; },
/* harmony export */   "xLe": function() { return /* binding */ SITES_RECEIVE; },
/* harmony export */   "M4_": function() { return /* binding */ SITES_REQUEST; },
/* harmony export */   "eTV": function() { return /* binding */ SITES_REQUEST_FAILURE; },
/* harmony export */   "KSQ": function() { return /* binding */ SITES_REQUEST_SUCCESS; },
/* harmony export */   "Khp": function() { return /* binding */ WORDADS_SITE_APPROVE_REQUEST_SUCCESS; },
/* harmony export */   "koV": function() { return /* binding */ WPCOM_HTTP_REQUEST; }
/* harmony export */ });
/* unused harmony exports ACCOUNT_CLOSE, ACCOUNT_CLOSE_SUCCESS, ACCOUNT_RECOVERY_SETTINGS_DELETE, ACCOUNT_RECOVERY_SETTINGS_DELETE_FAILED, ACCOUNT_RECOVERY_SETTINGS_DELETE_SUCCESS, ACCOUNT_RECOVERY_SETTINGS_FETCH, ACCOUNT_RECOVERY_SETTINGS_FETCH_FAILED, ACCOUNT_RECOVERY_SETTINGS_FETCH_SUCCESS, ACCOUNT_RECOVERY_SETTINGS_RESEND_VALIDATION, ACCOUNT_RECOVERY_SETTINGS_RESEND_VALIDATION_FAILED, ACCOUNT_RECOVERY_SETTINGS_RESEND_VALIDATION_SUCCESS, ACCOUNT_RECOVERY_SETTINGS_UPDATE, ACCOUNT_RECOVERY_SETTINGS_UPDATE_FAILED, ACCOUNT_RECOVERY_SETTINGS_UPDATE_SUCCESS, ACCOUNT_RECOVERY_SETTINGS_VALIDATE_PHONE, ACCOUNT_RECOVERY_SETTINGS_VALIDATE_PHONE_FAILED, ACCOUNT_RECOVERY_SETTINGS_VALIDATE_PHONE_SUCCESS, ACTIVE_PROMOTIONS_RECEIVE, ACTIVE_PROMOTIONS_REQUEST, ACTIVE_PROMOTIONS_REQUEST_FAILURE, ACTIVE_PROMOTIONS_REQUEST_SUCCESS, ACTIVITY_LOG_FILTER_SET, ACTIVITY_LOG_FILTER_UPDATE, ADMIN_MENU_RECEIVE, ADMIN_MENU_REQUEST, ALL_DOMAINS_REQUEST, ALL_DOMAINS_REQUEST_FAILURE, ALL_DOMAINS_REQUEST_SUCCESS, ANALYTICS_MULTI_TRACK, ATOMIC_TRANSFER_REQUEST, ATOMIC_TRANSFER_SET, ATOMIC_TRANSFER_INITIATE_TRANSFER, ATOMIC_TRANSFER_REQUEST_LATEST, ATOMIC_TRANSFER_SET_LATEST, ATOMIC_SOFTWARE_INITIATE_INSTALL, ATOMIC_SOFTWARE_REQUEST_STATUS, ATOMIC_SOFTWARE_SET_STATUS, ATOMIC_SOFTWARE_SET_ERROR, AUTOMATED_TRANSFER_ELIGIBILITY_REQUEST, AUTOMATED_TRANSFER_ELIGIBILITY_UPDATE, AUTOMATED_TRANSFER_INITIATE_WITH_PLUGIN_ZIP, AUTOMATED_TRANSFER_STATUS_REQUEST, AUTOMATED_TRANSFER_STATUS_REQUEST_FAILURE, AUTOMATED_TRANSFER_STATUS_SET, BILLING_RECEIPT_EMAIL_SEND, BILLING_RECEIPT_EMAIL_SEND_FAILURE, BILLING_RECEIPT_EMAIL_SEND_SUCCESS, BILLING_TRANSACTION_ERROR_CLEAR, BILLING_TRANSACTION_RECEIVE, BILLING_TRANSACTION_REQUEST, BILLING_TRANSACTION_REQUEST_FAILURE, BILLING_TRANSACTION_REQUEST_SUCCESS, BILLING_TRANSACTIONS_FILTER_SET_APP, BILLING_TRANSACTIONS_FILTER_SET_MONTH, BILLING_TRANSACTIONS_FILTER_SET_PAGE, BILLING_TRANSACTIONS_FILTER_SET_QUERY, BILLING_TRANSACTIONS_RECEIVE, BILLING_TRANSACTIONS_REQUEST, BILLING_TRANSACTIONS_REQUEST_FAILURE, BILLING_TRANSACTIONS_REQUEST_SUCCESS, BREADCRUMB_RESET_LIST, BREADCRUMB_UPDATE_LIST, BREADCRUMB_APPEND_ITEM, COMMENT_COUNTS_REQUEST, COMMENT_COUNTS_UPDATE, COMMENT_REQUEST, COMMENTS_CHANGE_STATUS, COMMENTS_COUNT_INCREMENT, COMMENTS_COUNT_RECEIVE, COMMENTS_DELETE, COMMENTS_EDIT, COMMENTS_LIKE, COMMENTS_LIST_REQUEST, COMMENTS_QUERY_UPDATE, COMMENTS_RECEIVE, COMMENTS_RECEIVE_ERROR, COMMENTS_REPLY_WRITE, COMMENTS_REQUEST, COMMENTS_SET_ACTIVE_REPLY, COMMENTS_UNLIKE, COMMENTS_UPDATES_RECEIVE, COMMENTS_WRITE, COMMENTS_WRITE_ERROR, CONCIERGE_APPOINTMENT_CANCEL, CONCIERGE_APPOINTMENT_CREATE, CONCIERGE_APPOINTMENT_DETAILS_REQUEST, CONCIERGE_APPOINTMENT_DETAILS_UPDATE, CONCIERGE_APPOINTMENT_RESCHEDULE, CONCIERGE_INITIAL_REQUEST, CONCIERGE_INITIAL_UPDATE, CONCIERGE_SIGNUP_FORM_UPDATE, CONCIERGE_UPDATE_BOOKING_STATUS, CONNECTED_APPLICATION_DELETE, CONNECTED_APPLICATION_DELETE_SUCCESS, CONNECTED_APPLICATIONS_RECEIVE, CONNECTED_APPLICATIONS_REQUEST, CONNECTION_LOST, CONNECTION_RESTORED, CONNECTIONS_SET_EXPANDED_SERVICE, COUNTRIES_DOMAINS_FETCH, COUNTRIES_DOMAINS_UPDATED, COUNTRIES_PAYMENTS_FETCH, COUNTRIES_PAYMENTS_UPDATED, COUNTRIES_SMS_FETCH, COUNTRIES_SMS_UPDATED, COUNTRIES_WOOCOMMERCE_FETCH, COUNTRIES_WOOCOMMERCE_UPDATED, COUNTRY_STATES_RECEIVE, COUNTRY_STATES_REQUEST, COUNTRY_STATES_REQUEST_FAILURE, COUNTRY_STATES_REQUEST_SUCCESS, CURRENT_USER_FETCH, DIRECTLY_ASK_QUESTION, DIRECTLY_INITIALIZATION_ERROR, DIRECTLY_INITIALIZATION_START, DIRECTLY_INITIALIZATION_SUCCESS, DOCUMENT_HEAD_LINK_SET, DOCUMENT_HEAD_META_SET, DOCUMENT_HEAD_TITLE_SET, DOCUMENT_HEAD_UNREAD_COUNT_SET, DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_RECEIVE, DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_REQUEST, DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_REQUEST_FAILURE, DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_REQUEST_SUCCESS, DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_UPDATE, DOMAIN_MANAGEMENT_WHOIS_RECEIVE, DOMAIN_MANAGEMENT_WHOIS_REQUEST, DOMAIN_MANAGEMENT_WHOIS_REQUEST_FAILURE, DOMAIN_MANAGEMENT_WHOIS_REQUEST_SUCCESS, DOMAIN_MANAGEMENT_WHOIS_SAVE, DOMAIN_MANAGEMENT_WHOIS_SAVE_FAILURE, DOMAIN_MANAGEMENT_WHOIS_SAVE_SUCCESS, DOMAIN_MANAGEMENT_WHOIS_UPDATE, DOMAIN_TRANSFER_ACCEPT, DOMAIN_TRANSFER_ACCEPT_COMPLETED, DOMAIN_TRANSFER_CANCEL_REQUEST, DOMAIN_TRANSFER_CANCEL_REQUEST_COMPLETED, DOMAIN_TRANSFER_CANCEL_REQUEST_FAILED, DOMAIN_TRANSFER_CODE_REQUEST, DOMAIN_TRANSFER_CODE_REQUEST_COMPLETED, DOMAIN_TRANSFER_CODE_REQUEST_FAILED, DOMAIN_TRANSFER_DECLINE, DOMAIN_TRANSFER_DECLINE_COMPLETED, DOMAIN_TRANSFER_IPS_TAG_SAVE, DOMAIN_TRANSFER_UPDATE, DOMAIN_TRANSFER_UPDATE_LOCK, DOMAIN_WAPI_INFO_FETCH, DOMAIN_WAPI_INFO_FETCH_FAILURE, DOMAIN_WAPI_INFO_FETCH_SUCCESS, DOMAINS_DNS_ADD, DOMAINS_DNS_ADD_COMPLETED, DOMAINS_DNS_ADD_FAILED, DOMAINS_DNS_APPLY_TEMPLATE_COMPLETED, DOMAINS_DNS_DELETE, DOMAINS_DNS_DELETE_COMPLETED, DOMAINS_DNS_DELETE_FAILED, DOMAINS_DNS_FETCH, DOMAINS_DNS_FETCH_COMPLETED, DOMAINS_DNS_FETCH_FAILED, DOMAINS_DNS_UPDATE, DOMAINS_DNS_UPDATE_COMPLETED, DOMAINS_DNS_UPDATE_FAILED, DOMAINS_SITE_REDIRECT_FETCH, DOMAINS_SITE_REDIRECT_FETCH_COMPLETED, DOMAINS_SITE_REDIRECT_FETCH_FAILED, DOMAINS_SITE_REDIRECT_NOTICE_CLOSE, DOMAINS_SITE_REDIRECT_UPDATE, DOMAINS_SITE_REDIRECT_UPDATE_COMPLETED, DOMAINS_SITE_REDIRECT_UPDATE_FAILED, DOMAINS_SUGGESTIONS_RECEIVE, DOMAINS_SUGGESTIONS_REQUEST, DOMAINS_SUGGESTIONS_REQUEST_FAILURE, DOMAINS_SUGGESTIONS_REQUEST_SUCCESS, EDITOR_IFRAME_LOADED, EDITOR_TYPE_REQUEST, EDITOR_TYPE_SET, EMAIL_ACCOUNTS_REQUEST, EMAIL_ACCOUNTS_REQUEST_FAILURE, EMAIL_ACCOUNTS_REQUEST_SUCCESS, EMAIL_FORWARDING_REQUEST, EMAIL_FORWARDING_REQUEST_FAILURE, EMAIL_FORWARDING_REQUEST_SUCCESS, EXPORT_ADVANCED_SETTINGS_FETCH, EXPORT_ADVANCED_SETTINGS_FETCH_FAIL, EXPORT_ADVANCED_SETTINGS_RECEIVE, EXPORT_CLEAR, EXPORT_COMPLETE, EXPORT_FAILURE, EXPORT_MEDIA_REQUEST, EXPORT_POST_TYPE_FIELD_SET, EXPORT_POST_TYPE_SET, EXPORT_START_REQUEST, EXPORT_STARTED, EXPORT_STATUS_FETCH, GOOGLE_MY_BUSINESS_STATS_CHANGE_INTERVAL, GOOGLE_MY_BUSINESS_STATS_FAILURE, GOOGLE_MY_BUSINESS_STATS_RECEIVE, GOOGLE_MY_BUSINESS_STATS_REQUEST, GRAVATAR_RECEIVE_IMAGE_FAILURE, GRAVATAR_UPLOAD_RECEIVE, GRAVATAR_UPLOAD_REQUEST, GRAVATAR_UPLOAD_REQUEST_FAILURE, GRAVATAR_UPLOAD_REQUEST_SUCCESS, GSUITE_USERS_REQUEST, GSUITE_USERS_REQUEST_FAILURE, GSUITE_USERS_REQUEST_SUCCESS, GUIDED_TOUR_PAUSE, GUIDED_TOUR_RESUME, GUTENBERG_IFRAME_ELIGIBLE_SET, HELP_CONTACT_FORM_SITE_SELECT, HELP_TICKET_CONFIGURATION_REQUEST, HELP_TICKET_CONFIGURATION_REQUEST_FAILURE, HELP_TICKET_CONFIGURATION_REQUEST_SUCCESS, HOSTING_CLEAR_CACHE_REQUEST, HOSTING_PHP_VERSION_REQUEST, HOSTING_PHP_VERSION_SET, HOSTING_PHP_VERSION_SET_REQUEST, HOSTING_RESTORE_DATABASE_PASSWORD, HOSTING_SFTP_PASSWORD_RESET, HOSTING_SFTP_USER_CREATE, HOSTING_SFTP_USER_UPDATE, HOSTING_SFTP_USERS_REQUEST, HOSTING_SFTP_USERS_SET, HOSTING_STATIC_FILE_404_REQUEST, HOSTING_STATIC_FILE_404_SET, HOSTING_STATIC_FILE_404_SET_REQUEST, I18N_LANGUAGE_NAMES_ADD, I18N_LANGUAGE_NAMES_REQUEST, I18N_LOCALE_SUGGESTIONS_ADD, I18N_LOCALE_SUGGESTIONS_REQUEST, IMAGE_EDITOR_COMPUTED_CROP, IMAGE_EDITOR_CROP, IMAGE_EDITOR_FLIP, IMAGE_EDITOR_IMAGE_HAS_LOADED, IMAGE_EDITOR_ROTATE_COUNTERCLOCKWISE, IMAGE_EDITOR_SET_ASPECT_RATIO, IMAGE_EDITOR_SET_CROP_BOUNDS, IMAGE_EDITOR_SET_DEFAULT_ASPECT_RATIO, IMAGE_EDITOR_SET_FILE_INFO, IMAGE_EDITOR_STATE_RESET, IMAGE_EDITOR_STATE_RESET_ALL, IMMEDIATE_LOGIN_SAVE_INFO, IMPORTS_AUTHORS_SET_MAPPING, IMPORTS_AUTHORS_START_MAPPING, IMPORTS_IMPORT_CANCEL, IMPORTS_IMPORT_LOCK, IMPORTS_IMPORT_RECEIVE, IMPORTS_IMPORT_RESET, IMPORTS_IMPORT_START, IMPORTS_IMPORT_UNLOCK, IMPORTS_START_IMPORTING, IMPORTS_UPLOAD_COMPLETED, IMPORTS_UPLOAD_FAILED, IMPORTS_UPLOAD_SET_PROGRESS, IMPORTS_UPLOAD_START, INLINE_HELP_POPOVER_HIDE, INLINE_HELP_POPOVER_SHOW, INVITE_ACCEPTED, INVITE_RESEND_REQUEST, INVITE_RESEND_REQUEST_FAILURE, INVITE_RESEND_REQUEST_SUCCESS, INVITES_DELETE_REQUEST, INVITES_DELETE_REQUEST_FAILURE, INVITES_DELETE_REQUEST_SUCCESS, INVITES_REQUEST, INVITES_REQUEST_FAILURE, INVITES_REQUEST_SUCCESS, JETPACK_CHECKOUT_UPDATE_SUPPORT_TICKET_RECEIVE, JETPACK_CHECKOUT_UPDATE_SUPPORT_TICKET_REQUEST, JETPACK_CHECKOUT_UPDATE_SUPPORT_TICKET_REQUEST_FAILURE, JETPACK_CHECKOUT_UPDATE_SUPPORT_TICKET_REQUEST_SUCCESS, JETPACK_CONNECTION_STATUS_RECEIVE, JETPACK_CONNECTION_STATUS_REQUEST, JETPACK_CONNECTION_STATUS_REQUEST_FAILURE, JETPACK_CONNECTION_STATUS_REQUEST_SUCCESS, JETPACK_CREDENTIALS_AUTOCONFIGURE, JETPACK_CREDENTIALS_DELETE, JETPACK_CREDENTIALS_GET, JETPACK_CREDENTIALS_GET_FAILURE, JETPACK_CREDENTIALS_GET_SUCCESS, JETPACK_CREDENTIALS_STORE, JETPACK_CREDENTIALS_UPDATE, JETPACK_CREDENTIALS_UPDATE_FAILURE, JETPACK_CREDENTIALS_UPDATE_PROGRESS_START, JETPACK_CREDENTIALS_UPDATE_PROGRESS_UPDATE, JETPACK_CREDENTIALS_UPDATE_RESET, JETPACK_CREDENTIALS_UPDATE_SUCCESS, JETPACK_MODULE_ACTIVATE, JETPACK_MODULE_ACTIVATE_FAILURE, JETPACK_MODULE_ACTIVATE_SUCCESS, JETPACK_MODULE_DEACTIVATE, JETPACK_MODULE_DEACTIVATE_FAILURE, JETPACK_MODULE_DEACTIVATE_SUCCESS, JETPACK_MODULES_RECEIVE, JETPACK_MODULES_REQUEST, JETPACK_MODULES_REQUEST_FAILURE, JETPACK_MODULES_REQUEST_SUCCESS, JETPACK_PARTNER_PORTAL_LICENSE_COUNTS_RECEIVE, JETPACK_PARTNER_PORTAL_LICENSE_COUNTS_REQUEST, JETPACK_PARTNER_PORTAL_LICENSES_RECEIVE, JETPACK_PARTNER_PORTAL_LICENSES_REQUEST, JETPACK_PARTNER_PORTAL_OAUTH_TOKEN_SET, JETPACK_PARTNER_PORTAL_PARTNER_ACTIVE_PARTNER_KEY_UPDATE, JETPACK_PARTNER_PORTAL_PARTNER_RECEIVE, JETPACK_PARTNER_PORTAL_PARTNER_RECEIVE_ERROR, JETPACK_PARTNER_PORTAL_PARTNER_REQUEST, JETPACK_PRODUCT_INSTALL_REQUEST, JETPACK_PRODUCT_INSTALL_STATUS_RECEIVE, JETPACK_PRODUCT_INSTALL_STATUS_REQUEST, JETPACK_REMOTE_INSTALL, JETPACK_REMOTE_INSTALL_FAILURE, JETPACK_REMOTE_INSTALL_SUCCESS, JETPACK_SCAN_ENQUEUE_REQUEST, JETPACK_SCAN_ENQUEUE_REQUEST_FAILURE, JETPACK_SCAN_ENQUEUE_REQUEST_SUCCESS, JETPACK_SCAN_ENQUEUE_UPDATE, JETPACK_SCAN_HISTORY_REQUEST, JETPACK_SCAN_HISTORY_REQUEST_FAILURE, JETPACK_SCAN_HISTORY_REQUEST_SUCCESS, JETPACK_SCAN_HISTORY_UPDATE, JETPACK_SCAN_REQUEST, JETPACK_SCAN_REQUEST_FAILURE, JETPACK_SCAN_REQUEST_SUCCESS, JETPACK_SCAN_THREAT_COUNTS_REQUEST, JETPACK_SCAN_THREAT_COUNTS_REQUEST_FAILURE, JETPACK_SCAN_THREAT_COUNTS_REQUEST_SUCCESS, JETPACK_SCAN_THREAT_COUNTS_UPDATE, JETPACK_SCAN_THREAT_FIX, JETPACK_SCAN_THREAT_IGNORE, JETPACK_SCAN_THREATS_FIX_ALL, JETPACK_SCAN_THREATS_GET_FIX_STATUS, JETPACK_SCAN_UPDATE, JETPACK_SCAN_UPDATE_THREAT, JETPACK_SCAN_UPDATE_THREAT_COMPLETED, JETPACK_SETTINGS_REQUEST, JETPACK_SETTINGS_SAVE, JETPACK_SETTINGS_SAVE_SUCCESS, JETPACK_SETTINGS_UPDATE, JETPACK_SITE_ALERT_THREAT_FIX, JETPACK_SITE_ALERT_THREAT_IGNORE, JETPACK_SYNC_START_ERROR, JETPACK_SYNC_START_REQUEST, JETPACK_SYNC_START_SUCCESS, JETPACK_SYNC_STATUS_ERROR, JETPACK_SYNC_STATUS_REQUEST, JETPACK_SYNC_STATUS_SUCCESS, JETPACK_USER_CONNECTION_CHANGE_OWNER, JETPACK_USER_CONNECTION_DATA_RECEIVE, JETPACK_USER_CONNECTION_DATA_REQUEST, JETPACK_USER_CONNECTION_DATA_REQUEST_FAILURE, JETPACK_USER_CONNECTION_DATA_REQUEST_SUCCESS, JITM_DISMISS, JITM_FETCH, JITM_SET, KEYRING_CONNECTION_DELETE, KEYRING_CONNECTION_DELETE_FAILURE, KEYRING_CONNECTIONS_RECEIVE, KEYRING_CONNECTIONS_REQUEST, KEYRING_CONNECTIONS_REQUEST_FAILURE, KEYRING_CONNECTIONS_REQUEST_SUCCESS, KEYRING_SERVICES_RECEIVE, KEYRING_SERVICES_REQUEST, KEYRING_SERVICES_REQUEST_FAILURE, KEYRING_SERVICES_REQUEST_SUCCESS, LASAGNA_SOCKET_CONNECTED, LASAGNA_SOCKET_DISCONNECTED, LEGAL_REQUEST, LEGAL_SET, LOGIN_AUTH_ACCOUNT_TYPE_REQUEST, LOGIN_AUTH_ACCOUNT_TYPE_REQUEST_FAILURE, LOGIN_AUTH_ACCOUNT_TYPE_REQUEST_SUCCESS, LOGIN_AUTH_ACCOUNT_TYPE_REQUESTING, LOGIN_AUTH_ACCOUNT_TYPE_RESET, LOGIN_EMAIL_SEND, LOGIN_FORM_UPDATE, LOGIN_REQUEST, LOGIN_REQUEST_FAILURE, LOGIN_REQUEST_SUCCESS, MAGIC_LOGIN_HIDE_REQUEST_FORM, MAGIC_LOGIN_HIDE_REQUEST_NOTICE, MAGIC_LOGIN_REQUEST_AUTH_ERROR, MAGIC_LOGIN_REQUEST_AUTH_FETCH, MAGIC_LOGIN_REQUEST_AUTH_SUCCESS, MAGIC_LOGIN_REQUEST_LOGIN_EMAIL_ERROR, MAGIC_LOGIN_REQUEST_LOGIN_EMAIL_FETCH, MAGIC_LOGIN_REQUEST_LOGIN_EMAIL_SUCCESS, MAGIC_LOGIN_RESET_REQUEST_FORM, MAGIC_LOGIN_SHOW_CHECK_YOUR_EMAIL_PAGE, MAGIC_LOGIN_SHOW_INTERSTITIAL_PAGE, MAGIC_LOGIN_SHOW_LINK_EXPIRED, MAILCHIMP_LISTS_LIST, MAILCHIMP_LISTS_RECEIVE, MAILCHIMP_SETTINGS_LIST, MAILCHIMP_SETTINGS_RECEIVE, MAILCHIMP_SETTINGS_UPDATE, MAILCHIMP_SETTINGS_UPDATE_FAILURE, MAILCHIMP_SETTINGS_UPDATE_SUCCESS, MARKETING_CLICK_UPGRADE_NUDGE, MARKETING_JETPACK_SALE_COUPON_FETCH_FAILURE, MARKETING_JETPACK_SALE_COUPON_FETCH, MARKETING_JETPACK_SALE_COUPON_RECEIVE, MARKETPLACE_BILLING_INTERVAL_SELECT, MARKETPLACE_PLUGIN_INSTALLATION_STATE_CHANGE, MARKETPLACE_PRIMARY_DOMAIN_SELECT, MARKETPLACE_QUEUE_PRODUCT_INSTALL, MEDIA_CLEAR_SITE, MEDIA_ERRORS_CLEAR, MEDIA_ITEM_CREATE, MEDIA_ITEM_EDIT, MEDIA_ITEM_ERRORS_CLEAR, MEDIA_ITEM_ERRORS_SET, MEDIA_ITEM_REQUEST, MEDIA_ITEM_REQUEST_FAILURE, MEDIA_ITEM_REQUEST_SUCCESS, MEDIA_LIBRARY_SELECTED_ITEMS_UPDATE, MEDIA_RECEIVE, MEDIA_REQUEST, MEDIA_REQUEST_FAILURE, MEDIA_REQUEST_SUCCESS, MEDIA_SET_NEXT_PAGE_HANDLE, MEDIA_SET_QUERY, MEDIA_SOURCE_CHANGE, MEMBERSHIPS_EARNINGS_GET, MEMBERSHIPS_EARNINGS_RECEIVE, MEMBERSHIPS_PRODUCT_ADD, MEMBERSHIPS_PRODUCT_ADD_FAILURE, MEMBERSHIPS_PRODUCT_DELETE, MEMBERSHIPS_PRODUCT_DELETE_FAILURE, MEMBERSHIPS_PRODUCT_RECEIVE, MEMBERSHIPS_PRODUCT_UPDATE, MEMBERSHIPS_PRODUCT_UPDATE_FAILURE, MEMBERSHIPS_PRODUCTS_LIST, MEMBERSHIPS_PRODUCTS_RECEIVE, MEMBERSHIPS_SETTINGS, MEMBERSHIPS_SETTINGS_RECEIVE, MEMBERSHIPS_SUBSCRIBERS_LIST, MEMBERSHIPS_SUBSCRIBERS_RECEIVE, MEMBERSHIPS_SUBSCRIPTION_STOP, MEMBERSHIPS_SUBSCRIPTION_STOP_FAILURE, MEMBERSHIPS_SUBSCRIPTION_STOP_SUCCESS, MEMBERSHIPS_SUBSCRIPTIONS_LIST_REQUEST, MEMBERSHIPS_SUBSCRIPTIONS_RECEIVE, MY_SITES_SIDEBAR_SECTION_TOGGLE, MY_SITES_SIDEBAR_SECTIONS_COLLAPSE_ALL, NOTICE_CREATE, NOTICE_REMOVE, NOTIFICATION_SETTINGS_FETCH, NOTIFICATION_SETTINGS_FETCH_COMPLETE, NOTIFICATION_SETTINGS_FETCH_FAILED, NOTIFICATION_SETTINGS_REQUEST, NOTIFICATION_SETTINGS_SAVE, NOTIFICATION_SETTINGS_SAVE_COMPLETE, NOTIFICATION_SETTINGS_SAVE_FAILED, NOTIFICATION_SETTINGS_TOGGLE_SETTING, NOTIFICATION_SETTINGS_UPDATE, NOTIFICATIONS_FORCE_REFRESH, NOTIFICATIONS_UNSEEN_COUNT_SET, OAUTH2_CLIENT_DATA_RECEIVE, ORDER_TRANSACTION_FETCH, ORDER_TRANSACTION_FETCH_ERROR, ORDER_TRANSACTION_SET, P2_CONNECTION_DELETE, P2_CONNECTION_DELETE_FAILURE, P2_CONNECTIONS_RECEIVE, P2_CONNECTIONS_REQUEST, P2_CONNECTIONS_REQUEST_FAILURE, P2_CONNECTIONS_REQUEST_SUCCESS, PLANS_RECEIVE, PLANS_REQUEST, PLANS_REQUEST_FAILURE, PLANS_REQUEST_SUCCESS, PLUGIN_ACTIVATE_REQUEST, PLUGIN_ACTIVATE_REQUEST_FAILURE, PLUGIN_ACTIVATE_REQUEST_SUCCESS, PLUGIN_AUTOUPDATE_DISABLE_REQUEST, PLUGIN_AUTOUPDATE_DISABLE_REQUEST_FAILURE, PLUGIN_AUTOUPDATE_DISABLE_REQUEST_SUCCESS, PLUGIN_AUTOUPDATE_ENABLE_REQUEST, PLUGIN_AUTOUPDATE_ENABLE_REQUEST_FAILURE, PLUGIN_AUTOUPDATE_ENABLE_REQUEST_SUCCESS, PLUGIN_DEACTIVATE_REQUEST, PLUGIN_DEACTIVATE_REQUEST_FAILURE, PLUGIN_DEACTIVATE_REQUEST_SUCCESS, PLUGIN_INSTALL_REQUEST, PLUGIN_INSTALL_REQUEST_FAILURE, PLUGIN_INSTALL_REQUEST_SUCCESS, PLUGIN_NOTICES_REMOVE, PLUGIN_REMOVE_REQUEST, PLUGIN_REMOVE_REQUEST_FAILURE, PLUGIN_REMOVE_REQUEST_SUCCESS, PLUGIN_SETUP_ACTIVATE, PLUGIN_SETUP_CONFIGURE, PLUGIN_SETUP_ERROR, PLUGIN_SETUP_FINISH, PLUGIN_SETUP_INSTALL, PLUGIN_SETUP_INSTRUCTIONS_FETCH, PLUGIN_SETUP_INSTRUCTIONS_RECEIVE, PLUGIN_UPDATE_REQUEST, PLUGIN_UPDATE_REQUEST_FAILURE, PLUGIN_UPDATE_REQUEST_SUCCESS, PLUGIN_UPLOAD, PLUGIN_UPLOAD_CLEAR, PLUGIN_UPLOAD_COMPLETE, PLUGIN_UPLOAD_ERROR, PLUGIN_UPLOAD_PROGRESS, PLUGINS_RECEIVE, PLUGINS_REQUEST, PLUGINS_REQUEST_FAILURE, PLUGINS_REQUEST_SUCCESS, PLUGINS_WPORG_LIST_RECEIVE, PLUGINS_WPORG_LIST_REQUEST, PLUGINS_WPORG_PLUGIN_RECEIVE, PLUGINS_WPORG_PLUGIN_REQUEST, POST_RESTORE_SUCCESS, POST_REVISIONS_AUTHORS_REQUEST, POST_REVISIONS_REQUEST, POST_SAVE_FAILURE, POST_STATS_RECEIVE, POST_STATS_REQUEST, POST_STATS_REQUEST_FAILURE, POST_STATS_REQUEST_SUCCESS, POST_TYPES_RECEIVE, POST_TYPES_REQUEST, POST_TYPES_TAXONOMIES_RECEIVE, POST_TYPES_TAXONOMIES_REQUEST, POST_TYPES_TAXONOMIES_REQUEST_FAILURE, POST_TYPES_TAXONOMIES_REQUEST_SUCCESS, PRODUCTS_LIST_RECEIVE, PRODUCTS_LIST_REQUEST, PRODUCTS_LIST_REQUEST_FAILURE, PUBLICIZE_CONNECTION_CREATE, PUBLICIZE_CONNECTION_CREATE_FAILURE, PUBLICIZE_CONNECTION_DELETE, PUBLICIZE_CONNECTION_DELETE_FAILURE, PUBLICIZE_CONNECTION_RECEIVE, PUBLICIZE_CONNECTION_UPDATE, PUBLICIZE_CONNECTION_UPDATE_FAILURE, PUBLICIZE_CONNECTIONS_RECEIVE, PUBLICIZE_CONNECTIONS_REQUEST, PUBLICIZE_CONNECTIONS_REQUEST_FAILURE, PUBLICIZE_CONNECTIONS_REQUEST_SUCCESS, PUBLICIZE_SHARE, PUBLICIZE_SHARE_ACTION_DELETE, PUBLICIZE_SHARE_ACTION_DELETE_FAILURE, PUBLICIZE_SHARE_ACTION_DELETE_SUCCESS, PUBLICIZE_SHARE_ACTION_SCHEDULE, PUBLICIZE_SHARE_ACTION_SCHEDULE_FAILURE, PUBLICIZE_SHARE_ACTION_SCHEDULE_SUCCESS, PUBLICIZE_SHARE_ACTIONS_PUBLISHED_REQUEST, PUBLICIZE_SHARE_ACTIONS_PUBLISHED_REQUEST_FAILURE, PUBLICIZE_SHARE_ACTIONS_PUBLISHED_REQUEST_SUCCESS, PUBLICIZE_SHARE_ACTIONS_SCHEDULED_REQUEST, PUBLICIZE_SHARE_ACTIONS_SCHEDULED_REQUEST_FAILURE, PUBLICIZE_SHARE_ACTIONS_SCHEDULED_REQUEST_SUCCESS, PUBLICIZE_SHARE_DISMISS, PUBLICIZE_SHARE_FAILURE, PUBLICIZE_SHARE_SUCCESS, PUSH_NOTIFICATIONS_API_NOT_READY, PUSH_NOTIFICATIONS_API_READY, PUSH_NOTIFICATIONS_AUTHORIZE, PUSH_NOTIFICATIONS_BLOCK, PUSH_NOTIFICATIONS_MUST_PROMPT, PUSH_NOTIFICATIONS_RECEIVE_REGISTER_DEVICE, PUSH_NOTIFICATIONS_RECEIVE_UNREGISTER_DEVICE, PUSH_NOTIFICATIONS_TOGGLE_ENABLED, PUSH_NOTIFICATIONS_TOGGLE_UNBLOCK_INSTRUCTIONS, RECEIPT_FETCH, RECEIPT_FETCH_COMPLETED, RECEIPT_FETCH_FAILED, REWIND_ACTIVATE_FAILURE, REWIND_ACTIVATE_REQUEST, REWIND_ACTIVATE_SUCCESS, REWIND_ACTIVITY_SHARE_REQUEST, REWIND_BACKUP, REWIND_BACKUP_DISMISS, REWIND_BACKUP_DISMISS_PROGRESS, REWIND_BACKUP_PROGRESS_REQUEST, REWIND_BACKUP_REQUEST, REWIND_BACKUP_SITE, REWIND_BACKUP_UPDATE_ERROR, REWIND_BACKUP_UPDATE_PROGRESS, REWIND_BACKUPS_REQUEST, REWIND_BACKUPS_SET, REWIND_CAPABILITIES_REQUEST, REWIND_CAPABILITIES_UPDATE, REWIND_CLONE, REWIND_DEACTIVATE_FAILURE, REWIND_DEACTIVATE_REQUEST, REWIND_DEACTIVATE_SUCCESS, REWIND_POLICIES_REQUEST, REWIND_POLICIES_REQUEST_FAILURE, REWIND_POLICIES_REQUEST_SUCCESS, REWIND_POLICIES_SET, REWIND_RESTORE, REWIND_RESTORE_DISMISS, REWIND_RESTORE_DISMISS_PROGRESS, REWIND_RESTORE_PROGRESS_REQUEST, REWIND_RESTORE_REQUEST, REWIND_RESTORE_UPDATE_PROGRESS, REWIND_SIZE_REQUEST, REWIND_SIZE_REQUEST_FAILURE, REWIND_SIZE_REQUEST_SUCCESS, REWIND_SIZE_SET, REWIND_STATE_REQUEST, REWIND_STATE_UPDATE, ROUTE_CLEAR_LAST_NON_EDITOR, SET_MEDIA_EXPORT_DATA, SIGNUP_COMPLETE_RESET, SIGNUP_CURRENT_FLOW_NAME_SET, SIGNUP_DEPENDENCY_STORE_REMOVE_SITE_SLUG, SIGNUP_DEPENDENCY_STORE_UPDATE, SIGNUP_OPTIONAL_DEPENDENCY_SUGGESTED_USERNAME_SET, SIGNUP_PREVIOUS_FLOW_NAME_SET, SIGNUP_FLOW_ADD_EXCLUDED_STEPS, SIGNUP_FLOW_REMOVE_EXCLUDED_STEPS, SIGNUP_FLOW_RESET_EXCLUDED_STEPS, SIGNUP_PROGRESS_ADD_STEP, SIGNUP_PROGRESS_COMPLETE_STEP, SIGNUP_PROGRESS_INVALIDATE_STEP, SIGNUP_PROGRESS_PROCESS_STEP, SIGNUP_PROGRESS_REMOVE_STEP, SIGNUP_PROGRESS_SAVE_STEP, SIGNUP_PROGRESS_SUBMIT_STEP, SIGNUP_STEPS_DESIGN_TYPE_SET, SIGNUP_STEPS_SITE_GOALS_SET, SIGNUP_STEPS_SITE_TITLE_SET, SIGNUP_STEPS_SITE_TYPE_SET, SIGNUP_STEPS_SITE_VERTICAL_SET, SIGNUP_STEPS_SURVEY_SET, SIGNUP_STEPS_SITE_INFO_COLLECTION_UPDATE, SIGNUP_STEPS_SITE_INFO_UPDATE_CURRENT_INDEX, SIGNUP_STEPS_WEBSITE_CONTENT_INITIALIZE_PAGES, SIGNUP_STEPS_WEBSITE_CONTENT_UPDATE_CURRENT_INDEX, SIGNUP_STEPS_WEBSITE_CONTENT_IMAGE_UPLOAD_STARTED, SIGNUP_STEPS_WEBSITE_CONTENT_IMAGE_UPLOAD_COMPLETED, SIGNUP_STEPS_WEBSITE_FIELD_CHANGED, SIGNUP_STEPS_WEBSITE_CONTENT_IMAGE_UPLOAD_FAILED, SIGNUP_STEPS_WEBSITE_CONTENT_IMAGE_REMOVED, SIGNUP_STEPS_WEBSITE_CONTENT_LOGO_UPLOAD_STARTED, SIGNUP_STEPS_WEBSITE_CONTENT_LOGO_UPLOAD_COMPLETED, SIGNUP_STEPS_WEBSITE_CONTENT_LOGO_UPLOAD_FAILED, SIGNUP_STEPS_SOCIAL_PROFILES_UPDATE, SIGNUP_STEPS_SOCIAL_PROFILES_RESET, SIGNUP_STEPS_WEBSITE_CONTENT_REMOVE_LOGO_URL, SIGNUP_STEPS_USER_EXPERIENCE_SET, SIGNUP_VERTICALS_REQUEST, SIGNUP_VERTICALS_SET, SITE_ADDRESS_AVAILABILITY_ERROR, SITE_ADDRESS_AVAILABILITY_ERROR_CLEAR, SITE_ADDRESS_AVAILABILITY_REQUEST, SITE_ADDRESS_AVAILABILITY_SUCCESS, SITE_ADDRESS_CHANGE_REQUEST, SITE_ADDRESS_CHANGE_REQUEST_FAILURE, SITE_ADDRESS_CHANGE_REQUEST_SUCCESS, SITE_CHECKLIST_RECEIVE, SITE_CHECKLIST_REQUEST, SITE_CHECKLIST_TASK_UPDATE, SITE_IMPORTER_IMPORT_FAILURE, SITE_IMPORTER_IMPORT_RESET, SITE_IMPORTER_IMPORT_START, SITE_IMPORTER_IMPORT_SUCCESS, SITE_IMPORTER_IS_SITE_IMPORTABLE_FAILURE, SITE_IMPORTER_IS_SITE_IMPORTABLE_START, SITE_IMPORTER_IS_SITE_IMPORTABLE_SUCCESS, SITE_IMPORTER_VALIDATION_ERROR_SET, SITE_KEYRINGS_DELETE, SITE_KEYRINGS_DELETE_FAILURE, SITE_KEYRINGS_DELETE_SUCCESS, SITE_KEYRINGS_REQUEST, SITE_KEYRINGS_REQUEST_FAILURE, SITE_KEYRINGS_REQUEST_SUCCESS, SITE_KEYRINGS_SAVE_SUCCESS, SITE_KEYRINGS_UPDATE, SITE_KEYRINGS_UPDATE_FAILURE, SITE_KEYRINGS_UPDATE_SUCCESS, SITE_LAUNCH, SITE_PLAN_OWNERSHIP_TRANSFER, SITE_SETTINGS_REQUEST, SITE_SETTINGS_REQUEST_FAILURE, SITE_SETTINGS_REQUEST_SUCCESS, SITE_SETTINGS_SAVE, SITE_SETTINGS_SAVE_FAILURE, SITE_SETTINGS_SAVE_SUCCESS, SITE_STATS_RECEIVE, SITE_STATS_REQUEST, SITE_STATS_REQUEST_FAILURE, SOCIAL_CONNECT_ACCOUNT_REQUEST, SOCIAL_CONNECT_ACCOUNT_REQUEST_FAILURE, SOCIAL_CONNECT_ACCOUNT_REQUEST_SUCCESS, SOCIAL_CREATE_ACCOUNT_REQUEST_FAILURE, SOCIAL_HANDOFF_CONNECT_ACCOUNT, SOCIAL_DISCONNECT_ACCOUNT_REQUEST, SOCIAL_DISCONNECT_ACCOUNT_REQUEST_FAILURE, SOCIAL_DISCONNECT_ACCOUNT_REQUEST_SUCCESS, SOCIAL_LOGIN_REQUEST, SOCIAL_LOGIN_REQUEST_FAILURE, SOCIAL_LOGIN_REQUEST_SUCCESS, STATS_CHART_COUNTS_RECEIVE, STATS_CHART_COUNTS_REQUEST, STATS_RECENT_POST_VIEWS_RECEIVE, STATS_RECENT_POST_VIEWS_REQUEST, STORED_CARDS_ADD_COMPLETED, STORED_CARDS_DELETE, STORED_CARDS_DELETE_COMPLETED, STORED_CARDS_DELETE_FAILED, STORED_CARDS_UPDATE_IS_PRIMARY_COMPLETED, STORED_CARDS_UPDATE_IS_BACKUP_COMPLETED, STORED_CARDS_FETCH, STORED_CARDS_FETCH_COMPLETED, STORED_CARDS_FETCH_FAILED, SUPPORT_ARTICLE_DIALOG_CLOSE, SUPPORT_ARTICLE_DIALOG_OPEN, SUPPORT_SESSION_TRANSITION, TERM_REMOVE, TERMS_RECEIVE, TERMS_REQUEST, TERMS_REQUEST_FAILURE, TERMS_REQUEST_SUCCESS, TIMEZONES_RECEIVE, TIMEZONES_REQUEST, TOS_ACCEPT, TWO_FACTOR_AUTHENTICATION_LOGIN_REQUEST, TWO_FACTOR_AUTHENTICATION_LOGIN_REQUEST_FAILURE, TWO_FACTOR_AUTHENTICATION_LOGIN_REQUEST_SUCCESS, TWO_FACTOR_AUTHENTICATION_SEND_SMS_CODE_REQUEST, TWO_FACTOR_AUTHENTICATION_SEND_SMS_CODE_REQUEST_FAILURE, TWO_FACTOR_AUTHENTICATION_SEND_SMS_CODE_REQUEST_SUCCESS, TWO_FACTOR_AUTHENTICATION_UPDATE_NONCE, URL_ANALYZER_ANALYZE, URL_ANALYZER_ANALYZE_DONE, URL_ANALYZER_ANALYZE_SUCCESS, URL_ANALYZER_ANALYZE_ERROR, URL_ANALYZER_RESET_ERROR, URL_ANALYZER_URL_DATA_UPDATE, USER_LICENSES_RECEIVE, USER_LICENSES_REQUEST, USER_LICENSES_REQUEST_SUCCESS, USER_LICENSES_REQUEST_FAILURE, USER_LICENSES_COUNTS_RECEIVE, USER_LICENSES_COUNTS_REQUEST, USER_LICENSES_COUNTS_REQUEST_SUCCESS, USER_LICENSES_COUNTS_REQUEST_FAILURE, USER_PROFILE_LINKS_ADD, USER_PROFILE_LINKS_ADD_DUPLICATE, USER_PROFILE_LINKS_ADD_FAILURE, USER_PROFILE_LINKS_ADD_MALFORMED, USER_PROFILE_LINKS_ADD_SUCCESS, USER_PROFILE_LINKS_DELETE, USER_PROFILE_LINKS_DELETE_FAILURE, USER_PROFILE_LINKS_DELETE_SUCCESS, USER_PROFILE_LINKS_RECEIVE, USER_PROFILE_LINKS_REQUEST, USER_PROFILE_LINKS_RESET_ERRORS, USER_SETTINGS_REQUEST, USER_SETTINGS_REQUEST_FAILURE, USER_SETTINGS_REQUEST_SUCCESS, USER_SETTINGS_SAVE, USER_SETTINGS_SAVE_FAILURE, USER_SETTINGS_SAVE_SUCCESS, USER_SETTINGS_UNSAVED_CLEAR, USER_SETTINGS_UNSAVED_REMOVE, USER_SETTINGS_UNSAVED_SET, USER_SUGGESTIONS_RECEIVE, USER_SUGGESTIONS_REQUEST, USER_SUGGESTIONS_REQUEST_FAILURE, USER_SUGGESTIONS_REQUEST_SUCCESS, VIDEO_EDITOR_SET_POSTER_URL, VIDEO_EDITOR_SHOW_ERROR, VIDEO_EDITOR_SHOW_UPLOAD_PROGRESS, VIDEO_EDITOR_UPDATE_POSTER, VIDEO_EDITOR_REFRESH_POSTER, WORDADS_EARNINGS_RECEIVE, WORDADS_EARNINGS_REQUEST, WORDADS_SETTINGS_RECEIVE, WORDADS_SETTINGS_REQUEST, WORDADS_SETTINGS_SAVE, WORDADS_SETTINGS_SAVE_FAILURE, WORDADS_SETTINGS_SAVE_SUCCESS, WORDADS_SETTINGS_UPDATE, WORDADS_PAYMENTS_RECEIVE, WORDADS_PAYMENTS_REQUEST, WORDADS_SITE_APPROVE_REQUEST, WORDADS_SITE_APPROVE_REQUEST_DISMISS_ERROR, WORDADS_SITE_APPROVE_REQUEST_DISMISS_SUCCESS, WORDADS_SITE_APPROVE_REQUEST_FAILURE, WORDADS_STATUS_RECEIVE, WORDADS_STATUS_REQUEST */
/**
 * Any new action type should be added to the set of exports below, with the
 * value mirroring its exported name.
 *
 * Please keep this list alphabetized!
 *
 * Unsure how to name an action type? Refer to our guidelines:
 *  - https://wpcalypso.wordpress.com/devdocs/docs/our-approach-to-data.md#actions
 */
const ACCOUNT_CLOSE = 'ACCOUNT_CLOSE';
const ACCOUNT_CLOSE_SUCCESS = 'ACCOUNT_CLOSE_SUCCESS';
const ACCOUNT_RECOVERY_SETTINGS_DELETE = 'ACCOUNT_RECOVERY_SETTINGS_DELETE';
const ACCOUNT_RECOVERY_SETTINGS_DELETE_FAILED = 'ACCOUNT_RECOVERY_SETTINGS_DELETE_FAILED';
const ACCOUNT_RECOVERY_SETTINGS_DELETE_SUCCESS = 'ACCOUNT_RECOVERY_SETTINGS_DELETE_SUCCESS';
const ACCOUNT_RECOVERY_SETTINGS_FETCH = 'ACCOUNT_RECOVERY_SETTINGS_FETCH';
const ACCOUNT_RECOVERY_SETTINGS_FETCH_FAILED = 'ACCOUNT_RECOVERY_SETTINGS_FETCH_FAILED';
const ACCOUNT_RECOVERY_SETTINGS_FETCH_SUCCESS = 'ACCOUNT_RECOVERY_SETTINGS_FETCH_SUCCESS';
const ACCOUNT_RECOVERY_SETTINGS_RESEND_VALIDATION = 'ACCOUNT_RECOVERY_SETTINGS_RESEND_VALIDATION';
const ACCOUNT_RECOVERY_SETTINGS_RESEND_VALIDATION_FAILED = 'ACCOUNT_RECOVERY_SETTINGS_RESEND_VALIDATION_FAILED';
const ACCOUNT_RECOVERY_SETTINGS_RESEND_VALIDATION_SUCCESS = 'ACCOUNT_RECOVERY_SETTINGS_RESEND_VALIDATION_SUCCESS';
const ACCOUNT_RECOVERY_SETTINGS_UPDATE = 'ACCOUNT_RECOVERY_SETTINGS_UPDATE';
const ACCOUNT_RECOVERY_SETTINGS_UPDATE_FAILED = 'ACCOUNT_RECOVERY_SETTINGS_UPDATE_FAILED';
const ACCOUNT_RECOVERY_SETTINGS_UPDATE_SUCCESS = 'ACCOUNT_RECOVERY_SETTINGS_UPDATE_SUCCESS';
const ACCOUNT_RECOVERY_SETTINGS_VALIDATE_PHONE = 'ACCOUNT_RECOVERY_SETTINGS_VALIDATE_PHONE';
const ACCOUNT_RECOVERY_SETTINGS_VALIDATE_PHONE_FAILED = 'ACCOUNT_RECOVERY_SETTINGS_VALIDATE_PHONE_FAILED';
const ACCOUNT_RECOVERY_SETTINGS_VALIDATE_PHONE_SUCCESS = 'ACCOUNT_RECOVERY_SETTINGS_VALIDATE_PHONE_SUCCESS';
const ACTIVE_PROMOTIONS_RECEIVE = 'ACTIVE_PROMOTIONS_RECEIVE';
const ACTIVE_PROMOTIONS_REQUEST = 'ACTIVE_PROMOTIONS_REQUEST';
const ACTIVE_PROMOTIONS_REQUEST_FAILURE = 'ACTIVE_PROMOTIONS_REQUEST_FAILURE';
const ACTIVE_PROMOTIONS_REQUEST_SUCCESS = 'ACTIVE_PROMOTIONS_REQUEST_SUCCESS';
const ACTIVITY_LOG_FILTER_SET = 'ACTIVITY_LOG_FILTER_SET';
const ACTIVITY_LOG_FILTER_UPDATE = 'ACTIVITY_LOG_FILTER_UPDATE';
const ADMIN_MENU_RECEIVE = 'ADMIN_MENU_RECEIVE';
const ADMIN_MENU_REQUEST = 'ADMIN_MENU_REQUEST';
const ALL_DOMAINS_REQUEST = 'ALL_DOMAINS_REQUEST';
const ALL_DOMAINS_REQUEST_FAILURE = 'ALL_DOMAINS_REQUEST_FAILURE';
const ALL_DOMAINS_REQUEST_SUCCESS = 'ALL_DOMAINS_REQUEST_SUCCESS';
const ANALYTICS_EVENT_RECORD = 'ANALYTICS_EVENT_RECORD';
const ANALYTICS_MULTI_TRACK = 'ANALYTICS_MULTI_TRACK';
const ANALYTICS_PAGE_VIEW_RECORD = 'ANALYTICS_PAGE_VIEW_RECORD';
const ANALYTICS_STAT_BUMP = 'ANALYTICS_STAT_BUMP';
const ANALYTICS_TRACKING_ON = 'ANALYTICS_TRACKING_ON';
const ANALYTICS_TRACKS_OPT_OUT = 'ANALYTICS_TRACKS_OPT_OUT';
const APP_BANNER_TOGGLE_VISIBILITY = 'APP_BANNER_TOGGLE_VISIBILITY';
const APP_BANNER_DISMISSED = 'APP_BANNER_DISMISSED';
const APPLY_STORED_STATE = 'APPLY_STORED_STATE';
const ATOMIC_TRANSFER_REQUEST = 'ATOMIC_TRANSFER_REQUEST';
const ATOMIC_TRANSFER_SET = 'ATOMIC_TRANSFER_SET';
const ATOMIC_TRANSFER_INITIATE_TRANSFER = 'ATOMIC_TRANSFER_INITIATE_TRANSFER';
const ATOMIC_TRANSFER_REQUEST_LATEST = 'ATOMIC_TRANSFER_REQUEST_LATEST';
const ATOMIC_TRANSFER_SET_LATEST = 'ATOMIC_TRANSFER_SET_LATEST';
const ATOMIC_SOFTWARE_INITIATE_INSTALL = 'ATOMIC_SOFTWARE_INITIATE_INSTALL';
const ATOMIC_SOFTWARE_REQUEST_STATUS = 'ATOMIC_SOFTWARE_REQUEST_STATUS';
const ATOMIC_SOFTWARE_SET_STATUS = 'ATOMIC_SOFTWARE_SET_STATUS';
const ATOMIC_SOFTWARE_SET_ERROR = 'ATOMIC_SOFTWARE_SET_ERROR';
const AUTOMATED_TRANSFER_ELIGIBILITY_REQUEST = 'AUTOMATED_TRANSFER_ELIGIBILITY_REQUEST';
const AUTOMATED_TRANSFER_ELIGIBILITY_UPDATE = 'AUTOMATED_TRANSFER_ELIGIBILITY_UPDATE';
const AUTOMATED_TRANSFER_INITIATE_WITH_PLUGIN_ZIP = 'AUTOMATED_TRANSFER_INITIATE_WITH_PLUGIN_ZIP';
const AUTOMATED_TRANSFER_STATUS_REQUEST = 'AUTOMATED_TRANSFER_STATUS_REQUEST';
const AUTOMATED_TRANSFER_STATUS_REQUEST_FAILURE = 'AUTOMATED_TRANSFER_STATUS_REQUEST_FAILURE';
const AUTOMATED_TRANSFER_STATUS_SET = 'AUTOMATED_TRANSFER_STATUS_SET';
const BILLING_RECEIPT_EMAIL_SEND = 'BILLING_RECEIPT_EMAIL_SEND';
const BILLING_RECEIPT_EMAIL_SEND_FAILURE = 'BILLING_RECEIPT_EMAIL_SEND_FAILURE';
const BILLING_RECEIPT_EMAIL_SEND_SUCCESS = 'BILLING_RECEIPT_EMAIL_SEND_SUCCESS';
const BILLING_TRANSACTION_ERROR_CLEAR = 'BILLING_TRANSACTION_ERROR_CLEAR';
const BILLING_TRANSACTION_RECEIVE = 'BILLING_TRANSACTION_RECEIVE';
const BILLING_TRANSACTION_REQUEST = 'BILLING_TRANSACTION_REQUEST';
const BILLING_TRANSACTION_REQUEST_FAILURE = 'BILLING_TRANSACTION_REQUEST_FAILURE';
const BILLING_TRANSACTION_REQUEST_SUCCESS = 'BILLING_TRANSACTION_REQUEST_SUCCESS';
const BILLING_TRANSACTIONS_FILTER_SET_APP = 'BILLING_TRANSACTIONS_FILTER_SET_APP';
const BILLING_TRANSACTIONS_FILTER_SET_MONTH = 'BILLING_TRANSACTIONS_FILTER_SET_MONTH';
const BILLING_TRANSACTIONS_FILTER_SET_PAGE = 'BILLING_TRANSACTIONS_FILTER_SET_PAGE';
const BILLING_TRANSACTIONS_FILTER_SET_QUERY = 'BILLING_TRANSACTIONS_FILTER_SET_QUERY';
const BILLING_TRANSACTIONS_RECEIVE = 'BILLING_TRANSACTIONS_RECEIVE';
const BILLING_TRANSACTIONS_REQUEST = 'BILLING_TRANSACTIONS_REQUEST';
const BILLING_TRANSACTIONS_REQUEST_FAILURE = 'BILLING_TRANSACTIONS_REQUEST_FAILURE';
const BILLING_TRANSACTIONS_REQUEST_SUCCESS = 'BILLING_TRANSACTIONS_REQUEST_SUCCESS';
const BREADCRUMB_RESET_LIST = 'BREADCRUMB_RESET_LIST';
const BREADCRUMB_UPDATE_LIST = 'BREADCRUMB_UPDATE_LIST';
const BREADCRUMB_APPEND_ITEM = 'BREADCRUMB_APPEND_ITEM';
const COMMENT_COUNTS_REQUEST = 'COMMENT_COUNTS_REQUEST';
const COMMENT_COUNTS_UPDATE = 'COMMENT_COUNTS_UPDATE';
const COMMENT_REQUEST = 'COMMENT_REQUEST';
const COMMENTS_CHANGE_STATUS = 'COMMENTS_CHANGE_STATUS';
const COMMENTS_COUNT_INCREMENT = 'COMMENTS_COUNT_INCREMENT';
const COMMENTS_COUNT_RECEIVE = 'COMMENTS_COUNT_RECEIVE';
const COMMENTS_DELETE = 'COMMENTS_DELETE';
const COMMENTS_EDIT = 'COMMENTS_EDIT';
const COMMENTS_LIKE = 'COMMENTS_LIKE';
const COMMENTS_LIST_REQUEST = 'COMMENTS_LIST_REQUEST';
const COMMENTS_QUERY_UPDATE = 'COMMENTS_QUERY_UPDATE';
const COMMENTS_RECEIVE = 'COMMENTS_RECEIVE';
const COMMENTS_RECEIVE_ERROR = 'COMMENTS_RECEIVE_ERROR';
const COMMENTS_REPLY_WRITE = 'COMMENTS_REPLY_WRITE';
const COMMENTS_REQUEST = 'COMMENTS_REQUEST';
const COMMENTS_SET_ACTIVE_REPLY = 'COMMENTS_SET_ACTIVE_REPLY';
const COMMENTS_UNLIKE = 'COMMENTS_UNLIKE';
const COMMENTS_UPDATES_RECEIVE = 'COMMENTS_UPDATES_RECEIVE';
const COMMENTS_WRITE = 'COMMENTS_WRITE';
const COMMENTS_WRITE_ERROR = 'COMMENTS_WRITE_ERROR';
const CONCIERGE_APPOINTMENT_CANCEL = 'CONCIERGE_APPOINTMENT_CANCEL';
const CONCIERGE_APPOINTMENT_CREATE = 'CONCIERGE_APPOINTMENT_CREATE';
const CONCIERGE_APPOINTMENT_DETAILS_REQUEST = 'CONCIERGE_APPOINTMENT_DETAILS_REQUEST';
const CONCIERGE_APPOINTMENT_DETAILS_UPDATE = 'CONCIERGE_APPOINTMENT_DETAILS_UPDATE';
const CONCIERGE_APPOINTMENT_RESCHEDULE = 'CONCIERGE_APPOINTMENT_RESCHEDULE';
const CONCIERGE_INITIAL_REQUEST = 'CONCIERGE_INITIAL_REQUEST';
const CONCIERGE_INITIAL_UPDATE = 'CONCIERGE_INITIAL_UPDATE';
const CONCIERGE_SIGNUP_FORM_UPDATE = 'CONCIERGE_SIGNUP_FORM_UPDATE';
const CONCIERGE_UPDATE_BOOKING_STATUS = 'CONCIERGE_UPDATE_BOOKING_STATUS';
const CONNECTED_APPLICATION_DELETE = 'CONNECTED_APPLICATION_DELETE';
const CONNECTED_APPLICATION_DELETE_SUCCESS = 'CONNECTED_APPLICATION_DELETE_SUCCESS';
const CONNECTED_APPLICATIONS_RECEIVE = 'CONNECTED_APPLICATIONS_RECEIVE';
const CONNECTED_APPLICATIONS_REQUEST = 'CONNECTED_APPLICATIONS_REQUEST';
const CONNECTION_LOST = 'CONNECTION_LOST';
const CONNECTION_RESTORED = 'CONNECTION_RESTORED';
const CONNECTIONS_SET_EXPANDED_SERVICE = 'CONNECTIONS_SET_EXPANDED_SERVICE';
const COUNTRIES_DOMAINS_FETCH = 'COUNTRIES_DOMAINS_FETCH';
const COUNTRIES_DOMAINS_UPDATED = 'COUNTRIES_DOMAINS_UPDATED';
const COUNTRIES_PAYMENTS_FETCH = 'COUNTRIES_PAYMENTS_FETCH';
const COUNTRIES_PAYMENTS_UPDATED = 'COUNTRIES_PAYMENTS_UPDATED';
const COUNTRIES_SMS_FETCH = 'COUNTRIES_SMS_FETCH';
const COUNTRIES_SMS_UPDATED = 'COUNTRIES_SMS_UPDATED';
const COUNTRIES_WOOCOMMERCE_FETCH = 'COUNTRIES_WOOCOMMERCE_FETCH';
const COUNTRIES_WOOCOMMERCE_UPDATED = 'COUNTRIES_WOOCOMMERCE_UPDATED';
const COUNTRY_STATES_RECEIVE = 'COUNTRY_STATES_RECEIVE';
const COUNTRY_STATES_REQUEST = 'COUNTRY_STATES_REQUEST';
const COUNTRY_STATES_REQUEST_FAILURE = 'COUNTRY_STATES_REQUEST_FAILURE';
const COUNTRY_STATES_REQUEST_SUCCESS = 'COUNTRY_STATES_REQUEST_SUCCESS';
const CURRENT_USER_FETCH = 'CURRENT_USER_FETCH';
const CURRENT_USER_RECEIVE = 'CURRENT_USER_RECEIVE';
const CURRENT_USER_SET_EMAIL_VERIFIED = 'CURRENT_USER_SET_EMAIL_VERIFIED';
const DIRECTLY_ASK_QUESTION = 'DIRECTLY_ASK_QUESTION';
const DIRECTLY_INITIALIZATION_ERROR = 'DIRECTLY_INITIALIZATION_ERROR';
const DIRECTLY_INITIALIZATION_START = 'DIRECTLY_INITIALIZATION_START';
const DIRECTLY_INITIALIZATION_SUCCESS = 'DIRECTLY_INITIALIZATION_SUCCESS';
const DOCUMENT_HEAD_LINK_SET = 'DOCUMENT_HEAD_LINK_SET';
const DOCUMENT_HEAD_META_SET = 'DOCUMENT_HEAD_META_SET';
const DOCUMENT_HEAD_TITLE_SET = 'DOCUMENT_HEAD_TITLE_SET';
const DOCUMENT_HEAD_UNREAD_COUNT_SET = 'DOCUMENT_HEAD_UNREAD_COUNT_SET';
const DOMAIN_CONTACT_INFO_DISCLOSE = 'DOMAIN_CONTACT_INFO_DISCLOSE';
const DOMAIN_CONTACT_INFO_DISCLOSE_FAILURE = 'DOMAIN_CONTACT_INFO_DISCLOSE_FAILURE';
const DOMAIN_CONTACT_INFO_DISCLOSE_SUCCESS = 'DOMAIN_CONTACT_INFO_DISCLOSE_SUCCESS';
const DOMAIN_CONTACT_INFO_REDACT = 'DOMAIN_CONTACT_INFO_REDACT';
const DOMAIN_CONTACT_INFO_REDACT_FAILURE = 'DOMAIN_CONTACT_INFO_REDACT_FAILURE';
const DOMAIN_CONTACT_INFO_REDACT_SUCCESS = 'DOMAIN_CONTACT_INFO_REDACT_SUCCESS';
const DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_RECEIVE = 'DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_RECEIVE';
const DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_REQUEST = 'DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_REQUEST';
const DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_REQUEST_FAILURE = 'DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_REQUEST_FAILURE';
const DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_REQUEST_SUCCESS = 'DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_REQUEST_SUCCESS';
const DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_UPDATE = 'DOMAIN_MANAGEMENT_CONTACT_DETAILS_CACHE_UPDATE';
const DOMAIN_MANAGEMENT_WHOIS_RECEIVE = 'DOMAIN_MANAGEMENT_WHOIS_RECEIVE';
const DOMAIN_MANAGEMENT_WHOIS_REQUEST = 'DOMAIN_MANAGEMENT_WHOIS_REQUEST';
const DOMAIN_MANAGEMENT_WHOIS_REQUEST_FAILURE = 'DOMAIN_MANAGEMENT_WHOIS_REQUEST_FAILURE';
const DOMAIN_MANAGEMENT_WHOIS_REQUEST_SUCCESS = 'DOMAIN_MANAGEMENT_WHOIS_REQUEST_SUCCESS';
const DOMAIN_MANAGEMENT_WHOIS_SAVE = 'DOMAIN_MANAGEMENT_WHOIS_SAVE';
const DOMAIN_MANAGEMENT_WHOIS_SAVE_FAILURE = 'DOMAIN_MANAGEMENT_WHOIS_SAVE_FAILURE';
const DOMAIN_MANAGEMENT_WHOIS_SAVE_SUCCESS = 'DOMAIN_MANAGEMENT_WHOIS_SAVE_SUCCESS';
const DOMAIN_MANAGEMENT_WHOIS_UPDATE = 'DOMAIN_MANAGEMENT_WHOIS_UPDATE';
const DOMAIN_PRIVACY_DISABLE = 'DOMAIN_PRIVACY_DISABLE';
const DOMAIN_PRIVACY_DISABLE_FAILURE = 'DOMAIN_PRIVACY_DISABLE_FAILURE';
const DOMAIN_PRIVACY_DISABLE_SUCCESS = 'DOMAIN_PRIVACY_DISABLE_SUCCESS';
const DOMAIN_PRIVACY_ENABLE = 'DOMAIN_PRIVACY_ENABLE';
const DOMAIN_PRIVACY_ENABLE_FAILURE = 'DOMAIN_PRIVACY_ENABLE_FAILURE';
const DOMAIN_PRIVACY_ENABLE_SUCCESS = 'DOMAIN_PRIVACY_ENABLE_SUCCESS';
const DOMAIN_TRANSFER_ACCEPT = 'DOMAIN_TRANSFER_ACCEPT';
const DOMAIN_TRANSFER_ACCEPT_COMPLETED = 'DOMAIN_TRANSFER_ACCEPT_COMPLETED';
const DOMAIN_TRANSFER_CANCEL_REQUEST = 'DOMAIN_TRANSFER_CANCEL_REQUEST';
const DOMAIN_TRANSFER_CANCEL_REQUEST_COMPLETED = 'DOMAIN_TRANSFER_CANCEL_REQUEST_COMPLETED';
const DOMAIN_TRANSFER_CANCEL_REQUEST_FAILED = 'DOMAIN_TRANSFER_CANCEL_REQUEST_FAILED';
const DOMAIN_TRANSFER_CODE_REQUEST = 'DOMAIN_TRANSFER_CODE_REQUEST';
const DOMAIN_TRANSFER_CODE_REQUEST_COMPLETED = 'DOMAIN_TRANSFER_CODE_REQUEST_COMPLETED';
const DOMAIN_TRANSFER_CODE_REQUEST_FAILED = 'DOMAIN_TRANSFER_CODE_REQUEST_FAILED';
const DOMAIN_TRANSFER_DECLINE = 'DOMAIN_TRANSFER_DECLINE';
const DOMAIN_TRANSFER_DECLINE_COMPLETED = 'DOMAIN_TRANSFER_DECLINE_COMPLETED';
const DOMAIN_TRANSFER_IPS_TAG_SAVE = 'DOMAIN_TRANSFER_IPS_TAG_SAVE';
const DOMAIN_TRANSFER_UPDATE = 'DOMAIN_TRANSFER_UPDATE';
const DOMAIN_TRANSFER_UPDATE_LOCK = 'DOMAIN_TRANSFER_UPDATE_LOCK';
const DOMAIN_WAPI_INFO_FETCH = 'DOMAIN_WAPI_INFO_FETCH';
const DOMAIN_WAPI_INFO_FETCH_FAILURE = 'DOMAIN_WAPI_INFO_FETCH_FAILURE';
const DOMAIN_WAPI_INFO_FETCH_SUCCESS = 'DOMAIN_WAPI_INFO_FETCH_SUCCESS';
const DOMAINS_DNS_ADD = 'DOMAINS_DNS_ADD';
const DOMAINS_DNS_ADD_COMPLETED = 'DOMAINS_DNS_ADD_COMPLETED';
const DOMAINS_DNS_ADD_FAILED = 'DOMAINS_DNS_ADD_FAILED';
const DOMAINS_DNS_APPLY_TEMPLATE_COMPLETED = 'DOMAINS_DNS_APPLY_TEMPLATE_COMPLETED';
const DOMAINS_DNS_DELETE = 'DOMAINS_DNS_DELETE';
const DOMAINS_DNS_DELETE_COMPLETED = 'DOMAINS_DNS_DELETE_COMPLETED';
const DOMAINS_DNS_DELETE_FAILED = 'DOMAINS_DNS_DELETE_FAILED';
const DOMAINS_DNS_FETCH = 'DOMAINS_DNS_FETCH';
const DOMAINS_DNS_FETCH_COMPLETED = 'DOMAINS_DNS_FETCH_COMPLETED';
const DOMAINS_DNS_FETCH_FAILED = 'DOMAINS_DNS_FETCH_FAILED';
const DOMAINS_DNS_UPDATE = 'DOMAINS_DNS_UPDATE';
const DOMAINS_DNS_UPDATE_COMPLETED = 'DOMAINS_DNS_UPDATE_COMPLETED';
const DOMAINS_DNS_UPDATE_FAILED = 'DOMAINS_DNS_UPDATE_FAILED';
const DOMAINS_SITE_REDIRECT_FETCH = 'DOMAINS_SITE_REDIRECT_FETCH';
const DOMAINS_SITE_REDIRECT_FETCH_COMPLETED = 'DOMAINS_SITE_REDIRECT_FETCH_COMPLETED';
const DOMAINS_SITE_REDIRECT_FETCH_FAILED = 'DOMAINS_SITE_REDIRECT_FETCH_FAILED';
const DOMAINS_SITE_REDIRECT_NOTICE_CLOSE = 'DOMAINS_SITE_REDIRECT_NOTICE_CLOSE';
const DOMAINS_SITE_REDIRECT_UPDATE = 'DOMAINS_SITE_REDIRECT_UPDATE';
const DOMAINS_SITE_REDIRECT_UPDATE_COMPLETED = 'DOMAINS_SITE_REDIRECT_UPDATE_COMPLETED';
const DOMAINS_SITE_REDIRECT_UPDATE_FAILED = 'DOMAINS_SITE_REDIRECT_UPDATE_FAILED';
const DOMAINS_SUGGESTIONS_RECEIVE = 'DOMAINS_SUGGESTIONS_RECEIVE';
const DOMAINS_SUGGESTIONS_REQUEST = 'DOMAINS_SUGGESTIONS_REQUEST';
const DOMAINS_SUGGESTIONS_REQUEST_FAILURE = 'DOMAINS_SUGGESTIONS_REQUEST_FAILURE';
const DOMAINS_SUGGESTIONS_REQUEST_SUCCESS = 'DOMAINS_SUGGESTIONS_REQUEST_SUCCESS';
const EDITOR_IFRAME_LOADED = 'EDITOR_IFRAME_LOADED';
const EDITOR_START = 'EDITOR_START';
const EDITOR_STOP = 'EDITOR_STOP';
const EDITOR_TYPE_REQUEST = 'EDITOR_TYPE_REQUEST';
const EDITOR_TYPE_SET = 'EDITOR_TYPE_SET';
const EMAIL_ACCOUNTS_REQUEST = 'EMAIL_ACCOUNTS_REQUEST';
const EMAIL_ACCOUNTS_REQUEST_FAILURE = 'EMAIL_ACCOUNTS_REQUEST_FAILURE';
const EMAIL_ACCOUNTS_REQUEST_SUCCESS = 'EMAIL_ACCOUNTS_REQUEST_SUCCESS';
const EMAIL_FORWARDING_REQUEST = 'EMAIL_FORWARDING_REQUEST';
const EMAIL_FORWARDING_REQUEST_FAILURE = 'EMAIL_FORWARDING_REQUEST_FAILURE';
const EMAIL_FORWARDING_REQUEST_SUCCESS = 'EMAIL_FORWARDING_REQUEST_SUCCESS';
const EMAIL_VERIFY_REQUEST = 'EMAIL_VERIFY_REQUEST';
const EMAIL_VERIFY_REQUEST_FAILURE = 'EMAIL_VERIFY_REQUEST_FAILURE';
const EMAIL_VERIFY_REQUEST_SUCCESS = 'EMAIL_VERIFY_REQUEST_SUCCESS';
const EMAIL_VERIFY_STATE_RESET = 'EMAIL_VERIFY_STATE_RESET';
const EXPORT_ADVANCED_SETTINGS_FETCH = 'EXPORT_ADVANCED_SETTINGS_FETCH';
const EXPORT_ADVANCED_SETTINGS_FETCH_FAIL = 'EXPORT_ADVANCED_SETTINGS_FETCH_FAIL';
const EXPORT_ADVANCED_SETTINGS_RECEIVE = 'EXPORT_ADVANCED_SETTINGS_RECEIVE';
const EXPORT_CLEAR = 'EXPORT_CLEAR';
const EXPORT_COMPLETE = 'EXPORT_COMPLETE';
const EXPORT_FAILURE = 'EXPORT_FAILURE';
const EXPORT_MEDIA_REQUEST = 'EXPORT_MEDIA_REQUEST';
const EXPORT_POST_TYPE_FIELD_SET = 'EXPORT_POST_TYPE_FIELD_SET';
const EXPORT_POST_TYPE_SET = 'EXPORT_POST_TYPE_SET';
const EXPORT_START_REQUEST = 'EXPORT_START_REQUEST';
const EXPORT_STARTED = 'EXPORT_STARTED';
const EXPORT_STATUS_FETCH = 'EXPORT_STATUS_FETCH';
const GOOGLE_MY_BUSINESS_STATS_CHANGE_INTERVAL = 'GOOGLE_MY_BUSINESS_STATS_CHANGE_INTERVAL';
const GOOGLE_MY_BUSINESS_STATS_FAILURE = 'GOOGLE_MY_BUSINESS_STATS_FAILURE';
const GOOGLE_MY_BUSINESS_STATS_RECEIVE = 'GOOGLE_MY_BUSINESS_STATS_RECEIVE';
const GOOGLE_MY_BUSINESS_STATS_REQUEST = 'GOOGLE_MY_BUSINESS_STATS_REQUEST';
const GRAVATAR_RECEIVE_IMAGE_FAILURE = 'GRAVATAR_RECEIVE_IMAGE_FAILURE';
const GRAVATAR_UPLOAD_RECEIVE = 'GRAVATAR_UPLOAD_RECEIVE';
const GRAVATAR_UPLOAD_REQUEST = 'GRAVATAR_UPLOAD_REQUEST';
const GRAVATAR_UPLOAD_REQUEST_FAILURE = 'GRAVATAR_UPLOAD_REQUEST_FAILURE';
const GRAVATAR_UPLOAD_REQUEST_SUCCESS = 'GRAVATAR_UPLOAD_REQUEST_SUCCESS';
const GSUITE_USERS_REQUEST = 'GSUITE_USERS_REQUEST';
const GSUITE_USERS_REQUEST_FAILURE = 'GSUITE_USERS_REQUEST_FAILURE';
const GSUITE_USERS_REQUEST_SUCCESS = 'GSUITE_USERS_REQUEST_SUCCESS';
const GUIDED_TOUR_PAUSE = 'GUIDED_TOUR_PAUSE';
const GUIDED_TOUR_RESUME = 'GUIDED_TOUR_RESUME';
const GUIDED_TOUR_UPDATE = 'GUIDED_TOUR_UPDATE';
const GUTENBERG_IFRAME_ELIGIBLE_SET = 'GUTENBERG_IFRAME_ELIGIBLE_SET';
const HAPPYCHAT_BLUR = 'HAPPYCHAT_BLUR';
const HAPPYCHAT_FOCUS = 'HAPPYCHAT_FOCUS';
const HAPPYCHAT_IO_INIT = 'HAPPYCHAT_IO_INIT';
const HAPPYCHAT_IO_RECEIVE_ACCEPT = 'HAPPYCHAT_IO_RECEIVE_ACCEPT';
const HAPPYCHAT_IO_RECEIVE_CONNECT = 'HAPPYCHAT_IO_RECEIVE_CONNECT';
const HAPPYCHAT_IO_RECEIVE_DISCONNECT = 'HAPPYCHAT_IO_RECEIVE_DISCONNECT';
const HAPPYCHAT_IO_RECEIVE_ERROR = 'HAPPYCHAT_IO_RECEIVE_ERROR';
const HAPPYCHAT_IO_RECEIVE_INIT = 'HAPPYCHAT_IO_RECEIVE_INIT';
const HAPPYCHAT_IO_RECEIVE_LOCALIZED_SUPPORT = 'HAPPYCHAT_IO_RECEIVE_LOCALIZED_SUPPORT';
const HAPPYCHAT_IO_RECEIVE_MESSAGE = 'HAPPYCHAT_IO_RECEIVE_MESSAGE';
const HAPPYCHAT_IO_RECEIVE_MESSAGE_OPTIMISTIC = 'HAPPYCHAT_IO_RECEIVE_MESSAGE_OPTIMISTIC';
const HAPPYCHAT_IO_RECEIVE_MESSAGE_UPDATE = 'HAPPYCHAT_IO_RECEIVE_MESSAGE_UPDATE';
const HAPPYCHAT_IO_RECEIVE_RECONNECTING = 'HAPPYCHAT_IO_RECEIVE_RECONNECTING';
const HAPPYCHAT_IO_RECEIVE_STATUS = 'HAPPYCHAT_IO_RECEIVE_STATUS';
const HAPPYCHAT_IO_RECEIVE_TOKEN = 'HAPPYCHAT_IO_RECEIVE_TOKEN';
const HAPPYCHAT_IO_RECEIVE_UNAUTHORIZED = 'HAPPYCHAT_IO_RECEIVE_UNAUTHORIZED';
const HAPPYCHAT_IO_REQUEST_TRANSCRIPT = 'HAPPYCHAT_IO_REQUEST_TRANSCRIPT';
const HAPPYCHAT_IO_REQUEST_TRANSCRIPT_RECEIVE = 'HAPPYCHAT_IO_REQUEST_TRANSCRIPT_RECEIVE';
const HAPPYCHAT_IO_SEND_MESSAGE_EVENT = 'HAPPYCHAT_IO_SEND_MESSAGE_EVENT';
const HAPPYCHAT_IO_SEND_MESSAGE_LOG = 'HAPPYCHAT_IO_SEND_MESSAGE_LOG';
const HAPPYCHAT_IO_SEND_MESSAGE_MESSAGE = 'HAPPYCHAT_IO_SEND_MESSAGE_MESSAGE';
const HAPPYCHAT_IO_SEND_MESSAGE_USERINFO = 'HAPPYCHAT_IO_SEND_MESSAGE_USERINFO';
const HAPPYCHAT_IO_SEND_PREFERENCES = 'HAPPYCHAT_IO_SEND_PREFERENCES';
const HAPPYCHAT_IO_SEND_TYPING = 'HAPPYCHAT_IO_SEND_TYPING';
const HAPPYCHAT_IO_SET_CUSTOM_FIELDS = 'HAPPYCHAT_IO_SET_CUSTOM_FIELDS';
const HAPPYCHAT_MINIMIZING = 'HAPPYCHAT_MINIMIZING';
const HAPPYCHAT_OPEN = 'HAPPYCHAT_OPEN';
const HAPPYCHAT_SET_CURRENT_MESSAGE = 'HAPPYCHAT_SET_CURRENT_MESSAGE';
const HAPPYCHAT_SET_USER_CONFIG = 'HAPPYCHAT_SET_USER_CONFIG';
const HELP_CENTER_VISIBLE = 'HELP_CENTER_VISIBLE';
const HELP_CONTACT_FORM_SITE_SELECT = 'HELP_CONTACT_FORM_SITE_SELECT';
const HELP_TICKET_CONFIGURATION_REQUEST = 'HELP_TICKET_CONFIGURATION_REQUEST';
const HELP_TICKET_CONFIGURATION_REQUEST_FAILURE = 'HELP_TICKET_CONFIGURATION_REQUEST_FAILURE';
const HELP_TICKET_CONFIGURATION_REQUEST_SUCCESS = 'HELP_TICKET_CONFIGURATION_REQUEST_SUCCESS';
const HOSTING_CLEAR_CACHE_REQUEST = 'HOSTING_CLEAR_CACHE_REQUEST';
const HOSTING_PHP_VERSION_REQUEST = 'HOSTING_PHP_VERSION_REQUEST';
const HOSTING_PHP_VERSION_SET = 'HOSTING_PHP_VERSION_SET';
const HOSTING_PHP_VERSION_SET_REQUEST = 'HOSTING_PHP_VERSION_SET_REQUEST';
const HOSTING_RESTORE_DATABASE_PASSWORD = 'HOSTING_RESTORE_DATABASE_PASSWORD';
const HOSTING_SFTP_PASSWORD_RESET = 'HOSTING_SFTP_PASSWORD_RESET';
const HOSTING_SFTP_USER_CREATE = 'HOSTING_SFTP_USER_CREATE';
const HOSTING_SFTP_USER_UPDATE = 'HOSTING_SFTP_USER_UPDATE';
const HOSTING_SFTP_USERS_REQUEST = 'HOSTING_SFTP_USERS_REQUEST';
const HOSTING_SFTP_USERS_SET = 'HOSTING_SFTP_USERS_SET';
const HOSTING_STATIC_FILE_404_REQUEST = 'HOSTING_STATIC_FILE_404_REQUEST';
const HOSTING_STATIC_FILE_404_SET = 'HOSTING_STATIC_FILE_404_SET';
const HOSTING_STATIC_FILE_404_SET_REQUEST = 'HOSTING_STATIC_FILE_404_SET_REQUEST';
const I18N_LANGUAGE_NAMES_ADD = 'I18N_LANGUAGE_NAMES_ADD';
const I18N_LANGUAGE_NAMES_REQUEST = 'I18N_LANGUAGE_NAMES_REQUEST';
const I18N_LOCALE_SUGGESTIONS_ADD = 'I18N_LOCALE_SUGGESTIONS_ADD';
const I18N_LOCALE_SUGGESTIONS_REQUEST = 'I18N_LOCALE_SUGGESTIONS_REQUEST';
const IMAGE_EDITOR_COMPUTED_CROP = 'IMAGE_EDITOR_COMPUTED_CROP';
const IMAGE_EDITOR_CROP = 'IMAGE_EDITOR_CROP';
const IMAGE_EDITOR_FLIP = 'IMAGE_EDITOR_FLIP';
const IMAGE_EDITOR_IMAGE_HAS_LOADED = 'IMAGE_EDITOR_IMAGE_HAS_LOADED';
const IMAGE_EDITOR_ROTATE_COUNTERCLOCKWISE = 'IMAGE_EDITOR_ROTATE_COUNTERCLOCKWISE';
const IMAGE_EDITOR_SET_ASPECT_RATIO = 'IMAGE_EDITOR_SET_ASPECT_RATIO';
const IMAGE_EDITOR_SET_CROP_BOUNDS = 'IMAGE_EDITOR_SET_CROP_BOUNDS';
const IMAGE_EDITOR_SET_DEFAULT_ASPECT_RATIO = 'IMAGE_EDITOR_SET_DEFAULT_ASPECT_RATIO';
const IMAGE_EDITOR_SET_FILE_INFO = 'IMAGE_EDITOR_SET_FILE_INFO';
const IMAGE_EDITOR_STATE_RESET = 'IMAGE_EDITOR_STATE_RESET';
const IMAGE_EDITOR_STATE_RESET_ALL = 'IMAGE_EDITOR_STATE_RESET_ALL';
const IMMEDIATE_LOGIN_SAVE_INFO = 'IMMEDIATE_LOGIN_SAVE_INFO';
const IMPORTS_AUTHORS_SET_MAPPING = 'IMPORTS_AUTHORS_SET_MAPPING';
const IMPORTS_AUTHORS_START_MAPPING = 'IMPORTS_AUTHORS_START_MAPPING';
const IMPORTS_IMPORT_CANCEL = 'IMPORTS_IMPORT_CANCEL';
const IMPORTS_IMPORT_LOCK = 'IMPORTS_IMPORT_LOCK';
const IMPORTS_IMPORT_RECEIVE = 'IMPORTS_IMPORT_RECEIVE';
const IMPORTS_IMPORT_RESET = 'IMPORTS_IMPORT_RESET';
const IMPORTS_IMPORT_START = 'IMPORTS_IMPORT_START';
const IMPORTS_IMPORT_UNLOCK = 'IMPORTS_IMPORT_UNLOCK';
const IMPORTS_START_IMPORTING = 'IMPORTS_START_IMPORTING';
const IMPORTS_UPLOAD_COMPLETED = 'IMPORTS_UPLOAD_COMPLETED';
const IMPORTS_UPLOAD_FAILED = 'IMPORTS_UPDLOAD_FAILED';
const IMPORTS_UPLOAD_SET_PROGRESS = 'IMPORTS_UPLOAD_SET_PROGRESS';
const IMPORTS_UPLOAD_START = 'IMPORTS_UPLOAD_START';
const INLINE_HELP_POPOVER_HIDE = 'INLINE_HELP_POPOVER_HIDE';
const INLINE_HELP_POPOVER_SHOW = 'INLINE_HELP_POPOVER_SHOW';
const INVITE_ACCEPTED = 'INVITE_ACCEPTED';
const INVITE_RESEND_REQUEST = 'INVITE_RESEND_REQUEST';
const INVITE_RESEND_REQUEST_FAILURE = 'INVITE_RESEND_REQUEST_FAILURE';
const INVITE_RESEND_REQUEST_SUCCESS = 'INVITE_RESEND_REQUEST_SUCCESS';
const INVITES_DELETE_REQUEST = 'INVITES_DELETE_REQUEST';
const INVITES_DELETE_REQUEST_FAILURE = 'INVITES_DELETE_REQUEST_FAILURE';
const INVITES_DELETE_REQUEST_SUCCESS = 'INVITES_DELETE_REQUEST_SUCCESS';
const INVITES_REQUEST = 'INVITES_REQUEST';
const INVITES_REQUEST_FAILURE = 'INVITES_REQUEST_FAILURE';
const INVITES_REQUEST_SUCCESS = 'INVITES_REQUEST_SUCCESS';
const JETPACK_CHECKOUT_UPDATE_SUPPORT_TICKET_RECEIVE = 'JETPACK_CHECKOUT_UPDATE_SUPPORT_TICKET_RECEIVE';
const JETPACK_CHECKOUT_UPDATE_SUPPORT_TICKET_REQUEST = 'JETPACK_CHECKOUT_UPDATE_SUPPORT_TICKET_REQUEST';
const JETPACK_CHECKOUT_UPDATE_SUPPORT_TICKET_REQUEST_FAILURE = 'JETPACK_CHECKOUT_UPDATE_SUPPORT_TICKET_REQUEST_FAILURE';
const JETPACK_CHECKOUT_UPDATE_SUPPORT_TICKET_REQUEST_SUCCESS = 'JETPACK_CHECKOUT_UPDATE_SUPPORT_TICKET_REQUEST_SUCCESS';
const JETPACK_CONNECTION_STATUS_RECEIVE = 'JETPACK_CONNECTION_STATUS_RECEIVE';
const JETPACK_CONNECTION_STATUS_REQUEST = 'JETPACK_CONNECTION_STATUS_REQUEST';
const JETPACK_CONNECTION_STATUS_REQUEST_FAILURE = 'JETPACK_CONNECTION_STATUS_REQUEST_FAILURE';
const JETPACK_CONNECTION_STATUS_REQUEST_SUCCESS = 'JETPACK_CONNECTION_STATUS_REQUEST_SUCCESS';
const JETPACK_CREDENTIALS_AUTOCONFIGURE = 'JETPACK_CREDENTIALS_AUTOCONFIGURE';
const JETPACK_CREDENTIALS_DELETE = 'JETPACK_CREDENTIALS_DELETE';
const JETPACK_CREDENTIALS_GET = 'JETPACK_CREDENTIALS_GET';
const JETPACK_CREDENTIALS_GET_FAILURE = 'JETPACK_CREDENTIALS_GET_FAILURE';
const JETPACK_CREDENTIALS_GET_SUCCESS = 'JETPACK_CREDENTIALS_GET_SUCCESS';
const JETPACK_CREDENTIALS_STORE = 'JETPACK_CREDENTIALS_STORE';
const JETPACK_CREDENTIALS_UPDATE = 'JETPACK_CREDENTIALS_UPDATE';
const JETPACK_CREDENTIALS_UPDATE_FAILURE = 'JETPACK_CREDENTIALS_UPDATE_FAILURE';
const JETPACK_CREDENTIALS_UPDATE_PROGRESS_START = 'JETPACK_CREDENTIALS_UPDATE_PROGRESS_START';
const JETPACK_CREDENTIALS_UPDATE_PROGRESS_UPDATE = 'JETPACK_CREDENTIALS_UPDATE_PROGRESS_UPDATE';
const JETPACK_CREDENTIALS_UPDATE_RESET = 'JETPACK_CREDENTIALS_UPDATE_RESET';
const JETPACK_CREDENTIALS_UPDATE_SUCCESS = 'JETPACK_CREDENTIALS_UPDATE_SUCCESS';
const JETPACK_DISCONNECT_RECEIVE = 'JETPACK_DISCONNECT_RECEIVE';
const JETPACK_SITE_DISCONNECT_REQUEST = 'JETPACK_SITE_DISCONNECT_REQUEST';
const JETPACK_MODULE_ACTIVATE = 'JETPACK_MODULE_ACTIVATE';
const JETPACK_MODULE_ACTIVATE_FAILURE = 'JETPACK_MODULE_ACTIVATE_FAILURE';
const JETPACK_MODULE_ACTIVATE_SUCCESS = 'JETPACK_MODULE_ACTIVATE_SUCCESS';
const JETPACK_MODULE_DEACTIVATE = 'JETPACK_MODULE_DEACTIVATE';
const JETPACK_MODULE_DEACTIVATE_FAILURE = 'JETPACK_MODULE_DEACTIVATE_FAILURE';
const JETPACK_MODULE_DEACTIVATE_SUCCESS = 'JETPACK_MODULE_DEACTIVATE_SUCCESS';
const JETPACK_MODULES_RECEIVE = 'JETPACK_MODULES_RECEIVE';
const JETPACK_MODULES_REQUEST = 'JETPACK_MODULES_REQUEST';
const JETPACK_MODULES_REQUEST_FAILURE = 'JETPACK_MODULES_REQUEST_FAILURE';
const JETPACK_MODULES_REQUEST_SUCCESS = 'JETPACK_MODULES_REQUEST_SUCCESS';
const JETPACK_PARTNER_PORTAL_LICENSE_COUNTS_RECEIVE = 'JETPACK_PARTNER_PORTAL_LICENSE_COUNTS_RECEIVE';
const JETPACK_PARTNER_PORTAL_LICENSE_COUNTS_REQUEST = 'JETPACK_PARTNER_PORTAL_LICENSE_COUNTS_REQUEST';
const JETPACK_PARTNER_PORTAL_LICENSES_RECEIVE = 'JETPACK_PARTNER_PORTAL_LICENSES_RECEIVE';
const JETPACK_PARTNER_PORTAL_LICENSES_REQUEST = 'JETPACK_PARTNER_PORTAL_LICENSES_REQUEST';
const JETPACK_PARTNER_PORTAL_OAUTH_TOKEN_SET = 'JETPACK_PARTNER_PORTAL_OAUTH_TOKEN_SET';
const JETPACK_PARTNER_PORTAL_PARTNER_ACTIVE_PARTNER_KEY_UPDATE = 'JETPACK_PARTNER_PORTAL_PARTNER_ACTIVE_PARTNER_KEY_UPDATE';
const JETPACK_PARTNER_PORTAL_PARTNER_RECEIVE = 'JETPACK_PARTNER_PORTAL_PARTNER_RECEIVE';
const JETPACK_PARTNER_PORTAL_PARTNER_RECEIVE_ERROR = 'JETPACK_PARTNER_PORTAL_PARTNER_RECEIVE_ERROR';
const JETPACK_PARTNER_PORTAL_PARTNER_REQUEST = 'JETPACK_PARTNER_PORTAL_PARTNER_REQUEST';
const JETPACK_PRODUCT_INSTALL_REQUEST = 'JETPACK_PRODUCT_INSTALL_REQUEST';
const JETPACK_PRODUCT_INSTALL_STATUS_RECEIVE = 'JETPACK_PRODUCT_INSTALL_STATUS_RECEIVE';
const JETPACK_PRODUCT_INSTALL_STATUS_REQUEST = 'JETPACK_PRODUCT_INSTALL_STATUS_REQUEST';
const JETPACK_REMOTE_INSTALL = 'JETPACK_REMOTE_INSTALL';
const JETPACK_REMOTE_INSTALL_FAILURE = 'JETPACK_REMOTE_INSTALL_FAILURE';
const JETPACK_REMOTE_INSTALL_SUCCESS = 'JETPACK_REMOTE_INSTALL_SUCCESS';
const JETPACK_SCAN_ENQUEUE_REQUEST = 'JETPACK_SCAN_ENQUEUE_REQUEST';
const JETPACK_SCAN_ENQUEUE_REQUEST_FAILURE = 'JETPACK_SCAN_ENQUEUE_REQUEST_FAILURE';
const JETPACK_SCAN_ENQUEUE_REQUEST_SUCCESS = 'JETPACK_SCAN_ENQUEUE_REQUEST_SUCCESS';
const JETPACK_SCAN_ENQUEUE_UPDATE = 'JETPACK_SCAN_ENQUEUE_UPDATE';
const JETPACK_SCAN_HISTORY_REQUEST = 'JETPACK_SCAN_HISTORY_REQUEST';
const JETPACK_SCAN_HISTORY_REQUEST_FAILURE = 'JETPACK_SCAN_HISTORY_REQUEST_FAILURE';
const JETPACK_SCAN_HISTORY_REQUEST_SUCCESS = 'JETPACK_SCAN_HISTORY_REQUEST_SUCCESS';
const JETPACK_SCAN_HISTORY_UPDATE = 'JETPACK_SCAN_HISTORY_UPDATE';
const JETPACK_SCAN_REQUEST = 'JETPACK_SCAN_REQUEST';
const JETPACK_SCAN_REQUEST_FAILURE = 'JETPACK_SCAN_REQUEST_FAILURE';
const JETPACK_SCAN_REQUEST_SUCCESS = 'JETPACK_SCAN_REQUEST_SUCCESS';
const JETPACK_SCAN_THREAT_COUNTS_REQUEST = 'JETPACK_SCAN_THREAT_COUNTS_REQUEST';
const JETPACK_SCAN_THREAT_COUNTS_REQUEST_FAILURE = 'JETPACK_SCAN_THREAT_COUNTS_REQUEST_FAILURE';
const JETPACK_SCAN_THREAT_COUNTS_REQUEST_SUCCESS = 'JETPACK_SCAN_THREAT_COUNTS_REQUEST_SUCCESS';
const JETPACK_SCAN_THREAT_COUNTS_UPDATE = 'JETPACK_SCAN_THREAT_COUNTS_UPDATE';
const JETPACK_SCAN_THREAT_FIX = 'JETPACK_SCAN_THREAT_FIX';
const JETPACK_SCAN_THREAT_IGNORE = 'JETPACK_SCAN_THREAT_IGNORE';
const JETPACK_SCAN_THREATS_FIX_ALL = 'JETPACK_SCAN_THREATS_FIX_ALL';
const JETPACK_SCAN_THREATS_GET_FIX_STATUS = 'JETPACK_SCAN_THREATS_GET_FIX_STATUS';
const JETPACK_SCAN_UPDATE = 'JETPACK_SCAN_UPDATE';
const JETPACK_SCAN_UPDATE_THREAT = 'JETPACK_SCAN_UPDATE_THREAT';
const JETPACK_SCAN_UPDATE_THREAT_COMPLETED = 'JETPACK_SCAN_UPDATE_THREAT_COMPLETED';
const JETPACK_SETTINGS_REQUEST = 'JETPACK_SETTINGS_REQUEST';
const JETPACK_SETTINGS_SAVE = 'JETPACK_SETTINGS_SAVE';
const JETPACK_SETTINGS_SAVE_SUCCESS = 'JETPACK_SETTINGS_SAVE_SUCCESS';
const JETPACK_SETTINGS_UPDATE = 'JETPACK_SETTINGS_UPDATE';
const JETPACK_SITE_ALERT_THREAT_FIX = 'JETPACK_SITE_ALERT_THREAT_FIX';
const JETPACK_SITE_ALERT_THREAT_IGNORE = 'JETPACK_SITE_ALERT_THREAT_IGNORE';
const JETPACK_SYNC_START_ERROR = 'JETPACK_SYNC_START_ERROR';
const JETPACK_SYNC_START_REQUEST = 'JETPACK_SYNC_START_REQUEST';
const JETPACK_SYNC_START_SUCCESS = 'JETPACK_SYNC_START_SUCCESS';
const JETPACK_SYNC_STATUS_ERROR = 'JETPACK_SYNC_STATUS_ERROR';
const JETPACK_SYNC_STATUS_REQUEST = 'JETPACK_SYNC_STATUS_REQUEST';
const JETPACK_SYNC_STATUS_SUCCESS = 'JETPACK_SYNC_STATUS_SUCCESS';
const JETPACK_USER_CONNECTION_CHANGE_OWNER = 'JETPACK_USER_CONNECTION_CHANGE_OWNER';
const JETPACK_USER_CONNECTION_DATA_RECEIVE = 'JETPACK_USER_CONNECTION_DATA_RECEIVE';
const JETPACK_USER_CONNECTION_DATA_REQUEST = 'JETPACK_USER_CONNECTION_DATA_REQUEST';
const JETPACK_USER_CONNECTION_DATA_REQUEST_FAILURE = 'JETPACK_USER_CONNECTION_DATA_REQUEST_FAILURE';
const JETPACK_USER_CONNECTION_DATA_REQUEST_SUCCESS = 'JETPACK_USER_CONNECTION_DATA_REQUEST_SUCCESS';
const JITM_DISMISS = 'JITM_DISMISS';
const JITM_FETCH = 'JITM_FETCH';
const JITM_SET = 'JITM_SET';
const KEYRING_CONNECTION_DELETE = 'KEYRING_CONNECTION_DELETE';
const KEYRING_CONNECTION_DELETE_FAILURE = 'KEYRING_CONNECTION_DELETE_FAILURE';
const KEYRING_CONNECTIONS_RECEIVE = 'KEYRING_CONNECTIONS_RECEIVE';
const KEYRING_CONNECTIONS_REQUEST = 'KEYRING_CONNECTIONS_REQUEST';
const KEYRING_CONNECTIONS_REQUEST_FAILURE = 'KEYRING_CONNECTIONS_REQUEST_FAILURE';
const KEYRING_CONNECTIONS_REQUEST_SUCCESS = 'KEYRING_CONNECTIONS_REQUEST_SUCCESS';
const KEYRING_SERVICES_RECEIVE = 'KEYRING_SERVICES_RECEIVE';
const KEYRING_SERVICES_REQUEST = 'KEYRING_SERVICES_REQUEST';
const KEYRING_SERVICES_REQUEST_FAILURE = 'KEYRING_SERVICES_REQUEST_FAILURE';
const KEYRING_SERVICES_REQUEST_SUCCESS = 'KEYRING_SERVICES_REQUEST_SUCCESS';
const LASAGNA_SOCKET_CONNECTED = 'LASAGNA_SOCKET_CONNECTED';
const LASAGNA_SOCKET_DISCONNECTED = 'LASAGNA_SOCKET_DISCONNECTED';
const LAYOUT_FOCUS_SET = 'LAYOUT_FOCUS_SET';
const LAYOUT_NEXT_FOCUS_ACTIVATE = 'LAYOUT_NEXT_FOCUS_ACTIVATE';
const LAYOUT_NEXT_FOCUS_SET = 'LAYOUT_NEXT_FOCUS_SET';
const LEGAL_REQUEST = 'LEGAL_REQUEST';
const LEGAL_SET = 'LEGAL_SET';
const LOCALE_SET = 'LOCALE_SET';
const LOGIN_AUTH_ACCOUNT_TYPE_REQUEST = 'LOGIN_AUTH_ACCOUNT_TYPE_REQUEST';
const LOGIN_AUTH_ACCOUNT_TYPE_REQUEST_FAILURE = 'LOGIN_AUTH_ACCOUNT_TYPE_REQUEST_FAILURE';
const LOGIN_AUTH_ACCOUNT_TYPE_REQUEST_SUCCESS = 'LOGIN_AUTH_ACCOUNT_TYPE_REQUEST_SUCCESS';
const LOGIN_AUTH_ACCOUNT_TYPE_REQUESTING = 'LOGIN_AUTH_ACCOUNT_TYPE_REQUESTING';
const LOGIN_AUTH_ACCOUNT_TYPE_RESET = 'LOGIN_AUTH_ACCOUNT_TYPE_RESET';
const LOGIN_EMAIL_SEND = 'LOGIN_EMAIL_SEND';
const LOGIN_FORM_UPDATE = 'LOGIN_FORM_UPDATE';
const LOGIN_REQUEST = 'LOGIN_REQUEST';
const LOGIN_REQUEST_FAILURE = 'LOGIN_REQUEST_FAILURE';
const LOGIN_REQUEST_SUCCESS = 'LOGIN_REQUEST_SUCCESS';
const MAGIC_LOGIN_HIDE_REQUEST_FORM = 'MAGIC_LOGIN_HIDE_REQUEST_FORM';
const MAGIC_LOGIN_HIDE_REQUEST_NOTICE = 'MAGIC_LOGIN_HIDE_REQUEST_NOTICE';
const MAGIC_LOGIN_REQUEST_AUTH_ERROR = 'MAGIC_LOGIN_REQUEST_AUTH_ERROR';
const MAGIC_LOGIN_REQUEST_AUTH_FETCH = 'MAGIC_LOGIN_REQUEST_AUTH_FETCH';
const MAGIC_LOGIN_REQUEST_AUTH_SUCCESS = 'MAGIC_LOGIN_REQUEST_AUTH_SUCCESS';
const MAGIC_LOGIN_REQUEST_LOGIN_EMAIL_ERROR = 'MAGIC_LOGIN_REQUEST_LOGIN_EMAIL_ERROR';
const MAGIC_LOGIN_REQUEST_LOGIN_EMAIL_FETCH = 'MAGIC_LOGIN_REQUEST_LOGIN_EMAIL_FETCH';
const MAGIC_LOGIN_REQUEST_LOGIN_EMAIL_SUCCESS = 'MAGIC_LOGIN_REQUEST_LOGIN_EMAIL_SUCCESS';
const MAGIC_LOGIN_RESET_REQUEST_FORM = 'MAGIC_LOGIN_RESET_REQUEST_FORM';
const MAGIC_LOGIN_SHOW_CHECK_YOUR_EMAIL_PAGE = 'MAGIC_LOGIN_SHOW_CHECK_YOUR_EMAIL_PAGE';
const MAGIC_LOGIN_SHOW_INTERSTITIAL_PAGE = 'MAGIC_LOGIN_SHOW_INTERSTITIAL_PAGE';
const MAGIC_LOGIN_SHOW_LINK_EXPIRED = 'MAGIC_LOGIN_SHOW_LINK_EXPIRED';
const MAILCHIMP_LISTS_LIST = 'MAILCHIMP_LISTS_LIST';
const MAILCHIMP_LISTS_RECEIVE = 'MAILCHIMP_LISTS_RECEIVE';
const MAILCHIMP_SETTINGS_LIST = 'MAILCHIMP_SETTINGS_LIST';
const MAILCHIMP_SETTINGS_RECEIVE = 'MAILCHIMP_SETTINGS_RECEIVE';
const MAILCHIMP_SETTINGS_UPDATE = 'MAILCHIMP_SETTINGS_UPDATE';
const MAILCHIMP_SETTINGS_UPDATE_FAILURE = 'MAILCHIMP_SETTINGS_UPDATE_FAILURE';
const MAILCHIMP_SETTINGS_UPDATE_SUCCESS = 'MAILCHIMP_SETTINGS_UPDATE_SUCCESS';
const MARKETING_CLICK_UPGRADE_NUDGE = 'MARKETING_CLICK_UPGRADE_NUDGE';
const MARKETING_JETPACK_SALE_COUPON_FETCH_FAILURE = 'MARKETING_JETPACK_SALE_COUPON_FETCH_FAILURE';
const MARKETING_JETPACK_SALE_COUPON_FETCH = 'MARKETING_JETPACK_SALE_COUPON_FETCH';
const MARKETING_JETPACK_SALE_COUPON_RECEIVE = 'MARKETING_JETPACK_SALE_COUPON_RECEIVE';
const MARKETPLACE_BILLING_INTERVAL_SELECT = 'MARKETPLACE_BILLING_INTERVAL_SELECT';
const MARKETPLACE_PLUGIN_INSTALLATION_STATE_CHANGE = 'MARKETPLACE_PLUGIN_INSTALLATION_STATE_CHANGE';
const MARKETPLACE_PRIMARY_DOMAIN_SELECT = 'MARKETPLACE_PRIMARY_DOMAIN_SELECT';
const MARKETPLACE_QUEUE_PRODUCT_INSTALL = 'MARKETPLACE_QUEUE_PRODUCT_INSTALL';
const MASTERBAR_TOGGLE_VISIBILITY = 'MASTERBAR_TOGGLE_VISIBILITY';
const MEDIA_CLEAR_SITE = 'MEDIA_CLEAR_SITE';
const MEDIA_DELETE = 'MEDIA_DELETE';
const MEDIA_ERRORS_CLEAR = 'MEDIA_ERRORS_CLEAR';
const MEDIA_ITEM_CREATE = 'MEDIA_ITEM_CREATE';
const MEDIA_ITEM_EDIT = 'MEDIA_ITEM_EDIT';
const MEDIA_ITEM_ERRORS_CLEAR = 'MEDIA_ITEM_ERRORS_CLEAR';
const MEDIA_ITEM_ERRORS_SET = 'MEDIA_ITEM_ERRORS_SET';
const MEDIA_ITEM_REQUEST = 'MEDIA_ITEM_REQUEST';
const MEDIA_ITEM_REQUEST_FAILURE = 'MEDIA_ITEM_REQUEST_FAILURE';
const MEDIA_ITEM_REQUEST_SUCCESS = 'MEDIA_ITEM_REQUEST_SUCCESS';
const MEDIA_LIBRARY_SELECTED_ITEMS_UPDATE = 'MEDIA_LIBRARY_SELECTED_ITEMS_UPDATE';
const MEDIA_MODAL_VIEW_SET = 'MEDIA_MODAL_VIEW_SET';
const MEDIA_RECEIVE = 'MEDIA_RECEIVE';
const MEDIA_REQUEST = 'MEDIA_REQUEST';
const MEDIA_REQUEST_FAILURE = 'MEDIA_REQUEST_FAILURE';
const MEDIA_REQUEST_SUCCESS = 'MEDIA_REQUEST_SUCCESS';
const MEDIA_SET_NEXT_PAGE_HANDLE = 'MEDIA_SET_NEXT_PAGE_HANDLE';
const MEDIA_SET_QUERY = 'MEDIA_SET_QUERY';
const MEDIA_SOURCE_CHANGE = 'MEDIA_SOURCE_CHANGE';
const MEMBERSHIPS_EARNINGS_GET = 'MEMBERSHIPS_EARNINGS_GET';
const MEMBERSHIPS_EARNINGS_RECEIVE = 'MEMBERSHIPS_EARNINGS_RECEIVE';
const MEMBERSHIPS_PRODUCT_ADD = 'MEMBERSHIPS_PRODUCT_ADD';
const MEMBERSHIPS_PRODUCT_ADD_FAILURE = 'MEMBERSHIPS_PRODUCT_ADD_FAILURE';
const MEMBERSHIPS_PRODUCT_DELETE = 'MEMBERSHIPS_PRODUCT_DELETE';
const MEMBERSHIPS_PRODUCT_DELETE_FAILURE = 'MEMBERSHIPS_PRODUCT_DELETE_FAILURE';
const MEMBERSHIPS_PRODUCT_RECEIVE = 'MEMBERSHIPS_PRODUCT_RECEIVE';
const MEMBERSHIPS_PRODUCT_UPDATE = 'MEMBERSHIPS_PRODUCT_UPDATE';
const MEMBERSHIPS_PRODUCT_UPDATE_FAILURE = 'MEMBERSHIPS_PRODUCT_UPDATE_FAILURE';
const MEMBERSHIPS_PRODUCTS_LIST = 'MEMBERSHIPS_PRODUCTS_LIST';
const MEMBERSHIPS_PRODUCTS_RECEIVE = 'MEMBERSHIPS_PRODUCTS_RECEIVE';
const MEMBERSHIPS_SETTINGS = 'MEMBERSHIPS_SETTINGS';
const MEMBERSHIPS_SETTINGS_RECEIVE = 'MEMBERSHIPS_SETTINGS_RECEIVE';
const MEMBERSHIPS_SUBSCRIBERS_LIST = 'MEMBERSHIPS_SUBSCRIBERS_LIST';
const MEMBERSHIPS_SUBSCRIBERS_RECEIVE = 'MEMBERSHIPS_SUBSCRIBERS_RECEIVE';
const MEMBERSHIPS_SUBSCRIPTION_STOP = 'MEMBERSHIPS_SUBSCRIPTION_STOP';
const MEMBERSHIPS_SUBSCRIPTION_STOP_FAILURE = 'MEMBERSHIPS_SUBSCRIPTION_STOP_FAILURE';
const MEMBERSHIPS_SUBSCRIPTION_STOP_SUCCESS = 'MEMBERSHIPS_SUBSCRIPTION_STOP_SUCCESS';
const MEMBERSHIPS_SUBSCRIPTIONS_LIST_REQUEST = 'MEMBERSHIPS_SUBSCRIPTIONS_LIST_REQUEST';
const MEMBERSHIPS_SUBSCRIPTIONS_RECEIVE = 'MEMBERSHIPS_SUBSCRIPTIONS_RECEIVE';
const MY_SITES_SIDEBAR_SECTION_TOGGLE = 'MY_SITES_SIDEBAR_SECTION_TOGGLE';
const MY_SITES_SIDEBAR_SECTIONS_COLLAPSE_ALL = 'MY_SITES_SIDEBAR_SECTIONS_COLLAPSE_ALL';
const NOTICE_CREATE = 'NOTICE_CREATE';
const NOTICE_REMOVE = 'NOTICE_REMOVE';
const NOTIFICATION_SETTINGS_FETCH = 'NOTIFICATION_SETTINGS_FETCH';
const NOTIFICATION_SETTINGS_FETCH_COMPLETE = 'NOTIFICATION_SETTINGS_FETCH_COMPLETE';
const NOTIFICATION_SETTINGS_FETCH_FAILED = 'NOTIFICATION_SETTINGS_FETCH_FAILED';
const NOTIFICATION_SETTINGS_REQUEST = 'NOTIFICATION_SETTINGS_REQUEST';
const NOTIFICATION_SETTINGS_SAVE = 'NOTIFICATION_SETTINGS_SAVE';
const NOTIFICATION_SETTINGS_SAVE_COMPLETE = 'NOTIFICATION_SETTINGS_SAVE_COMPLETE';
const NOTIFICATION_SETTINGS_SAVE_FAILED = 'NOTIFICATION_SETTINGS_SAVE_FAILED';
const NOTIFICATION_SETTINGS_TOGGLE_SETTING = 'NOTIFICATION_SETTINGS_TOGGLE_SETTING';
const NOTIFICATION_SETTINGS_UPDATE = 'NOTIFICATION_SETTINGS_UPDATE';
const NOTIFICATIONS_FORCE_REFRESH = 'NOTIFICATIONS_FORCE_REFRESH';
const NOTIFICATIONS_PANEL_TOGGLE = 'NOTIFICATIONS_PANEL_TOGGLE';
const NOTIFICATIONS_UNSEEN_COUNT_SET = 'NOTIFICATIONS_UNSEEN_COUNT_SET';
const OAUTH2_CLIENT_DATA_RECEIVE = 'OAUTH2_CLIENT_DATA_RECEIVE';
const ORDER_TRANSACTION_FETCH = 'ORDER_TRANSACTION_FETCH';
const ORDER_TRANSACTION_FETCH_ERROR = 'ORDER_TRANSACTION_FETCH_ERROR';
const ORDER_TRANSACTION_SET = 'ORDER_TRANSACTION_SET';
const P2_CONNECTION_DELETE = 'P2_CONNECTION_DELETE';
const P2_CONNECTION_DELETE_FAILURE = 'P2_CONNECTION_DELETE_FAILURE';
const P2_CONNECTIONS_RECEIVE = 'P2_CONNECTIONS_RECEIVE';
const P2_CONNECTIONS_REQUEST = 'P2_CONNECTIONS_REQUEST';
const P2_CONNECTIONS_REQUEST_FAILURE = 'P2_CONNECTIONS_REQUEST_FAILURE';
const P2_CONNECTIONS_REQUEST_SUCCESS = 'P2_CONNECTIONS_REQUEST_SUCCESS';
const PLANS_RECEIVE = 'PLANS_RECEIVE';
const PLANS_REQUEST = 'PLANS_REQUEST';
const PLANS_REQUEST_FAILURE = 'PLANS_REQUEST_FAILURE';
const PLANS_REQUEST_SUCCESS = 'PLANS_REQUEST_SUCCESS';
const PLUGIN_ACTIVATE_REQUEST = 'PLUGINS_ACTIVATE_REQUEST';
const PLUGIN_ACTIVATE_REQUEST_FAILURE = 'PLUGINS_ACTIVATE_REQUEST_FAILURE';
const PLUGIN_ACTIVATE_REQUEST_SUCCESS = 'PLUGINS_ACTIVATE_REQUEST_SUCCESS';
const PLUGIN_AUTOUPDATE_DISABLE_REQUEST = 'PLUGIN_AUTOUPDATE_DISABLE_REQUEST';
const PLUGIN_AUTOUPDATE_DISABLE_REQUEST_FAILURE = 'PLUGIN_AUTOUPDATE_DISABLE_REQUEST_FAILURE';
const PLUGIN_AUTOUPDATE_DISABLE_REQUEST_SUCCESS = 'PLUGIN_AUTOUPDATE_DISABLE_REQUEST_SUCCESS';
const PLUGIN_AUTOUPDATE_ENABLE_REQUEST = 'PLUGIN_AUTOUPDATE_ENABLE_REQUEST';
const PLUGIN_AUTOUPDATE_ENABLE_REQUEST_FAILURE = 'PLUGIN_AUTOUPDATE_ENABLE_REQUEST_FAILURE';
const PLUGIN_AUTOUPDATE_ENABLE_REQUEST_SUCCESS = 'PLUGIN_AUTOUPDATE_ENABLE_REQUEST_SUCCESS';
const PLUGIN_DEACTIVATE_REQUEST = 'PLUGIN_DEACTIVATE_REQUEST';
const PLUGIN_DEACTIVATE_REQUEST_FAILURE = 'PLUGIN_DEACTIVATE_REQUEST_FAILURE';
const PLUGIN_DEACTIVATE_REQUEST_SUCCESS = 'PLUGIN_DEACTIVATE_REQUEST_SUCCESS';
const PLUGIN_INSTALL_REQUEST = 'PLUGIN_INSTALL_REQUEST';
const PLUGIN_INSTALL_REQUEST_FAILURE = 'PLUGIN_INSTALL_REQUEST_FAILURE';
const PLUGIN_INSTALL_REQUEST_SUCCESS = 'PLUGIN_INSTALL_REQUEST_SUCCESS';
const PLUGIN_NOTICES_REMOVE = 'PLUGIN_NOTICES_REMOVE';
const PLUGIN_REMOVE_REQUEST = 'PLUGIN_REMOVE_REQUEST';
const PLUGIN_REMOVE_REQUEST_FAILURE = 'PLUGIN_REMOVE_REQUEST_FAILURE';
const PLUGIN_REMOVE_REQUEST_SUCCESS = 'PLUGIN_REMOVE_REQUEST_SUCCESS';
const PLUGIN_SETUP_ACTIVATE = 'PLUGIN_SETUP_ACTIVATE';
const PLUGIN_SETUP_CONFIGURE = 'PLUGIN_SETUP_CONFIGURE';
const PLUGIN_SETUP_ERROR = 'PLUGIN_SETUP_ERROR';
const PLUGIN_SETUP_FINISH = 'PLUGIN_SETUP_FINISH';
const PLUGIN_SETUP_INSTALL = 'PLUGIN_SETUP_INSTALL';
const PLUGIN_SETUP_INSTRUCTIONS_FETCH = 'PLUGIN_SETUP_INSTRUCTIONS_FETCH';
const PLUGIN_SETUP_INSTRUCTIONS_RECEIVE = 'PLUGIN_SETUP_INSTRUCTIONS_RECEIVE';
const PLUGIN_UPDATE_REQUEST = 'PLUGINS_UPDATE_REQUEST';
const PLUGIN_UPDATE_REQUEST_FAILURE = 'PLUGIN_UPDATE_REQUEST_FAILURE';
const PLUGIN_UPDATE_REQUEST_SUCCESS = 'PLUGIN_UPDATE_REQUEST_SUCCESS';
const PLUGIN_UPLOAD = 'PLUGIN_UPLOAD';
const PLUGIN_UPLOAD_CLEAR = 'PLUGIN_UPLOAD_CLEAR';
const PLUGIN_UPLOAD_COMPLETE = 'PLUGIN_UPLOAD_COMPLETE';
const PLUGIN_UPLOAD_ERROR = 'PLUGIN_UPLOAD_ERROR';
const PLUGIN_UPLOAD_PROGRESS = 'PLUGIN_UPLOAD_PROGRESS';
const PLUGINS_RECEIVE = 'PLUGINS_RECEIVE';
const PLUGINS_REQUEST = 'PLUGINS_REQUEST';
const PLUGINS_REQUEST_FAILURE = 'PLUGINS_REQUEST_FAILURE';
const PLUGINS_REQUEST_SUCCESS = 'PLUGINS_REQUEST_SUCCESS';
const PLUGINS_WPORG_LIST_RECEIVE = 'PLUGINS_WPORG_LIST_RECEIVE';
const PLUGINS_WPORG_LIST_REQUEST = 'PLUGINS_WPORG_LIST_REQUEST';
const PLUGINS_WPORG_PLUGIN_RECEIVE = 'PLUGINS_WPORG_PLUGIN_RECEIVE';
const PLUGINS_WPORG_PLUGIN_REQUEST = 'PLUGINS_WPORG_PLUGIN_REQUEST';
const POST_COUNTS_RECEIVE = 'POST_COUNTS_RECEIVE';
const POST_COUNTS_REQUEST = 'POST_COUNTS_REQUEST';
const POST_COUNTS_REQUEST_FAILURE = 'POST_COUNTS_REQUEST_FAILURE';
const POST_COUNTS_REQUEST_SUCCESS = 'POST_COUNTS_REQUEST_SUCCESS';
const POST_COUNTS_RESET_INTERNAL_STATE = 'POST_COUNTS_RESET_INTERNAL_STATE';
const POST_DELETE = 'POST_DELETE';
const POST_DELETE_FAILURE = 'POST_DELETE_FAILURE';
const POST_DELETE_SUCCESS = 'POST_DELETE_SUCCESS';
const POST_EDIT = 'POST_EDIT';
const POST_LIKE = 'POST_LIKE';
const POST_LIKES_ADD_LIKER = 'POST_LIKES_ADD_LIKER';
const POST_LIKES_RECEIVE = 'POST_LIKES_RECEIVE';
const POST_LIKES_REMOVE_LIKER = 'POST_LIKES_REMOVE_LIKER';
const POST_LIKES_REQUEST = 'POST_LIKES_REQUEST';
const POST_REQUEST = 'POST_REQUEST';
const POST_REQUEST_FAILURE = 'POST_REQUEST_FAILURE';
const POST_REQUEST_SUCCESS = 'POST_REQUEST_SUCCESS';
const POST_RESTORE = 'POST_RESTORE';
const POST_RESTORE_FAILURE = 'POST_RESTORE_FAILURE';
const POST_RESTORE_SUCCESS = 'POST_RESTORE_SUCCESS';
const POST_REVISION_AUTHORS_RECEIVE = 'POST_REVISION_AUTHORS_RECEIVE';
const POST_REVISIONS_AUTHORS_REQUEST = 'POST_REVISIONS_AUTHORS_REQUEST';
const POST_REVISIONS_DIALOG_CLOSE = 'POST_REVISIONS_DIALOG_CLOSE';
const POST_REVISIONS_DIALOG_OPEN = 'POST_REVISIONS_DIALOG_OPEN';
const POST_REVISIONS_DIFF_SPLIT_VIEW = 'POST_REVISIONS_DIFF_SPLIT_VIEW';
const POST_REVISIONS_DIFF_UNIFY_VIEW = 'POST_REVISIONS_DIFF_UNIFY_VIEW';
const POST_REVISIONS_RECEIVE = 'POST_REVISIONS_RECEIVE';
const POST_REVISIONS_REQUEST = 'POST_REVISIONS_REQUEST';
const POST_REVISIONS_SELECT = 'POST_REVISIONS_SELECT';
const POST_SAVE = 'POST_SAVE';
const POST_SAVE_FAILURE = 'POST_SAVE_FAILURE';
const POST_SAVE_SUCCESS = 'POST_SAVE_SUCCESS';
const POST_STATS_RECEIVE = 'POST_STATS_RECEIVE';
const POST_STATS_REQUEST = 'POST_STATS_REQUEST';
const POST_STATS_REQUEST_FAILURE = 'POST_STATS_REQUEST_FAILURE';
const POST_STATS_REQUEST_SUCCESS = 'POST_STATS_REQUEST_SUCCESS';
const POST_TYPE_LIST_SHARE_PANEL_HIDE = 'POST_TYPE_LIST_SHARE_PANEL_HIDE';
const POST_TYPE_LIST_SHARE_PANEL_TOGGLE = 'POST_TYPE_LIST_SHARE_PANEL_TOGGLE';
const POST_TYPES_RECEIVE = 'POST_TYPES_RECEIVE';
const POST_TYPES_REQUEST = 'POST_TYPES_REQUEST';
const POST_TYPES_TAXONOMIES_RECEIVE = 'POST_TYPES_TAXONOMIES_RECEIVE';
const POST_TYPES_TAXONOMIES_REQUEST = 'POST_TYPES_TAXONOMIES_REQUEST';
const POST_TYPES_TAXONOMIES_REQUEST_FAILURE = 'POST_TYPES_TAXONOMIES_REQUEST_FAILURE';
const POST_TYPES_TAXONOMIES_REQUEST_SUCCESS = 'POST_TYPES_TAXONOMIES_REQUEST_SUCCESS';
const POST_UNLIKE = 'POST_UNLIKE';
const POSTS_RECEIVE = 'POSTS_RECEIVE';
const POSTS_REQUEST = 'POSTS_REQUEST';
const POSTS_REQUEST_FAILURE = 'POSTS_REQUEST_FAILURE';
const POSTS_REQUEST_SUCCESS = 'POSTS_REQUEST_SUCCESS';
const PREFERENCES_FETCH = 'PREFERENCES_FETCH';
const PREFERENCES_FETCH_FAILURE = 'PREFERENCES_FETCH_FAILURE';
const PREFERENCES_FETCH_SUCCESS = 'PREFERENCES_FETCH_SUCCESS';
const PREFERENCES_RECEIVE = 'PREFERENCES_RECEIVE';
const PREFERENCES_SAVE_SUCCESS = 'PREFERENCES_SAVE_SUCCESS';
const PREFERENCES_SET = 'PREFERENCES_SET';
const PREVIEW_URL_CLEAR = 'PREVIEW_URL_CLEAR';
const PREVIEW_URL_SET = 'PREVIEW_URL_SET';
const PRODUCTS_LIST_RECEIVE = 'PRODUCTS_LIST_RECEIVE';
const PRODUCTS_LIST_REQUEST = 'PRODUCTS_LIST_REQUEST';
const PRODUCTS_LIST_REQUEST_FAILURE = 'PRODUCTS_LIST_REQUEST_FAILURE';
const PUBLICIZE_CONNECTION_CREATE = 'PUBLICIZE_CONNECTION_CREATE';
const PUBLICIZE_CONNECTION_CREATE_FAILURE = 'PUBLICIZE_CONNECTION_CREATE_FAILURE';
const PUBLICIZE_CONNECTION_DELETE = 'PUBLICIZE_CONNECTION_DELETE';
const PUBLICIZE_CONNECTION_DELETE_FAILURE = 'PUBLICIZE_CONNECTION_DELETE_FAILURE';
const PUBLICIZE_CONNECTION_RECEIVE = 'PUBLICIZE_CONNECTION_RECEIVE';
const PUBLICIZE_CONNECTION_UPDATE = 'PUBLICIZE_CONNECTION_UPDATE';
const PUBLICIZE_CONNECTION_UPDATE_FAILURE = 'PUBLICIZE_CONNECTION_UPDATE_FAILURE';
const PUBLICIZE_CONNECTIONS_RECEIVE = 'PUBLICIZE_CONNECTIONS_RECEIVE';
const PUBLICIZE_CONNECTIONS_REQUEST = 'PUBLICIZE_CONNECTIONS_REQUEST';
const PUBLICIZE_CONNECTIONS_REQUEST_FAILURE = 'PUBLICIZE_CONNECTIONS_REQUEST_FAILURE';
const PUBLICIZE_CONNECTIONS_REQUEST_SUCCESS = 'PUBLICIZE_CONNECTIONS_REQUEST_SUCCESS';
const PUBLICIZE_SHARE = 'PUBLICIZE_SHARE';
const PUBLICIZE_SHARE_ACTION_DELETE = 'PUBLICIZE_SHARE_ACTION_DELETE';
const PUBLICIZE_SHARE_ACTION_DELETE_FAILURE = 'PUBLICIZE_SHARE_ACTION_DELETE_FAILURE';
const PUBLICIZE_SHARE_ACTION_DELETE_SUCCESS = 'PUBLICIZE_SHARE_ACTION_DELETE_SUCCESS';
const PUBLICIZE_SHARE_ACTION_SCHEDULE = 'PUBLICIZE_SHARE_ACTION_SCHEDULE';
const PUBLICIZE_SHARE_ACTION_SCHEDULE_FAILURE = 'PUBLICIZE_SHARE_ACTION_SCHEDULE_FAILURE';
const PUBLICIZE_SHARE_ACTION_SCHEDULE_SUCCESS = 'PUBLICIZE_SHARE_ACTION_SCHEDULE_SUCCESS';
const PUBLICIZE_SHARE_ACTIONS_PUBLISHED_REQUEST = 'PUBLICIZE_SHARE_ACTIONS_PUBLISHED_REQUEST';
const PUBLICIZE_SHARE_ACTIONS_PUBLISHED_REQUEST_FAILURE = 'PUBLICIZE_SHARE_ACTIONS_PUBLISHED_REQUEST_FAILURE';
const PUBLICIZE_SHARE_ACTIONS_PUBLISHED_REQUEST_SUCCESS = 'PUBLICIZE_SHARE_ACTIONS_PUBLISHED_REQUEST_SUCCESS';
const PUBLICIZE_SHARE_ACTIONS_SCHEDULED_REQUEST = 'PUBLICIZE_SHARE_ACTIONS_SCHEDULED_REQUEST';
const PUBLICIZE_SHARE_ACTIONS_SCHEDULED_REQUEST_FAILURE = 'PUBLICIZE_SHARE_ACTIONS_SCHEDULED_REQUEST_FAILURE';
const PUBLICIZE_SHARE_ACTIONS_SCHEDULED_REQUEST_SUCCESS = 'PUBLICIZE_SHARE_ACTIONS_SCHEDULED_REQUEST_SUCCESS';
const PUBLICIZE_SHARE_DISMISS = 'PUBLICIZE_SHARE_DISMISS';
const PUBLICIZE_SHARE_FAILURE = 'PUBLICIZE_SHARE_FAILURE';
const PUBLICIZE_SHARE_SUCCESS = 'PUBLICIZE_SHARE_SUCCESS';
const PURCHASE_REMOVE_COMPLETED = 'PURCHASE_REMOVE_COMPLETED';
const PURCHASE_REMOVE_FAILED = 'PURCHASE_REMOVE_FAILED';
const PURCHASES_REMOVE = 'PURCHASES_REMOVE';
const PURCHASES_SITE_FETCH = 'PURCHASES_SITE_FETCH';
const PURCHASES_SITE_FETCH_COMPLETED = 'PURCHASES_SITE_FETCH_COMPLETED';
const PURCHASES_SITE_FETCH_FAILED = 'PURCHASES_SITE_FETCH_FAILED';
const PURCHASES_SITE_RESET_STATE = 'PURCHASES_SITE_RESET_STATE';
const PURCHASES_USER_FETCH = 'PURCHASES_USER_FETCH';
const PURCHASES_USER_FETCH_COMPLETED = 'PURCHASES_USER_FETCH_COMPLETED';
const PURCHASES_USER_FETCH_FAILED = 'PURCHASES_USER_FETCH_FAILED';
const PUSH_NOTIFICATIONS_API_NOT_READY = 'PUSH_NOTIFICATIONS_API_NOT_READY';
const PUSH_NOTIFICATIONS_API_READY = 'PUSH_NOTIFICATIONS_API_READY';
const PUSH_NOTIFICATIONS_AUTHORIZE = 'PUSH_NOTIFICATIONS_AUTHORIZE';
const PUSH_NOTIFICATIONS_BLOCK = 'PUSH_NOTIFICATIONS_BLOCK';
const PUSH_NOTIFICATIONS_MUST_PROMPT = 'PUSH_NOTIFICATIONS_MUST_PROMPT';
const PUSH_NOTIFICATIONS_RECEIVE_REGISTER_DEVICE = 'PUSH_NOTIFICATIONS_RECEIVE_REGISTER_DEVICE';
const PUSH_NOTIFICATIONS_RECEIVE_UNREGISTER_DEVICE = 'PUSH_NOTIFICATIONS_RECEIVE_UNREGISTER_DEVICE';
const PUSH_NOTIFICATIONS_TOGGLE_ENABLED = 'PUSH_NOTIFICATIONS_TOGGLE_ENABLED';
const PUSH_NOTIFICATIONS_TOGGLE_UNBLOCK_INSTRUCTIONS = 'PUSH_NOTIFICATIONS_TOGGLE_UNBLOCK_INSTRUCTIONS';
const RECEIPT_FETCH = 'RECEIPT_FETCH';
const RECEIPT_FETCH_COMPLETED = 'RECEIPT_FETCH_COMPLETED';
const RECEIPT_FETCH_FAILED = 'RECEIPT_FETCH_FAILED';
const REWIND_ACTIVATE_FAILURE = 'REWIND_ACTIVATE_FAILURE';
const REWIND_ACTIVATE_REQUEST = 'REWIND_ACTIVATE_REQUEST';
const REWIND_ACTIVATE_SUCCESS = 'REWIND_ACTIVATE_SUCCESS';
const REWIND_ACTIVITY_SHARE_REQUEST = 'REWIND_ACTIVITY_SHARE_REQUEST';
const REWIND_BACKUP = 'REWIND_BACKUP';
const REWIND_BACKUP_DISMISS = 'REWIND_BACKUP_DISMISS';
const REWIND_BACKUP_DISMISS_PROGRESS = 'REWIND_BACKUP_DISMISS_PROGRESS';
const REWIND_BACKUP_PROGRESS_REQUEST = 'REWIND_BACKUP_PROGRESS_REQUEST';
const REWIND_BACKUP_REQUEST = 'REWIND_BACKUP_REQUEST';
const REWIND_BACKUP_SITE = 'REWIND_BACKUP_SITE';
const REWIND_BACKUP_UPDATE_ERROR = 'REWIND_BACKUP_UPDATE_ERROR';
const REWIND_BACKUP_UPDATE_PROGRESS = 'REWIND_BACKUP_UPDATE_PROGRESS';
const REWIND_BACKUPS_REQUEST = 'REWIND_BACKUPS_REQUEST';
const REWIND_BACKUPS_SET = 'REWIND_BACKUPS_SET';
const REWIND_CAPABILITIES_REQUEST = 'REWIND_CAPABILITIES_REQUEST';
const REWIND_CAPABILITIES_UPDATE = 'REWIND_CAPABILITIES_UPDATE';
const REWIND_CLONE = 'REWIND_CLONE';
const REWIND_DEACTIVATE_FAILURE = 'REWIND_DEACTIVATE_FAILURE';
const REWIND_DEACTIVATE_REQUEST = 'REWIND_DEACTIVATE_REQUEST';
const REWIND_DEACTIVATE_SUCCESS = 'REWIND_DEACTIVATE_SUCCESS';
const REWIND_POLICIES_REQUEST = 'REWIND_POLICIES_REQUEST';
const REWIND_POLICIES_REQUEST_FAILURE = 'REWIND_POLICIES_REQUEST_FAILURE';
const REWIND_POLICIES_REQUEST_SUCCESS = 'REWIND_POLICIES_REQUEST_SUCCESS';
const REWIND_POLICIES_SET = 'REWIND_POLICIES_SET';
const REWIND_RESTORE = 'REWIND_RESTORE';
const REWIND_RESTORE_DISMISS = 'REWIND_RESTORE_DISMISS';
const REWIND_RESTORE_DISMISS_PROGRESS = 'REWIND_RESTORE_DISMISS_PROGRESS';
const REWIND_RESTORE_PROGRESS_REQUEST = 'REWIND_RESTORE_PROGRESS_REQUEST';
const REWIND_RESTORE_REQUEST = 'REWIND_RESTORE_REQUEST';
const REWIND_RESTORE_UPDATE_PROGRESS = 'REWIND_RESTORE_UPDATE_PROGRESS';
const REWIND_SIZE_REQUEST = 'REWIND_SIZE_REQUEST';
const REWIND_SIZE_REQUEST_FAILURE = 'REWIND_SIZE_REQUEST_FAILURE';
const REWIND_SIZE_REQUEST_SUCCESS = 'REWIND_SIZE_REQUEST_SUCCESS';
const REWIND_SIZE_SET = 'REWIND_SIZE_SET';
const REWIND_STATE_REQUEST = 'REWIND_STATE_REQUEST';
const REWIND_STATE_UPDATE = 'REWIND_STATE_UPDATE';
const ROUTE_CLEAR_LAST_NON_EDITOR = 'ROUTE_CLEAR_LAST_NON_EDITOR';
const ROUTE_SET = 'ROUTE_SET';
const SECTION_LOADING_SET = 'SECTION_LOADING_SET';
const SECTION_SET = 'SECTION_SET';
const SELECTED_SITE_SET = 'SELECTED_SITE_SET';
const SET_MEDIA_EXPORT_DATA = 'SET_MEDIA_EXPORT_DATA';
const SIGNUP_COMPLETE_RESET = 'SIGNUP_COMPLETE_RESET';
const SIGNUP_CURRENT_FLOW_NAME_SET = 'SIGNUP_CURRENT_FLOW_NAME_SET';
const SIGNUP_DEPENDENCY_STORE_REMOVE_SITE_SLUG = 'SIGNUP_DEPENDENCY_STORE_REMOVE_SITE_SLUG';
const SIGNUP_DEPENDENCY_STORE_UPDATE = 'SIGNUP_DEPENDENCY_STORE_UPDATE';
const SIGNUP_OPTIONAL_DEPENDENCY_SUGGESTED_USERNAME_SET = 'SIGNUP_OPTIONAL_DEPENDENCY_SUGGESTED_USERNAME_SET';
const SIGNUP_PREVIOUS_FLOW_NAME_SET = 'SIGNUP_PREVIOUS_FLOW_NAME_SET';
const SIGNUP_FLOW_ADD_EXCLUDED_STEPS = 'SIGNUP_FLOW_ADD_EXCLUDED_STEPS';
const SIGNUP_FLOW_REMOVE_EXCLUDED_STEPS = 'SIGNUP_FLOW_REMOVE_EXCLUDED_STEPS';
const SIGNUP_FLOW_RESET_EXCLUDED_STEPS = 'SIGNUP_FLOW_RESET_EXCLUDED_STEPS';
const SIGNUP_PROGRESS_ADD_STEP = 'SIGNUP_PROGRESS_ADD_STEP';
const SIGNUP_PROGRESS_COMPLETE_STEP = 'SIGNUP_PROGRESS_COMPLETE_STEP';
const SIGNUP_PROGRESS_INVALIDATE_STEP = 'SIGNUP_PROGRESS_INVALIDATE_STEP';
const SIGNUP_PROGRESS_PROCESS_STEP = 'SIGNUP_PROGRESS_PROCESS_STEP';
const SIGNUP_PROGRESS_REMOVE_STEP = 'SIGNUP_PROGRESS_REMOVE_STEP';
const SIGNUP_PROGRESS_SAVE_STEP = 'SIGNUP_PROGRESS_SAVE_STEP';
const SIGNUP_PROGRESS_SUBMIT_STEP = 'SIGNUP_PROGRESS_SUBMIT_STEP';
const SIGNUP_STEPS_DESIGN_TYPE_SET = 'SIGNUP_STEPS_DESIGN_TYPE_SET';
const SIGNUP_STEPS_SITE_GOALS_SET = 'SIGNUP_STEPS_SITE_GOALS_SET';
const SIGNUP_STEPS_SITE_TITLE_SET = 'SIGNUP_STEPS_SITE_TITLE_SET';
const SIGNUP_STEPS_SITE_TYPE_SET = 'SIGNUP_STEPS_SITE_TYPE_SET';
const SIGNUP_STEPS_SITE_VERTICAL_SET = 'SIGNUP_STEPS_SITE_VERTICAL_SET';
const SIGNUP_STEPS_SURVEY_SET = 'SIGNUP_STEPS_SURVEY_SET'; // Signup DIFM Actions

const SIGNUP_STEPS_SITE_INFO_COLLECTION_UPDATE = 'SIGNUP_STEPS_SITE_INFO_COLLECTION_UPDATE';
const SIGNUP_STEPS_SITE_INFO_UPDATE_CURRENT_INDEX = 'SIGNUP_STEPS_SITE_INFO_UPDATE_CURRENT_INDEX';
const SIGNUP_STEPS_WEBSITE_CONTENT_INITIALIZE_PAGES = 'SIGNUP_STEPS_WEBSITE_CONTENT_INITIALIZE_PAGES';
const SIGNUP_STEPS_WEBSITE_CONTENT_UPDATE_CURRENT_INDEX = 'SIGNUP_STEPS_WEBSITE_CONTENT_UPDATE_CURRENT_INDEX';
const SIGNUP_STEPS_WEBSITE_CONTENT_IMAGE_UPLOAD_STARTED = 'SIGNUP_STEPS_WEBSITE_CONTENT_IMAGE_UPLOAD_STARTED';
const SIGNUP_STEPS_WEBSITE_CONTENT_IMAGE_UPLOAD_COMPLETED = 'SIGNUP_STEPS_WEBSITE_CONTENT_IMAGE_UPLOAD_COMPLETED';
const SIGNUP_STEPS_WEBSITE_FIELD_CHANGED = 'SIGNUP_STEPS_WEBSITE_FIELD_CHANGED';
const SIGNUP_STEPS_WEBSITE_CONTENT_IMAGE_UPLOAD_FAILED = 'SIGNUP_STEPS_WEBSITE_CONTENT_IMAGE_UPLOAD_FAILED';
const SIGNUP_STEPS_WEBSITE_CONTENT_IMAGE_REMOVED = 'SIGNUP_STEPS_WEBSITE_CONTENT_IMAGE_REMOVED';
const SIGNUP_STEPS_WEBSITE_CONTENT_LOGO_UPLOAD_STARTED = 'SIGNUP_STEPS_WEBSITE_CONTENT_LOGO_UPLOAD_STARTED';
const SIGNUP_STEPS_WEBSITE_CONTENT_LOGO_UPLOAD_COMPLETED = 'SIGNUP_STEPS_WEBSITE_CONTENT_LOGO_UPLOAD_COMPLETED';
const SIGNUP_STEPS_WEBSITE_CONTENT_LOGO_UPLOAD_FAILED = 'SIGNUP_STEPS_WEBSITE_CONTENT_LOGO_UPLOAD_FAILED';
const SIGNUP_STEPS_SOCIAL_PROFILES_UPDATE = 'SIGNUP_STEPS_SOCIAL_PROFILES_UPDATE';
const SIGNUP_STEPS_SOCIAL_PROFILES_RESET = 'SIGNUP_STEPS_SOCIAL_PROFILES_RESET';
const SIGNUP_STEPS_WEBSITE_CONTENT_REMOVE_LOGO_URL = 'SIGNUP_STEPS_WEBSITE_CONTENT_REMOVE_LOGO_URL';
const SIGNUP_STEPS_USER_EXPERIENCE_SET = 'SIGNUP_STEPS_USER_EXPERIENCE_SET';
const SIGNUP_VERTICALS_REQUEST = 'SIGNUP_VERTICALS_REQUEST';
const SIGNUP_VERTICALS_SET = 'SIGNUP_VERTICALS_SET';
const SITE_ADDRESS_AVAILABILITY_ERROR = 'SITE_ADDRESS_AVAILABILITY_ERROR';
const SITE_ADDRESS_AVAILABILITY_ERROR_CLEAR = 'SITE_ADDRESS_AVAILABILITY_ERROR_CLEAR';
const SITE_ADDRESS_AVAILABILITY_REQUEST = 'SITE_ADDRESS_AVAILABILITY_REQUEST';
const SITE_ADDRESS_AVAILABILITY_SUCCESS = 'SITE_ADDRESS_AVAILABILITY_SUCCESS';
const SITE_ADDRESS_CHANGE_REQUEST = 'SITE_ADDRESS_CHANGE_REQUEST';
const SITE_ADDRESS_CHANGE_REQUEST_FAILURE = 'SITE_ADDRESS_CHANGE_REQUEST_FAILURE';
const SITE_ADDRESS_CHANGE_REQUEST_SUCCESS = 'SITE_ADDRESS_CHANGE_REQUEST_SUCCESS';
const SITE_CHECKLIST_RECEIVE = 'SITE_CHECKLIST_RECEIVE';
const SITE_CHECKLIST_REQUEST = 'SITE_CHECKLIST_REQUEST';
const SITE_CHECKLIST_TASK_UPDATE = 'SITE_CHECKLIST_TASK_UPDATE';
const SITE_CONNECTION_STATUS_RECEIVE = 'SITE_CONNECTION_STATUS_RECEIVE';
const SITE_CONNECTION_STATUS_REQUEST = 'SITE_CONNECTION_STATUS_REQUEST';
const SITE_CONNECTION_STATUS_REQUEST_FAILURE = 'SITE_CONNECTION_STATUS_REQUEST_FAILURE';
const SITE_CONNECTION_STATUS_REQUEST_SUCCESS = 'SITE_CONNECTION_STATUS_REQUEST_SUCCESS';
const SITE_DELETE_RECEIVE = 'SITE_DELETE_RECEIVE';
const SITE_DOMAINS_RECEIVE = 'SITE_DOMAINS_RECEIVE';
const SITE_DOMAINS_REQUEST = 'SITE_DOMAINS_REQUEST';
const SITE_DOMAINS_REQUEST_FAILURE = 'SITE_DOMAINS_REQUEST_FAILURE';
const SITE_DOMAINS_REQUEST_SUCCESS = 'SITE_DOMAINS_REQUEST_SUCCESS';
const SITE_FEATURES_FETCH = 'SITE_FEATURES_FETCH';
const SITE_FEATURES_FETCH_COMPLETED = 'SITE_FEATURES_FETCH_COMPLETED';
const SITE_FEATURES_FETCH_FAILED = 'SITE_FEATURES_FETCH_FAILED';
const SITE_FRONT_PAGE_UPDATE = 'SITE_FRONT_PAGE_UPDATE';
const SITE_INTRO_OFFER_RECEIVE = 'SITE_INTRO_OFFER_RECEIVE';
const SITE_INTRO_OFFER_REQUEST = 'SITE_INTRO_OFFER_REQUEST';
const SITE_INTRO_OFFER_REQUEST_FAILURE = 'SITE_INTRO_OFFER_REQUEST_FAILURE';
const SITE_INTRO_OFFER_REQUEST_SUCCESS = 'SITE_INTRO_OFFER_REQUEST_SUCCESS';
const SITE_IMPORTER_IMPORT_FAILURE = 'SITE_IMPORTER_IMPORT_FAILURE';
const SITE_IMPORTER_IMPORT_RESET = 'SITE_IMPORTER_IMPORT_RESET';
const SITE_IMPORTER_IMPORT_START = 'SITE_IMPORTER_IMPORT_START';
const SITE_IMPORTER_IMPORT_SUCCESS = 'SITE_IMPORTER_IMPORT_SUCCESS';
const SITE_IMPORTER_IS_SITE_IMPORTABLE_FAILURE = 'SITE_IMPORTER_IS_SITE_IMPORTABLE_FAILURE';
const SITE_IMPORTER_IS_SITE_IMPORTABLE_START = 'SITE_IMPORTER_IS_SITE_IMPORTABLE_START';
const SITE_IMPORTER_IS_SITE_IMPORTABLE_SUCCESS = 'SITE_IMPORTER_IS_SITE_IMPORTABLE_SUCCESS';
const SITE_IMPORTER_VALIDATION_ERROR_SET = 'SITE_IMPORTER_VALIDATION_ERROR_SET';
const SITE_KEYRINGS_DELETE = 'SITE_KEYRINGS_DELETE';
const SITE_KEYRINGS_DELETE_FAILURE = 'SITE_KEYRINGS_DELETE_FAILURE';
const SITE_KEYRINGS_DELETE_SUCCESS = 'SITE_KEYRINGS_DELETE_SUCCESS';
const SITE_KEYRINGS_REQUEST = 'SITE_KEYRINGS_REQUEST';
const SITE_KEYRINGS_REQUEST_FAILURE = 'SITE_KEYRINGS_REQUEST_FAILURE';
const SITE_KEYRINGS_REQUEST_SUCCESS = 'SITE_KEYRINGS_REQUEST_SUCCESS';
const SITE_KEYRINGS_SAVE_SUCCESS = 'SITE_KEYRINGS_SAVE_SUCCESS';
const SITE_KEYRINGS_UPDATE = 'SITE_KEYRINGS_UPDATE';
const SITE_KEYRINGS_UPDATE_FAILURE = 'SITE_KEYRINGS_UPDATE_FAILURE';
const SITE_KEYRINGS_UPDATE_SUCCESS = 'SITE_KEYRINGS_UPDATE_SUCCESS';
const SITE_LAUNCH = 'SITE_LAUNCH';
const SITE_MIGRATION_STATUS_UPDATE = 'SITE_MIGRATION_STATUS_UPDATE';
const SITE_PLAN_OWNERSHIP_TRANSFER = 'SITE_PLAN_OWNERSHIP_TRANSFER';
const SITE_PLANS_FETCH = 'SITE_PLANS_FETCH';
const SITE_PLANS_FETCH_COMPLETED = 'SITE_PLANS_FETCH_COMPLETED';
const SITE_PLANS_FETCH_FAILED = 'SITE_PLANS_FETCH_FAILED';
const SITE_PLANS_REMOVE = 'SITE_PLANS_REMOVE';
const SITE_PLUGIN_UPDATED = 'SITE_PLUGIN_UPDATED';
const SITE_PRODUCTS_FETCH = 'SITE_PRODUCTS_FETCH';
const SITE_PRODUCTS_FETCH_COMPLETED = 'SITE_PRODUCTS_FETCH_COMPLETED';
const SITE_PRODUCTS_FETCH_FAILED = 'SITE_PRODUCTS_FETCH_FAILED';
const SITE_RECEIVE = 'SITE_RECEIVE';
const SITE_REQUEST = 'SITE_REQUEST';
const SITE_REQUEST_FAILURE = 'SITE_REQUEST_FAILURE';
const SITE_REQUEST_SUCCESS = 'SITE_REQUEST_SUCCESS';
const SITE_SETTINGS_RECEIVE = 'SITE_SETTINGS_RECEIVE';
const SITE_SETTINGS_REQUEST = 'SITE_SETTINGS_REQUEST';
const SITE_SETTINGS_REQUEST_FAILURE = 'SITE_SETTINGS_REQUEST_FAILURE';
const SITE_SETTINGS_REQUEST_SUCCESS = 'SITE_SETTINGS_REQUEST_SUCCESS';
const SITE_SETTINGS_SAVE = 'SITE_SETTINGS_SAVE';
const SITE_SETTINGS_SAVE_FAILURE = 'SITE_SETTINGS_SAVE_FAILURE';
const SITE_SETTINGS_SAVE_SUCCESS = 'SITE_SETTINGS_SAVE_SUCCESS';
const SITE_SETTINGS_UPDATE = 'SITE_SETTINGS_UPDATE';
const SITE_STATS_RECEIVE = 'SITE_STATS_RECEIVE';
const SITE_STATS_REQUEST = 'SITE_STATS_REQUEST';
const SITE_STATS_REQUEST_FAILURE = 'SITE_STATS_REQUEST_FAILURE';
const SITES_RECEIVE = 'SITES_RECEIVE';
const SITES_REQUEST = 'SITES_REQUEST';
const SITES_REQUEST_FAILURE = 'SITES_REQUEST_FAILURE';
const SITES_REQUEST_SUCCESS = 'SITES_REQUEST_SUCCESS';
const SOCIAL_CONNECT_ACCOUNT_REQUEST = 'SOCIAL_CONNECT_ACCOUNT_REQUEST';
const SOCIAL_CONNECT_ACCOUNT_REQUEST_FAILURE = 'SOCIAL_CONNECT_ACCOUNT_REQUEST_FAILURE';
const SOCIAL_CONNECT_ACCOUNT_REQUEST_SUCCESS = 'SOCIAL_CONNECT_ACCOUNT_REQUEST_SUCCESS';
const SOCIAL_CREATE_ACCOUNT_REQUEST_FAILURE = 'SOCIAL_CREATE_ACCOUNT_REQUEST_FAILURE';
const SOCIAL_HANDOFF_CONNECT_ACCOUNT = 'SOCIAL_HANDOFF_CONNECT_ACCOUNT';
const SOCIAL_DISCONNECT_ACCOUNT_REQUEST = 'SOCIAL_DISCONNECT_ACCOUNT_REQUEST';
const SOCIAL_DISCONNECT_ACCOUNT_REQUEST_FAILURE = 'SOCIAL_DISCONNECT_ACCOUNT_REQUEST_FAILURE';
const SOCIAL_DISCONNECT_ACCOUNT_REQUEST_SUCCESS = 'SOCIAL_DISCONNECT_ACCOUNT_REQUEST_SUCCESS';
const SOCIAL_LOGIN_REQUEST = 'SOCIAL_LOGIN_REQUEST';
const SOCIAL_LOGIN_REQUEST_FAILURE = 'SOCIAL_LOGIN_REQUEST_FAILURE';
const SOCIAL_LOGIN_REQUEST_SUCCESS = 'SOCIAL_LOGIN_REQUEST_SUCCESS';
const STATS_CHART_COUNTS_RECEIVE = 'STATS_CHART_COUNTS_RECEIVE';
const STATS_CHART_COUNTS_REQUEST = 'STATS_CHART_COUNTS_REQUEST';
const STATS_RECENT_POST_VIEWS_RECEIVE = 'STATS_RECENT_POST_VIEWS_RECEIVE';
const STATS_RECENT_POST_VIEWS_REQUEST = 'STATS_RECENT_POST_VIEWS_REQUEST';
const STORED_CARDS_ADD_COMPLETED = 'STORED_CARDS_ADD_COMPLETED';
const STORED_CARDS_DELETE = 'STORED_CARDS_DELETE';
const STORED_CARDS_DELETE_COMPLETED = 'STORED_CARDS_DELETE_COMPLETED';
const STORED_CARDS_DELETE_FAILED = 'STORED_CARDS_DELETE_FAILED';
const STORED_CARDS_UPDATE_IS_PRIMARY_COMPLETED = 'STORED_CARDS_UPDATE_IS_PRIMARY_COMPLETED';
const STORED_CARDS_UPDATE_IS_BACKUP_COMPLETED = 'STORED_CARDS_UPDATE_IS_BACKUP_COMPLETED';
const STORED_CARDS_FETCH = 'STORED_CARDS_FETCH';
const STORED_CARDS_FETCH_COMPLETED = 'STORED_CARDS_FETCH_COMPLETED';
const STORED_CARDS_FETCH_FAILED = 'STORED_CARDS_FETCH_FAILED';
const SUPPORT_ARTICLE_DIALOG_CLOSE = 'SUPPORT_ARTICLE_DIALOG_CLOSE';
const SUPPORT_ARTICLE_DIALOG_OPEN = 'SUPPORT_ARTICLE_DIALOG_OPEN';
const SUPPORT_SESSION_TRANSITION = 'SUPPORT_SESSION_TRANSITION';
const TERM_REMOVE = 'TERM_REMOVE';
const TERMS_RECEIVE = 'TERMS_RECEIVE';
const TERMS_REQUEST = 'TERMS_REQUEST';
const TERMS_REQUEST_FAILURE = 'TERMS_REQUEST_FAILURE';
const TERMS_REQUEST_SUCCESS = 'TERMS_REQUEST_SUCCESS';
const TIMEZONES_RECEIVE = 'TIMEZONES_RECEIVE';
const TIMEZONES_REQUEST = 'TIMEZONES_REQUEST';
const TOS_ACCEPT = 'TOS_ACCEPT';
const TWO_FACTOR_AUTHENTICATION_LOGIN_REQUEST = 'TWO_FACTOR_AUTHENTICATION_LOGIN_REQUEST';
const TWO_FACTOR_AUTHENTICATION_LOGIN_REQUEST_FAILURE = 'TWO_FACTOR_AUTHENTICATION_LOGIN_REQUEST_FAILURE';
const TWO_FACTOR_AUTHENTICATION_LOGIN_REQUEST_SUCCESS = 'TWO_FACTOR_AUTHENTICATION_LOGIN_REQUEST_SUCCESS';
const TWO_FACTOR_AUTHENTICATION_SEND_SMS_CODE_REQUEST = 'TWO_FACTOR_AUTHENTICATION_SEND_SMS_CODE_REQUEST';
const TWO_FACTOR_AUTHENTICATION_SEND_SMS_CODE_REQUEST_FAILURE = 'TWO_FACTOR_AUTHENTICATION_SEND_SMS_CODE_REQUEST_FAILURE';
const TWO_FACTOR_AUTHENTICATION_SEND_SMS_CODE_REQUEST_SUCCESS = 'TWO_FACTOR_AUTHENTICATION_SEND_SMS_CODE_REQUEST_SUCCESS';
const TWO_FACTOR_AUTHENTICATION_UPDATE_NONCE = 'TWO_FACTOR_AUTHENTICATION_UPDATE_NONCE';
const URL_ANALYZER_ANALYZE = 'URL_ANALYZER_ANALYZE';
const URL_ANALYZER_ANALYZE_DONE = 'URL_ANALYZER_ANALYZE_DONE';
const URL_ANALYZER_ANALYZE_SUCCESS = 'URL_ANALYZER_ANALYZE_SUCCESS';
const URL_ANALYZER_ANALYZE_ERROR = 'URL_ANALYZER_ANALYZE_ERROR';
const URL_ANALYZER_RESET_ERROR = 'URL_ANALYZER_RESET_ERROR';
const URL_ANALYZER_URL_DATA_UPDATE = 'URL_ANALYZER_URL_DATA_UPDATE';
const USER_LICENSES_RECEIVE = 'USER_LICENSES_RECEIVE';
const USER_LICENSES_REQUEST = 'USER_LICENSES_REQUEST';
const USER_LICENSES_REQUEST_SUCCESS = 'USER_LICENSES_REQUEST_SUCCESS';
const USER_LICENSES_REQUEST_FAILURE = 'USER_LICENSES_REQUEST_FAILURE';
const USER_LICENSES_COUNTS_RECEIVE = 'USER_LICENSES_COUNTS_RECEIVE';
const USER_LICENSES_COUNTS_REQUEST = 'USER_LICENSES_COUNTS_REQUEST';
const USER_LICENSES_COUNTS_REQUEST_SUCCESS = 'USER_LICENSES_COUNTS_REQUEST_SUCCESS';
const USER_LICENSES_COUNTS_REQUEST_FAILURE = 'USER_LICENSES_COUNTS_REQUEST_FAILURE';
const USER_PROFILE_LINKS_ADD = 'USER_PROFILE_LINKS_ADD';
const USER_PROFILE_LINKS_ADD_DUPLICATE = 'USER_PROFILE_LINKS_ADD_DUPLICATE';
const USER_PROFILE_LINKS_ADD_FAILURE = 'USER_PROFILE_LINKS_ADD_FAILURE';
const USER_PROFILE_LINKS_ADD_MALFORMED = 'USER_PROFILE_LINKS_ADD_MALFORMED';
const USER_PROFILE_LINKS_ADD_SUCCESS = 'USER_PROFILE_LINKS_ADD_SUCCESS';
const USER_PROFILE_LINKS_DELETE = 'USER_PROFILE_LINKS_DELETE';
const USER_PROFILE_LINKS_DELETE_FAILURE = 'USER_PROFILE_LINKS_DELETE_FAILURE';
const USER_PROFILE_LINKS_DELETE_SUCCESS = 'USER_PROFILE_LINKS_DELETE_SUCCESS';
const USER_PROFILE_LINKS_RECEIVE = 'USER_PROFILE_LINKS_RECEIVE';
const USER_PROFILE_LINKS_REQUEST = 'USER_PROFILE_LINKS_REQUEST';
const USER_PROFILE_LINKS_RESET_ERRORS = 'USER_PROFILE_LINKS_RESET_ERRORS';
const USER_SETTINGS_REQUEST = 'USER_SETTINGS_REQUEST';
const USER_SETTINGS_REQUEST_FAILURE = 'USER_SETTINGS_REQUEST_FAILURE';
const USER_SETTINGS_REQUEST_SUCCESS = 'USER_SETTINGS_REQUEST_SUCCESS ';
const USER_SETTINGS_SAVE = 'USER_SETTINGS_SAVE';
const USER_SETTINGS_SAVE_FAILURE = 'USER_SETTINGS_SAVE_FAILURE';
const USER_SETTINGS_SAVE_SUCCESS = 'USER_SETTINGS_SAVE_SUCCESS';
const USER_SETTINGS_UNSAVED_CLEAR = 'USER_SETTINGS_UNSAVED_CLEAR';
const USER_SETTINGS_UNSAVED_REMOVE = 'USER_SETTINGS_UNSAVED_REMOVE';
const USER_SETTINGS_UNSAVED_SET = 'USER_SETTINGS_UNSAVED_SET';
const USER_SUGGESTIONS_RECEIVE = 'USER_SUGGESTIONS_RECEIVE';
const USER_SUGGESTIONS_REQUEST = 'USER_SUGGESTIONS_REQUEST';
const USER_SUGGESTIONS_REQUEST_FAILURE = 'USER_SUGGESTIONS_REQUEST_FAILURE';
const USER_SUGGESTIONS_REQUEST_SUCCESS = 'USER_SUGGESTIONS_REQUEST_SUCCESS';
const VIDEO_EDITOR_SET_POSTER_URL = 'VIDEO_EDITOR_SET_POSTER_URL';
const VIDEO_EDITOR_SHOW_ERROR = 'VIDEO_EDITOR_SHOW_ERROR';
const VIDEO_EDITOR_SHOW_UPLOAD_PROGRESS = 'VIDEO_EDITOR_SHOW_UPLOAD_PROGRESS';
const VIDEO_EDITOR_UPDATE_POSTER = 'VIDEO_EDITOR_UPDATE_POSTER';
const VIDEO_EDITOR_REFRESH_POSTER = 'VIDEO_EDITOR_REFRESH_POSTER';
const WORDADS_EARNINGS_RECEIVE = 'WORDADS_EARNINGS_RECEIVE';
const WORDADS_EARNINGS_REQUEST = 'WORDADS_EARNINGS_REQUEST';
const WORDADS_SETTINGS_RECEIVE = 'WORDADS_SETTINGS_RECEIVE';
const WORDADS_SETTINGS_REQUEST = 'WORDADS_SETTINGS_REQUEST';
const WORDADS_SETTINGS_SAVE = 'WORDADS_SETTINGS_SAVE';
const WORDADS_SETTINGS_SAVE_FAILURE = 'WORDADS_SETTINGS_SAVE_FAILURE';
const WORDADS_SETTINGS_SAVE_SUCCESS = 'WORDADS_SETTINGS_SAVE_SUCCESS';
const WORDADS_SETTINGS_UPDATE = 'WORDADS_SETTINGS_UPDATE';
const WORDADS_PAYMENTS_RECEIVE = 'WORDADS_PAYMENTS_RECEIVE';
const WORDADS_PAYMENTS_REQUEST = 'WORDADS_PAYMENTS_REQUEST';
const WORDADS_SITE_APPROVE_REQUEST = 'WORDADS_SITE_APPROVE_REQUEST';
const WORDADS_SITE_APPROVE_REQUEST_DISMISS_ERROR = 'WORDADS_SITE_APPROVE_REQUEST_DISMISS_ERROR';
const WORDADS_SITE_APPROVE_REQUEST_DISMISS_SUCCESS = 'WORDADS_SITE_APPROVE_REQUEST_DISMISS_SUCCESS';
const WORDADS_SITE_APPROVE_REQUEST_FAILURE = 'WORDADS_SITE_APPROVE_REQUEST_FAILURE';
const WORDADS_SITE_APPROVE_REQUEST_SUCCESS = 'WORDADS_SITE_APPROVE_REQUEST_SUCCESS';
const WORDADS_STATUS_RECEIVE = 'WORDADS_STATUS_RECEIVE';
const WORDADS_STATUS_REQUEST = 'WORDADS_STATUS_REQUEST';
const WPCOM_HTTP_REQUEST = 'WPCOM_HTTP_REQUEST';

/***/ }),

/***/ 48539:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "A": function() { return /* binding */ mergeHandlers; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Merge handler for lodash.mergeWith
 *
 * Note that a return value of `undefined`
 * indicates to lodash that it should use
 * its normal merge algorithm.
 *
 * In this case, we want to merge keys if
 * they don't exists but when they do, we
 * prefer to concatenate lists instead of
 * overwriting them.
 *
 * @param {?Array<Function>} left existing handlers
 * @param {Array<Function>} right new handlers to add
 * @returns {Array<Function>} combined handlers
 */

const concatHandlers = (left, right) => Array.isArray(left) ? left.concat(right) : undefined;

const mergeHandlers = function () {
  for (var _len = arguments.length, handlers = new Array(_len), _key = 0; _key < _len; _key++) {
    handlers[_key] = arguments[_key];
  }

  return handlers.length > 1 ? (0,lodash__WEBPACK_IMPORTED_MODULE_0__.mergeWith)(Object.create(null), ...handlers, concatHandlers) : handlers[0];
};

/***/ }),

/***/ 86398:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ clear; },
/* harmony export */   "l": function() { return /* binding */ addReducerToStore; }
/* harmony export */ });
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);

const initializations = new Map();
const reducers = new Map();

function normalizeKey(key) {
  return key.join('.');
}

function clear() {
  initializations.clear();
  reducers.clear();
} // For a given store, creates a function that adds a new reducer to the store,
// and loads (asynchronously) and applies the persisted state for it.

const addReducerToStore = (store, getStoredState) => (key, reducer) => {
  const storageKey = reducer.storageKey;
  const normalizedKey = normalizeKey(key);
  const previousReducer = reducers.get(normalizedKey);
  const init = initializations.get(normalizedKey);

  if (previousReducer && reducer !== previousReducer) {
    throw new Error(`Different reducers on multiple calls to \`addReducerToStore\` for key: ${normalizedKey}`);
  }

  if (!init) {
    store.addReducer(key, reducer);

    if (storageKey && getStoredState) {
      const storedState = getStoredState(reducer, storageKey);

      if (storedState) {
        store.dispatch({
          type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .APPLY_STORED_STATE */ .gm2,
          storageKey,
          storedState
        });
      }
    }

    initializations.set(normalizedKey, true);
    reducers.set(normalizedKey, reducer);
  }
};

/***/ }),

/***/ 19298:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "jN": function() { return /* binding */ recordTracksEvent; }
/* harmony export */ });
/* unused harmony exports recordEvent, recordGoogleEvent, recordCustomFacebookConversionEvent, recordCustomAdWordsRemarketingEvent, recordPageView, recordGooglePageView */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);

const recordEvent = (service, args) => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .ANALYTICS_EVENT_RECORD */ .u2u,
  meta: {
    analytics: [{
      type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .ANALYTICS_EVENT_RECORD */ .u2u,
      payload: Object.assign({}, {
        service
      }, args)
    }]
  }
});
const recordGoogleEvent = (category, action, label, value) => recordEvent('ga', {
  category,
  action,
  label,
  value
});
const recordTracksEvent = (name, properties) => recordEvent('tracks', {
  name,
  properties
});
const recordCustomFacebookConversionEvent = (name, properties) => recordEvent('fb', {
  name,
  properties
});
const recordCustomAdWordsRemarketingEvent = properties => recordEvent('adwords', {
  properties
});
const recordPageView = function (url, title, service) {
  let properties = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  let options = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : {};
  return {
    type: ANALYTICS_PAGE_VIEW_RECORD,
    meta: {
      analytics: [{
        type: ANALYTICS_PAGE_VIEW_RECORD,
        payload: {
          service,
          url,
          title,
          options,
          ...properties
        }
      }]
    }
  };
};
const recordGooglePageView = (url, title) => recordPageView(url, title, 'ga');

/***/ }),

/***/ 15223:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export analyticsMiddleware */
/* harmony import */ var calypso_lib_analytics_ad_tracking__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(25394);
/* harmony import */ var calypso_lib_analytics_ga__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(44567);
/* harmony import */ var calypso_lib_analytics_hotjar__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(80252);
/* harmony import */ var calypso_lib_analytics_mc__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(7689);
/* harmony import */ var calypso_lib_analytics_page_view__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(66610);
/* harmony import */ var calypso_lib_analytics_tracks__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(17032);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(40211);







const eventServices = {
  ga: _ref => {
    let {
      category,
      action,
      label,
      value
    } = _ref;
    return (0,calypso_lib_analytics_ga__WEBPACK_IMPORTED_MODULE_0__/* .gaRecordEvent */ .Yh)(category, action, label, value);
  },
  tracks: _ref2 => {
    let {
      name,
      properties
    } = _ref2;
    return (0,calypso_lib_analytics_tracks__WEBPACK_IMPORTED_MODULE_4__.recordTracksEvent)(name, properties);
  },
  fb: _ref3 => {
    let {
      name,
      properties
    } = _ref3;
    return (0,calypso_lib_analytics_ad_tracking__WEBPACK_IMPORTED_MODULE_5__/* .trackCustomFacebookConversionEvent */ .K)(name, properties);
  },
  adwords: _ref4 => {
    let {
      properties
    } = _ref4;
    return (0,calypso_lib_analytics_ad_tracking__WEBPACK_IMPORTED_MODULE_5__/* .trackCustomAdWordsRemarketingEvent */ .w)(properties);
  }
};
const pageViewServices = {
  ga: _ref5 => {
    let {
      url,
      title
    } = _ref5;
    return (0,calypso_lib_analytics_ga__WEBPACK_IMPORTED_MODULE_0__/* .gaRecordPageView */ .eK)(url, title);
  },
  default: _ref6 => {
    let {
      url,
      title,
      options,
      ...params
    } = _ref6;
    return (0,calypso_lib_analytics_page_view__WEBPACK_IMPORTED_MODULE_3__/* .recordPageView */ .A)(url, title, params, options);
  }
};

const loadTrackingTool = trackingTool => {
  if (trackingTool === 'HotJar') {
    (0,calypso_lib_analytics_hotjar__WEBPACK_IMPORTED_MODULE_1__/* .addHotJarScript */ .o)();
  }
};

const statBump = _ref7 => {
  let {
    group,
    name
  } = _ref7;
  return (0,calypso_lib_analytics_mc__WEBPACK_IMPORTED_MODULE_2__/* .bumpStat */ .P)(group, name);
};

const dispatcher = action => {
  const analyticsMeta = action.meta.analytics;
  analyticsMeta.forEach(_ref8 => {
    var _eventServices$servic, _pageViewServices$ser;

    let {
      type,
      payload
    } = _ref8;
    const {
      service = 'default',
      ...params
    } = payload;

    switch (type) {
      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_6__/* .ANALYTICS_EVENT_RECORD */ .u2u:
        return (_eventServices$servic = eventServices[service]) === null || _eventServices$servic === void 0 ? void 0 : _eventServices$servic.call(eventServices, params);

      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_6__/* .ANALYTICS_PAGE_VIEW_RECORD */ .Wj3:
        return (_pageViewServices$ser = pageViewServices[service]) === null || _pageViewServices$ser === void 0 ? void 0 : _pageViewServices$ser.call(pageViewServices, params);

      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_6__/* .ANALYTICS_STAT_BUMP */ .lAo:
        return statBump(params);
    }
  });
};

const analyticsMiddleware = () => next => action => {
  var _action$meta;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_6__/* .ANALYTICS_TRACKING_ON */ .K5f:
      loadTrackingTool(action.trackingTool);
      return;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_6__/* .ANALYTICS_TRACKS_OPT_OUT */ .ti2:
      (0,calypso_lib_analytics_tracks__WEBPACK_IMPORTED_MODULE_4__.setTracksOptOut)(action.isOptingOut);
      return;

    default:
      if ((_action$meta = action.meta) !== null && _action$meta !== void 0 && _action$meta.analytics) {
        dispatcher(action);
      }

  }

  return next(action);
};
/* harmony default export */ __webpack_exports__["Z"] = (analyticsMiddleware);

/***/ }),

/***/ 6255:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export consoleDispatcher */
/**
 * Console dispatcher Redux store enhancer
 *
 * Inject at the top of the `createStore` enhancer chain
 * to provide access to actionTypes and store methods directly
 * from the console.
 *
 * Will only attach if the `window` variable is available
 * globally. If not it will simply be an empty link in the
 * chain, passing straight through.
 *
 * @param {Function} next next store enhancer in chain
 * @returns {Function} console dispatcher store enhancer
 */
const consoleDispatcher = next => function () {
  const store = next(...arguments);

  if ('undefined' !== typeof window) {
    Object.assign(window, store);
    Object.defineProperty(window, 'state', {
      enumerable: true,
      get: store.getState
    });
  }

  return store;
};
/* harmony default export */ __webpack_exports__["Z"] = (consoleDispatcher);

/***/ }),

/***/ 91668:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "lx": function() { return /* binding */ setCurrentUser; }
/* harmony export */ });
/* unused harmony exports fetchCurrentUser, redirectToLogout, setUserEmailVerified */
/* harmony import */ var calypso_lib_user_store__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(65792);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_current_user_selectors__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36747);




/**
 * Returns an action object that sets the current user object on the store
 *
 * @param  {object} user user object
 * @returns {object}        Action object
 */

function setCurrentUser(user) {
  return {
    type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .CURRENT_USER_RECEIVE */ .uBM,
    user
  };
}
let fetchingUser = null;
function fetchCurrentUser() {
  return dispatch => {
    if (fetchingUser) {
      return fetchingUser;
    }

    dispatch({
      type: CURRENT_USER_FETCH
    });
    fetchingUser = rawCurrentUserFetch().then(async user => {
      const userData = filterUserObject(user);
      const storedUserId = getStoredUserId();

      if (storedUserId != null && storedUserId !== userData.ID) {
        await clearStore();
      }

      setStoredUserId(userData.ID);
      dispatch(setCurrentUser(userData));
    }).catch(() => {// @TODO: Improve error handling
    }).finally(() => {
      fetchingUser = null;
    });
    return fetchingUser;
  };
}
function redirectToLogout(postLogoutRedirectUrl) {
  return async (dispatch, getState) => {
    const userData = getCurrentUser(getState());
    const logoutUrl = getLogoutUrl(userData, postLogoutRedirectUrl); // Clear any data stored locally within the user data module or localStorage

    disablePersistence();
    await clearStore();
    window.location.href = logoutUrl;
  };
}
function setUserEmailVerified(verified) {
  return {
    type: CURRENT_USER_SET_EMAIL_VERIFIED,
    verified
  };
}

/***/ }),

/***/ 79482:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports status, errorMessage */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(95884);


const status = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .EMAIL_VERIFY_REQUEST */ .G1W:
      return 'requesting';

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .EMAIL_VERIFY_REQUEST_SUCCESS */ .YPU:
      return 'sent';

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .EMAIL_VERIFY_REQUEST_FAILURE */ .dAl:
      return 'error';

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .EMAIL_VERIFY_STATE_RESET */ .iHL:
      return null;
  }

  return state;
};
const errorMessage = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .EMAIL_VERIFY_REQUEST */ .G1W:
      return '';

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .EMAIL_VERIFY_REQUEST_SUCCESS */ .YPU:
      return '';

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .EMAIL_VERIFY_REQUEST_FAILURE */ .dAl:
      {
        const {
          message
        } = action;
        return message;
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .EMAIL_VERIFY_STATE_RESET */ .iHL:
      return '';
  }

  return state;
};
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .combineReducers */ .U)({
  status,
  errorMessage
}));

/***/ }),

/***/ 18724:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports id, user, flags, capabilities, lasagnaJwt */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(95884);
/* harmony import */ var _email_verification_reducer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(79482);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(21826);




/**
 * Tracks the current user ID.
 *
 * In development, if you are receiving Redux errors like this:
 *
 *     Error: Given action "CURRENT_USER_RECEIVE", reducer "id" returned undefined.
 *
 * This is likely caused by a server-side error or stored state corruption/auth token expiry.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const id = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_1__/* .idSchema */ .K6, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .CURRENT_USER_RECEIVE */ .uBM:
      return action.user.ID;
  }

  return state;
});
const user = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .CURRENT_USER_RECEIVE */ .uBM:
      return action.user;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .CURRENT_USER_SET_EMAIL_VERIFIED */ .KAg:
      return { ...state,
        email_verified: action.verified
      };
  }

  return state;
};
const flags = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_1__/* .flagsSchema */ .bH, function () {
  var _action$user$meta, _action$user$meta$dat, _action$user$meta$dat2;

  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .CURRENT_USER_RECEIVE */ .uBM:
      return ((_action$user$meta = action.user.meta) === null || _action$user$meta === void 0 ? void 0 : (_action$user$meta$dat = _action$user$meta.data) === null || _action$user$meta$dat === void 0 ? void 0 : (_action$user$meta$dat2 = _action$user$meta$dat.flags) === null || _action$user$meta$dat2 === void 0 ? void 0 : _action$user$meta$dat2.active_flags) ?? [];
  }

  return state;
});
/**
 * Compare if two sets of capabilities are equal.
 *
 * Capability sets are simple objects with boolean flags,
 * so comparison is as simple as comparing objects at the first level.
 *
 * @param  {object} capA First set of capabilities
 * @param  {object} capB Second set of capabilities
 * @returns {boolean} True if capability sets are the same, false otherwise.
 */

function areCapabilitiesEqual(capA, capB) {
  if (!capA || !capB) {
    return false;
  }

  const keysA = Object.keys(capA);
  const keysB = Object.keys(capB);
  return keysA.length === keysB.length && keysA.every(key => capB[key] === capA[key]);
}
/**
 * Returns the updated capabilities state after an action has been dispatched.
 * The state maps site ID keys to an object of current user capabilities for
 * that site.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */


const capabilities = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_1__/* .capabilitiesSchema */ .kX, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .SITE_RECEIVE */ .UUJ:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .SITES_RECEIVE */ .xLe:
      {
        const sites = action.site ? [action.site] : action.sites;
        return sites.reduce((memo, site) => {
          if (!site.capabilities || areCapabilitiesEqual(site.capabilities, memo[site.ID])) {
            return memo;
          }

          if (memo === state) {
            memo = { ...state
            };
          }

          memo[site.ID] = site.capabilities;
          return memo;
        }, state);
      }
  }

  return state;
});
const lasagnaJwt = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_1__/* .lasagnaSchema */ .y4, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .CURRENT_USER_RECEIVE */ .uBM:
      return action.user.lasagna_jwt || null;
  }

  return state;
});
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__/* .combineReducers */ .U)({
  id,
  user,
  capabilities,
  flags,
  emailVerification: _email_verification_reducer__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP,
  lasagnaJwt
}));

/***/ }),

/***/ 21826:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "K6": function() { return /* binding */ idSchema; },
/* harmony export */   "kX": function() { return /* binding */ capabilitiesSchema; },
/* harmony export */   "bH": function() { return /* binding */ flagsSchema; },
/* harmony export */   "y4": function() { return /* binding */ lasagnaSchema; }
/* harmony export */ });
const idSchema = {
  type: ['integer', 'null'],
  minimum: 0
};
const capabilitiesSchema = {
  type: 'object',
  additionalProperties: false,
  patternProperties: {
    '^\\d+$': {
      type: 'object',
      properties: {
        edit_pages: {
          type: 'boolean'
        },
        edit_posts: {
          type: 'boolean'
        },
        edit_others_posts: {
          type: 'boolean'
        },
        edit_others_pages: {
          type: 'boolean'
        },
        delete_posts: {
          type: 'boolean'
        },
        delete_others_posts: {
          type: 'boolean'
        },
        edit_theme_options: {
          type: 'boolean'
        },
        edit_users: {
          type: 'boolean'
        },
        list_users: {
          type: 'boolean'
        },
        manage_categories: {
          type: 'boolean'
        },
        manage_options: {
          type: 'boolean'
        },
        promote_users: {
          type: 'boolean'
        },
        publish_posts: {
          type: 'boolean'
        },
        upload_files: {
          type: 'boolean'
        },
        delete_users: {
          type: 'boolean'
        },
        remove_users: {
          type: 'boolean'
        },
        view_stats: {
          type: 'boolean'
        }
      }
    }
  }
};
const flagsSchema = {
  type: 'array'
};
const lasagnaSchema = {
  type: ['string', 'null']
};

/***/ }),

/***/ 36747:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "rc": function() { return /* binding */ getCurrentUserId; },
/* harmony export */   "ts": function() { return /* binding */ getCurrentUser; },
/* harmony export */   "bo": function() { return /* binding */ getCurrentUserSiteCount; }
/* harmony export */ });
/* unused harmony exports isUserLoggedIn, createCurrentUserSelector, getCurrentUserLocale, getCurrentUserCountryCode, getCurrentUserVisibleSiteCount, getCurrentUserDate, getCurrentUserName, getCurrentUserEmail, getCurrentUserDisplayName, currentUserHasFlag, isCurrentUserEmailVerified, getCurrentUserLasagnaJwt, isCurrentUserBootstrapped */
/**
 * Returns the current user ID
 *
 * @param  {object}  state  Global state tree
 * @returns {?number}        Current user ID
 */
function getCurrentUserId(state) {
  var _state$currentUser;

  return (_state$currentUser = state.currentUser) === null || _state$currentUser === void 0 ? void 0 : _state$currentUser.id;
}
/**
 * Is the current user logged in?
 *
 * @param {object} state Global state tree
 * @returns {boolean}	True if logged in, False if not
 */

function isUserLoggedIn(state) {
  return getCurrentUserId(state) !== null;
}
/**
 * Returns the user object for the current user.
 *
 * @param  {object}  state  Global state tree
 * @returns {import('calypso/lib/user/user').UserData|null}        Current user
 */

function getCurrentUser(state) {
  var _state$currentUser2;

  return (state === null || state === void 0 ? void 0 : (_state$currentUser2 = state.currentUser) === null || _state$currentUser2 === void 0 ? void 0 : _state$currentUser2.user) ?? null;
}
/**
 * Returns a selector that fetches a property from the current user object
 *
 * @template S,T
 * @param {string} path Path to the property in the user object
 * @param {?T} otherwise A default value that is returned if no user or property is found
 * @returns {(state: S) => T} A selector which takes the state as a parameter
 */

const createCurrentUserSelector = function (path) {
  let otherwise = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  return state => {
    const user = getCurrentUser(state);
    return (user === null || user === void 0 ? void 0 : user[path]) ?? otherwise;
  };
};
/**
 * Returns the locale slug for the current user.
 *
 * @param  {object}  state  Global state tree
 * @returns {?string}        Current user locale
 */

const getCurrentUserLocale = createCurrentUserSelector('localeSlug');
/**
 * Returns the country code for the current user.
 *
 * @param  {object}  state  Global state tree
 * @returns {?string}        Current user country code
 */

const getCurrentUserCountryCode = createCurrentUserSelector('user_ip_country_code');
/**
 * Returns the number of sites for the current user.
 *
 * @param  {object}  state  Global state tree
 * @returns {?number}        Current user site count
 */

function getCurrentUserSiteCount(state) {
  const user = getCurrentUser(state);

  if (!user) {
    return null;
  }

  return user.site_count || 0;
}
/**
 * Returns the number of visible sites for the current user.
 *
 * @param  {object}  state  Global state tree
 * @returns {?number}        Current user visible site count
 */

function getCurrentUserVisibleSiteCount(state) {
  const user = getCurrentUser(state);

  if (!user) {
    return null;
  }

  return user.visible_site_count || 0;
}
/**
 * Returns the date (of registration) for the current user.
 *
 * @param  {object}  state  Global state tree
 * @returns {?string}        Date of registration for user
 */

const getCurrentUserDate = createCurrentUserSelector('date');
/**
 *  Returns the username of the current user.
 *
 *  @param {object} state Global state tree
 *  @returns {?string} The username of the current user.
 */

const getCurrentUserName = createCurrentUserSelector('username');
/**
 *  Returns the primary email of the current user.
 *
 *  @param {object} state Global state tree
 *  @returns {?string} The primary email of the current user.
 */

const getCurrentUserEmail = createCurrentUserSelector('email');
/**
 *  Returns the primary email of the current user.
 *
 *  @param {object} state Global state tree
 *  @returns {?string} The primary email of the current user.
 */

const getCurrentUserDisplayName = createCurrentUserSelector('display_name');
/**
 * Returns true if the specified flag is enabled for the user
 *
 * @param  {object}   state      Global state tree
 * @param {string}    flagName   Flag name
 * @returns {boolean}            Whether the flag is enabled for the user
 */

function currentUserHasFlag(state, flagName) {
  return state.currentUser.flags.indexOf(flagName) !== -1;
}
/**
 * Returns true if the current user is email-verified.
 *
 * @param   {object } state Global state tree
 * @returns {boolean}       Whether the current user is email-verified.
 */

const isCurrentUserEmailVerified = createCurrentUserSelector('email_verified', false);
/**
 * Returns the Lasagna JWT for the current user.
 *
 * @param  {object}  state  Global state tree
 * @returns {?string}       Lasagna JWT
 */

function getCurrentUserLasagnaJwt(state) {
  return state.currentUser.lasagnaJwt;
}
/**
 * Returns true if the user was bootstrapped (i.e. user data was fetched by the server
 * and hydrated using window.currentUser)
 *
 * @returns {boolean} Whether the current user is bootstrapped
 */

const isCurrentUserBootstrapped = createCurrentUserSelector('bootstrapped', false);

/***/ }),

/***/ 50505:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z9": function() { return /* binding */ registerHandlers; }
/* harmony export */ });
/* unused harmony exports getHandlers, testReset */
/* harmony import */ var calypso_state_action_watchers_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(48539);

/** Stores lists of handlers by action type */

let registeredHandlers = {};
/** Stores names of already-included handler sets */

const registeredNames = new Set();
/**
 * Loads action handlers into the data layer
 *
 * @param {string} id name of handler set
 * @param {object<string, Array<Function>>} handlers set of handlers to inject
 */

const registerHandlers = (id, handlers) => {
  if (registeredNames.has(id)) {
    return;
  }

  registeredNames.add(id);
  registeredHandlers = (0,calypso_state_action_watchers_utils__WEBPACK_IMPORTED_MODULE_0__/* .mergeHandlers */ .A)(registeredHandlers, handlers);
};
/**
 * Returns list of handlers for given action type else undefined
 *
 * @param {string} actionType requested action type
 * @returns {?Array<Function>} list of handlers for type
 */

const getHandlers = actionType => registeredHandlers[actionType];
/**
 * For testing only: reset handlers
 */

const testReset = () => {
  if (false) {}
};

/***/ }),

/***/ 85875:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "aF": function() { return /* binding */ bypassDataLayer; }
/* harmony export */ });
/* unused harmony exports convertKeysBy, convertToCamelCase, convertToSnakeCase */
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_1__);


const doBypassDataLayer = {
  meta: {
    dataLayer: {
      doBypass: true
    }
  }
};
const bypassDataLayer = action => (0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .extendAction */ .zc)(action, doBypassDataLayer);
/**
 * Deeply converts keys of an object using provided function.
 *
 * @param {object} obj object to convert
 * @param  {Function} fn function to apply to each key of the object
 * @returns {object} a new object with all keys converted
 */

function convertKeysBy(obj, fn) {
  if (Array.isArray(obj)) {
    return map(obj, v => convertKeysBy(v, fn));
  }

  if (typeof obj === 'object' && obj !== null) {
    return reduce(obj, (result, value, key) => {
      const newKey = fn(key);
      const newValue = convertKeysBy(value, fn);
      return set(result, [newKey], newValue);
    }, {});
  }

  return obj;
}
/**
 * Deeply converts keys from the specified object to camelCase notation.
 *
 * @param {object} obj object to convert
 * @returns {object} a new object with all keys converted
 */

const convertToCamelCase = obj => convertKeysBy(obj, camelCase);
/**
 * Deeply convert keys of an object to snake_case.
 *
 * @param {object} obj Object to convert
 * @returns {object} a new object with snake_cased keys
 */

const convertToSnakeCase = obj => convertKeysBy(obj, snakeCase);

/***/ }),

/***/ 28867:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "d": function() { return /* binding */ http; }
/* harmony export */ });
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);

/**
 * @typedef {object} RequestDescription
 * @property {string}   [apiVersion] specific API version for request
 * @property {string}   [apiNamespace] specific API namespace for request (preferred over version)
 * @property {object}   [body] JSON-serializable body for POST requests
 * @property {string}   method name of HTTP method to use
 * @property {string}   path WordPress.com API path with %s and %d placeholders, e.g. /sites/%s
 * @property {object}   [query] key/value pairs for query string
 * @property {FormData} [formData] key/value pairs for POST body, encoded as "multipart/form-data"
 * @property {object}   [onSuccess] Redux action to call when request succeeds
 * @property {object}   [onFailure] Redux action to call when request fails
 * @property {object}   [onProgress] Redux action to call on progress events from an upload
 * @property {object}   [onStreamRecord] callback for each record of a streamed response
 * @property {object}   [options] extra options to send to the middleware, e.g. retry policy or offline policy
 */

/**
 * Returns a valid WordPress.com API HTTP Request action object
 *
 * @param {RequestDescription} HTTP request description
 * @param {?object} action default action to call on HTTP events
 * @returns {import('redux').Action} Redux action describing WordPress.com API HTTP request
 */

const http = function (_ref) {
  let {
    apiVersion,
    apiNamespace,
    body,
    method,
    path,
    query = {},
    formData,
    onSuccess,
    onFailure,
    onProgress,
    onStreamRecord,
    ...options
  } = _ref;
  let action = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  const version = apiNamespace ? {
    apiNamespace
  } : {
    apiVersion
  };

  if (false) {}

  return {
    type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .WPCOM_HTTP_REQUEST */ .koV,
    body,
    method,
    path,
    query: { ...query,
      ...version
    },
    formData,
    onSuccess: onSuccess || action,
    onFailure: onFailure || action,
    onProgress: onProgress || action,
    onStreamRecord: onStreamRecord || action,
    options
  };
};

/***/ }),

/***/ 57195:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "iD": function() { return /* binding */ noRetry; }
/* harmony export */ });
/* unused harmony export exponentialBackoff */
const exponentialBackoff = function () {
  let {
    delay = 1000,
    maxAttempts = 3
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return {
    name: 'EXPONENTIAL_BACKOFF',
    delay: Math.max(500, delay),
    maxAttempts: Math.min(5, maxAttempts)
  };
};
const noRetry = () => ({
  name: 'NO_RETRY'
});
/* unused harmony default export */ var __WEBPACK_DEFAULT_EXPORT__ = (exponentialBackoff());

/***/ }),

/***/ 67577:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "BN": function() { return /* binding */ dispatchRequest; }
/* harmony export */ });
/* unused harmony exports getData, getError, getHeaders, getProgress, getStreamRecord, getRequestKey, requestsReducerItem, reducer, trackRequests, requestDispatcher */
/* harmony import */ var _wordpress_warning__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(12560);
/* harmony import */ var _wordpress_warning__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_warning__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var fast_json_stable_stringify__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(85695);
/* harmony import */ var fast_json_stable_stringify__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(fast_json_stable_stringify__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(15960);





const noop = () => {};

const identity = data => data;
/**
 * Returns response data from an HTTP request success action if available
 *
 * @param {object} action may contain HTTP response data
 * @returns {*|undefined} response data if available
 */


const getData = action => (0,lodash__WEBPACK_IMPORTED_MODULE_2__.get)(action, 'meta.dataLayer.data', undefined);
/**
 * Returns error data from an HTTP request failure action if available
 *
 * @param {object} action may contain HTTP response error data
 * @returns {*|undefined} error data if available
 */

const getError = action => (0,lodash__WEBPACK_IMPORTED_MODULE_2__.get)(action, 'meta.dataLayer.error', undefined);
/**
 * Returns (response) headers data from an HTTP request action if available
 *
 * @param   {object}      action Request action for which to retrieve HTTP response headers
 * @returns {*|undefined}        Headers data if available
 */

const getHeaders = action => get(action, 'meta.dataLayer.headers', undefined);
/**
 * @typedef {object} ProgressData
 * @property {number} loaded Number of bytes already transferred
 * @property {number} total  Total number of bytes to transfer
 */

/**
 * Returns progress data from an HTTP request progress action if available
 *
 * @param  {object} action          may contain HTTP progress data
 * @returns {ProgressData|undefined} Progress data if available
 */

const getProgress = action => (0,lodash__WEBPACK_IMPORTED_MODULE_2__.get)(action, 'meta.dataLayer.progress', undefined);
/**
 * Returns stream record from an HTTP request action if available
 *
 * @param {object} action may contain stream record
 * @returns {*|undefined} response data if available
 */

const getStreamRecord = action => (0,lodash__WEBPACK_IMPORTED_MODULE_2__.get)(action, 'meta.dataLayer.streamRecord', undefined);

const getRequestStatus = action => {
  if (undefined !== getError(action)) {
    return 'failure';
  }

  if (undefined !== getData(action)) {
    return 'success';
  }

  return 'pending';
};

const getRequestKey = fullAction => {
  const {
    meta,
    ...action
  } = fullAction;
  const requestKey = (0,lodash__WEBPACK_IMPORTED_MODULE_2__.get)(meta, 'dataLayer.requestKey');
  return requestKey ? requestKey : fast_json_stable_stringify__WEBPACK_IMPORTED_MODULE_1___default()(action);
};
const requestsReducerItem = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let {
    meta: {
      dataLayer: {
        lastUpdated,
        pendingSince,
        status
      } = {}
    } = {}
  } = arguments.length > 1 ? arguments[1] : undefined;

  if (status === undefined) {
    return state;
  }

  return Object.assign({ ...state
  }, {
    status
  }, lastUpdated && {
    lastUpdated
  }, pendingSince && {
    pendingSince
  });
};
const reducer = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__/* .keyedReducer */ .J)('meta.dataLayer.requestKey', requestsReducerItem);
/**
 * Tracks the state of network activity for a given request type
 *
 * When we issue _REQUEST type actions they usually create some
 * associated network activity by means of an HTTP request.
 * We may want to know what the status of those requests are, if
 * they have completed or if they have failed.
 *
 * This tracker stores the meta data for those requests which
 * can then be independently polled by React components which
 * need to know about those data requests.
 *
 * Note that this is meta data about remote data requests and
 * _not_ about network activity, which is why this is code is
 * here operating on the _REQUEST actions and not in the HTTP
 * pipeline as a processor on HTTP_REQUEST actions.
 *
 * @param {Function} next next link in HTTP middleware chain
 * @returns {Function} middleware function to track requests
 */

const trackRequests = next => (store, action) => {
  // progress events don't affect
  // any tracking meta at the moment
  if (true !== (0,lodash__WEBPACK_IMPORTED_MODULE_2__.get)(action, 'meta.dataLayer.trackRequest') || getProgress(action)) {
    return next(store, action);
  }

  const requestKey = getRequestKey(action);
  const status = getRequestStatus(action);
  const dataLayer = Object.assign({
    requestKey,
    status
  }, status === 'pending' ? {
    pendingSince: Date.now()
  } : {
    lastUpdated: Date.now()
  });

  const dispatch = response => store.dispatch((0,lodash__WEBPACK_IMPORTED_MODULE_2__.merge)(response, {
    meta: {
      dataLayer
    }
  }));

  next({ ...store,
    dispatch
  }, action);
};
/**
 * Dispatches to appropriate function based on HTTP request meta
 *
 * @see state/data-layer/wpcom-http/actions#fetch creates HTTP requests
 *
 * When the WPCOM HTTP data layer handles requests it will add
 * response data and errors to a meta property on the given success
 * error, and progress handling actions.
 *
 * This function accepts several functions as the fetch, success, error and
 * progress handlers for actions and it will call the appropriate
 * one based on the stored meta.
 *
 * These handlers are action creators: based on the input data coming from the HTTP request,
 * it will return an action (or an action thunk) to be executed as a response to the given
 * HTTP event.
 *
 * If both error and response data is available this will call the
 * error handler in preference over the success handler, but the
 * response data will also still be available through the action meta.
 *
 * The functions should conform to the following type signatures:
 *   fetch  :: Action -> Action (action creator with one Action parameter)
 *   onSuccess  :: Action -> ResponseData -> Action (action creator with two params)
 *   onError    :: Action -> ErrorData -> Action
 *   onProgress :: Action -> ProgressData -> Action
 *   fromApi    :: ResponseData -> TransformedData throws TransformerError|SchemaError
 * @param {Function} middleware intercepts requests moving through the system
 * object - options object with named parameters:
 * function - options.fetch called if action lacks response meta; should create HTTP request
 * function - options.onSuccess called if the action meta includes response data
 * function - options.onError called if the action meta includes error data
 * function - options.onProgress called on progress events when uploading
 * function - options.fromApi maps between API data and Calypso data
 * @returns {(options: {fetch?: any; onSuccess?: any; onError?: any; onProgress?: any; fromApi?: any}) => any} action or action thunk to be executed in response to HTTP event
 */

const requestDispatcher = middleware => options => {
  if (!options.fetch) {
    _wordpress_warning__WEBPACK_IMPORTED_MODULE_0___default()('fetch handler is not defined: no request will ever be issued');
  }

  if (!options.onSuccess) {
    _wordpress_warning__WEBPACK_IMPORTED_MODULE_0___default()('onSuccess handler is not defined: response to the request is being ignored');
  }

  if (!options.onError) {
    _wordpress_warning__WEBPACK_IMPORTED_MODULE_0___default()('onError handler is not defined: error during the request is being ignored');
  }

  return middleware((store, action) => {
    // create the low-level action we want to dispatch
    const requestAction = createRequestAction(options, action); // dispatch the low level action (if any was created) and return the result

    if (!requestAction) {
      return;
    }

    if (Array.isArray(requestAction)) {
      return requestAction.map(store.dispatch);
    }

    return store.dispatch(requestAction);
  });
};
const dispatchRequest = requestDispatcher(trackRequests);
/*
 * Converts an application-level Calypso action that's handled by the data-layer middleware
 * into a low-level action. For example, HTTP request that's being initiated, or a response
 * action with a `meta.dataLayer` property.
 */

function createRequestAction(options, action) {
  const {
    fetch = noop,
    onSuccess = noop,
    onError = noop,
    onProgress = noop,
    onStreamRecord = noop,
    fromApi = identity
  } = options;
  const error = getError(action);

  if (error) {
    return onError(action, error);
  }

  const data = getData(action);

  if (data) {
    try {
      return onSuccess(action, fromApi(data));
    } catch (err) {
      return onError(action, err);
    }
  }

  const progress = getProgress(action);

  if (progress) {
    return onProgress(action, progress);
  }

  const record = getStreamRecord(action);

  if (record) {
    return onStreamRecord(action, record);
  }

  return fetch(action);
}

/***/ }),

/***/ 8681:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports requestReadSite, receiveReadSiteSuccess, receiveReadSiteError */
/* harmony import */ var calypso_state_data_layer_handler_registry__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(50505);
/* harmony import */ var calypso_state_data_layer_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(85875);
/* harmony import */ var calypso_state_data_layer_wpcom_http_actions__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(28867);
/* harmony import */ var calypso_state_data_layer_wpcom_http_pipeline_retry_on_failure_policies__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(57195);
/* harmony import */ var calypso_state_data_layer_wpcom_http_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(67577);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_reader_sites_actions__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(63262);
/* harmony import */ var calypso_state_reader_sites_fields__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(70418);








function requestReadSite(action) {
  return (0,calypso_state_data_layer_wpcom_http_actions__WEBPACK_IMPORTED_MODULE_4__/* .http */ .d)({
    apiVersion: '1.1',
    method: 'GET',
    path: `/read/sites/${action.payload.ID}`,
    query: {
      fields: calypso_state_reader_sites_fields__WEBPACK_IMPORTED_MODULE_5__/* .fields.join */ .X.join(','),
      options: ['is_mapped_domain', 'unmapped_url', 'is_redirect'].join(',')
    },
    retryPolicy: (0,calypso_state_data_layer_wpcom_http_pipeline_retry_on_failure_policies__WEBPACK_IMPORTED_MODULE_2__/* .noRetry */ .iD)()
  }, action);
}
function receiveReadSiteSuccess(action, response) {
  return (0,calypso_state_data_layer_utils__WEBPACK_IMPORTED_MODULE_1__/* .bypassDataLayer */ .aF)((0,calypso_state_reader_sites_actions__WEBPACK_IMPORTED_MODULE_6__/* .receiveReaderSiteRequestSuccess */ .N0)(response));
}
function receiveReadSiteError(action, response) {
  return (0,calypso_state_data_layer_utils__WEBPACK_IMPORTED_MODULE_1__/* .bypassDataLayer */ .aF)((0,calypso_state_reader_sites_actions__WEBPACK_IMPORTED_MODULE_6__/* .receiveReaderSiteRequestFailure */ .vE)(action, response));
}
(0,calypso_state_data_layer_handler_registry__WEBPACK_IMPORTED_MODULE_0__/* .registerHandlers */ .Z9)('state/data-layer/wpcom/read/sites/index.js', {
  [calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_7__/* .READER_SITE_REQUEST */ .LW]: [(0,calypso_state_data_layer_wpcom_http_utils__WEBPACK_IMPORTED_MODULE_3__/* .dispatchRequest */ .BN)({
    fetch: requestReadSite,
    onSuccess: receiveReadSiteSuccess,
    onError: receiveReadSiteError
  })]
});

/***/ }),

/***/ 26385:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports fetch, fromApi, onSuccess */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_action_watchers_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(48539);
/* harmony import */ var calypso_state_data_layer_handler_registry__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(50505);
/* harmony import */ var calypso_state_data_layer_wpcom_http_actions__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(28867);
/* harmony import */ var calypso_state_data_layer_wpcom_http_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(67577);
/* harmony import */ var calypso_state_posts_likes_actions__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(4184);
/* harmony import */ var _mine__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(46600);
/* harmony import */ var _new__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(90347);








const fetch = action => (0,calypso_state_data_layer_wpcom_http_actions__WEBPACK_IMPORTED_MODULE_5__/* .http */ .d)({
  method: 'GET',
  path: `/sites/${action.siteId}/posts/${action.postId}/likes`,
  apiVersion: '1.1'
}, action);
const fromApi = data => ({
  found: +data.found,
  iLike: !!data.i_like,
  likes: data.likes
});
const onSuccess = (_ref, data) => {
  let {
    siteId,
    postId
  } = _ref;
  return (0,calypso_state_posts_likes_actions__WEBPACK_IMPORTED_MODULE_6__/* .receiveLikes */ .u5)(siteId, postId, data);
};
(0,calypso_state_data_layer_handler_registry__WEBPACK_IMPORTED_MODULE_1__/* .registerHandlers */ .Z9)('state/data-layer/wpcom/sites/posts/likes/index.js', (0,calypso_state_action_watchers_utils__WEBPACK_IMPORTED_MODULE_0__/* .mergeHandlers */ .A)(_new__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .ZP, _mine__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z, {
  [calypso_state_action_types__WEBPACK_IMPORTED_MODULE_7__/* .POST_LIKES_REQUEST */ .PP1]: [(0,calypso_state_data_layer_wpcom_http_utils__WEBPACK_IMPORTED_MODULE_2__/* .dispatchRequest */ .BN)({
    fetch,
    fromApi,
    onSuccess,
    onError: () => {}
  })]
}));

/***/ }),

/***/ 77433:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports fromApi, fetch, onSuccess, onError */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_data_layer_handler_registry__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(50505);
/* harmony import */ var calypso_state_data_layer_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(85875);
/* harmony import */ var calypso_state_data_layer_wpcom_http_actions__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(28867);
/* harmony import */ var calypso_state_data_layer_wpcom_http_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(67577);
/* harmony import */ var calypso_state_posts_likes_actions__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(4184);






function fromApi(response) {
  if (!response.success) {
    throw new Error('Unsuccessful unlike API request');
  }

  return {
    likeCount: +response.like_count,
    liker: response.liker
  };
}
const fetch = action => {
  const query = {};

  if (action.source) {
    query.source = action.source;
  }

  return (0,calypso_state_data_layer_wpcom_http_actions__WEBPACK_IMPORTED_MODULE_3__/* .http */ .d)({
    method: 'POST',
    path: `/sites/${action.siteId}/posts/${action.postId}/likes/mine/delete`,
    apiVersion: '1.1',
    body: {},
    query
  }, action);
};
const onSuccess = (_ref, _ref2) => {
  let {
    siteId,
    postId
  } = _ref;
  let {
    likeCount,
    liker
  } = _ref2;
  return (0,calypso_state_posts_likes_actions__WEBPACK_IMPORTED_MODULE_4__/* .removeLiker */ .Ui)(siteId, postId, likeCount, liker);
};
const onError = _ref3 => {
  let {
    siteId,
    postId
  } = _ref3;
  return (0,calypso_state_data_layer_utils__WEBPACK_IMPORTED_MODULE_1__/* .bypassDataLayer */ .aF)((0,calypso_state_posts_likes_actions__WEBPACK_IMPORTED_MODULE_4__/* .like */ .vL)(siteId, postId));
};
(0,calypso_state_data_layer_handler_registry__WEBPACK_IMPORTED_MODULE_0__/* .registerHandlers */ .Z9)('state/data-layer/wpcom/sites/posts/likes/mine/delete/index.js', {
  [calypso_state_action_types__WEBPACK_IMPORTED_MODULE_5__/* .POST_UNLIKE */ .vP0]: [(0,calypso_state_data_layer_wpcom_http_utils__WEBPACK_IMPORTED_MODULE_2__/* .dispatchRequest */ .BN)({
    fetch,
    onSuccess,
    onError,
    fromApi
  })]
});
/* harmony default export */ __webpack_exports__["ZP"] = ({});

/***/ }),

/***/ 46600:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _delete__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(77433);

/* harmony default export */ __webpack_exports__["Z"] = (_delete__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP);

/***/ }),

/***/ 90347:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports fetch, onSuccess, onError, fromApi */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_data_layer_handler_registry__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(50505);
/* harmony import */ var calypso_state_data_layer_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(85875);
/* harmony import */ var calypso_state_data_layer_wpcom_http_actions__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(28867);
/* harmony import */ var calypso_state_data_layer_wpcom_http_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(67577);
/* harmony import */ var calypso_state_posts_likes_actions__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(4184);






const fetch = action => {
  const query = {};

  if (action.source) {
    query.source = action.source;
  }

  return (0,calypso_state_data_layer_wpcom_http_actions__WEBPACK_IMPORTED_MODULE_3__/* .http */ .d)({
    method: 'POST',
    path: `/sites/${action.siteId}/posts/${action.postId}/likes/new`,
    body: {},
    apiVersion: '1.1',
    query
  }, action);
};
const onSuccess = (_ref, _ref2) => {
  let {
    siteId,
    postId
  } = _ref;
  let {
    likeCount,
    liker
  } = _ref2;
  return (0,calypso_state_posts_likes_actions__WEBPACK_IMPORTED_MODULE_4__/* .addLiker */ .eT)(siteId, postId, likeCount, liker);
};
const onError = _ref3 => {
  let {
    siteId,
    postId
  } = _ref3;
  return (0,calypso_state_data_layer_utils__WEBPACK_IMPORTED_MODULE_1__/* .bypassDataLayer */ .aF)((0,calypso_state_posts_likes_actions__WEBPACK_IMPORTED_MODULE_4__/* .unlike */ .Yt)(siteId, postId));
};
function fromApi(response) {
  if (!response.success) {
    throw new Error('Unsuccessful like API call');
  }

  return {
    likeCount: +response.like_count,
    liker: response.liker
  };
}
(0,calypso_state_data_layer_handler_registry__WEBPACK_IMPORTED_MODULE_0__/* .registerHandlers */ .Z9)('state/data-layer/wpcom/sites/posts/likes/new/index.js', {
  [calypso_state_action_types__WEBPACK_IMPORTED_MODULE_5__/* .POST_LIKE */ .RFP]: [(0,calypso_state_data_layer_wpcom_http_utils__WEBPACK_IMPORTED_MODULE_2__/* .dispatchRequest */ .BN)({
    fetch,
    onSuccess,
    onError,
    fromApi
  })]
});
/* harmony default export */ __webpack_exports__["ZP"] = ({});

/***/ }),

/***/ 85745:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports maybeUpscaleTimePrecision, lastActivityTimestamp, status, timeline */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(28447);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(71085);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(95884);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(83551);



 // We compare incoming timestamps against a known future Unix time in seconds date
// to determine if the timestamp is in seconds or milliseconds resolution. If the former,
// we "upgrade" it by multiplying by 1000.
//
// This will all be removed once the server-side is fully converted.

const UNIX_TIMESTAMP_2023_IN_SECONDS = 1700000000;
const maybeUpscaleTimePrecision = time => time < UNIX_TIMESTAMP_2023_IN_SECONDS ? time * 1000 : time;
const lastActivityTimestampSchema = {
  type: 'number'
};
const lastActivityTimestamp = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .withSchemaValidation */ .G)(lastActivityTimestampSchema, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_SEND_MESSAGE_MESSAGE */ .qjX:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_MESSAGE */ .$Tb:
      return Date.now();
  }

  return state;
});
/**
 * Tracks the state of the happychat chat. Valid states are:
 *
 *  - HAPPYCHAT_CHAT_STATUS_DEFAULT : no chat has been started
 *  - HAPPYCHAT_CHAT_STATUS_PENDING : chat has been started but no operator assigned
 *  - HAPPYCHAT_CHAT_STATUS_ASSIGNING : system is assigning to an operator
 *  - HAPPYCHAT_CHAT_STATUS_ASSIGNED : operator has been connected to the chat
 *  - HAPPYCHAT_CHAT_STATUS_MISSED : no operator could be assigned
 *  - HAPPYCHAT_CHAT_STATUS_ABANDONED : operator was disconnected
 *  - HAPPYCHAT_CHAT_STATUS_CLOSED : chat was closed
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const status = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_2__/* .HAPPYCHAT_CHAT_STATUS_DEFAULT */ .s0;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_STATUS */ .myH:
      return action.status;
  }

  return state;
};
/**
 * Returns a timeline event from the redux action
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const timelineEvent = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_MESSAGE */ .$Tb:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_MESSAGE_OPTIMISTIC */ .IoY:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_MESSAGE_UPDATE */ .Ylp:
      {
        var _message$meta;

        const {
          message
        } = action;
        return {
          id: message.id,
          source: message.source,
          message: message.text,
          name: message.user.name,
          image: message.user.avatarURL,
          isEdited: !!message.revisions,
          isOptimistic: message.isOptimistic,
          files: message.files,
          timestamp: maybeUpscaleTimePrecision(message.timestamp),
          user_id: message.user.id,
          type: message.type ?? 'message',
          links: (_message$meta = message.meta) === null || _message$meta === void 0 ? void 0 : _message$meta.links
        };
      }
  }

  return state;
};

const getEventTimestamp = event => parseInt(event.timestamp, 10);

const timelineSortCmp = (a, b) => getEventTimestamp(a) - getEventTimestamp(b);

const sortTimeline = timeline => timeline.slice().sort(timelineSortCmp);
/**
 * Adds timeline events for happychat
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */


const timelineReducer = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_MESSAGE */ .$Tb:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_MESSAGE_OPTIMISTIC */ .IoY:
      {
        var _action$message$meta;

        // if meta.forOperator is set, skip so won't show to user
        if ((_action$message$meta = action.message.meta) !== null && _action$message$meta !== void 0 && _action$message$meta.forOperator) {
          return state;
        }

        const event = timelineEvent({}, action); // If the message already exists in the timeline, replace it

        const idx = state.findIndex(_ref => {
          let {
            id
          } = _ref;
          return event.id === id;
        });

        if (idx >= 0) {
          return [...state.slice(0, idx), event, ...state.slice(idx + 1)];
        } // This is a new message — append it!


        return state.concat([event]);
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_MESSAGE_UPDATE */ .Ylp:
      {
        const index = state.findIndex(_ref2 => {
          let {
            id
          } = _ref2;
          return action.message.id === id;
        });
        return index === -1 ? state : [...state.slice(0, index), timelineEvent({}, action), ...state.slice(index + 1)];
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_REQUEST_TRANSCRIPT_RECEIVE */ .kJ4:
      {
        var _action$messages;

        const messages = ((_action$messages = action.messages) === null || _action$messages === void 0 ? void 0 : _action$messages.filter(message => {
          var _message$meta2;

          if (!message.id) {
            return false;
          } // if meta.forOperator is set, skip so won't show to user


          if ((_message$meta2 = message.meta) !== null && _message$meta2 !== void 0 && _message$meta2.forOperator) {
            return false;
          }

          return !state.some(event => event.id === message.id);
        })) ?? [];
        return sortTimeline(state.concat(messages.map(message => {
          var _message$meta3;

          return {
            id: message.id,
            source: message.source,
            message: message.text,
            name: message.user.name,
            image: message.user.picture,
            isEdited: !!message.revisions,
            files: message.files,
            timestamp: maybeUpscaleTimePrecision(message.timestamp),
            user_id: message.user.id,
            type: message.type ?? 'message',
            links: (_message$meta3 = message.meta) === null || _message$meta3 === void 0 ? void 0 : _message$meta3.links
          };
        })));
      }
  }

  return state;
};

const timeline = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_3__/* .timelineSchema */ .v, (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__/* .withPersistence */ .$)(timelineReducer, {
  serialize: state => state.slice(-1 * calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_2__/* .HAPPYCHAT_MAX_STORED_MESSAGES */ .lc)
}));
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_5__/* .combineReducers */ .U)({
  status,
  timeline,
  lastActivityTimestamp
}));

/***/ }),

/***/ 83551:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "v": function() { return /* binding */ timelineSchema; }
/* harmony export */ });
/* unused harmony export eventSchema */
const eventSchema = {
  type: 'object',
  additionalProperties: false,
  required: ['id', 'source', 'message', 'timestamp', 'user_id', 'type'],
  properties: {
    id: {
      type: 'string'
    },
    source: {
      type: 'string'
    },
    message: {
      type: 'string'
    },
    name: {
      type: 'string'
    },
    image: {
      type: 'string'
    },
    timestamp: {
      type: ['number', 'string']
    },
    user_id: {
      type: ['number', 'string']
    },
    type: {
      type: 'string'
    },
    links: {
      type: 'array'
    }
  }
};
const timelineSchema = {
  type: 'array',
  additionalProperties: false,
  items: eventSchema
};

/***/ }),

/***/ 94002:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "id": function() { return /* binding */ receiveConnect; },
/* harmony export */   "nv": function() { return /* binding */ receiveDisconnect; },
/* harmony export */   "wH": function() { return /* binding */ receiveToken; },
/* harmony export */   "k_": function() { return /* binding */ receiveInit; },
/* harmony export */   "up": function() { return /* binding */ receiveUnauthorized; },
/* harmony export */   "Mo": function() { return /* binding */ receiveReconnecting; },
/* harmony export */   "pL": function() { return /* binding */ receiveAccept; },
/* harmony export */   "$W": function() { return /* binding */ receiveLocalizedSupport; },
/* harmony export */   "QM": function() { return /* binding */ receiveMessage; },
/* harmony export */   "dN": function() { return /* binding */ receiveMessageOptimistic; },
/* harmony export */   "gg": function() { return /* binding */ receiveMessageUpdate; },
/* harmony export */   "KX": function() { return /* binding */ receiveStatus; },
/* harmony export */   "Mx": function() { return /* binding */ receiveError; },
/* harmony export */   "bi": function() { return /* binding */ requestTranscript; },
/* harmony export */   "qP": function() { return /* binding */ sendEvent; },
/* harmony export */   "yW": function() { return /* binding */ setChatCustomFields; }
/* harmony export */ });
/* unused harmony exports initConnection, receiveTranscript, sendMessage, sendLog, sendUserInfo, sendTyping, sendNotTyping, sendPreferences */
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(88767);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(28447);
/* harmony import */ var calypso_state_happychat_init__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(84656);




/**
 * Returns an action object indicating that the connection is being stablished.
 *
 * @param { Promise } auth Authentication promise, will return the user info upon fulfillment
 * @returns {object} Action object
 */

const initConnection = auth => ({
  type: HAPPYCHAT_IO_INIT,
  auth
});
/**
 * Returns an action object for the connect event,
 * as it was received from Happychat.
 *
 * @returns {object} Action object
 */

const receiveConnect = () => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_CONNECT */ .oH7
});
/**
 * Returns an action object for the disconnect event,
 * as it was received from Happychat.
 *
 * @param {string} error The error
 * @returns {object} Action object
 */

const receiveDisconnect = error => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_DISCONNECT */ .f5U,
  error
});
/**
 * Returns an action object for the token event,
 * as it was received from Happychat.
 *
 * @returns {object} Action object
 */

const receiveToken = () => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_TOKEN */ .yGK
});
/**
 * Returns an action object for the init event, as received from Happychat.
 * Indicates that the connection is ready to be used.
 *
 * @param {object} user User object received
 * @returns {object} Action object
 */

const receiveInit = user => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_INIT */ .M7f,
  user
});
/**
 * Returns an action object for the unauthorized event,
 * as it was received from Happychat
 *
 * @param {string} error Error reported
 * @returns {object} Action object
 */

const receiveUnauthorized = error => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_UNAUTHORIZED */ .IwF,
  error
});
/**
 * Returns an action object for the reconnecting event,
 * as it was received from Happychat.
 *
 * @returns {object} Action object
 */

const receiveReconnecting = () => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_RECONNECTING */ .k_K
});
/**
 * Returns an action object for the accept event indicating the system availability,
 * as it was received from Happychat.
 *
 * @param  {object} isAvailable Whether Happychat is available
 * @returns {object} Action object
 */

const receiveAccept = isAvailable => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_ACCEPT */ .nHy,
  isAvailable
});
/**
 * Returns an action object for the accept event indicating the system availability,
 * as it was received from Happychat.
 *
 * @param  {object} isAvailable Whether Happychat is available
 * @returns {object} Action object
 */

const receiveLocalizedSupport = isAvailable => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_LOCALIZED_SUPPORT */ .Sur,
  isAvailable
});
/**
 * Returns an action object for the message event,
 * as it was received from Happychat.
 *
 * @param  {object} message Message received
 * @returns {object} Action object
 */

const receiveMessage = message => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_MESSAGE */ .$Tb,
  message
});
/**
 * Returns an action object for the optimistic message event,
 * as it was received from Happychat.
 *
 * @param  {object} message Message received
 * @returns {object} Action object
 */

const receiveMessageOptimistic = message => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_MESSAGE_OPTIMISTIC */ .IoY,
  message: { ...message,
    isOptimistic: true
  }
});
/**
 * Returns an action object for the message update event,
 * as it was received from Happychat.
 *
 * @param  {object} message Updated message
 * @returns {object} Action object
 */

const receiveMessageUpdate = message => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_MESSAGE_UPDATE */ .Ylp,
  message
});
/**
 * Returns an action object for the status event,
 * as it was received from Happychat.
 *
 * @param  {string} status New chat status
 * @returns {object} Action object
 */

const receiveStatus = status => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_STATUS */ .myH,
  status
});
/**
 * Returns an action object with the error received from Happychat
 * upon trying to send an event.
 *
 * @param  {object} error Error received
 * @returns {object} Action object
 */

const receiveError = error => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_RECEIVE_ERROR */ .AKl,
  error
});
/**
 * Returns an action object for the transcript reception.
 *
 * @param {object} result           An object with {messages, timestamp} props
 * @param {Array}  result.messages  An array of message objects
 * @param {number} result.timestamp The transcript reception timestamp
 * @returns {object} Action object
 */

const receiveTranscript = _ref => {
  let {
    messages,
    timestamp
  } = _ref;
  return {
    type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_REQUEST_TRANSCRIPT_RECEIVE */ .kJ4,
    messages,
    timestamp
  };
};
/**
 * Returns an action object that prepares the transcript request
 * to be send to happychat as a SocketIO event.
 *
 * @param {string} timestamp Latest transcript timestamp
 * @param {number} timeout The number of milliseconds to wait for server response.
 * @returns {object} Action object
 */

const requestTranscript = function (timestamp) {
  let timeout = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 10000;
  return {
    type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_REQUEST_TRANSCRIPT */ .R_D,
    event: 'transcript',
    payload: timestamp,
    timeout: timeout,
    callback: receiveTranscript
  };
};
/**
 * Returns an action object that prepares the chat message
 * to be send to Happychat as a SocketIO event.
 *
 * @param  {object} message Message to be sent
 * @param  {object} meta meta info to be sent along the message
 * @returns {object} Action object
 */

const sendMessage = function (message) {
  let meta = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  return {
    type: HAPPYCHAT_IO_SEND_MESSAGE_MESSAGE,
    event: 'message',
    payload: {
      id: uuid(),
      text: message,
      meta
    }
  };
};
/**
 * Returns an action object that prepares the event message
 * to be send to Happychat as a SocketIO event.
 *
 * @param  {object} message Message to be sent
 * @returns {object} Action object
 */

const sendEvent = message => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_SEND_MESSAGE_EVENT */ .Syf,
  event: 'message',
  payload: {
    id: (0,uuid__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(),
    text: message,
    type: calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_MESSAGE_TYPES.CUSTOMER_EVENT */ .so.CUSTOMER_EVENT,
    meta: {
      forOperator: true,
      event_type: calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_MESSAGE_TYPES.CUSTOMER_EVENT */ .so.CUSTOMER_EVENT
    }
  }
});
/**
 * Returns an action object that prepares the log message
 * to be send to Happychat as a SocketIO event.
 *
 * @param  {object} message Message to be sent
 * @returns {object} Action object
 */

const sendLog = message => ({
  type: HAPPYCHAT_IO_SEND_MESSAGE_LOG,
  event: 'message',
  payload: {
    id: uuid(),
    text: message,
    type: HAPPYCHAT_MESSAGE_TYPES.LOG,
    meta: {
      forOperator: true,
      event_type: HAPPYCHAT_MESSAGE_TYPES.LOG
    }
  }
});
/**
 * Returns an action object that prepares the user information
 * to be send to Happychat as a SocketIO event.
 *
 * @param  {object} info Selected user info
 * @returns {object} Action object
 */

const sendUserInfo = info => ({
  type: HAPPYCHAT_IO_SEND_MESSAGE_USERINFO,
  event: 'message',
  payload: {
    id: uuid(),
    type: HAPPYCHAT_MESSAGE_TYPES.CUSTOMER_INFO,
    meta: {
      forOperator: true,
      ...info
    }
  }
});
/**
 * Returns an action object that prepares the typing info
 * to be sent to Happychat as a SocketIO event.
 *
 * @param  {object} message What the user is typing
 * @returns {object} Action object
 */

const sendTyping = message => ({
  type: HAPPYCHAT_IO_SEND_TYPING,
  event: 'typing',
  payload: {
    message
  }
});
/**
 * Returns an action object that prepares typing info (the user stopped typing)
 * to be sent to Happychat as a SocketIO event.
 *
 * @returns {object} Action object
 */

const sendNotTyping = () => sendTyping(false);
/**
 * Returns an action object that prepares the user routing preferences (locale and groups)
 * to be send to happychat as a SocketIO event.
 *
 * @param {string} locale representing the user selected locale
 * @param { Array } groups of string happychat groups (wp.com, jpop) based on the site selected
 * @param {object} skills object based on product and language ( formerly group and locale )
 * @returns {object} Action object
 */

const sendPreferences = (locale, groups, skills) => ({
  type: HAPPYCHAT_IO_SEND_PREFERENCES,
  event: 'preferences',
  payload: {
    locale,
    groups,
    skills
  }
});
/**
 * Returns an action object that will send the given Custom Field key/values to be
 * set on the current chat.
 *
 * @param {object} fieldData Key/values of Custom Fields to be set
 * @returns {object} Action object
 */

const setChatCustomFields = fieldData => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_IO_SET_CUSTOM_FIELDS */ .SgU,
  event: 'chat.setFields',
  payload: fieldData
});

/***/ }),

/***/ 80258:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export localizedSupport */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(28447);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(95884);




const error = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_IO_RECEIVE_INIT */ .M7f:
      return null;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_IO_RECEIVE_DISCONNECT */ .f5U:
      return action.error;
  }

  return state;
};
/**
 * Tracks the state of the happychat client connection
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */


const status = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_CONNECTION_STATUS_UNINITIALIZED */ .SJ;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_IO_INIT */ .Mei:
      return calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_CONNECTION_STATUS_CONNECTING */ .bp;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_IO_RECEIVE_INIT */ .M7f:
      return calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_CONNECTION_STATUS_CONNECTED */ .XY;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_IO_RECEIVE_DISCONNECT */ .f5U:
      return calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_CONNECTION_STATUS_DISCONNECTED */ .oP;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_IO_RECEIVE_RECONNECTING */ .k_K:
      return calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_CONNECTION_STATUS_RECONNECTING */ .ad;
  }

  return state;
};
/**
 * Tracks whether happychat.io is accepting new chats.
 *
 * @param  {boolean} state  Current happychat status
 * @param  {object}  action Action playload
 * @returns {boolean}        Updated happychat status
 */


const isAvailable = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_IO_RECEIVE_ACCEPT */ .nHy:
      return action.isAvailable;
  }

  return state;
};
/**
 * Tracks whether happychat.io is accepting fully localized chats.
 * Customers locale and HE locale should be an exact match ( doesn't default routing to english speaker HEs )
 *
 * @param  {boolean} state  Current happychat status
 * @param  {object}  action Action playload
 * @returns {boolean}        Updated happychat status
 */


const localizedSupport = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_IO_RECEIVE_LOCALIZED_SUPPORT */ .Sur:
      return action.isAvailable;
  }

  return state;
};
/* harmony default export */ __webpack_exports__["Z"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .combineReducers */ .U)({
  error,
  isAvailable,
  localizedSupport,
  status
}));

/***/ }),

/***/ 28447:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "SJ": function() { return /* binding */ HAPPYCHAT_CONNECTION_STATUS_UNINITIALIZED; },
/* harmony export */   "bp": function() { return /* binding */ HAPPYCHAT_CONNECTION_STATUS_CONNECTING; },
/* harmony export */   "XY": function() { return /* binding */ HAPPYCHAT_CONNECTION_STATUS_CONNECTED; },
/* harmony export */   "oP": function() { return /* binding */ HAPPYCHAT_CONNECTION_STATUS_DISCONNECTED; },
/* harmony export */   "ad": function() { return /* binding */ HAPPYCHAT_CONNECTION_STATUS_RECONNECTING; },
/* harmony export */   "lc": function() { return /* binding */ HAPPYCHAT_MAX_STORED_MESSAGES; },
/* harmony export */   "so": function() { return /* binding */ HAPPYCHAT_MESSAGE_TYPES; },
/* harmony export */   "dZ": function() { return /* binding */ HAPPYCHAT_CHAT_STATUS_ASSIGNED; },
/* harmony export */   "s0": function() { return /* binding */ HAPPYCHAT_CHAT_STATUS_DEFAULT; }
/* harmony export */ });
/* unused harmony exports HAPPYCHAT_CONNECTION_ERROR_FORCED_CLOSE, HAPPYCHAT_CONNECTION_ERROR_PING_TIMEOUT, HAPPYCHAT_CONNECTION_ERROR_TRANSPORT_CLOSE, HAPPYCHAT_CONNECTION_ERROR_TRANSPORT_ERROR, HAPPYCHAT_CONNECTION_STATUS_UNAUTHORIZED, HAPPYCHAT_SKILL_PRODUCT, HAPPYCHAT_SKILL_LANGUAGE, HAPPYCHAT_GROUP_JPOP, HAPPYCHAT_GROUP_WOO, HAPPYCHAT_GROUP_JPPHP, HAPPYCHAT_GROUP_WPCOM, HAPPYCHAT_CHAT_STATUS_ABANDONED, HAPPYCHAT_CHAT_STATUS_ASSIGNING, HAPPYCHAT_CHAT_STATUS_BLOCKED, HAPPYCHAT_CHAT_STATUS_CLOSED, HAPPYCHAT_CHAT_STATUS_NEW, HAPPYCHAT_CHAT_STATUS_MISSED, HAPPYCHAT_CHAT_STATUS_PENDING */
// These CONNECTION_ERROR constants come directly from the Socket.IO client library.
// These are the possible reasons for a connection disconnect.
const HAPPYCHAT_CONNECTION_ERROR_FORCED_CLOSE = 'forced close';
const HAPPYCHAT_CONNECTION_ERROR_PING_TIMEOUT = 'ping timeout';
const HAPPYCHAT_CONNECTION_ERROR_TRANSPORT_CLOSE = 'transport close';
const HAPPYCHAT_CONNECTION_ERROR_TRANSPORT_ERROR = 'transport error'; // connection status

const HAPPYCHAT_CONNECTION_STATUS_UNINITIALIZED = 'uninitialized';
const HAPPYCHAT_CONNECTION_STATUS_CONNECTING = 'connecting';
const HAPPYCHAT_CONNECTION_STATUS_CONNECTED = 'connected';
const HAPPYCHAT_CONNECTION_STATUS_DISCONNECTED = 'disconnected';
const HAPPYCHAT_CONNECTION_STATUS_RECONNECTING = 'reconnecting';
const HAPPYCHAT_CONNECTION_STATUS_UNAUTHORIZED = 'unauthorized'; // Max number of messages to save between refreshes

const HAPPYCHAT_MAX_STORED_MESSAGES = 30; // Skills

const HAPPYCHAT_SKILL_PRODUCT = 'product';
const HAPPYCHAT_SKILL_LANGUAGE = 'language'; // Groups

const HAPPYCHAT_GROUP_JPOP = 'jpop';
const HAPPYCHAT_GROUP_WOO = 'woo';
const HAPPYCHAT_GROUP_JPPHP = 'jpphp';
const HAPPYCHAT_GROUP_WPCOM = 'WP.com'; // Message types

const HAPPYCHAT_MESSAGE_TYPES = {
  CUSTOMER_EVENT: 'customer-event',
  CUSTOMER_INFO: 'customer-info',
  LOG: 'log'
}; // Chat status

const HAPPYCHAT_CHAT_STATUS_ABANDONED = 'abandoned';
const HAPPYCHAT_CHAT_STATUS_ASSIGNED = 'assigned';
const HAPPYCHAT_CHAT_STATUS_ASSIGNING = 'assigning';
const HAPPYCHAT_CHAT_STATUS_BLOCKED = 'blocked';
const HAPPYCHAT_CHAT_STATUS_CLOSED = 'closed';
const HAPPYCHAT_CHAT_STATUS_DEFAULT = 'default';
const HAPPYCHAT_CHAT_STATUS_NEW = 'new';
const HAPPYCHAT_CHAT_STATUS_MISSED = 'missed';
const HAPPYCHAT_CHAT_STATUS_PENDING = 'pending';

/***/ }),

/***/ 84656:
/***/ (function(__unused_webpack_module, __unused_webpack___webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9044);
/* harmony import */ var _reducer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(61741);


(0,calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_0__/* .registerReducer */ .x)(['happychat'], _reducer__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z);

/***/ }),

/***/ 76693:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export socketMiddleware */
/* harmony import */ var _automattic_happychat_connection__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(10819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(94002);
/* harmony import */ var calypso_state_happychat_selectors_is_happychat_chat_assigned__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(11834);
/* harmony import */ var calypso_state_happychat_selectors_is_happychat_client_connected__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(27443);







const noop = () => {};

const eventMessage = {
  HAPPYCHAT_BLUR: 'Stopped looking at Happychat',
  HAPPYCHAT_FOCUS: 'Started looking at Happychat'
};
const socketMiddleware = function () {
  let connection = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;

  // Allow a connection object to be specified for
  // testing. If blank, use a real connection.
  if (connection == null) {
    connection = (0,_automattic_happychat_connection__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)({
      receiveAccept: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveAccept */ .pL,
      receiveConnect: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveConnect */ .id,
      receiveDisconnect: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveDisconnect */ .nv,
      receiveError: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveError */ .Mx,
      receiveInit: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveInit */ .k_,
      receiveLocalizedSupport: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveLocalizedSupport */ .$W,
      receiveMessage: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveMessage */ .QM,
      receiveMessageOptimistic: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveMessageOptimistic */ .dN,
      receiveMessageUpdate: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveMessageUpdate */ .gg,
      receiveReconnecting: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveReconnecting */ .Mo,
      receiveStatus: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveStatus */ .KX,
      receiveToken: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveToken */ .wH,
      receiveUnauthorized: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .receiveUnauthorized */ .up,
      requestTranscript: calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .requestTranscript */ .bi
    });
  }

  return store => next => action => {
    const state = store.getState();

    switch (action.type) {
      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_IO_INIT */ .Mei:
        connection.init(store.dispatch, action.auth);
        break;

      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_IO_REQUEST_TRANSCRIPT */ .R_D:
        {
          connection.request(action, action.timeout);
          break;
        }

      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_IO_SEND_MESSAGE_USERINFO */ .$tj:
        // When user info is sent, pass it through in a message...
        connection.send(action); // ... and also set a few of the values in Custom Fields

        store.dispatch((0,calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .setChatCustomFields */ .yW)({
          howCanWeHelp: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(action, 'payload.meta.howCanWeHelp', null),
          howYouFeel: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(action, 'payload.meta.howYouFeel', null)
        }));
        break;

      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_IO_SEND_MESSAGE_EVENT */ .Syf:
      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_IO_SEND_MESSAGE_LOG */ .vsK:
      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_IO_SEND_MESSAGE_MESSAGE */ .qjX:
      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_IO_SEND_PREFERENCES */ .Do$:
      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_IO_SEND_TYPING */ .ILV:
      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_IO_SET_CUSTOM_FIELDS */ .SgU:
        connection.send(action);
        break;

      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_BLUR */ .vQd:
      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .HAPPYCHAT_FOCUS */ .o9b:
        (0,calypso_state_happychat_selectors_is_happychat_client_connected__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(state) && (0,calypso_state_happychat_selectors_is_happychat_chat_assigned__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(state) && eventMessage[action.type] ? store.dispatch((0,calypso_state_happychat_connection_actions__WEBPACK_IMPORTED_MODULE_2__/* .sendEvent */ .qP)(eventMessage[action.type])) : noop;
        break;
    }

    return next(action);
  };
};
/* harmony default export */ __webpack_exports__["Z"] = (socketMiddleware());

/***/ }),

/***/ 61741:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(95884);
/* harmony import */ var _chat_reducer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(85745);
/* harmony import */ var _connection_reducer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(80258);
/* harmony import */ var _ui_reducer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(29837);
/* harmony import */ var _user_reducer__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(12844);






const combinedReducer = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .combineReducers */ .U)({
  chat: _chat_reducer__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP,
  connection: _connection_reducer__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z,
  ui: _ui_reducer__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .ZP,
  user: _user_reducer__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .ZP
});
/* harmony default export */ __webpack_exports__["Z"] = ((0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .withStorageKey */ .xi)('happychat', combinedReducer));

/***/ }),

/***/ 83455:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* export default binding */ __WEBPACK_DEFAULT_EXPORT__; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_happychat_init__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(84656);


/**
 * Gets the current happychat connection status
 *
 * @param {object} state - global redux state
 * @returns {string} current state value
 */

/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(state) {
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(state, 'happychat.connection.status');
}

/***/ }),

/***/ 11834:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(28447);
/* harmony import */ var calypso_state_happychat_init__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(84656);



/* harmony default export */ __webpack_exports__["Z"] = (state => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(state, 'happychat.chat.status') === calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_2__/* .HAPPYCHAT_CHAT_STATUS_ASSIGNED */ .dZ);

/***/ }),

/***/ 27443:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* export default binding */ __WEBPACK_DEFAULT_EXPORT__; }
/* harmony export */ });
/* harmony import */ var calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(28447);
/* harmony import */ var calypso_state_happychat_selectors_get_happychat_connection_status__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83455);


/**
 * Returns true if connection status is connected
 *
 * @param {object} state - global redux state
 * @returns {boolean} Whether Happychat connection status is connected
 */

/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(state) {
  return (0,calypso_state_happychat_selectors_get_happychat_connection_status__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state) === calypso_state_happychat_constants__WEBPACK_IMPORTED_MODULE_1__/* .HAPPYCHAT_CONNECTION_STATUS_CONNECTED */ .XY;
}

/***/ }),

/***/ 29837:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports currentMessage, lostFocusAt */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(71085);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(95884);


/**
 * Tracks the current message the user has typed into the happychat client
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const currentMessage = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_IO_SEND_MESSAGE_MESSAGE */ .qjX:
      return '';

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_SET_CURRENT_MESSAGE */ .c2t:
      return action.message;
  }

  return state;
};
const lostFocusAtSchema = {
  type: 'number'
};
/**
 * Tracks the last time Happychat had focus. This lets us determine things like
 * whether the user has unread messages. A numerical value is the timestamp where focus
 * was lost, and `null` means HC currently has focus.
 *
 * @param {object} state Current state
 * @param {object} action Action payload
 * @returns {object}        Updated state
 */

const lostFocusAt = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .withSchemaValidation */ .G)(lostFocusAtSchema, (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .withPersistence */ .$)(function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_BLUR */ .vQd:
      return Date.now();

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_FOCUS */ .o9b:
      return null;
  }

  return state;
}, {
  serialize: state => {
    // If there's already a timestamp set, use that. Otherwise treat serialization as a
    // "loss of focus" since it represents the state when the browser (and HC) closed.
    if (state === null) {
      return Date.now();
    }

    return state;
  }
}));

const isOpen = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_OPEN */ .eYx:
      return !!action.isOpen;
  }

  return state;
};
/**
 * Tracks the state of the happychat minimizing process
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */


const isMinimizing = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HAPPYCHAT_MINIMIZING */ .tyO:
      return action.isMinimizing ? true : false;
  }

  return state;
};

/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__/* .combineReducers */ .U)({
  currentMessage,
  isMinimizing,
  isOpen,
  lostFocusAt
}));

/***/ }),

/***/ 12844:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports geoLocation, isEligible, availability, supportLevel */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(95884);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(71320);



/**
 * Tracks the current user geo location.
 *
 *
 * @param {object} action Action payload
 * @returns {object}        Updated state
 */

const geoLocation = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_1__/* .geoLocationSchema */ .FB, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .HAPPYCHAT_IO_RECEIVE_INIT */ .M7f:
      {
        const location = action.user.geoLocation;

        if (location && location.country_long && location.city) {
          return location;
        }

        return state;
      }
  }

  return state;
});
const isEligible = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_1__/* .isEligibleSchema */ .Cv, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .HAPPYCHAT_SET_USER_CONFIG */ .Xeb:
      return action.config.isUserEligible;
  }

  return state;
});
const availability = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_1__/* .availabilitySchema */ .i6, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .HAPPYCHAT_SET_USER_CONFIG */ .Xeb:
      return action.config.availability;
  }

  return state;
});
/**
 * The level of support we're offering to this user (represents their highest paid plan).
 */

const supportLevel = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_1__/* .supportLevelSchema */ ._B, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .HAPPYCHAT_SET_USER_CONFIG */ .Xeb:
      return action.config.supportLevel;

    default:
      return state;
  }
});
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__/* .combineReducers */ .U)({
  geoLocation,
  isEligible,
  availability,
  supportLevel
}));

/***/ }),

/***/ 71320:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "FB": function() { return /* binding */ geoLocationSchema; },
/* harmony export */   "Cv": function() { return /* binding */ isEligibleSchema; },
/* harmony export */   "i6": function() { return /* binding */ availabilitySchema; },
/* harmony export */   "_B": function() { return /* binding */ supportLevelSchema; }
/* harmony export */ });
const geoLocationSchema = {
  type: ['object', 'null'],
  properties: {
    city: {
      type: 'string'
    },
    country_long: {
      type: 'string'
    },
    country_short: {
      type: 'string'
    },
    region: {
      type: 'string'
    }
  }
};
const isEligibleSchema = {
  type: ['boolean', 'null']
};
const availabilitySchema = {
  type: ['object', 'null'],
  properties: {
    precancellation: {
      type: 'boolean'
    },
    presale: {
      type: 'boolean'
    }
  }
};
const supportLevelSchema = {
  type: ['string', 'null']
};

/***/ }),

/***/ 89621:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_blocks_inline_help_admin_sections__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(67459);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(20834);



/**
 * Returns a filtered site admin collection using the memoized getAdminSections.
 *
 * Note that the first argument `state` is not used,
 * because the admin sections are store in the admin-sections.js,
 * in the inline-block component.
 *
 * @param   {object} state      Global state tree
 * @param   {string} searchTerm The search term
 * @param   {number} limit      The maximum number of results to show
 * @returns {Array}             A filtered (or empty) array
 */

const getAdminHelpResults = (0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .createSelector */ .P1)(function (state) {
  let searchTerm = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  let limit = arguments.length > 2 ? arguments[2] : undefined;

  if (!searchTerm) {
    return [];
  }

  const siteId = (0,calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state);
  return (0,calypso_blocks_inline_help_admin_sections__WEBPACK_IMPORTED_MODULE_1__/* .filterListBySearchTerm */ .x)(searchTerm, (0,calypso_blocks_inline_help_admin_sections__WEBPACK_IMPORTED_MODULE_1__/* .getAdminSections */ .p)(state, siteId), limit);
}, state => [(0,calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state)]);
/* harmony default export */ __webpack_exports__["Z"] = (getAdminHelpResults);

/***/ }),

/***/ 80951:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "e": function() { return /* binding */ DEFAULT_POST_QUERY; }
/* harmony export */ });
/* unused harmony export POST_STATUSES */
const DEFAULT_POST_QUERY = {
  context: 'display',
  http_envelope: false,
  pretty: false,
  number: 20,
  offset: 0,
  page: 1,
  order: 'DESC',
  order_by: 'date',
  type: 'post',
  status: 'publish',
  sticky: 'include',
  search: ''
}; // All post statuses displayed in Calypso.

const POST_STATUSES = (/* unused pure expression or super */ null && (['publish', 'draft', 'pending', 'private', 'future', 'trash']));

/***/ }),

/***/ 72725:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports requesting, counts */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(95884);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(32988);




/**
 * Returns the updated post types requesting state after an action has been
 * dispatched. The state reflects a mapping of site ID, post type pairing to a
 * boolean reflecting whether a request for the post types is in progress.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

function requesting() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_COUNTS_REQUEST */ .T3s:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_COUNTS_REQUEST_SUCCESS */ .h2B:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_COUNTS_REQUEST_FAILURE */ .X5K:
      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, state, {
        [action.siteId]: {
          [action.postType]: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_COUNTS_REQUEST */ .T3s === action.type
        }
      });
  }

  return state;
}
/**
 * Returns the updated post count state after an action has been dispatched.
 * The state reflects a mapping of site ID, post type, [all/mine], post status
 * to the number of posts.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const counts = (() => {
  let currentUserId;
  let postStatuses = {};
  /**
   * Returns a serialized key to be used in tracking post status properties
   *
   * @param  {number} siteId Site ID
   * @param  {number} postId Post ID
   * @returns {string}        Serialized key
   */

  function getPostStatusKey(siteId, postId) {
    return [siteId, postId].join();
  }
  /**
   * Returns the updated post count state after transitioning a post to a new
   * status.
   *
   * @param  {object} state  Current state
   * @param  {number} siteId Site ID
   * @param  {number} postId Post ID
   * @param  {string} status Post status
   * @returns {object}        Updated state
   */


  function transitionPostStateToStatus(state, siteId, postId, status) {
    const postStatusKey = getPostStatusKey(siteId, postId);
    const postStatus = postStatuses[postStatusKey];

    if (!postStatus) {
      return state;
    } // Determine which count subkeys need to be updated, depending on
    // whether the current user authored the post


    const subKeys = ['all'];

    if (postStatus.authorId === currentUserId) {
      subKeys.push('mine');
    }

    const revisions = subKeys.reduce((memo, subKey) => {
      const subKeyCounts = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(state, [siteId, postStatus.type, subKey], {});
      memo[subKey] = {}; // Decrement count from the current status before transitioning

      memo[subKey][postStatus.status] = Math.max((subKeyCounts[postStatus.status] || 0) - 1, 0); // So long as we're not trashing an already trashed post or page,
      // increment the count for the transitioned status

      if ('deleted' !== status) {
        memo[subKey][status] = (subKeyCounts[status] || 0) + 1;
      }

      return memo;
    }, {});

    if ('deleted' === status) {
      // If post is permanently deleted, omit from tracked statuses
      postStatuses = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(postStatuses, postStatusKey);
    } else {
      // Otherwise, update object to reflect new status
      postStatus.status = status;
    } // Ensure that `all` and `mine` keys are always present


    (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)(revisions, {
      all: {},
      mine: {}
    });
    return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, state, {
      [siteId]: {
        [postStatus.type]: revisions
      }
    });
  }

  return (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_3__/* .countsSchema */ .A, function () {
    let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    let action = arguments.length > 1 ? arguments[1] : undefined;

    switch (action.type) {
      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_COUNTS_RESET_INTERNAL_STATE */ .Rp6:
        {
          currentUserId = undefined;
          postStatuses = {};
          return state;
        }

      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .CURRENT_USER_RECEIVE */ .uBM:
        {
          currentUserId = action.user.ID;
          return state;
        }

      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POSTS_RECEIVE */ .hYA:
        {
          action.posts.forEach(post => {
            const postStatusKey = getPostStatusKey(post.site_ID, post.ID);
            const postStatus = postStatuses[postStatusKey]; // If the post is known to us and the status has changed,
            // update state to reflect change

            if (postStatus && post.status !== postStatus.status) {
              state = transitionPostStateToStatus(state, post.site_ID, post.ID, post.status);
            }

            postStatuses[postStatusKey] = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.pick)(post, 'type', 'status');
            postStatuses[postStatusKey].authorId = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(post.author, 'ID');
          });
          return state;
        }

      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_SAVE */ .CNw:
        {
          const {
            siteId,
            postId,
            post
          } = action;

          if (!post.status) {
            return state;
          }

          return transitionPostStateToStatus(state, siteId, postId, post.status);
        }

      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_DELETE */ .LbL:
        {
          return transitionPostStateToStatus(state, action.siteId, action.postId, 'deleted');
        }

      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_COUNTS_RECEIVE */ .C6k:
        {
          return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, state, {
            [action.siteId]: {
              [action.postType]: action.counts
            }
          });
        }
    }

    return state;
  });
})();
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__/* .combineReducers */ .U)({
  requesting,
  counts
}));

/***/ }),

/***/ 32988:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "A": function() { return /* binding */ countsSchema; }
/* harmony export */ });
const countsSchema = {
  type: 'object',
  patternProperties: {
    '^[0-9]+$': {
      type: 'object',
      patternProperties: {
        '^[\\w-]+$': {
          type: 'object',
          patternProperties: {
            '^(all|mine)$': {
              type: 'object',
              patternProperties: {
                '^\\w+$': {
                  type: 'integer'
                }
              },
              additionalProperties: false
            }
          },
          additionalProperties: false
        }
      },
      additionalProperties: false
    }
  },
  additionalProperties: false
};

/***/ }),

/***/ 70263:
/***/ (function(__unused_webpack_module, __unused_webpack___webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9044);
/* harmony import */ var _reducer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(49985);


(0,calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_0__/* .registerReducer */ .x)(['posts'], _reducer__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP);

/***/ }),

/***/ 4184:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "vL": function() { return /* binding */ like; },
/* harmony export */   "Yt": function() { return /* binding */ unlike; },
/* harmony export */   "u5": function() { return /* binding */ receiveLikes; },
/* harmony export */   "eT": function() { return /* binding */ addLiker; },
/* harmony export */   "Ui": function() { return /* binding */ removeLiker; }
/* harmony export */ });
/* unused harmony export requestPostLikes */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_data_layer_wpcom_sites_posts_likes__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(26385);
/* harmony import */ var calypso_state_posts_init__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70263);



/**
 * Returns an action thunk which, when invoked, triggers a network request to
 * retrieve post likes for a post.
 *
 * @param  {number}   siteId Site ID
 * @param  {number}   postId Post ID
 * @returns {object}        Action
 */

function requestPostLikes(siteId, postId) {
  return {
    type: POST_LIKES_REQUEST,
    siteId,
    postId
  };
}
/**
 * Create a like action for a given site and post
 *
 * @param {number} siteId Site ID
 * @param {number} postId Post ID
 * @returns {object} The like action
 */

const like = function (siteId, postId) {
  let {
    source
  } = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  return {
    type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .POST_LIKE */ .RFP,
    siteId,
    postId,
    source
  };
};
/**
 * Create an unlike action for a given site and post
 *
 * @param {number} siteId Site ID
 * @param {number} postId Post ID
 * @returns {object} The unlike action
 */

const unlike = function (siteId, postId) {
  let {
    source
  } = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  return {
    type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .POST_UNLIKE */ .vP0,
    siteId,
    postId,
    source
  };
};
const receiveLikes = (siteId, postId, _ref) => {
  let {
    likes,
    iLike,
    found
  } = _ref;
  return {
    type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .POST_LIKES_RECEIVE */ .AVO,
    siteId,
    postId,
    likes,
    iLike,
    found
  };
};
const addLiker = (siteId, postId, likeCount, liker) => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .POST_LIKES_ADD_LIKER */ .rgA,
  siteId,
  postId,
  likeCount,
  liker
});
const removeLiker = (siteId, postId, likeCount, liker) => ({
  type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .POST_LIKES_REMOVE_LIKER */ .a7F,
  siteId,
  postId,
  likeCount,
  liker
});

/***/ }),

/***/ 26353:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports itemReducer, items */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(15960);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(95884);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(40057);




/**
 * Returns the updated items state after an action has been dispatched. The
 * state maps site ID, post ID keys to the post's likes.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const itemReducer = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {
    likes: undefined,
    iLike: false,
    found: 0,
    lastUpdated: undefined
  };
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .POST_LIKES_RECEIVE */ .AVO:
      {
        const {
          likes,
          iLike,
          found
        } = action;
        return {
          likes: Array.isArray(likes) ? likes.map(like => {
            return {
              ID: like.ID,
              avatar_URL: like.avatar_URL,
              login: like.login,
              name: like.name,
              site_ID: like.site_ID,
              site_visible: like.site_visible
            };
          }) : state.likes,
          iLike,
          found,
          lastUpdated: Date.now()
        };
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .POST_LIKE */ .RFP:
      {
        if (state.iLike) {
          return state;
        }

        return {
          likes: state.likes,
          iLike: true,
          found: state.found + 1,
          lastUpdated: state.lastUpdated
        };
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .POST_UNLIKE */ .vP0:
      {
        if (!state.iLike) {
          return state;
        }

        return {
          likes: state.likes,
          iLike: false,
          found: Math.max(0, state.found - 1),
          lastUpdated: state.lastUpdated
        };
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .POST_LIKES_ADD_LIKER */ .rgA:
      {
        const {
          likeCount,
          liker
        } = action;
        const hasLiker = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.some)(state.likes, like => like.ID === liker.ID);

        if (state.found === likeCount && hasLiker) {
          // if the like count matches and we already have this liker, bail
          return state;
        }

        let likes = state.likes;

        if (!hasLiker) {
          likes = [liker, ...(state.likes || [])];
        }

        return {
          likes,
          iLike: state.iLike,
          found: likeCount,
          lastUpdated: state.lastUpdated
        };
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .POST_LIKES_REMOVE_LIKER */ .a7F:
      {
        const {
          likeCount,
          liker
        } = action;
        const hasLiker = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.some)(state.likes, like => like.ID === liker.ID);

        if (state.found === likeCount && !hasLiker) {
          // if the like count matches and we don't have this liker, bail
          return state;
        }

        let likes = state.likes;

        if (hasLiker) {
          likes = state.likes.filter(l => liker.ID !== l.ID);
        }

        return {
          likes,
          iLike: state.iLike,
          found: likeCount,
          lastUpdated: state.lastUpdated
        };
      }
  }

  return state;
});
const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__/* .keyedReducer */ .J)('siteId', (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__/* .keyedReducer */ .J)('postId', itemReducer));
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_5__/* .combineReducers */ .U)({
  items
}));

/***/ }),

/***/ 40057:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/* harmony default export */ __webpack_exports__["Z"] = ({
  type: 'object',
  additionalProperties: false,
  required: ['iLike', 'found'],
  properties: {
    likes: {
      type: 'array',
      description: 'List of post likes'
    },
    iLike: {
      type: 'boolean',
      description: 'Whether the current authenticated user likes the post or not'
    },
    found: {
      type: 'number',
      description: 'The total of post likes'
    },
    lastUpdated: {
      type: 'number',
      description: 'When we last updated the liker info'
    }
  }
});

/***/ }),

/***/ 49985:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, siteRequests, queryRequests, queries, allSitesQueries, edits */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_lib_query_manager_post__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(3982);
/* harmony import */ var calypso_lib_query_manager_with_query_manager__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(96252);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_posts_utils__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(13360);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(71085);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(95884);
/* harmony import */ var _counts_reducer__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(72725);
/* harmony import */ var _likes_reducer__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(26353);
/* harmony import */ var _revisions_reducer__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(8588);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(49061);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(41900);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(2205);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(78261);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(78928);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(38239);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(26588);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(73831);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(57384);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(40178);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(92110);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(40373);
/* eslint-disable no-case-declarations */











/**
 * Tracks all known post objects, indexed by post global ID.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_3__/* .itemsSchema */ .dj, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POSTS_RECEIVE */ .hYA:
      {
        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(action.posts, (memo, post) => {
          const {
            site_ID: siteId,
            ID: postId,
            global_ID: globalId
          } = post;

          if (memo[globalId]) {
            // We're making an assumption here that the site ID and post ID
            // corresponding with a global ID will never change
            return memo;
          }

          if (memo === state) {
            memo = { ...memo
            };
          }

          memo[globalId] = [siteId, postId];
          return memo;
        }, state);
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_DELETE_SUCCESS */ .kNW:
      {
        const globalId = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.findKey)(state, _ref => {
          let [siteId, postId] = _ref;
          return siteId === action.siteId && postId === action.postId;
        });

        if (!globalId) {
          return state;
        }

        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state, globalId);
      }
  }

  return state;
});
/**
 * Returns the updated site post requests state after an action has been
 * dispatched. The state reflects a mapping of site ID, post ID pairing to a
 * boolean reflecting whether a request for the post is in progress.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

function siteRequests() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_REQUEST */ .pgH:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_REQUEST_SUCCESS */ .nL0:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_REQUEST_FAILURE */ .Ra4:
      return Object.assign({}, state, {
        [action.siteId]: Object.assign({}, state[action.siteId], {
          [action.postId]: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_REQUEST */ .pgH === action.type
        })
      });
  }

  return state;
}
/**
 * Returns the updated post query requesting state after an action has been
 * dispatched. The state reflects a mapping of serialized query to whether a
 * network request is in-progress for that query.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

function queryRequests() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POSTS_REQUEST */ .XMF:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POSTS_REQUEST_SUCCESS */ .A4M:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POSTS_REQUEST_FAILURE */ .LEp:
      const serializedQuery = (0,_utils__WEBPACK_IMPORTED_MODULE_5__/* .getSerializedPostsQuery */ .v)(action.query, action.siteId);
      return Object.assign({}, state, {
        [serializedQuery]: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POSTS_REQUEST */ .XMF === action.type
      });
  }

  return state;
}
/**
 * Returns the updated post query state after an action has been dispatched.
 * The state reflects a mapping by site ID of serialized query key to an array
 * of post IDs for the query, if a query response was successfully received.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const queriesReducer = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POSTS_REQUEST_SUCCESS */ .A4M:
      {
        const {
          siteId,
          query,
          posts,
          found
        } = action;

        if (!siteId) {
          // Handle site-specific queries only
          return state;
        }

        const normalizedPosts = posts.map(_utils__WEBPACK_IMPORTED_MODULE_6__/* .normalizePostForState */ .P);
        return (0,calypso_lib_query_manager_with_query_manager__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(state, siteId, m => m.receive(normalizedPosts, {
          query,
          found
        }), () => new calypso_lib_query_manager_post__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z());
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POSTS_RECEIVE */ .hYA:
      {
        const {
          posts
        } = action;
        const postsBySiteId = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(posts, (memo, post) => {
          return Object.assign(memo, {
            [post.site_ID]: [...(memo[post.site_ID] || []), (0,_utils__WEBPACK_IMPORTED_MODULE_6__/* .normalizePostForState */ .P)(post)]
          });
        }, {});
        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(postsBySiteId, (memo, sitePosts, siteId) => (0,calypso_lib_query_manager_with_query_manager__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(memo, siteId, m => m.receive(sitePosts), () => new calypso_lib_query_manager_post__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z()), state);
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_RESTORE */ .F1Z:
      {
        const {
          siteId,
          postId
        } = action;
        return (0,calypso_lib_query_manager_with_query_manager__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(state, siteId, m => m.receive({
          ID: postId,
          status: '__RESTORE_PENDING'
        }, {
          patch: true
        }));
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_RESTORE_FAILURE */ .JZv:
      {
        const {
          siteId,
          postId
        } = action;
        return (0,calypso_lib_query_manager_with_query_manager__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(state, siteId, m => m.receive({
          ID: postId,
          status: 'trash'
        }, {
          patch: true
        }));
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_SAVE */ .CNw:
      {
        const {
          siteId,
          postId,
          post
        } = action;
        return (0,calypso_lib_query_manager_with_query_manager__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(state, siteId, m => m.receive({
          ID: postId,
          ...post
        }, {
          patch: true
        }));
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_DELETE */ .LbL:
      {
        const {
          siteId,
          postId
        } = action;
        return (0,calypso_lib_query_manager_with_query_manager__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(state, siteId, m => m.receive({
          ID: postId,
          status: '__DELETE_PENDING'
        }, {
          patch: true
        }));
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_DELETE_FAILURE */ .xkR:
      {
        const {
          siteId,
          postId
        } = action;
        return (0,calypso_lib_query_manager_with_query_manager__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(state, siteId, m => m.receive({
          ID: postId,
          status: 'trash'
        }, {
          patch: true
        }));
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_DELETE_SUCCESS */ .kNW:
      {
        const {
          siteId,
          postId
        } = action;
        return (0,calypso_lib_query_manager_with_query_manager__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(state, siteId, m => m.removeItem(postId));
      }
  }

  return state;
};

const queries = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_3__/* .queriesSchema */ .kl, (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_8__/* .withPersistence */ .$)(queriesReducer, {
  serialize: state => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.mapValues)(state, _ref2 => {
    let {
      data,
      options
    } = _ref2;
    return {
      data,
      options
    };
  }),
  deserialize: persisted => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.mapValues)(persisted, _ref3 => {
    let {
      data,
      options
    } = _ref3;
    return new calypso_lib_query_manager_post__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z(data, options);
  })
}));

function findItemKey(state, siteId, postId) {
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.findKey)(state.data.items, post => {
    return post.site_ID === siteId && post.ID === postId;
  }) || null;
}
/**
 * Returns the updated post query state for queries of all sites at once after
 * an action has been dispatched.  The state reflects a mapping of serialized
 * query key to an array of post global IDs for the query, if a query response
 * was successfully received.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */


const allSitesQueriesReducer = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : new calypso_lib_query_manager_post__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z({}, {
    itemKey: 'global_ID'
  });
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POSTS_REQUEST_SUCCESS */ .A4M:
      {
        const {
          siteId,
          query,
          posts,
          found
        } = action;

        if (siteId) {
          // Handle all-sites queries only.
          return state;
        }

        return state.receive(posts.map(_utils__WEBPACK_IMPORTED_MODULE_6__/* .normalizePostForState */ .P), {
          query,
          found
        });
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POSTS_RECEIVE */ .hYA:
      {
        const {
          posts
        } = action;
        return state.receive(posts);
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_RESTORE */ .F1Z:
      {
        const {
          siteId,
          postId
        } = action;
        const globalId = findItemKey(state, siteId, postId);
        return state.receive({
          global_ID: globalId,
          status: '__RESTORE_PENDING'
        }, {
          patch: true
        });
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_RESTORE_FAILURE */ .JZv:
      {
        const {
          siteId,
          postId
        } = action;
        const globalId = findItemKey(state, siteId, postId);
        return state.receive({
          global_ID: globalId,
          status: 'trash'
        }, {
          patch: true
        });
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_SAVE */ .CNw:
      {
        const {
          siteId,
          postId,
          post
        } = action;
        const globalId = findItemKey(state, siteId, postId);
        return state.receive({
          global_ID: globalId,
          ...post
        }, {
          patch: true
        });
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_DELETE */ .LbL:
      {
        const {
          siteId,
          postId
        } = action;
        const globalId = findItemKey(state, siteId, postId);
        return state.receive({
          global_ID: globalId,
          status: '__DELETE_PENDING'
        }, {
          patch: true
        });
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_DELETE_FAILURE */ .xkR:
      {
        const {
          siteId,
          postId
        } = action;
        const globalId = findItemKey(state, siteId, postId);
        return state.receive({
          global_ID: globalId,
          status: 'trash'
        }, {
          patch: true
        });
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_DELETE_SUCCESS */ .kNW:
      {
        const {
          siteId,
          postId
        } = action;
        const globalId = findItemKey(state, siteId, postId);
        return state.removeItem(globalId);
      }
  }

  return state;
};

const allSitesQueries = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z, (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_8__/* .withPersistence */ .$)(allSitesQueriesReducer, {
  serialize: _ref4 => {
    let {
      data,
      options
    } = _ref4;
    return {
      data,
      options
    };
  },
  deserialize: _ref5 => {
    let {
      data,
      options
    } = _ref5;
    return new calypso_lib_query_manager_post__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z(data, options);
  }
}));
/**
 * Returns the updated editor posts state after an action has been dispatched.
 * The state maps site ID, post ID pairing to an object containing revisions
 * for the post.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

function edits() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POSTS_RECEIVE */ .hYA:
      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(action.posts, (memoState, post) => {
        // Receive a new version of a post object, in most cases returned in the POST
        // response after a successful save. Removes the edits that have been applied
        // and leaves only the ones that are not noops.
        let postEditsLog = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(memoState, [post.site_ID, post.ID]);

        if (!postEditsLog) {
          return memoState;
        }

        if (memoState === state) {
          memoState = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, state);
        } // if the action has a save marker, remove the edits before that marker


        if (action.saveMarker) {
          const markerIndex = postEditsLog.indexOf(action.saveMarker);

          if (markerIndex !== -1) {
            postEditsLog = postEditsLog.slice(markerIndex + 1);
          }
        } // merge the array of remaining edits into one object


        const postEdits = (0,_utils__WEBPACK_IMPORTED_MODULE_10__/* .mergePostEdits */ .Z)(...postEditsLog);
        let newEditsLog = null;

        if (postEdits) {
          // remove the edits that try to set an attribute to a value it already has.
          // For most attributes, it's a simple `isEqual` deep comparison, but a few
          // properties are more complicated than that.
          const unappliedPostEdits = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omitBy)(postEdits, (value, key) => {
            switch (key) {
              case 'author':
                return (0,_utils__WEBPACK_IMPORTED_MODULE_11__/* .isAuthorEqual */ .J)(value, post[key]);

              case 'date':
                return (0,_utils__WEBPACK_IMPORTED_MODULE_12__/* .isDateEqual */ .S)(value, post[key]);

              case 'discussion':
                return (0,_utils__WEBPACK_IMPORTED_MODULE_13__/* .isDiscussionEqual */ .y)(value, post[key]);

              case 'featured_image':
                return value === (0,calypso_state_posts_utils__WEBPACK_IMPORTED_MODULE_14__/* .getFeaturedImageId */ .g)(post);

              case 'metadata':
                // omit from unappliedPostEdits, metadata edits will be merged
                return true;

              case 'status':
                return (0,_utils__WEBPACK_IMPORTED_MODULE_15__/* .isStatusEqual */ .D)(value, post[key]);

              case 'terms':
                return (0,_utils__WEBPACK_IMPORTED_MODULE_16__/* .isTermsEqual */ .v)(value, post[key]);
            }

            return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEqual)(post[key], value);
          }); // remove edits that are already applied in the incoming metadata values and
          // leave only the unapplied ones.

          if (postEdits.metadata) {
            const unappliedMetadataEdits = (0,_utils__WEBPACK_IMPORTED_MODULE_17__/* .getUnappliedMetadataEdits */ .F)(postEdits.metadata, post.metadata);

            if (unappliedMetadataEdits.length > 0) {
              unappliedPostEdits.metadata = unappliedMetadataEdits;
            }
          }

          if (!(0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEmpty)(unappliedPostEdits)) {
            newEditsLog = [unappliedPostEdits];
          }
        }

        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.set)(memoState, [post.site_ID, post.ID], newEditsLog);
      }, state);

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_EDIT */ .oD3:
      {
        // process new edit for a post: merge it into the existing edits
        const siteId = action.siteId;
        const postId = action.postId || '';
        const postEditsLog = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(state, [siteId, postId]);
        const newEditsLog = (0,_utils__WEBPACK_IMPORTED_MODULE_18__/* .appendToPostEditsLog */ .V)(postEditsLog, action.post);
        return { ...state,
          [siteId]: { ...state[siteId],
            [postId]: newEditsLog
          }
        };
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .EDITOR_START */ .gQI:
      return Object.assign({}, state, {
        [action.siteId]: { ...state[action.siteId],
          [action.postId || '']: null
        }
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .EDITOR_STOP */ .cnn:
      if (!state.hasOwnProperty(action.siteId)) {
        break;
      }

      return Object.assign({}, state, {
        [action.siteId]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state[action.siteId], action.postId || '')
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_4__/* .POST_SAVE_SUCCESS */ .hZH:
      {
        const siteId = action.siteId;
        const postId = action.postId || ''; // if new post (edited with a transient postId of '') has been just saved and assigned
        // a real numeric ID, rewrite the state key with the new postId.

        if (postId === '' && action.savedPost) {
          const newPostId = action.savedPost.ID;
          state = { ...state,
            [siteId]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.mapKeys)(state[siteId], (value, key) => key === '' ? newPostId : key)
          };
        }

        return state;
      }
  }

  return state;
}
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_19__/* .combineReducers */ .U)({
  counts: _counts_reducer__WEBPACK_IMPORTED_MODULE_20__/* ["default"] */ .ZP,
  items,
  siteRequests,
  queryRequests,
  queries,
  allSitesQueries,
  edits,
  likes: _likes_reducer__WEBPACK_IMPORTED_MODULE_21__/* ["default"] */ .ZP,
  revisions: _revisions_reducer__WEBPACK_IMPORTED_MODULE_22__/* ["default"] */ .ZP
}));

/***/ }),

/***/ 17811:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export items */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(95884);



/**
 * Tracks all known user objects, indexed by user ID.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

function items() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_REVISION_AUTHORS_RECEIVE */ .R$r:
      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(action.users, (newState, user) => {
        if (newState === state) {
          newState = { ...state
          };
        }

        newState[user.ID] = user;
        return newState;
      }, state);
  }

  return state;
}
/* harmony default export */ __webpack_exports__["Z"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .combineReducers */ .U)({
  items
}));

/***/ }),

/***/ 8588:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports diffs, selection, ui */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(95884);
/* harmony import */ var _authors_reducer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(17811);




function diffs() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let {
    diffs: diffsFromServer,
    postId,
    revisions,
    siteId,
    type
  } = arguments.length > 1 ? arguments[1] : undefined;

  if (type !== calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_REVISIONS_RECEIVE */ .vIA) {
    return state;
  }

  if (!Number.isInteger(siteId) || siteId <= 0) {
    return state;
  }

  const sitePostState = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(state, [siteId, postId], {});
  const mergedRevisions = { ...(0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(sitePostState, 'revisions', {}),
    ...revisions
  };
  const filteredDiffs = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.filter)(diffsFromServer, _ref => {
    let {
      diff,
      from,
      to
    } = _ref;

    if (!Number.isInteger(from) || from < 0) {
      // `from` can be zero
      return false;
    }

    if (!Number.isInteger(to) || to < 1) {
      // `to` cannot be zero
      return false;
    } // Ensure fresh revisions were provided for `from` and `to` in the payload


    if (from !== 0 && (0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEmpty)(mergedRevisions[from])) {
      // if `from` is `0`, there won't be a revision to validate
      return false;
    }

    if ((0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEmpty)(mergedRevisions[to])) {
      return false;
    }

    return !(0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEmpty)(diff);
  });

  if ((0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEmpty)(filteredDiffs)) {
    return state;
  }

  return { ...state,
    [siteId]: { ...state[siteId],
      [postId]: { ...{ ...(0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(sitePostState, 'revisions'),
          ...(0,lodash__WEBPACK_IMPORTED_MODULE_0__.keyBy)(filteredDiffs, d => `${d.from}:${d.to}`)
        },
        revisions: mergedRevisions
      }
    }
  };
}
function selection() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_REVISIONS_SELECT */ .N__:
      {
        return { ...state,
          revisionId: action.revisionId
        };
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_EDIT */ .oD3:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .SELECTED_SITE_SET */ .bgv:
      {
        return { ...state,
          revisionId: null
        };
      }

    default:
      return state;
  }
}
function ui() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_REVISIONS_DIALOG_CLOSE */ .NYz:
      return { ...state,
        isDialogVisible: false
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_REVISIONS_DIALOG_OPEN */ .gpX:
      return { ...state,
        isDialogVisible: true
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_REVISIONS_DIFF_SPLIT_VIEW */ .Se1:
      return { ...state,
        diffView: 'split'
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .POST_REVISIONS_DIFF_UNIFY_VIEW */ .bE0:
      return { ...state,
        diffView: 'unified'
      };

    default:
      return state;
  }
}
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .combineReducers */ .U)({
  diffs,
  selection,
  ui,
  authors: _authors_reducer__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z
}));

/***/ }),

/***/ 49061:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "dj": function() { return /* binding */ itemsSchema; },
/* harmony export */   "kl": function() { return /* binding */ queriesSchema; }
/* harmony export */ });
/* harmony import */ var calypso_lib_query_manager_schema__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(41900);

const itemsSchema = {
  type: 'object',
  patternProperties: {
    '^\\w+$': {
      type: 'array',
      items: {
        type: 'number'
      },
      minItems: 2,
      maxItems: 2
    }
  },
  additionalProperties: false
};
const queriesSchema = {
  type: 'object',
  patternProperties: {
    // Site ID
    '^\\d+$': calypso_lib_query_manager_schema__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z
  },
  additionalProperties: false
};


/***/ }),

/***/ 40373:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "V": function() { return /* binding */ appendToPostEditsLog; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_posts_utils_merge_post_edits__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(78928);


/**
 * Appends a new edits object to existing edits log. If the last one is
 * an edits object, they will be merged. If the last one is a save marker,
 * the save marker will be left intact and a new edits object will be appended
 * at the end. This helps to keep the edits log as compact as possible.
 *
 * @param {?Array<object>} postEditsLog Existing edits log to be appended to
 * @param {object} newPostEdits New edits to be appended to the log
 * @returns {Array<object>} Merged edits log
 */

function appendToPostEditsLog(postEditsLog, newPostEdits) {
  if ((0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEmpty)(postEditsLog)) {
    return [newPostEdits];
  }

  const lastEdits = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.last)(postEditsLog);

  if (typeof lastEdits === 'string') {
    return [...postEditsLog, newPostEdits];
  }

  const newEditsLog = postEditsLog.slice(0, -1);
  newEditsLog.push((0,calypso_state_posts_utils_merge_post_edits__WEBPACK_IMPORTED_MODULE_1__/* .mergePostEdits */ .Z)(lastEdits, newPostEdits));
  return newEditsLog;
}

/***/ }),

/***/ 13360:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "g": function() { return /* binding */ getFeaturedImageId; }
/* harmony export */ });
/**
 * Returns the ID of the featured image assigned to the specified post, or
 * `undefined` otherwise. A utility function is useful because the format
 * of a post varies between the retrieve and update endpoints. When
 * retrieving a post, the thumbnail ID is assigned in `post_thumbnail`, but
 * in creating a post, the thumbnail ID is assigned to `featured_image`.
 *
 * @param  {object} post Post object
 * @returns {*} featured image id or undefined
 */
function getFeaturedImageId(post) {
  if (!post) {
    return;
  }

  if ('featured_image' in post && !/^https?:\/\//.test(post.featured_image)) {
    // Return the `featured_image` property if it does not appear to be
    // formatted as a URL
    return post.featured_image;
  }

  if (post.post_thumbnail) {
    // After the initial load from the REST API, pull the numeric ID
    // from the thumbnail object if one exists
    return post.post_thumbnail.ID;
  }
}

/***/ }),

/***/ 91602:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "B": function() { return /* binding */ getNormalizedPostsQuery; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_posts_constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(80951);


/**
 * Returns a normalized posts query, excluding any values which match the
 * default post query.
 *
 * @param  {object} query Posts query
 * @returns {object}       Normalized posts query
 */

function getNormalizedPostsQuery(query) {
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omitBy)(query, (value, key) => calypso_state_posts_constants__WEBPACK_IMPORTED_MODULE_1__/* .DEFAULT_POST_QUERY */ .e[key] === value);
}

/***/ }),

/***/ 2205:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "v": function() { return /* binding */ getSerializedPostsQuery; }
/* harmony export */ });
/* harmony import */ var calypso_state_posts_utils_get_normalized_posts_query__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(91602);

/**
 * Returns a serialized posts query
 *
 * @param  {object} query  Posts query
 * @param  {number} siteId Optional site ID
 * @returns {string}        Serialized posts query
 */

function getSerializedPostsQuery() {
  let query = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let siteId = arguments.length > 1 ? arguments[1] : undefined;
  const normalizedQuery = (0,calypso_state_posts_utils_get_normalized_posts_query__WEBPACK_IMPORTED_MODULE_0__/* .getNormalizedPostsQuery */ .B)(query);
  const serializedQuery = JSON.stringify(normalizedQuery);

  if (siteId) {
    return [siteId, serializedQuery].join(':');
  }

  return serializedQuery;
}

/***/ }),

/***/ 38239:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "J": function() { return /* binding */ isAuthorEqual; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Returns true if the locally edited author ID is equal to the saved post author's ID. Other
 * properties of the `author` object are irrelevant.
 *
 * @param  {object}  localAuthorEdit locally edited author object
 * @param  {object}  savedAuthor     author property returned from API POST
 * @returns {boolean}                 are the locally edited and saved values equal?
 */

function isAuthorEqual(localAuthorEdit, savedAuthor) {
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(localAuthorEdit, 'ID') === (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(savedAuthor, 'ID');
}

/***/ }),

/***/ 26588:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "S": function() { return /* binding */ isDateEqual; }
/* harmony export */ });
function isDateEqual(localDateEdit, savedDate) {
  // if the local date edit is false, it means we are asking the server to reset
  // the scheduled date to "now". In that case, we accept the date value returned
  // by the server and consider the edit saved.
  if (localDateEdit === false) {
    return true;
  }

  return localDateEdit && new Date(localDateEdit).getTime() === new Date(savedDate).getTime();
}

/***/ }),

/***/ 73831:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "y": function() { return /* binding */ isDiscussionEqual; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Returns true if the modified properties in the local edit of the `discussion` object (the edited
 * properties are a subset of the full object) are equal to the values in the saved post.
 *
 * @param  {object}  localDiscussionEdits local state of discussion edits
 * @param  {object}  savedDiscussion      discussion property returned from API POST
 * @returns {boolean}                      are there differences in local edits vs saved values?
 */

function isDiscussionEqual(localDiscussionEdits, savedDiscussion) {
  return Object.entries(localDiscussionEdits).every(_ref => {
    let [key, value] = _ref;
    return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(savedDiscussion, [key]) === value;
  });
}

/***/ }),

/***/ 57384:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "D": function() { return /* binding */ isStatusEqual; }
/* harmony export */ });
function isStatusEqual(localStatusEdit, savedStatus) {
  // When receiving a request to change the `status` attribute, the server
  // treats `publish` and `future` as synonyms. It's really the post's `date`
  // that determines the resulting status, not the requested value.
  // Therefore, the `status` edit is considered saved and removed from the
  // local edits even if the value returned by server is different.
  if (['publish', 'future'].includes(localStatusEdit)) {
    return ['publish', 'future'].includes(savedStatus);
  } // All other statuses (draft, private, pending) are 1:1. The only possible
  // exception is requesting `publish` and not having rights to publish new
  // posts. Then the server sets a `pending` status. But we check for this case
  // in the UI and request `pending` instead of `publish` if the user doesn't
  // have the rights.


  return localStatusEdit === savedStatus;
}

/***/ }),

/***/ 40178:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "v": function() { return /* binding */ isTermsEqual; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Returns truthy if local terms object is the same as the API response
 *
 * @param  {object}  localTermEdits local state of term edits
 * @param  {object}  savedTerms     term object returned from API POST
 * @returns {boolean}                are there differences in local edits vs saved terms
 */

function isTermsEqual(localTermEdits, savedTerms) {
  return Object.entries(localTermEdits).every(_ref => {
    let [taxonomy, terms] = _ref;
    const termsArray = Object.values(terms);
    const isHierarchical = typeof termsArray[0] === 'object' && termsArray[0] !== null;
    const normalizedEditedTerms = isHierarchical ? (0,lodash__WEBPACK_IMPORTED_MODULE_0__.map)(termsArray, 'ID') : termsArray;
    const normalizedKey = isHierarchical ? 'ID' : 'name';
    const normalizedSavedTerms = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.map)(savedTerms[taxonomy], normalizedKey);
    return !(0,lodash__WEBPACK_IMPORTED_MODULE_0__.xor)(normalizedEditedTerms, normalizedSavedTerms).length;
  });
}

/***/ }),

/***/ 78928:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ mergePostEdits; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);


function mergeMetadataEdits(edits, nextEdits) {
  // remove existing edits that get updated in `nextEdits`
  const newEdits = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reject)(edits, edit => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.find)(nextEdits, {
    key: edit.key
  })); // append the new edits at the end

  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.concat)(newEdits, nextEdits);
}
/**
 * Merges an array of post edits (called 'edits log') into one object. Essentially performs
 * a repeated deep merge of two objects, except:
 * - arrays are treated as atomic values and overwritten rather than merged.
 *   That's important especially for term removals.
 * - metadata edits, which are also arrays, are merged with a special algorithm.
 *
 * @param  {Array<object>} postEditsLog Edits objects to be merged
 * @returns {object?}                    Merged edits object with changes from all sources
 */


const mergePostEdits = function () {
  for (var _len = arguments.length, postEditsLog = new Array(_len), _key = 0; _key < _len; _key++) {
    postEditsLog[_key] = arguments[_key];
  }

  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(postEditsLog, (mergedEdits, nextEdits) => {
    // filter out save markers
    if (typeof nextEdits === 'string') {
      return mergedEdits;
    } // return the input object if it's the first one to merge (optimization that avoids cloning)


    if (mergedEdits === null) {
      return nextEdits;
    } // proceed to do the merge


    return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.mergeWith)((0,lodash__WEBPACK_IMPORTED_MODULE_0__.cloneDeep)(mergedEdits), nextEdits, (objValue, srcValue, key, obj, src, stack) => {
      if (key === 'metadata' && stack.size === 0) {
        // merge metadata specially
        return mergeMetadataEdits(objValue, srcValue);
      }

      if (Array.isArray(srcValue)) {
        return srcValue;
      }
    });
  }, null);
};

/***/ }),

/***/ 92110:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "F": function() { return /* binding */ getUnappliedMetadataEdits; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);


function isUnappliedMetadataEdit(edit, savedMetadata) {
  const savedRecord = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.find)(savedMetadata, {
    key: edit.key
  }); // is an update already performed?

  if (edit.operation === 'update') {
    return !savedRecord || savedRecord.value !== edit.value;
  } // is a property already deleted?


  if (edit.operation === 'delete') {
    return !!savedRecord;
  }

  return false;
}
/*
 * Returns edits that are not yet applied, i.e.:
 * - when updating, the property doesn't already have the desired value in `savedMetadata`
 * - when deleting, the property is still present in `savedMetadata`
 */


function getUnappliedMetadataEdits(edits, savedMetadata) {
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.filter)(edits, edit => isUnappliedMetadataEdit(edit, savedMetadata));
}

/***/ }),

/***/ 78261:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "P": function() { return /* binding */ normalizePostForState; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Recursively unset a value in an object by its path, represented by an array.
 * Intentionally mutates `object` to mirror native `delete` operator's behavior.
 *
 * @param {object} object Object to remove a property from
 * @param {Array}  path   Path to the property to remove
 */

const recursiveUnset = (object, path) => {
  if (path.length > 1) {
    const [, ...remainingPath] = path;
    recursiveUnset(object[path[0]], remainingPath);
    return;
  }

  if (object && object.hasOwnProperty(path[0])) {
    delete object[path[0]];
  }
};
/**
 * Given a post object, returns a normalized post object prepared for storing
 * in the global state object.
 *
 * @param  {object} post Raw post object
 * @returns {object}      Normalized post object
 */


function normalizePostForState(post) {
  const normalizedPost = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.cloneDeep)(post);
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)([[], ...(0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(post.terms, (memo, terms, taxonomy) => memo.concat((0,lodash__WEBPACK_IMPORTED_MODULE_0__.map)(terms, (term, slug) => ['terms', taxonomy, slug])), []), ...(0,lodash__WEBPACK_IMPORTED_MODULE_0__.map)(post.categories, (category, slug) => ['categories', slug]), ...(0,lodash__WEBPACK_IMPORTED_MODULE_0__.map)(post.tags, (tag, slug) => ['tags', slug]), ...(0,lodash__WEBPACK_IMPORTED_MODULE_0__.map)(post.attachments, (attachment, id) => ['attachments', id])], (memo, path) => {
    recursiveUnset(memo, path.concat('meta', 'links'));
    return memo;
  }, normalizedPost);
}

/***/ }),

/***/ 18223:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "p": function() { return /* binding */ DEFAULT_PREFERENCE_VALUES; }
/* harmony export */ });
/* unused harmony export USER_SETTING_KEY */
const USER_SETTING_KEY = 'calypso_preferences';
const DEFAULT_PREFERENCE_VALUES = {
  'guided-tours-history': [],
  recentSites: [],
  mediaScale: 0.157,
  colorScheme: 'default',
  homeQuickLinksToggleStatus: 'expanded'
};

/***/ }),

/***/ 54614:
/***/ (function(__unused_webpack_module, __unused_webpack___webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9044);
/* harmony import */ var _reducer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(22420);


(0,calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_0__/* .registerReducer */ .x)(['preferences'], _reducer__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP);

/***/ }),

/***/ 22420:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports localValues, remoteValues, fetching */
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(95884);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(85290);




/**
 * Returns the updated local values state after an action has been dispatched.
 * The local values state reflects preferences which are not saved to the
 * remote endpoint. If a local value is set and then later saved to the remote,
 * it will be removed from state.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const localValues = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PREFERENCES_SET */ .JPH:
      {
        const {
          key,
          value
        } = action;

        if (state[key] === value) {
          return state;
        }

        return { ...state,
          [key]: value
        };
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PREFERENCES_SAVE_SUCCESS */ .lCo:
      {
        const {
          [action.key]: removed,
          ...rest
        } = state;
        return rest;
      }
  }

  return state;
};
/**
 * Returns the updated remote values state after an action has been dispatched.
 * The remote values state reflects preferences which are persisted to the REST
 * API current user settings endpoint.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const remoteValues = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_3__/* .remoteValuesSchema */ .U, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PREFERENCES_RECEIVE */ .XuD:
      {
        const {
          values
        } = action;
        return values;
      }
  }

  return state;
});
const fetching = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PREFERENCES_FETCH_SUCCESS */ .N8o:
      return false;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PREFERENCES_FETCH_FAILURE */ .PD1:
      return false;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PREFERENCES_FETCH */ .pSd:
      return true;
  }

  return state;
};

const lastFetchedTimestamp = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PREFERENCES_FETCH_SUCCESS */ .N8o:
      return Date.now();
  }

  return state;
};

const combinedReducer = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__/* .combineReducers */ .U)({
  localValues,
  remoteValues,
  fetching,
  lastFetchedTimestamp
});
const preferencesReducer = (0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .withStorageKey */ .xi)('preferences', combinedReducer);
/* harmony default export */ __webpack_exports__["ZP"] = (preferencesReducer);

/***/ }),

/***/ 85290:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "U": function() { return /* binding */ remoteValuesSchema; }
/* harmony export */ });
const remoteValuesSchema = {
  type: ['null', 'object'],
  patternProperties: {
    '^dismissible-card-.+$': {
      type: ['boolean', 'object']
    },
    '^time-mismatch-warning-\\d+$': {
      type: ['boolean', 'number']
    }
  },
  properties: {
    'guided-tours-history': {
      type: 'array',
      items: {
        type: 'object',
        properties: {
          tourName: {
            type: 'string'
          },
          timestamp: {
            type: 'number',
            minimum: 0
          },
          finished: {
            type: 'boolean'
          }
        },
        required: ['tourName', 'timestamp', 'finished'],
        additionalProperties: false
      }
    },
    recentSites: {
      type: 'array',
      items: {
        type: 'number'
      }
    },
    mediaScale: {
      type: 'number',
      minimum: 0,
      maximum: 1
    },
    colorScheme: {
      type: 'string',
      enum: ['aquatic', 'blue', 'classic-blue', 'classic-bright', 'classic-dark', 'coffee', 'contrast', 'ectoplasm', 'light', 'midnight', 'modern', 'nightfall', 'ocean', 'powder-snow', 'sakura', 'sunrise', 'sunset']
    },
    'upwork-dismissible-banner': {
      type: 'object',
      '^[a-z-]+$': {
        type: 'array',
        items: {
          type: 'object',
          properties: {
            dismissedAt: {
              type: 'number',
              minimum: 0
            },
            type: {
              type: 'string',
              enum: ['dismiss']
            }
          },
          required: ['dismissedAt', 'type']
        }
      }
    },
    'jetpack-review-prompt': {
      type: 'object',
      properties: {
        scan: {
          $ref: '#/definitions/dismissiblePrompt'
        },
        restore: {
          $ref: '#/definitions/dismissiblePrompt'
        }
      }
    },
    homeQuickLinksToggleStatus: {
      type: 'string',
      enum: ['collapsed', 'expanded']
    },
    'persistent-counter': {
      type: 'object',
      properties: {
        // counter-name (possibly suffixed with siteId)
        '^[a-z0-9-]+$': {
          type: 'object',
          properties: {
            count: {
              type: 'number',
              minimum: 0
            },
            lastCountDate: {
              type: ['number', 'null']
            }
          }
        }
      }
    }
  },
  definitions: {
    dismissiblePrompt: {
      type: 'object',
      properties: {
        dismissedAt: {
          type: ['number', 'null']
        },
        dismissedCount: {
          type: 'number',
          minimum: 0
        },
        reviewed: {
          type: 'number'
        },
        validFrom: {
          type: ['number', 'null']
        }
      },
      required: ['dismissedAt', 'dismissedCount', 'reviewed', 'validFrom']
    }
  }
};

/***/ }),

/***/ 85300:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Oz": function() { return /* binding */ getPreference; }
/* harmony export */ });
/* unused harmony exports isFetchingPreferences, getAllRemotePreferences, preferencesLastFetchedTimestamp, hasReceivedRemotePreferences */
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(18223);
/* harmony import */ var calypso_state_preferences_init__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(54614);


const isFetchingPreferences = state => !!state.preferences.fetching;
/**
 * Returns the preference value associated with the specified key. Attempts to
 * find in local and remote preferences, then any applicable default value,
 * otherwise returning null.
 *
 * @param  {object} state Global state tree
 * @param  {string} key   Preference key
 * @returns {*}            Preference value
 */

function getPreference(state, key) {
  for (const source of [(_state$preferences = state.preferences) === null || _state$preferences === void 0 ? void 0 : _state$preferences.localValues, (_state$preferences2 = state.preferences) === null || _state$preferences2 === void 0 ? void 0 : _state$preferences2.remoteValues, _constants__WEBPACK_IMPORTED_MODULE_1__/* .DEFAULT_PREFERENCE_VALUES */ .p]) {
    var _state$preferences, _state$preferences2;

    if (source && source.hasOwnProperty(key)) {
      return source[key] ?? null;
    }
  }

  return null;
}
/**
 * Returns the a key value store of all current remote preferences. The keys
 * of the object are each preference key and the values are the preference
 * values.
 *
 * @param  {object} state Global state tree
 * @returns {object}       Preference value
 */

function getAllRemotePreferences(state) {
  return state.preferences.remoteValues;
}
const preferencesLastFetchedTimestamp = state => state.preferences.lastFetchedTimestamp;
/**
 * Returns true if preferences have been received from the remote source, or
 * false otherwise.
 *
 * @param  {object}  state Global state tree
 * @returns {boolean}       Whether preferences have been received
 */

function hasReceivedRemotePreferences(state) {
  return !!state.preferences.remoteValues;
}

/***/ }),

/***/ 86169:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Y9": function() { return /* binding */ fetchUserPurchases; }
/* harmony export */ });
/* unused harmony exports clearPurchases, fetchSitePurchases, removePurchase, resetSiteState */
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(11481);
/* harmony import */ var calypso_lib_wp__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(72429);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_purchases_init__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(65811);







const PURCHASES_FETCH_ERROR_MESSAGE = i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('There was an error retrieving purchases.');
const PURCHASE_REMOVE_ERROR_MESSAGE = i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('There was an error removing the purchase.');
const clearPurchases = () => (dispatch, getState) => {
  const siteId = getSelectedSiteId(getState());
  dispatch({
    type: PURCHASES_REMOVE
  });
  dispatch(requestHappychatEligibility());

  if (siteId) {
    dispatch(requestAdminMenu(siteId));
  }
};
const fetchSitePurchases = siteId => dispatch => {
  dispatch({
    type: PURCHASES_SITE_FETCH,
    siteId
  });
  return wpcom.req.get(`/sites/${siteId}/purchases`).then(data => {
    dispatch({
      type: PURCHASES_SITE_FETCH_COMPLETED,
      siteId,
      purchases: data
    });
  }).catch(() => {
    dispatch({
      type: PURCHASES_SITE_FETCH_FAILED,
      error: PURCHASES_FETCH_ERROR_MESSAGE
    });
  });
};
const fetchUserPurchases = userId => dispatch => {
  dispatch({
    type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .PURCHASES_USER_FETCH */ .$5Y
  });
  return calypso_lib_wp__WEBPACK_IMPORTED_MODULE_0__/* ["default"].req.get */ .Z.req.get('/me/purchases').then(data => {
    dispatch({
      type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .PURCHASES_USER_FETCH_COMPLETED */ .XMH,
      purchases: data,
      userId
    });
  }).catch(() => {
    dispatch({
      type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .PURCHASES_USER_FETCH_FAILED */ ._MG,
      error: PURCHASES_FETCH_ERROR_MESSAGE
    });
  });
};
const removePurchase = (purchaseId, userId) => (dispatch, getState) => {
  const siteId = getSelectedSiteId(getState());
  return new Promise(resolve => wpcom.req.post({
    path: `/purchases/${purchaseId}/delete`,
    apiNamespace: 'wpcom/v2'
  }).then(data => {
    dispatch({
      type: PURCHASE_REMOVE_COMPLETED,
      purchases: data.purchases,
      userId
    });
    dispatch(requestHappychatEligibility());

    if (siteId) {
      dispatch(requestAdminMenu(siteId));
    }

    resolve(data);
  }).catch(error => {
    dispatch({
      type: PURCHASE_REMOVE_FAILED,
      error: error.message || PURCHASE_REMOVE_ERROR_MESSAGE
    });
    resolve(error);
  }));
};
const resetSiteState = () => dispatch => dispatch({
  type: PURCHASES_SITE_RESET_STATE
});

/***/ }),

/***/ 65811:
/***/ (function(__unused_webpack_module, __unused_webpack___webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9044);
/* harmony import */ var _reducer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(31012);


(0,calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_0__/* .registerReducer */ .x)(['purchases'], _reducer__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z);

/***/ }),

/***/ 31012:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export reducer */
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);


/**
 * Constants
 */

const initialState = {
  data: [],
  error: null,
  isFetchingSitePurchases: false,
  isFetchingUserPurchases: false,
  hasLoadedSitePurchasesFromServer: false,
  hasLoadedUserPurchasesFromServer: false
};

function mergePurchase(existingPurchases, newPurchase) {
  // Update any matching existing purchase in place.
  let foundMatch = false;
  const merged = existingPurchases.map(purchase => {
    if (newPurchase.ID === purchase.ID) {
      foundMatch = true;
      return newPurchase;
    }

    return purchase;
  });

  if (foundMatch) {
    return merged;
  } // If there is no matching existing purchase, append the new purchase.


  return [...merged, newPurchase];
}
/**
 * Merges a new array of purchases with the existing array and updates items
 * in-place if they change.
 *
 * @param {Array} existingPurchases - an array of purchases in the store
 * @param {Array} newPurchases - an array of purchases fetched from the API
 * @returns {Array} An array of purchases
 */


function mergePurchases(existingPurchases, newPurchases) {
  return newPurchases.reduce((merged, newPurchase) => mergePurchase(merged, newPurchase), existingPurchases);
}

function updatePurchases(existingPurchases, action) {
  // If the action is to update a user, replace all the data.
  if (action.type === calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASES_USER_FETCH_COMPLETED */ .XMH) {
    return action.purchases;
  } // If the action is to update a site, remove all existing purchases for that site that are not in the new purchases array.


  if (action.type === calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASES_SITE_FETCH_COMPLETED */ .m58) {
    existingPurchases = existingPurchases.filter(purchase => {
      if (parseInt(purchase.blog_id, 10) !== parseInt(action.siteId, 10)) {
        return true;
      }

      if (action.purchases.some(newPurchase => newPurchase.ID === purchase.ID)) {
        return true;
      }

      return false;
    });
  } // If the action is to remove purchases, remove all existing purchases that are not in the new purchases array.


  if (action.type === calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASE_REMOVE_COMPLETED */ .WjV) {
    existingPurchases = existingPurchases.filter(purchase => {
      if (action.purchases.some(newPurchase => newPurchase.ID === purchase.ID)) {
        return true;
      }

      return false;
    });
  }

  return mergePurchases(existingPurchases, action.purchases);
}

const reducer = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASES_REMOVE */ .gbe:
      return { ...state,
        data: [],
        hasLoadedSitePurchasesFromServer: false,
        hasLoadedUserPurchasesFromServer: false
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASES_SITE_FETCH */ .pJb:
      return { ...state,
        isFetchingSitePurchases: true
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASES_USER_FETCH */ .$5Y:
      return { ...state,
        isFetchingUserPurchases: true
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASE_REMOVE_COMPLETED */ .WjV:
      return { ...state,
        data: updatePurchases(state.data, action),
        error: null,
        isFetchingSitePurchases: false,
        isFetchingUserPurchases: false,
        hasLoadedSitePurchasesFromServer: true,
        hasLoadedUserPurchasesFromServer: true
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASES_SITE_FETCH_COMPLETED */ .m58:
      return { ...state,
        data: updatePurchases(state.data, action),
        error: null,
        isFetchingSitePurchases: false,
        hasLoadedSitePurchasesFromServer: true
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASES_USER_FETCH_COMPLETED */ .XMH:
      return { ...state,
        data: updatePurchases(state.data, action),
        error: null,
        isFetchingUserPurchases: false,
        hasLoadedUserPurchasesFromServer: true
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASE_REMOVE_FAILED */ .RIF:
      return { ...state,
        error: action.error,
        hasLoadedSitePurchasesFromServer: true,
        hasLoadedUserPurchasesFromServer: true
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASES_SITE_FETCH_FAILED */ ._qM:
      return { ...state,
        error: action.error,
        hasLoadedSitePurchasesFromServer: true,
        isFetchingSitePurchases: false
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASES_USER_FETCH_FAILED */ ._MG:
      return { ...state,
        error: action.error,
        hasLoadedUserPurchasesFromServer: true,
        isFetchingUserPurchases: false
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .PURCHASES_SITE_RESET_STATE */ .Fsf:
      return { ...state,
        hasLoadedSitePurchasesFromServer: false,
        isFetchingSitePurchases: false
      };
  }

  return state;
};


/* harmony default export */ __webpack_exports__["Z"] = ((0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .withStorageKey */ .xi)('purchases', reducer));

/***/ }),

/***/ 12726:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Mo": function() { return /* binding */ isFetchingUserPurchases; },
/* harmony export */   "iJ": function() { return /* binding */ hasLoadedUserPurchasesFromServer; }
/* harmony export */ });
/* unused harmony exports isFetchingSitePurchases, hasLoadedSitePurchasesFromServer */
/* harmony import */ var calypso_state_purchases_init__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(65811);

const isFetchingUserPurchases = state => state.purchases.isFetchingUserPurchases;
const isFetchingSitePurchases = state => state.purchases.isFetchingSitePurchases;
const hasLoadedUserPurchasesFromServer = state => state.purchases.hasLoadedUserPurchasesFromServer;
const hasLoadedSitePurchasesFromServer = state => state.purchases.hasLoadedSitePurchasesFromServer;

/***/ }),

/***/ 99432:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "G": function() { return /* binding */ getPurchases; }
/* harmony export */ });
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_lib_purchases_assembler__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(29950);
/* harmony import */ var calypso_state_purchases_init__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(65811);



/**
 * Return the list of purchases from state object
 *
 * @param   {object} state - current state object
 * @returns {Array} Purchases
 */

const getPurchases = (0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .createSelector */ .P1)(state => (0,calypso_lib_purchases_assembler__WEBPACK_IMPORTED_MODULE_1__/* .createPurchasesArray */ .W)(state.purchases.data), state => [state.purchases.data]);

/***/ }),

/***/ 76678:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "I": function() { return /* binding */ getUserPurchases; }
/* harmony export */ });
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_state_current_user_selectors__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36747);
/* harmony import */ var _fetching__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(12726);
/* harmony import */ var _get_purchases__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(99432);
/* harmony import */ var calypso_state_purchases_init__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(65811);





/**
 * Returns a list of purchases associated with the current user
 *
 * @param {object} state Redux state
 * @returns {Array|null} array of the matching purchases or `null` if the list hasn't been loaded from server yet
 */

const getUserPurchases = (0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .createSelector */ .P1)(state => {
  if (!(0,_fetching__WEBPACK_IMPORTED_MODULE_3__/* .hasLoadedUserPurchasesFromServer */ .iJ)(state)) {
    return null;
  }

  const userId = (0,calypso_state_current_user_selectors__WEBPACK_IMPORTED_MODULE_1__/* .getCurrentUserId */ .rc)(state);
  return (0,_get_purchases__WEBPACK_IMPORTED_MODULE_4__/* .getPurchases */ .G)(state).filter(purchase => purchase.userId === userId);
}, state => [(0,_fetching__WEBPACK_IMPORTED_MODULE_3__/* .hasLoadedUserPurchasesFromServer */ .iJ)(state), (0,calypso_state_current_user_selectors__WEBPACK_IMPORTED_MODULE_1__/* .getCurrentUserId */ .rc)(state), (0,_get_purchases__WEBPACK_IMPORTED_MODULE_4__/* .getPurchases */ .G)(state)]);

/***/ }),

/***/ 78772:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "BQ": function() { return /* binding */ READER_CONVERSATION_FOLLOW; },
/* harmony export */   "tx": function() { return /* binding */ READER_CONVERSATION_MUTE; },
/* harmony export */   "_n": function() { return /* binding */ READER_CONVERSATION_UPDATE_FOLLOW_STATUS; },
/* harmony export */   "K1": function() { return /* binding */ READER_DISMISS_POST; },
/* harmony export */   "D8": function() { return /* binding */ READER_DISMISS_SITE; },
/* harmony export */   "Ae": function() { return /* binding */ READER_FEED_REQUEST; },
/* harmony export */   "_h": function() { return /* binding */ READER_FEED_REQUEST_FAILURE; },
/* harmony export */   "M1": function() { return /* binding */ READER_FEED_REQUEST_SUCCESS; },
/* harmony export */   "_p": function() { return /* binding */ READER_FEED_SEARCH_RECEIVE; },
/* harmony export */   "AH": function() { return /* binding */ READER_FOLLOW; },
/* harmony export */   "lH": function() { return /* binding */ READER_FOLLOW_ERROR; },
/* harmony export */   "P6": function() { return /* binding */ READER_FOLLOWS_RECEIVE; },
/* harmony export */   "b3": function() { return /* binding */ READER_FOLLOWS_SYNC_COMPLETE; },
/* harmony export */   "sh": function() { return /* binding */ READER_FOLLOWS_SYNC_START; },
/* harmony export */   "DJ": function() { return /* binding */ READER_LIST_CREATE; },
/* harmony export */   "kB": function() { return /* binding */ READER_LIST_DELETE; },
/* harmony export */   "R1": function() { return /* binding */ READER_LIST_FOLLOW_RECEIVE; },
/* harmony export */   "cu": function() { return /* binding */ READER_LIST_ITEM_ADD_FEED_RECEIVE; },
/* harmony export */   "MW": function() { return /* binding */ READER_LIST_ITEM_DELETE_FEED; },
/* harmony export */   "a$": function() { return /* binding */ READER_LIST_ITEM_DELETE_SITE; },
/* harmony export */   "nY": function() { return /* binding */ READER_LIST_ITEM_DELETE_TAG; },
/* harmony export */   "q_": function() { return /* binding */ READER_LIST_ITEMS_RECEIVE; },
/* harmony export */   "B_": function() { return /* binding */ READER_LIST_REQUEST; },
/* harmony export */   "gS": function() { return /* binding */ READER_LIST_REQUEST_FAILURE; },
/* harmony export */   "L5": function() { return /* binding */ READER_LIST_REQUEST_SUCCESS; },
/* harmony export */   "Nr": function() { return /* binding */ READER_LIST_UNFOLLOW_RECEIVE; },
/* harmony export */   "s5": function() { return /* binding */ READER_LIST_UPDATE; },
/* harmony export */   "ud": function() { return /* binding */ READER_LIST_UPDATE_FAILURE; },
/* harmony export */   "we": function() { return /* binding */ READER_LIST_UPDATE_SUCCESS; },
/* harmony export */   "_O": function() { return /* binding */ READER_LISTS_RECEIVE; },
/* harmony export */   "Ny": function() { return /* binding */ READER_LISTS_REQUEST; },
/* harmony export */   "$J": function() { return /* binding */ READER_ORGANIZATIONS_RECEIVE; },
/* harmony export */   "S6": function() { return /* binding */ READER_ORGANIZATIONS_REQUEST; },
/* harmony export */   "ch": function() { return /* binding */ READER_POST_SEEN; },
/* harmony export */   "nB": function() { return /* binding */ READER_POSTS_RECEIVE; },
/* harmony export */   "rE": function() { return /* binding */ READER_RECOMMENDED_SITES_RECEIVE; },
/* harmony export */   "Bi": function() { return /* binding */ READER_RELATED_POSTS_RECEIVE; },
/* harmony export */   "Cm": function() { return /* binding */ READER_RELATED_POSTS_REQUEST; },
/* harmony export */   "Rn": function() { return /* binding */ READER_RELATED_POSTS_REQUEST_FAILURE; },
/* harmony export */   "yZ": function() { return /* binding */ READER_RELATED_POSTS_REQUEST_SUCCESS; },
/* harmony export */   "c1": function() { return /* binding */ READER_SEEN_MARK_ALL_AS_SEEN_RECEIVE; },
/* harmony export */   "e_": function() { return /* binding */ READER_SEEN_MARK_AS_SEEN_RECEIVE; },
/* harmony export */   "iv": function() { return /* binding */ READER_SEEN_MARK_AS_UNSEEN_RECEIVE; },
/* harmony export */   "IJ": function() { return /* binding */ READER_SITE_BLOCK; },
/* harmony export */   "zF": function() { return /* binding */ READER_SITE_BLOCKS_RECEIVE; },
/* harmony export */   "zg": function() { return /* binding */ READER_SITE_BLOCKS_REQUEST; },
/* harmony export */   "LW": function() { return /* binding */ READER_SITE_REQUEST; },
/* harmony export */   "Fy": function() { return /* binding */ READER_SITE_REQUEST_FAILURE; },
/* harmony export */   "qY": function() { return /* binding */ READER_SITE_REQUEST_SUCCESS; },
/* harmony export */   "Qw": function() { return /* binding */ READER_SITE_UNBLOCK; },
/* harmony export */   "pu": function() { return /* binding */ READER_STREAMS_PAGE_RECEIVE; },
/* harmony export */   "CI": function() { return /* binding */ READER_STREAMS_PAGE_REQUEST; },
/* harmony export */   "_7": function() { return /* binding */ READER_STREAMS_SELECT_ITEM; },
/* harmony export */   "l0": function() { return /* binding */ READER_STREAMS_SELECT_NEXT_ITEM; },
/* harmony export */   "rC": function() { return /* binding */ READER_STREAMS_SELECT_PREV_ITEM; },
/* harmony export */   "c7": function() { return /* binding */ READER_STREAMS_SHOW_UPDATES; },
/* harmony export */   "RN": function() { return /* binding */ READER_STREAMS_UPDATES_RECEIVE; },
/* harmony export */   "Qr": function() { return /* binding */ READER_SUBSCRIBE_TO_NEW_COMMENT_EMAIL; },
/* harmony export */   "HC": function() { return /* binding */ READER_SUBSCRIBE_TO_NEW_POST_EMAIL; },
/* harmony export */   "aL": function() { return /* binding */ READER_SUBSCRIBE_TO_NEW_POST_NOTIFICATIONS; },
/* harmony export */   "Ep": function() { return /* binding */ READER_TAG_IMAGES_RECEIVE; },
/* harmony export */   "hB": function() { return /* binding */ READER_TAG_IMAGES_REQUEST; },
/* harmony export */   "Jx": function() { return /* binding */ READER_TAG_IMAGES_REQUEST_FAILURE; },
/* harmony export */   "_i": function() { return /* binding */ READER_TAG_IMAGES_REQUEST_SUCCESS; },
/* harmony export */   "fY": function() { return /* binding */ READER_TAGS_RECEIVE; },
/* harmony export */   "CE": function() { return /* binding */ READER_THUMBNAIL_RECEIVE; },
/* harmony export */   "Q6": function() { return /* binding */ READER_UNFOLLOW; },
/* harmony export */   "tN": function() { return /* binding */ READER_UNFOLLOW_TAG_RECEIVE; },
/* harmony export */   "BZ": function() { return /* binding */ READER_UNSUBSCRIBE_TO_NEW_COMMENT_EMAIL; },
/* harmony export */   "VV": function() { return /* binding */ READER_UNSUBSCRIBE_TO_NEW_POST_EMAIL; },
/* harmony export */   "vy": function() { return /* binding */ READER_UNSUBSCRIBE_TO_NEW_POST_NOTIFICATIONS; },
/* harmony export */   "OT": function() { return /* binding */ READER_UPDATE_NEW_POST_EMAIL_SUBSCRIPTION; }
/* harmony export */ });
/* unused harmony exports READER_EXPAND_COMMENTS, READER_FEED_SEARCH_REQUEST, READER_FOLLOW_TAG_REQUEST, READER_FOLLOWS_SYNC_PAGE, READER_LIST_FOLLOW, READER_LIST_ITEM_ADD_FEED, READER_LIST_ITEM_ADD_TAG, READER_LIST_ITEM_ADD_TAG_RECEIVE, READER_LIST_ITEMS_REQUEST, READER_LIST_UNFOLLOW, READER_RECOMMENDED_SITES_REQUEST, READER_SEEN_MARK_ALL_AS_SEEN_REQUEST, READER_SEEN_MARK_AS_SEEN_BLOG_REQUEST, READER_SEEN_MARK_AS_SEEN_REQUEST, READER_SEEN_MARK_AS_UNSEEN_BLOG_REQUEST, READER_SEEN_MARK_AS_UNSEEN_REQUEST, READER_TAGS_REQUEST, READER_UNFOLLOW_TAG_REQUEST, READER_VIEWING_FULL_POST_SET, READER_VIEWING_FULL_POST_UNSET */
/**
 * Please keep this list alphabetized!
 */
const READER_CONVERSATION_FOLLOW = 'READER_CONVERSATION_FOLLOW';
const READER_CONVERSATION_MUTE = 'READER_CONVERSATION_MUTE';
const READER_CONVERSATION_UPDATE_FOLLOW_STATUS = 'READER_CONVERSATION_UPDATE_FOLLOW_STATUS';
const READER_DISMISS_POST = 'READER_DISMISS_POST';
const READER_DISMISS_SITE = 'READER_DISMISS_SITE';
const READER_EXPAND_COMMENTS = 'READER_EXPAND_COMMENTS';
const READER_FEED_REQUEST = 'READER_FEED_REQUEST';
const READER_FEED_REQUEST_FAILURE = 'READER_FEED_REQUEST_FAILURE';
const READER_FEED_REQUEST_SUCCESS = 'READER_FEED_REQUEST_SUCCESS';
const READER_FEED_SEARCH_RECEIVE = 'READER_FEED_SEARCH_RECEIVE';
const READER_FEED_SEARCH_REQUEST = 'READER_FEED_SEARCH_REQUEST';
const READER_FOLLOW = 'READER_FOLLOW';
const READER_FOLLOW_ERROR = 'READER_FOLLOW_ERROR';
const READER_FOLLOW_TAG_REQUEST = 'READER_FOLLOW_TAG_REQUEST';
const READER_FOLLOWS_RECEIVE = 'READER_FOLLOWS_RECEIVE';
const READER_FOLLOWS_SYNC_COMPLETE = 'READER_FOLLOWS_SYNC_COMPLETE';
const READER_FOLLOWS_SYNC_PAGE = 'READER_FOLLOWS_SYNC_PAGE';
const READER_FOLLOWS_SYNC_START = 'READER_FOLLOWS_SYNC_START';
const READER_LIST_CREATE = 'READER_LIST_CREATE';
const READER_LIST_DELETE = 'READER_LIST_DELETE';
const READER_LIST_FOLLOW = 'READER_LIST_FOLLOW';
const READER_LIST_FOLLOW_RECEIVE = 'READER_LIST_FOLLOW_RECEIVE';
const READER_LIST_ITEM_ADD_FEED = 'READER_LIST_ITEM_ADD_FEED';
const READER_LIST_ITEM_ADD_FEED_RECEIVE = 'READER_LIST_ITEM_ADD_FEED_RECEIVE';
const READER_LIST_ITEM_ADD_TAG = 'READER_LIST_ITEM_ADD_TAG';
const READER_LIST_ITEM_ADD_TAG_RECEIVE = 'READER_LIST_ITEM_ADD_TAG_RECEIVE';
const READER_LIST_ITEM_DELETE_FEED = 'READER_LIST_ITEM_DELETE_FEED';
const READER_LIST_ITEM_DELETE_SITE = 'READER_LIST_ITEM_DELETE_SITE';
const READER_LIST_ITEM_DELETE_TAG = 'READER_LIST_ITEM_DELETE_TAG';
const READER_LIST_ITEMS_RECEIVE = 'READER_LIST_ITEMS_RECEIVE';
const READER_LIST_ITEMS_REQUEST = 'READER_LIST_ITEMS_REQUEST';
const READER_LIST_REQUEST = 'READER_LIST_REQUEST';
const READER_LIST_REQUEST_FAILURE = 'READER_LIST_REQUEST_FAILURE';
const READER_LIST_REQUEST_SUCCESS = 'READER_LIST_REQUEST_SUCCESS';
const READER_LIST_UNFOLLOW = 'READER_LIST_UNFOLLOW';
const READER_LIST_UNFOLLOW_RECEIVE = 'READER_LIST_UNFOLLOW_RECEIVE';
const READER_LIST_UPDATE = 'READER_LIST_UPDATE';
const READER_LIST_UPDATE_FAILURE = 'READER_LIST_UPDATE_FAILURE';
const READER_LIST_UPDATE_SUCCESS = 'READER_LIST_UPDATE_SUCCESS';
const READER_LISTS_RECEIVE = 'READER_LISTS_RECEIVE';
const READER_LISTS_REQUEST = 'READER_LISTS_REQUEST';
const READER_ORGANIZATIONS_RECEIVE = 'READER_ORGANIZATIONS_RECEIVE';
const READER_ORGANIZATIONS_REQUEST = 'READER_ORGANIZATIONS_REQUEST';
const READER_POST_SEEN = 'READER_POST_SEEN';
const READER_POSTS_RECEIVE = 'READER_POSTS_RECEIVE';
const READER_RECOMMENDED_SITES_RECEIVE = 'READER_RECOMMENDED_SITES_RECEIVE';
const READER_RECOMMENDED_SITES_REQUEST = 'READER_RECOMMENDED_SITES_REQUEST';
const READER_RELATED_POSTS_RECEIVE = 'READER_RELATED_POSTS_RECEIVE';
const READER_RELATED_POSTS_REQUEST = 'READER_RELATED_POSTS_REQUEST';
const READER_RELATED_POSTS_REQUEST_FAILURE = 'READER_RELATED_POSTS_REQUEST_FAILURE';
const READER_RELATED_POSTS_REQUEST_SUCCESS = 'READER_RELATED_POSTS_REQUEST_SUCCESS';
const READER_SEEN_MARK_ALL_AS_SEEN_RECEIVE = 'READER_SEEN_MARK_ALL_AS_SEEN_RECEIVE';
const READER_SEEN_MARK_ALL_AS_SEEN_REQUEST = 'READER_SEEN_MARK_ALL_AS_SEEN_REQUEST';
const READER_SEEN_MARK_AS_SEEN_BLOG_REQUEST = 'READER_SEEN_MARK_AS_SEEN_BLOG_REQUEST';
const READER_SEEN_MARK_AS_SEEN_RECEIVE = 'READER_SEEN_MARK_AS_SEEN_RECEIVE';
const READER_SEEN_MARK_AS_SEEN_REQUEST = 'READER_SEEN_MARK_AS_SEEN_REQUEST';
const READER_SEEN_MARK_AS_UNSEEN_BLOG_REQUEST = 'READER_SEEN_MARK_AS_UNSEEN_BLOG_REQUEST';
const READER_SEEN_MARK_AS_UNSEEN_RECEIVE = 'READER_SEEN_MARK_AS_UNSEEN_RECEIVE';
const READER_SEEN_MARK_AS_UNSEEN_REQUEST = 'READER_SEEN_MARK_AS_UNSEEN_REQUEST';
const READER_SITE_BLOCK = 'READER_SITE_BLOCK';
const READER_SITE_BLOCKS_RECEIVE = 'READER_SITE_BLOCKS_RECEIVE';
const READER_SITE_BLOCKS_REQUEST = 'READER_SITE_BLOCKS_REQUEST';
const READER_SITE_REQUEST = 'READER_SITE_REQUEST';
const READER_SITE_REQUEST_FAILURE = 'READER_SITE_REQUEST_FAILURE';
const READER_SITE_REQUEST_SUCCESS = 'READER_SITE_REQUEST_SUCCESS';
const READER_SITE_UNBLOCK = 'READER_SITE_UNBLOCK';
const READER_STREAMS_PAGE_RECEIVE = 'READER_STREAMS_PAGE_RECEIVE';
const READER_STREAMS_PAGE_REQUEST = 'READER_STREAMS_PAGE_REQUEST';
const READER_STREAMS_SELECT_ITEM = 'READER_STREAMS_SELECT_ITEM';
const READER_STREAMS_SELECT_NEXT_ITEM = 'READER_STREAMS_SELECT_NEXT_ITEM';
const READER_STREAMS_SELECT_PREV_ITEM = 'READER_STREAMS_SELECT_PREV_ITEM';
const READER_STREAMS_SHOW_UPDATES = 'READER_STREAMS_SHOW_UPDATES';
const READER_STREAMS_UPDATES_RECEIVE = 'READER_STREAMS_UPDATES_RECEIVE';
const READER_SUBSCRIBE_TO_NEW_COMMENT_EMAIL = 'READER_SUBSCRIBE_TO_NEW_COMMENT_EMAIL';
const READER_SUBSCRIBE_TO_NEW_POST_EMAIL = 'READER_SUBSCRIBE_TO_NEW_POST_EMAIL';
const READER_SUBSCRIBE_TO_NEW_POST_NOTIFICATIONS = 'READER_SUBSCRIBE_TO_NEW_POST_NOTIFICATIONS';
const READER_TAG_IMAGES_RECEIVE = 'READER_TAG_IMAGES_RECEIVE';
const READER_TAG_IMAGES_REQUEST = 'READER_TAG_IMAGES_REQUEST';
const READER_TAG_IMAGES_REQUEST_FAILURE = 'READER_TAG_IMAGES_REQUEST_FAILURE';
const READER_TAG_IMAGES_REQUEST_SUCCESS = 'READER_TAG_IMAGES_REQUEST_SUCCESS';
const READER_TAGS_RECEIVE = 'READER_TAGS_RECEIVE';
const READER_TAGS_REQUEST = 'READER_TAGS_REQUEST';
const READER_THUMBNAIL_RECEIVE = 'READER_THUMBNAIL_RECEIVE';
const READER_UNFOLLOW = 'READER_UNFOLLOW';
const READER_UNFOLLOW_TAG_RECEIVE = 'READER_UNFOLLOW_TAG_RECEIVE';
const READER_UNFOLLOW_TAG_REQUEST = 'READER_UNFOLLOW_TAG_REQUEST';
const READER_UNSUBSCRIBE_TO_NEW_COMMENT_EMAIL = 'READER_UNSUBSCRIBE_TO_NEW_COMMENT_EMAIL';
const READER_UNSUBSCRIBE_TO_NEW_POST_EMAIL = 'READER_UNSUBSCRIBE_TO_NEW_POST_EMAIL';
const READER_UNSUBSCRIBE_TO_NEW_POST_NOTIFICATIONS = 'READER_UNSUBSCRIBE_TO_NEW_POST_NOTIFICATIONS';
const READER_UPDATE_NEW_POST_EMAIL_SUBSCRIPTION = 'READER_UPDATE_NEW_POST_EMAIL_SUBSCRIPTION';
const READER_VIEWING_FULL_POST_SET = 'READER_VIEWING_FULL_POST_SET';
const READER_VIEWING_FULL_POST_UNSET = 'READER_VIEWING_FULL_POST_UNSET';

/***/ }),

/***/ 84225:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "I": function() { return /* binding */ CONVERSATION_FOLLOW_STATUS; }
/* harmony export */ });
/**
 * Follow status constants
 */
const CONVERSATION_FOLLOW_STATUS = Object.freeze({
  following: 'F',
  not_following: null,
  muting: 'M'
});

/***/ }),

/***/ 26395:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export items */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(95884);
/* harmony import */ var _follow_status__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(84225);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(91706);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(51260);






/**
 * Tracks all known conversation following statuses.
 */

const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_2__/* .itemsSchema */ .d, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_CONVERSATION_FOLLOW */ .BQ:
      {
        const newState = { ...state,
          [(0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .key */ .J)(action.payload.siteId, action.payload.postId)]: _follow_status__WEBPACK_IMPORTED_MODULE_5__/* .CONVERSATION_FOLLOW_STATUS.following */ .I.following
        };
        return newState;
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_CONVERSATION_MUTE */ .tx:
      {
        const newState = { ...state,
          [(0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .key */ .J)(action.payload.siteId, action.payload.postId)]: _follow_status__WEBPACK_IMPORTED_MODULE_5__/* .CONVERSATION_FOLLOW_STATUS.muting */ .I.muting
        };
        return newState;
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_CONVERSATION_UPDATE_FOLLOW_STATUS */ ._n:
      {
        const stateKey = (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .key */ .J)(action.payload.siteId, action.payload.postId); // If followStatus is null, remove the key from the state map entirely

        if (action.payload.followStatus === _follow_status__WEBPACK_IMPORTED_MODULE_5__/* .CONVERSATION_FOLLOW_STATUS.not_following */ .I.not_following) {
          return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state, stateKey);
        }

        const newState = { ...state,
          [stateKey]: action.payload.followStatus
        };
        return newState;
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_POSTS_RECEIVE */ .nB:
      {
        if (!action.posts) {
          return state;
        }

        const newState = {};
        (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(action.posts, post => {
          if (post.is_following_conversation) {
            newState[(0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .key */ .J)(post.site_ID, post.ID)] = _follow_status__WEBPACK_IMPORTED_MODULE_5__/* .CONVERSATION_FOLLOW_STATUS.following */ .I.following;
          }
        });

        if ((0,lodash__WEBPACK_IMPORTED_MODULE_0__.size)(newState) === 0) {
          return state;
        }

        return { ...state,
          ...newState
        };
      }
  }

  return state;
});
/* harmony default export */ __webpack_exports__["Z"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_6__/* .combineReducers */ .U)({
  items
}));

/***/ }),

/***/ 91706:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "d": function() { return /* binding */ itemsSchema; }
/* harmony export */ });
/* harmony import */ var _follow_status__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(84225);

/* eslint-disable quote-props */

const itemsSchema = {
  type: 'object',
  patternProperties: {
    '^[0-9]+-[0-9]+$': {
      enum: Object.values(_follow_status__WEBPACK_IMPORTED_MODULE_0__/* .CONVERSATION_FOLLOW_STATUS */ .I)
    }
  },
  additionalProperties: false
};
/* eslint-enable quote-props */

/***/ }),

/***/ 51260:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "J": function() { return /* binding */ key; }
/* harmony export */ });
function key(siteId, postId) {
  return `${siteId}-${postId}`;
}

/***/ }),

/***/ 13838:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, total */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(15960);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(95884);



/**
 * Tracks mappings between queries --> feed results
 *
 * A map of query to results, keyed by query key.
 * The query key is supplied by the action, making it opaque to the reducer.
 * Here is what the state tree may look like:
 * feedSearches: {
		items: {
			'wordpress tavern-X': [ feed1, feed2, ],
			...
		},
	}
 *
 * @param  {Array} state  Current state
 * @param  {object} action Action payload
 * @returns {Array}        Updated state
 */

const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .keyedReducer */ .J)('queryKey', function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_FEED_SEARCH_RECEIVE */ ._p:
      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.uniqBy)((state || []).concat(action.payload.feeds), 'feed_URL');
  }

  return state;
});
/**
 * Tracks mappings between queries --> num results
 *
 * A of query counts to results, keyed by query key.
 * The query key is supplied by the action, making it opaque to the reducer.
 * Here is what the state tree may look like:
 * feedSearches: {
		total: {
			'wordpress tavern-X': 4,
			'thingsldkjflskjfsdf-A': 0,
			'chickens-A': 4000,
			...
		},
	}
 *
 * @param  {Array}  state  Current state
 * @param  {object} action Action payload
 * @returns {Array}         Updated state
 */

const total = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .keyedReducer */ .J)('queryKey', function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_FEED_SEARCH_RECEIVE */ ._p:
      return action.payload.total;
  }

  return state;
});
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__/* .combineReducers */ .U)({
  items,
  total
}));

/***/ }),

/***/ 64380:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, queuedRequests, lastFetched */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(50118);
/* harmony import */ var calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(8165);
/* harmony import */ var calypso_lib_post_normalizer_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(48265);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(71085);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(95884);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(46518);







function handleRequestFailure(state, action) {
  // new object precedes current state to prevent new errors from overwriting existing values
  return {
    [action.payload.feed_ID]: {
      feed_ID: action.payload.feed_ID,
      is_error: true
    },
    ...state
  };
}

function adaptFeed(feed) {
  return {
    feed_ID: +feed.feed_ID,
    blog_ID: +feed.blog_ID,
    name: feed.name && (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_1__/* .decodeEntities */ .S)(feed.name),
    URL: (0,calypso_lib_post_normalizer_utils__WEBPACK_IMPORTED_MODULE_2__/* .safeLink */ .m)(feed.URL),
    feed_URL: (0,calypso_lib_post_normalizer_utils__WEBPACK_IMPORTED_MODULE_2__/* .safeLink */ .m)(feed.feed_URL),
    is_following: feed.is_following,
    subscribers_count: feed.subscribers_count,
    description: feed.description && (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_1__/* .decodeEntities */ .S)((0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_3__/* .stripHTML */ .C)(feed.description)),
    last_update: feed.last_update,
    image: feed.image,
    organization_id: feed.organization_id,
    unseen_count: feed.unseen_count
  };
}

function handleRequestSuccess(state, action) {
  const feed = adaptFeed(action.payload);
  return { ...state,
    [feed.feed_ID]: feed
  };
}

const itemsReducer = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_4__/* .READER_FEED_REQUEST_SUCCESS */ .M1:
      return handleRequestSuccess(state, action);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_4__/* .READER_FEED_REQUEST_FAILURE */ ._h:
      return handleRequestFailure(state, action);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_4__/* .READER_SEEN_MARK_AS_SEEN_RECEIVE */ .e_:
      {
        const existingEntry = state[action.feedId];

        if (!existingEntry) {
          return state;
        }

        return { ...state,
          [action.feedId]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, existingEntry, {
            unseen_count: Math.max(existingEntry.unseen_count - action.globalIds.length, 0)
          })
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_4__/* .READER_SEEN_MARK_AS_UNSEEN_RECEIVE */ .iv:
      {
        const existingEntry = state[action.feedId];

        if (!existingEntry) {
          return state;
        }

        return { ...state,
          [action.feedId]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, existingEntry, {
            unseen_count: Math.max(existingEntry.unseen_count + action.globalIds.length, 0)
          })
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_4__/* .READER_SEEN_MARK_ALL_AS_SEEN_RECEIVE */ .c1:
      {
        (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(action.feedIds, feedId => {
          state[feedId] = { ...state[feedId],
            unseen_count: 0
          };
        });
        return { ...state
        };
      }
  }

  return state;
};

const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_5__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_6__/* .itemsSchema */ .d, (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_7__/* .withPersistence */ .$)(itemsReducer, {
  // remove errors from the serialized state
  serialize: state => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omitBy)(state, 'is_error')
}));
function queuedRequests() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_4__/* .READER_FEED_REQUEST */ .Ae:
      return { ...state,
        [action.payload.feed_ID]: true
      };

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_4__/* .READER_FEED_REQUEST_SUCCESS */ .M1:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_4__/* .READER_FEED_REQUEST_FAILURE */ ._h:
      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state, action.payload.feed_ID);
  }

  return state;
}
const lastFetched = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_4__/* .READER_FEED_REQUEST_SUCCESS */ .M1:
      return { ...state,
        [action.payload.feed_ID]: Date.now()
      };
  }

  return state;
};
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_8__/* .combineReducers */ .U)({
  items,
  lastFetched,
  queuedRequests
}));

/***/ }),

/***/ 46518:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "d": function() { return /* binding */ itemsSchema; }
/* harmony export */ });
const itemsSchema = {
  type: 'object',
  patternProperties: {
    //be careful to escape regexes properly
    '^[0-9a-z]+$': {
      type: 'object',
      required: ['feed_ID', 'blog_ID'],
      properties: {
        feed_ID: {
          type: 'integer'
        },
        blog_ID: {
          type: 'integer'
        },
        name: {
          type: ['string', 'null']
        },
        URL: {
          type: ['string', 'null']
        },
        feed_URL: {
          type: ['string', 'null']
        },
        is_following: {
          type: ['boolean', 'null']
        },
        subscribers_count: {
          type: ['integer', 'null']
        },
        description: {
          type: ['string', 'null']
        },
        last_update: {
          type: ['string', 'null']
        },
        image: {
          type: ['string', 'null']
        },
        organization_id: {
          type: ['integer', 'null']
        },
        unseen_count: {
          type: ['integer', 'null']
        }
      }
    }
  },
  additionalProperties: false
};

/***/ }),

/***/ 38357:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, itemsCount, lastSyncTime */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(71085);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(95884);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(75235);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(46486);






function updateEmailSubscription(state, _ref) {
  let {
    payload,
    type
  } = _ref;
  const follow = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.find)(state, {
    blog_ID: +payload.blogId
  });

  if (!follow) {
    return state;
  }

  const currentFollowState = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(follow, ['delivery_methods', 'email'], {});
  const newProps = {};

  switch (type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SUBSCRIBE_TO_NEW_POST_EMAIL */ .HC:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_UNSUBSCRIBE_TO_NEW_POST_EMAIL */ .VV:
      newProps.send_posts = !(type === calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_UNSUBSCRIBE_TO_NEW_POST_EMAIL */ .VV);
      break;

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SUBSCRIBE_TO_NEW_COMMENT_EMAIL */ .Qr:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_UNSUBSCRIBE_TO_NEW_COMMENT_EMAIL */ .BZ:
      newProps.send_comments = !(type === calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_UNSUBSCRIBE_TO_NEW_COMMENT_EMAIL */ .BZ);
      break;
  }

  if (payload.deliveryFrequency) {
    newProps.post_delivery_frequency = payload.deliveryFrequency;
  }

  const newFollowState = { ...currentFollowState,
    ...newProps
  };

  if ((0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEqual)(currentFollowState, newFollowState)) {
    return state;
  }

  return { ...state,
    [(0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .prepareComparableUrl */ .C)(follow.URL)]: { ...follow,
      delivery_methods: {
        email: newFollowState,
        notification: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(follow, ['delivery_methods', 'notification'], {})
      }
    }
  };
}

function updateNotificationSubscription(state, _ref2) {
  let {
    payload,
    type
  } = _ref2;
  const follow = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.find)(state, {
    blog_ID: +payload.blogId
  });

  if (!follow) {
    return state;
  }

  const currentFollowState = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(follow, ['delivery_methods', 'notification', 'send_posts'], false);
  const newFollowState = !(type === calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_UNSUBSCRIBE_TO_NEW_POST_NOTIFICATIONS */ .vy);

  if (currentFollowState === newFollowState) {
    return state;
  }

  return { ...state,
    [(0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .prepareComparableUrl */ .C)(follow.URL)]: { ...follow,
      delivery_methods: {
        email: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(follow, ['delivery_methods', 'email'], {}),
        notification: {
          send_posts: newFollowState
        }
      }
    }
  };
}

const itemsReducer = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_FOLLOW_ERROR */ .lH:
      {
        const urlKey = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .prepareComparableUrl */ .C)(action.payload.feedUrl);
        return { ...state,
          [urlKey]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, state[urlKey], {
            error: action.payload.error
          })
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_FOLLOW */ .AH:
      {
        let urlKey = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .prepareComparableUrl */ .C)(action.payload.feedUrl);
        const newValues = {
          is_following: true
        };
        const actualFeedUrl = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(action.payload, ['follow', 'feed_URL'], action.payload.feedUrl);
        const newState = { ...state
        }; // for the case where a user entered an exact url to follow something, sometimes the
        // correct feed_URL is slightly different from what they typed in.
        // e.g. example.com --> example.com/rss.
        // Since we are keying this reducer by url,
        // we need delete the old key and move it to the new one.
        // also keep what was typed in as an alias.  pretty edge casey but ideally we should retain aliases to
        // display correct followByUrl follow button status

        if (actualFeedUrl !== action.payload.feedUrl) {
          newValues.alias_feed_URLs = [...(state[urlKey].alias_feed_URLs || []), (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .prepareComparableUrl */ .C)(action.payload.feedUrl)];
          delete newState[urlKey];
          urlKey = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .prepareComparableUrl */ .C)(actualFeedUrl);
        } else if (state[urlKey] && state[urlKey].error) {
          // Reset follow error state
          newValues.error = null;
        } // Respect the existing state of the new post notification toggle.
        // User may have toggled it on immediately after subscribing and
        // action.payload.follow may overwrite it with the old value


        const existingNotificationState = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(state[urlKey], ['delivery_methods', 'notification']);

        if (existingNotificationState) {
          newValues.delivery_methods = {
            notification: existingNotificationState
          };
        }

        return Object.assign(newState, {
          [urlKey]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({
            feed_URL: actualFeedUrl
          }, state[urlKey], action.payload.follow, newValues)
        });
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_UNFOLLOW */ .Q6:
      {
        const urlKey = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .prepareComparableUrl */ .C)(action.payload.feedUrl);
        const currentFollow = state[urlKey];

        if (!(currentFollow && currentFollow.is_following)) {
          return state;
        }

        return { ...state,
          [urlKey]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, currentFollow, {
            is_following: false,
            delivery_methods: {
              notification: {
                send_posts: false
              }
            }
          })
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_FOLLOWS_RECEIVE */ .P6:
      {
        const follows = action.payload.follows;
        const keyedNewFollows = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(follows, (hash, follow) => {
          const urlKey = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .prepareComparableUrl */ .C)(follow.URL);
          const newFollow = { ...follow,
            is_following: true
          };
          hash[urlKey] = newFollow;
          return hash;
        }, {});
        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, state, keyedNewFollows);
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SITE_REQUEST_SUCCESS */ .qY:
      {
        const incomingSite = action.payload;

        if (!incomingSite || !incomingSite.feed_URL || !incomingSite.is_following) {
          return state;
        }

        const urlKey = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .prepareComparableUrl */ .C)(incomingSite.feed_URL);
        const currentFollow = state[urlKey];
        const newFollow = {
          delivery_methods: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(incomingSite, 'subscription.delivery_methods'),
          is_following: true,
          URL: incomingSite.URL,
          feed_URL: incomingSite.feed_URL,
          blog_ID: incomingSite.ID
        };
        return { ...state,
          [urlKey]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, currentFollow, newFollow)
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SUBSCRIBE_TO_NEW_POST_EMAIL */ .HC:
      return updateEmailSubscription(state, action);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_UPDATE_NEW_POST_EMAIL_SUBSCRIPTION */ .OT:
      return updateEmailSubscription(state, action);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_UNSUBSCRIBE_TO_NEW_POST_EMAIL */ .VV:
      return updateEmailSubscription(state, action);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SUBSCRIBE_TO_NEW_COMMENT_EMAIL */ .Qr:
      return updateEmailSubscription(state, action);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_UNSUBSCRIBE_TO_NEW_COMMENT_EMAIL */ .BZ:
      return updateEmailSubscription(state, action);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SUBSCRIBE_TO_NEW_POST_NOTIFICATIONS */ .aL:
      return updateNotificationSubscription(state, action);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_UNSUBSCRIBE_TO_NEW_POST_NOTIFICATIONS */ .vy:
      return updateNotificationSubscription(state, action);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_FOLLOWS_SYNC_COMPLETE */ .b3:
      {
        const seenSubscriptions = new Set(action.payload); // diff what we saw vs. what's in state and remove anything extra
        // extra would be active subscriptions that were not seen in the sync
        //
        // Only check items with an ID (the subscription ID) because those are what
        // we show on the manage listing. Items without an ID are either inflight follows
        // or follows that we picked up from a feed, site, or post object.

        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omitBy)(state, follow => follow.ID && !seenSubscriptions.has(follow.feed_URL));
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SEEN_MARK_AS_SEEN_RECEIVE */ .e_:
      {
        const urlKey = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .prepareComparableUrl */ .C)(action.feedUrl);
        const existingEntry = state[urlKey];

        if (!existingEntry) {
          return state;
        }

        return { ...state,
          [urlKey]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, existingEntry, {
            unseen_count: existingEntry.unseen_count - action.globalIds.length
          })
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SEEN_MARK_AS_UNSEEN_RECEIVE */ .iv:
      {
        const urlKey = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .prepareComparableUrl */ .C)(action.feedUrl);
        const existingEntry = state[urlKey];

        if (!existingEntry) {
          return state;
        }

        return { ...state,
          [urlKey]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, existingEntry, {
            unseen_count: existingEntry.unseen_count + action.globalIds.length
          })
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SEEN_MARK_ALL_AS_SEEN_RECEIVE */ .c1:
      {
        (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(action.feedUrls, feedUrl => {
          const urlKey = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .prepareComparableUrl */ .C)(feedUrl);
          state[urlKey] = { ...state[urlKey],
            unseen_count: 0
          };
        });
        return { ...state
        };
      }
  }

  return state;
};

const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_4__/* .items */ .e, (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_5__/* .withPersistence */ .$)(itemsReducer, {
  serialize: state => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.pickBy)(state, item => item.ID && item.is_following)
}));
const itemsCount = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_FOLLOWS_RECEIVE */ .P6:
      {
        return action.payload.totalCount ? action.payload.totalCount : state;
      }
  }

  return state;
};
const lastSyncTime = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_FOLLOWS_SYNC_START */ .sh:
      {
        return Date.now();
      }
  }

  return state;
};
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_6__/* .combineReducers */ .U)({
  items,
  itemsCount,
  lastSyncTime
}));

/***/ }),

/***/ 75235:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "e": function() { return /* binding */ items; }
/* harmony export */ });
const items = {
  type: 'object',
  patternProperties: {
    //be careful to escape regexes properly
    '.+': {
      type: 'object',
      required: ['feed_URL', 'URL', 'is_following'],
      properties: {
        URL: {
          type: 'string'
        },
        feed_URL: {
          type: 'string'
        },
        is_following: {
          type: 'boolean'
        },
        ID: {
          type: ['integer', 'null']
        },
        blog_ID: {
          type: ['integer', 'null']
        },
        feed_ID: {
          type: ['integer', 'null']
        },
        date_subscribed: {
          type: ['integer', 'null']
        },
        last_updated: {
          type: ['integer', 'null']
        },
        delivery_methods: {
          type: ['object', 'null']
        },
        is_owner: {
          type: ['boolean', 'null']
        },
        organization_id: {
          type: ['integer', 'null']
        },
        name: {
          type: ['string', 'null']
        },
        unseen_count: {
          type: ['integer', 'null']
        },
        site_icon: {
          type: ['string', 'null']
        }
      }
    }
  },
  additionalProperties: false
};

/***/ }),

/***/ 46486:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "C": function() { return /* binding */ prepareComparableUrl; }
/* harmony export */ });
/* harmony import */ var calypso_lib_route__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(55347);

function prepareComparableUrl(url) {
  const preparedUrl = url && (0,calypso_lib_route__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(url);
  return preparedUrl && preparedUrl.replace(/^https?:\/\//, '').toLowerCase();
}

/***/ }),

/***/ 35929:
/***/ (function(__unused_webpack_module, __unused_webpack___webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9044);
/* harmony import */ var _reducer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(97589);


(0,calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_0__/* .registerReducer */ .x)(['reader'], _reducer__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z);

/***/ }),

/***/ 6693:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, listItems, subscribedLists, isRequestingList, isCreatingList, isUpdatingList, isRequestingLists */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(95884);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(40932);
/* eslint-disable no-case-declarations */




/**
 * Tracks all known list objects, indexed by list ID.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_2__/* .itemsSchema */ .d, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LISTS_RECEIVE */ ._O:
      return Object.assign({}, state, (0,lodash__WEBPACK_IMPORTED_MODULE_0__.keyBy)(action.lists, 'ID'));

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_REQUEST_SUCCESS */ .L5:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_UPDATE_SUCCESS */ .we:
      return Object.assign({}, state, (0,lodash__WEBPACK_IMPORTED_MODULE_0__.keyBy)([action.data.list], 'ID'));

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_DELETE */ .kB:
      if (!(action.listId in state)) {
        return state;
      }

      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state, action.listId);
  }

  return state;
});

function removeItemBy(state, action, predicate) {
  if (!(action.listId in state)) {
    return state;
  }

  const list = state[action.listId];
  const newList = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reject)(list, predicate);
  return { ...state,
    [action.listId]: newList
  };
}

const listItems = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_ITEMS_RECEIVE */ .q_:
      return { ...state,
        [action.listId]: action.listItems
      };

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_ITEM_ADD_FEED_RECEIVE */ .cu:
      {
        const currentItems = state[action.listId] || [];

        if ((0,lodash__WEBPACK_IMPORTED_MODULE_0__.some)(currentItems, {
          feed_ID: action.feedId
        })) {
          return state;
        }

        return { ...state,
          [action.listId]: [...currentItems, {
            feed_ID: action.feedId
          }]
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_ITEM_DELETE_FEED */ .MW:
      return removeItemBy(state, action, item => item.feed_ID === action.feedId);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_ITEM_DELETE_TAG */ .nY:
      return removeItemBy(state, action, item => item.tag_ID === action.tagId);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_ITEM_DELETE_SITE */ .a$:
      return removeItemBy(state, action, item => item.site_ID === action.siteId);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_DELETE */ .kB:
      if (!(action.listId in state)) {
        return state;
      }

      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state, action.listId);
  }

  return state;
};
/**
 * Tracks which list IDs the current user is subscribed to.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const subscribedLists = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_2__/* .subscriptionsSchema */ .E, function () {
  var _action$list, _action$list2;

  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LISTS_RECEIVE */ ._O:
      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.map)(action.lists, 'ID');

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_FOLLOW_RECEIVE */ .R1:
      const followedListId = (_action$list = action.list) === null || _action$list === void 0 ? void 0 : _action$list.ID;

      if (!followedListId || (0,lodash__WEBPACK_IMPORTED_MODULE_0__.includes)(state, followedListId)) {
        return state;
      }

      return [...state, followedListId];

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_UNFOLLOW_RECEIVE */ .Nr:
      // Remove the unfollowed list ID from subscribedLists
      const unfollowedListId = (_action$list2 = action.list) === null || _action$list2 === void 0 ? void 0 : _action$list2.ID;

      if (!unfollowedListId) {
        return state;
      }

      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.filter)(state, listId => {
        return listId !== unfollowedListId;
      });

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_DELETE */ .kB:
      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.filter)(state, listId => {
        return listId !== action.listId;
      });

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_REQUEST_SUCCESS */ .L5:
      if (!state.includes(action.data.list.ID)) {
        return [...state, action.data.list.ID];
      }

      return state;
  }

  return state;
});
/**
 * Returns the updated requests state after an action has been dispatched.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

function isRequestingList() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_REQUEST */ .B_:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_REQUEST_SUCCESS */ .L5:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_REQUEST_FAILURE */ .gS:
      return calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_REQUEST */ .B_ === action.type;
  }

  return state;
}
/**
 * Records if there is a pending list creation request.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

function isCreatingList() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_CREATE */ .DJ:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_REQUEST_SUCCESS */ .L5:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_REQUEST_FAILURE */ .gS:
      return calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_CREATE */ .DJ === action.type;
  }

  return state;
}
/**
 * Records if there is a pending list update request.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

function isUpdatingList() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_UPDATE */ .s5:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_UPDATE_SUCCESS */ .we:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_UPDATE_FAILURE */ .ud:
      return calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LIST_UPDATE */ .s5 === action.type;
  }

  return state;
}
/**
 * Returns the updated requests state after an action has been dispatched.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

function isRequestingLists() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LISTS_REQUEST */ .Ny:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LISTS_RECEIVE */ ._O:
      return calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_LISTS_REQUEST */ .Ny === action.type;
  }

  return state;
}
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__/* .combineReducers */ .U)({
  items,
  listItems,
  subscribedLists,
  isCreatingList,
  isRequestingList,
  isRequestingLists,
  isUpdatingList
}));

/***/ }),

/***/ 40932:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "d": function() { return /* binding */ itemsSchema; },
/* harmony export */   "E": function() { return /* binding */ subscriptionsSchema; }
/* harmony export */ });
const itemsSchema = {
  type: 'object',
  patternProperties: {
    //be careful to escape regexes properly
    '^[0-9]+$': {
      type: 'object',
      required: ['ID'],
      properties: {
        ID: {
          type: 'integer'
        },
        title: {
          type: 'string'
        },
        slug: {
          type: 'string'
        },
        description: {
          type: 'string'
        },
        owner: {
          type: 'string'
        },
        is_owner: {
          type: 'boolean'
        },
        is_public: {
          type: 'boolean'
        }
      }
    }
  },
  additionalProperties: false
};
const subscriptionsSchema = {
  type: 'array'
};

/***/ }),

/***/ 61923:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, isRequesting */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(95884);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(37013);




const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_2__/* .itemsSchema */ .d, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_ORGANIZATIONS_RECEIVE */ .$J:
      {
        if (action.error) {
          return state;
        }

        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(action, ['payload', 'organizations'], state);
      }
  }

  return state;
});
const isRequesting = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_ORGANIZATIONS_REQUEST */ .S6:
      return true;

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_ORGANIZATIONS_RECEIVE */ .$J:
      return false;
  }

  return state;
};
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__/* .combineReducers */ .U)({
  items,
  isRequesting
}));

/***/ }),

/***/ 37013:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "d": function() { return /* binding */ itemsSchema; }
/* harmony export */ });
const itemsSchema = {
  type: 'array',
  items: {
    type: 'object',
    properties: {
      id: {
        type: 'integer'
      },
      title: {
        type: 'string'
      },
      slug: {
        type: 'string'
      },
      sites_count: {
        type: 'integer'
      }
    }
  }
};

/***/ }),

/***/ 93125:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "SD": function() { return /* binding */ fetchPost; }
/* harmony export */ });
/* unused harmony exports receivePosts, reloadPost, markPostSeen */
/* harmony import */ var _automattic_help_center__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(97006);
/* harmony import */ var _wordpress_api_fetch__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(86989);
/* harmony import */ var _wordpress_api_fetch__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_api_fetch__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(88767);
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(18552);
/* harmony import */ var calypso_lib_analytics_mc__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(7689);
/* harmony import */ var calypso_lib_wp__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(72429);
/* harmony import */ var calypso_reader_lib_content_width__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(58414);
/* harmony import */ var calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(77327);
/* harmony import */ var calypso_state_posts_likes_actions__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(4184);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(78772);
/* harmony import */ var _normalization_rules__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(89258);
/* harmony import */ var calypso_state_reader_init__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(35929);













 // TODO: make underlying lib/analytics/tracks and reader/stats capable of existing in test code without mocks
// OR switch to analytics middleware

let tracks = {
  recordEvent: () => {}
};

let pageViewForPost = () => {};

if (true) {
  pageViewForPost = (__webpack_require__(29789)/* .pageViewForPost */ .yg);
  tracks = __webpack_require__(17032);
}

function trackRailcarRender(post) {
  tracks.recordTracksEvent('calypso_traintracks_render', post.railcar);
}

function fetchForKey(postKey) {
  let isHelpCenter = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  let isSimpleSite = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
  const query = {};
  const contentWidth = (0,calypso_reader_lib_content_width__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)();

  if (contentWidth) {
    query.content_width = contentWidth;
  }

  if (postKey.blogId) {
    if (isHelpCenter) {
      return (0,_automattic_help_center__WEBPACK_IMPORTED_MODULE_6__/* .shouldTargetWpcom */ .DS)(isSimpleSite) ? (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .ZP)({
        path: `help/article/${encodeURIComponent(postKey.blogId)}/${encodeURIComponent(postKey.postId)}`,
        apiNamespace: 'wpcom/v2/',
        apiVersion: '2'
      }) : _wordpress_api_fetch__WEBPACK_IMPORTED_MODULE_0___default()({
        global: true,
        path: `/wpcom/v2/help-center/fetch-post?post_id=${encodeURIComponent(postKey.postId)}&blog_id=${encodeURIComponent(postKey.blogId)}`
      });
    }

    return calypso_lib_wp__WEBPACK_IMPORTED_MODULE_3__/* ["default"].req.get */ .Z.req.get(`/read/sites/${encodeURIComponent(postKey.blogId)}/posts/${encodeURIComponent(postKey.postId)}`, query);
  }

  const {
    postId,
    feedId,
    ...params
  } = postKey;
  return calypso_lib_wp__WEBPACK_IMPORTED_MODULE_3__/* ["default"].req.get */ .Z.req.get(`/read/feed/${encodeURIComponent(feedId)}/posts/${encodeURIComponent(postId)}`, {
    apiVersion: '1.2',
    ...params,
    ...query
  });
} // helper that hides promise rejections so they return successfully with null instead of rejecting
// this is so that a failure within a slow run of normalization doesn't stop successful posts
// from being dispatched


const hideRejections = promise => promise.catch(() => null);
/**
 * Returns an action object to signal that post objects have been received.
 *
 * @param  {Array}  posts Posts received
 * @returns {object} Action object
 */


const receivePosts = posts => dispatch => {
  if (!posts) {
    return Promise.resolve([]);
  }

  const [toReload, toProcess] = (0,lodash__WEBPACK_IMPORTED_MODULE_1__.partition)(posts, '_should_reload');
  toReload.forEach(post => dispatch(reloadPost(post)));
  const normalizedPosts = (0,lodash__WEBPACK_IMPORTED_MODULE_1__.compact)(toProcess).map(_normalization_rules__WEBPACK_IMPORTED_MODULE_8__/* .runFastRules */ .lp); // dispatch post like additions before the posts. Cuts down on rerenders a bit.

  (0,lodash__WEBPACK_IMPORTED_MODULE_1__.forEach)(normalizedPosts, post => {
    if (!post.is_external) {
      dispatch((0,calypso_state_posts_likes_actions__WEBPACK_IMPORTED_MODULE_9__/* .receiveLikes */ .u5)(post.site_ID, post.ID, {
        iLike: Boolean(post.i_like),
        found: +post.like_count
      }));
    }
  }); // save the posts after running the fast rules

  dispatch({
    type: calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_10__/* .READER_POSTS_RECEIVE */ .nB,
    posts: normalizedPosts
  }); // also save them after running the slow rules

  Promise.all(normalizedPosts.map(_normalization_rules__WEBPACK_IMPORTED_MODULE_8__/* .runSlowRules */ .yv).map(hideRejections)).then(processedPosts => dispatch({
    type: calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_10__/* .READER_POSTS_RECEIVE */ .nB,
    posts: (0,lodash__WEBPACK_IMPORTED_MODULE_1__.compact)(processedPosts) // prune out the "null" rejections

  }));
  (0,lodash__WEBPACK_IMPORTED_MODULE_1__.forEach)((0,lodash__WEBPACK_IMPORTED_MODULE_1__.filter)(normalizedPosts, 'railcar'), trackRailcarRender); // TODO: resolve weird dependency between related-posts and the return here

  return Promise.resolve(normalizedPosts);
};
const requestsInFlight = new Set();
const fetchPost = function (postKey) {
  let isHelpCenter = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  let isSimpleSite = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
  return dispatch => {
    const requestKey = (0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_11__/* .keyToString */ .C$)(postKey);

    if (requestsInFlight.has(requestKey)) {
      return;
    }

    requestsInFlight.add(requestKey);

    function removeKey() {
      requestsInFlight.delete(requestKey);
    }

    return fetchForKey(postKey, isHelpCenter, isSimpleSite).then(data => {
      removeKey();
      return dispatch(receivePosts([data]));
    }).catch(error => {
      removeKey();
      return dispatch(receiveErrorForPostKey(error, postKey));
    });
  };
};

function receiveErrorForPostKey(error, postKey) {
  return {
    type: calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_10__/* .READER_POSTS_RECEIVE */ .nB,
    posts: [{
      feed_ID: postKey.feedId,
      ID: postKey.postId,
      site_ID: postKey.blogId,
      is_external: !postKey.blogId,
      global_ID: (0,uuid__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z)(),
      is_error: true,
      error
    }]
  };
}

function reloadPost(post) {
  return function (dispatch) {
    // keep track of any railcars we might have
    const railcar = post.railcar;
    const postKey = (0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_11__/* .keyForPost */ .WO)(post);
    fetchForKey(postKey).then(data => {
      data.railcar = railcar;
      dispatch(receivePosts([data]));
    });
  };
}
const markPostSeen = (post, site) => (dispatch, getState) => {
  if (!post || hasPostBeenSeen(getState(), post.global_ID)) {
    return;
  }

  dispatch({
    type: READER_POST_SEEN,
    payload: {
      post,
      site
    }
  });

  if (post.site_ID) {
    // they have a site ID, let's try to push a page view
    const isAdmin = !!get(site, 'capabilities.manage_options', false);

    if (site && site.ID) {
      if (site.is_private || !isAdmin) {
        pageViewForPost(site.ID, site.URL, post.ID, site.is_private);
        bumpStat('reader_pageviews', site.is_private ? 'private_view' : 'public_view');
      }
    }
  }
};

/***/ }),

/***/ 81823:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/**
 * Feed post display types
 *
 * @type {object} Types of post for display
 */
/* harmony default export */ __webpack_exports__["Z"] = ({
  UNCLASSIFIED: 0,
  PHOTO_ONLY: 1,
  LARGE_BANNER: 2,
  ONE_LINER: 4,
  LANDSCAPE_BANNER: 8,
  PORTRAIT_BANNER: 16,
  GALLERY: 32,
  VIDEO: 64,
  THUMBNAIL: 128,
  CANONICAL_IN_CONTENT: 256,
  FEATURED_VIDEO: 512,
  X_POST: 1024
});

/***/ }),

/***/ 89258:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "lp": function() { return /* binding */ runFastRules; },
/* harmony export */   "yv": function() { return /* binding */ runSlowRules; }
/* harmony export */ });
/* unused harmony exports imageIsBigEnoughForGallery, classifyPost */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_lib_post_normalizer_rule_add_discover_properties__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(77804);
/* harmony import */ var calypso_lib_post_normalizer_rule_content_detect_media__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(53544);
/* harmony import */ var calypso_lib_post_normalizer_rule_content_detect_polls__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(10363);
/* harmony import */ var calypso_lib_post_normalizer_rule_content_detect_surveys__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(37183);
/* harmony import */ var calypso_lib_post_normalizer_rule_content_disable_autoplay__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(40691);
/* harmony import */ var calypso_lib_post_normalizer_rule_content_link_jetpack_carousels__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(17431);
/* harmony import */ var calypso_lib_post_normalizer_rule_content_make_embeds_safe__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(50917);
/* harmony import */ var calypso_lib_post_normalizer_rule_content_make_images_safe__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(30757);
/* harmony import */ var calypso_lib_post_normalizer_rule_content_make_links_safe__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(51088);
/* harmony import */ var calypso_lib_post_normalizer_rule_content_remove_elements_by_selector__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(64000);
/* harmony import */ var calypso_lib_post_normalizer_rule_content_remove_styles__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(42347);
/* harmony import */ var calypso_lib_post_normalizer_rule_create_better_excerpt__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(47401);
/* harmony import */ var calypso_lib_post_normalizer_rule_decode_entities__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(12800);
/* harmony import */ var calypso_lib_post_normalizer_rule_keep_valid_images__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(31564);
/* harmony import */ var calypso_lib_post_normalizer_rule_make_links_safe__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(91410);
/* harmony import */ var calypso_lib_post_normalizer_rule_make_site_id_safe_for_api__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(21036);
/* harmony import */ var calypso_lib_post_normalizer_rule_pick_canonical_image__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(53317);
/* harmony import */ var calypso_lib_post_normalizer_rule_pick_canonical_media__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(66184);
/* harmony import */ var calypso_lib_post_normalizer_rule_pick_primary_tag__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(49147);
/* harmony import */ var calypso_lib_post_normalizer_rule_prevent_widows__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(59654);
/* harmony import */ var calypso_lib_post_normalizer_rule_safe_image_properties__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(36003);
/* harmony import */ var calypso_lib_post_normalizer_rule_strip_html__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(60566);
/* harmony import */ var calypso_lib_post_normalizer_rule_wait_for_images_to_load__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(75659);
/* harmony import */ var calypso_lib_post_normalizer_rule_with_content_dom__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(55454);
/* harmony import */ var _display_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(81823);
/* harmony import */ var _sizes__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(99891);




























function getCharacterCount(post) {
  if (!post || !post.content_no_html) {
    return 0;
  }

  return post.content_no_html.length;
}

function imageIsBigEnoughForGallery(image) {
  return image.width >= _sizes__WEBPACK_IMPORTED_MODULE_1__/* .GALLERY_MIN_IMAGE_WIDTH */ .hM && image.height >= _sizes__WEBPACK_IMPORTED_MODULE_1__/* .MIN_IMAGE_HEIGHT */ .qg;
}

const hasShortContent = post => getCharacterCount(post) <= _sizes__WEBPACK_IMPORTED_MODULE_1__/* .PHOTO_ONLY_MAX_CHARACTER_COUNT */ .ml;
/**
 * Attempt to classify the post into a display type
 *
 * @param  {object}   post     A post to classify
 * @returns {object}            The classified post
 */


function classifyPost(post) {
  const imagesForGallery = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.filter)(post.content_images, imageIsBigEnoughForGallery);
  let displayType = _display_types__WEBPACK_IMPORTED_MODULE_2__/* ["default"].UNCLASSIFIED */ .Z.UNCLASSIFIED;

  if (imagesForGallery.length >= _sizes__WEBPACK_IMPORTED_MODULE_1__/* .GALLERY_MIN_IMAGES */ .y_) {
    displayType ^= _display_types__WEBPACK_IMPORTED_MODULE_2__/* ["default"].GALLERY */ .Z.GALLERY;
  } else if (post.canonical_media && post.canonical_media.mediaType === 'image' && post.canonical_media.width >= _sizes__WEBPACK_IMPORTED_MODULE_1__/* .PHOTO_ONLY_MIN_WIDTH */ .Ws && hasShortContent(post)) {
    displayType ^= _display_types__WEBPACK_IMPORTED_MODULE_2__/* ["default"].PHOTO_ONLY */ .Z.PHOTO_ONLY;
  }

  if (post.canonical_media && post.canonical_media.mediaType === 'video') {
    displayType ^= _display_types__WEBPACK_IMPORTED_MODULE_2__/* ["default"].FEATURED_VIDEO */ .Z.FEATURED_VIDEO;
  }

  if (post.tags && post.tags['p2-xpost']) {
    displayType ^= _display_types__WEBPACK_IMPORTED_MODULE_2__/* ["default"].X_POST */ .Z.X_POST;
  }

  post.display_type = displayType;
  return post;
}
const fastPostNormalizationRules = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.flow)([calypso_lib_post_normalizer_rule_decode_entities__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_strip_html__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_prevent_widows__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_make_site_id_safe_for_api__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_pick_primary_tag__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z, (0,calypso_lib_post_normalizer_rule_safe_image_properties__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)(_sizes__WEBPACK_IMPORTED_MODULE_1__/* .READER_CONTENT_WIDTH */ .fY), calypso_lib_post_normalizer_rule_make_links_safe__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z, (0,calypso_lib_post_normalizer_rule_with_content_dom__WEBPACK_IMPORTED_MODULE_10__/* ["default"] */ .Z)([calypso_lib_post_normalizer_rule_content_remove_styles__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_content_remove_elements_by_selector__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, (0,calypso_lib_post_normalizer_rule_content_make_images_safe__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .Z)(), calypso_lib_post_normalizer_rule_content_make_embeds_safe__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_content_make_links_safe__WEBPACK_IMPORTED_MODULE_15__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_content_disable_autoplay__WEBPACK_IMPORTED_MODULE_16__/* .disableAutoPlayOnEmbeds */ .b, calypso_lib_post_normalizer_rule_content_disable_autoplay__WEBPACK_IMPORTED_MODULE_16__/* .disableAutoPlayOnMedia */ .Y, calypso_lib_post_normalizer_rule_content_detect_media__WEBPACK_IMPORTED_MODULE_17__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_content_detect_polls__WEBPACK_IMPORTED_MODULE_18__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_content_detect_surveys__WEBPACK_IMPORTED_MODULE_19__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_content_link_jetpack_carousels__WEBPACK_IMPORTED_MODULE_20__/* ["default"] */ .Z]), calypso_lib_post_normalizer_rule_create_better_excerpt__WEBPACK_IMPORTED_MODULE_21__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_pick_canonical_image__WEBPACK_IMPORTED_MODULE_22__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_pick_canonical_media__WEBPACK_IMPORTED_MODULE_23__/* ["default"] */ .Z, classifyPost, calypso_lib_post_normalizer_rule_add_discover_properties__WEBPACK_IMPORTED_MODULE_24__/* ["default"] */ .Z]);
function runFastRules(post) {
  if (!post) {
    return post;
  }

  post = Object.assign({}, post);
  fastPostNormalizationRules(post);
  return post;
}
const slowSyncRules = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.flow)([(0,calypso_lib_post_normalizer_rule_keep_valid_images__WEBPACK_IMPORTED_MODULE_25__/* ["default"] */ .Z)(_sizes__WEBPACK_IMPORTED_MODULE_1__/* .MIN_IMAGE_WIDTH */ .Kt, _sizes__WEBPACK_IMPORTED_MODULE_1__/* .MIN_IMAGE_HEIGHT */ .qg), calypso_lib_post_normalizer_rule_pick_canonical_image__WEBPACK_IMPORTED_MODULE_22__/* ["default"] */ .Z, calypso_lib_post_normalizer_rule_pick_canonical_media__WEBPACK_IMPORTED_MODULE_23__/* ["default"] */ .Z, classifyPost]);
function runSlowRules(post) {
  post = Object.assign({}, post);
  return (0,calypso_lib_post_normalizer_rule_wait_for_images_to_load__WEBPACK_IMPORTED_MODULE_26__/* ["default"] */ .Z)(post).then(slowSyncRules);
}

/***/ }),

/***/ 42334:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, seen */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(95884);
/* eslint-disable no-case-declarations */



/**
 * Tracks all known post objects, indexed by post ID.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

function items() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_POSTS_RECEIVE */ .nB:
      const posts = action.posts || action.payload.posts;
      return { ...state,
        ...(0,lodash__WEBPACK_IMPORTED_MODULE_0__.keyBy)(posts, 'global_ID')
      };

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SEEN_MARK_AS_SEEN_RECEIVE */ .e_:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SEEN_MARK_ALL_AS_SEEN_RECEIVE */ .c1:
      (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(action.globalIds, globalId => {
        state[globalId] = { ...state[globalId],
          is_seen: true
        };
      });
      return { ...state
      };

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SEEN_MARK_AS_UNSEEN_RECEIVE */ .iv:
      (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(action.globalIds, globalId => {
        state[globalId] = { ...state[globalId],
          is_seen: false
        };
      });
      return { ...state
      };
  }

  return state;
}
function seen() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;
  const id = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(action, 'payload.post.global_ID');

  if (action.type === calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_POST_SEEN */ .ch && id) {
    return { ...state,
      [id]: true
    };
  }

  return state;
} // @TODO: evaluate serialization later
// import { itemsSchema } from './schema';
// export const items = withSchemaValidation( itemsSchema, itemsReducer );

/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .combineReducers */ .U)({
  items,
  seen
}));

/***/ }),

/***/ 6712:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "UK": function() { return /* binding */ getPostByKey; }
/* harmony export */ });
/* unused harmony exports getPostById, getPostsByKeys, hasPostBeenSeen */
/* harmony import */ var _automattic_tree_select__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(56868);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(77327);
/* harmony import */ var calypso_state_reader_init__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(35929);




/**
 * Returns a single post.
 *
 * @param  {object}  state  Global state tree
 * @param  {string}  postGlobalId Post global ID
 * @returns {object} Post
 */

function getPostById(state, postGlobalId) {
  return state.reader.posts.items[postGlobalId];
}
const getPostMapByPostKey = (0,_automattic_tree_select__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state => [state.reader.posts.items], _ref => {
  let [posts] = _ref;
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.keyBy)(posts, post => (0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keyToString */ .C$)((0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keyForPost */ .WO)(post)));
});
const getPostByKey = (state, postKey) => {
  if (!postKey || !(0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keyToString */ .C$)(postKey)) {
    return null;
  }

  const postMap = getPostMapByPostKey(state);
  return postMap[(0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keyToString */ .C$)(postKey)];
};
const getPostsByKeys = (0,_automattic_tree_select__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state => [getPostMapByPostKey(state)], (_ref2, postKeys) => {
  let [postMap] = _ref2;

  if (!postKeys || (0,lodash__WEBPACK_IMPORTED_MODULE_0__.some)(postKeys, postKey => !(0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keyToString */ .C$)(postKey))) {
    return null;
  }

  return postKeys.map(calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keyToString */ .C$).map(key => postMap[key]);
}, {
  getCacheKey: postKeys => postKeys.map(calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keyToString */ .C$).join()
});
const hasPostBeenSeen = (state, globalId) => !!get(state, ['reader', 'posts', 'seen', globalId]);

/***/ }),

/***/ 99891:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "fY": function() { return /* binding */ READER_CONTENT_WIDTH; },
/* harmony export */   "Ws": function() { return /* binding */ PHOTO_ONLY_MIN_WIDTH; },
/* harmony export */   "ml": function() { return /* binding */ PHOTO_ONLY_MAX_CHARACTER_COUNT; },
/* harmony export */   "y_": function() { return /* binding */ GALLERY_MIN_IMAGES; },
/* harmony export */   "hM": function() { return /* binding */ GALLERY_MIN_IMAGE_WIDTH; },
/* harmony export */   "Kt": function() { return /* binding */ MIN_IMAGE_WIDTH; },
/* harmony export */   "qg": function() { return /* binding */ MIN_IMAGE_HEIGHT; }
/* harmony export */ });
/**
 * Module vars
 */
const READER_CONTENT_WIDTH = 800;
const PHOTO_ONLY_MIN_WIDTH = 440;
const PHOTO_ONLY_MAX_CHARACTER_COUNT = 85;
const GALLERY_MIN_IMAGES = 4;
const GALLERY_MIN_IMAGE_WIDTH = 300;
const MIN_IMAGE_WIDTH = 144;
const MIN_IMAGE_HEIGHT = 72;

/***/ }),

/***/ 12622:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, pagingOffset */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(15960);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(95884);



/**
 * Tracks mappings between randomization seeds and site recs.
 * Sites get stored in a flat list. Just the basics like title/feedId,blogId.
 *
 * @param  {Array} state  Current state
 * @param  {object} action Action payload
 * @returns {Array}        Updated state
 */

const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .keyedReducer */ .J)('seed', function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_RECOMMENDED_SITES_RECEIVE */ .rE:
      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.uniqBy)(state.concat(action.payload.sites), 'feedId');
  }

  return state;
});
/**
 * Tracks mappings between randomization seeds and current offset in the that seed's stream.
 * this is for used whenrequesting the next page of site recs
 *
 * @param  {Array} state Current state
 * @param  {object} action Action payload
 * @returns {Array}        Updated state
 */

const pagingOffset = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .keyedReducer */ .J)('seed', function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_RECOMMENDED_SITES_RECEIVE */ .rE:
      return Math.max(action.payload.offset, state);
  }

  return state;
});
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__/* .combineReducers */ .U)({
  items,
  pagingOffset
}));

/***/ }),

/***/ 97589:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(95884);
/* harmony import */ var _conversations_reducer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(26395);
/* harmony import */ var _feed_searches_reducer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(13838);
/* harmony import */ var _feeds_reducer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(64380);
/* harmony import */ var _follows_reducer__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(38357);
/* harmony import */ var _lists_reducer__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(6693);
/* harmony import */ var _organizations_reducer__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(61923);
/* harmony import */ var _posts_reducer__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(42334);
/* harmony import */ var _recommended_sites_reducer__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(12622);
/* harmony import */ var _related_posts_reducer__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(1788);
/* harmony import */ var _site_blocks_reducer__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(92972);
/* harmony import */ var _site_dismissals_reducer__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(8614);
/* harmony import */ var _sites_reducer__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(53761);
/* harmony import */ var _streams_reducer__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(83530);
/* harmony import */ var _tags_reducer__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(64805);
/* harmony import */ var _thumbnails_reducer__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(39493);

















const combinedReducer = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .combineReducers */ .U)({
  conversations: _conversations_reducer__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z,
  feeds: _feeds_reducer__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP,
  feedSearches: _feed_searches_reducer__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .ZP,
  follows: _follows_reducer__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .ZP,
  lists: _lists_reducer__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .ZP,
  posts: _posts_reducer__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .ZP,
  recommendedSites: _recommended_sites_reducer__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .ZP,
  relatedPosts: _related_posts_reducer__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .ZP,
  siteBlocks: _site_blocks_reducer__WEBPACK_IMPORTED_MODULE_10__/* ["default"] */ .ZP,
  siteDismissals: _site_dismissals_reducer__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z,
  sites: _sites_reducer__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .ZP,
  streams: _streams_reducer__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .ZP,
  tags: _tags_reducer__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .Z,
  thumbnails: _thumbnails_reducer__WEBPACK_IMPORTED_MODULE_15__/* ["default"] */ .Z,
  organizations: _organizations_reducer__WEBPACK_IMPORTED_MODULE_16__/* ["default"] */ .ZP
});
const readerReducer = (0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .withStorageKey */ .xi)('reader', combinedReducer);
/* harmony default export */ __webpack_exports__["Z"] = (readerReducer);

/***/ }),

/***/ 1788:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, queuedRequests */
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(95884);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92310);




function setStateForKey(state, action, val) {
  const {
    siteId,
    postId,
    scope
  } = action.payload;
  return { ...state,
    [(0,_utils__WEBPACK_IMPORTED_MODULE_0__/* .key */ .Jy)(siteId, postId, scope)]: val
  };
}

const items = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_RELATED_POSTS_RECEIVE */ .Bi:
      return setStateForKey(state, action, action.payload.posts.map(p => p.global_ID));
  }

  return state;
};
const queuedRequests = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_RELATED_POSTS_REQUEST */ .Cm:
      return setStateForKey(state, action, true);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_RELATED_POSTS_REQUEST_SUCCESS */ .yZ:
      return setStateForKey(state, action, false);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_RELATED_POSTS_REQUEST_FAILURE */ .Rn:
      return setStateForKey(state, action, false);
  }

  return state;
};
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .combineReducers */ .U)({
  items,
  queuedRequests
}));

/***/ }),

/***/ 92310:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Jy": function() { return /* binding */ key; }
/* harmony export */ });
/* unused harmony exports SCOPE_ALL, SCOPE_SAME, SCOPE_OTHER */
const SCOPE_ALL = 'all';
const SCOPE_SAME = 'same';
const SCOPE_OTHER = 'other';
function key(siteId, postId) {
  let scope = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : SCOPE_ALL;
  return `${siteId}-${postId}-${scope}`;
}

/***/ }),

/***/ 92972:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, currentPage, lastPage, inflightPages */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(95884);



const items = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SITE_BLOCK */ .IJ:
      {
        return { ...state,
          [action.payload.siteId]: true
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SITE_UNBLOCK */ .Qw:
      {
        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state, action.payload.siteId);
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SITE_REQUEST_SUCCESS */ .qY:
      {
        if (!action.payload.is_blocked) {
          if (!state[action.payload.ID]) {
            return state;
          }

          return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state, action.payload.ID);
        }

        return { ...state,
          [action.payload.ID]: true
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SITE_BLOCKS_RECEIVE */ .zF:
      {
        if (!action.payload || !action.payload.sites) {
          return state;
        }

        const newBlocks = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(action.payload.sites, (obj, site) => {
          obj[site.ID] = true;
          return obj;
        }, {});
        return { ...state,
          ...newBlocks
        };
      }
  }

  return state;
};
const currentPage = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 1;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SITE_BLOCKS_RECEIVE */ .zF:
      {
        if (!action.payload || !action.payload.page) {
          return state;
        }

        return action.payload.page;
      }
  }

  return state;
};
const lastPage = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SITE_BLOCKS_RECEIVE */ .zF:
      {
        if (!action.payload || !action.payload.page || action.payload.count > 0) {
          return state;
        }

        return action.payload.page;
      }
  }

  return state;
};
const inflightPages = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SITE_BLOCKS_REQUEST */ .zg:
      {
        if (!action.payload || !action.payload.page) {
          return state;
        }

        return { ...state,
          [action.payload.page]: true
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_SITE_BLOCKS_RECEIVE */ .zF:
      {
        if (!action.payload || !action.payload.page) {
          return state;
        }

        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state, action.payload.page);
      }
  }

  return state;
};
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .combineReducers */ .U)({
  items,
  currentPage,
  lastPage,
  inflightPages
}));

/***/ }),

/***/ 8614:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export items */
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(95884);


const items = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_0__/* .READER_DISMISS_SITE */ .D8:
      {
        return { ...state,
          [action.payload.siteId]: true
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_0__/* .READER_DISMISS_POST */ .K1:
      {
        return { ...state,
          [action.payload.siteId]: true
        };
      }
  }

  return state;
};
/* harmony default export */ __webpack_exports__["Z"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .combineReducers */ .U)({
  items
}));

/***/ }),

/***/ 63262:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "LV": function() { return /* binding */ requestSite; },
/* harmony export */   "N0": function() { return /* binding */ receiveReaderSiteRequestSuccess; },
/* harmony export */   "vE": function() { return /* binding */ receiveReaderSiteRequestFailure; }
/* harmony export */ });
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_data_layer_wpcom_read_sites__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(8681);
/* harmony import */ var calypso_state_reader_init__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(35929);



function requestSite(blogId) {
  return {
    type: calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_SITE_REQUEST */ .LW,
    payload: {
      ID: blogId
    }
  };
}
function receiveReaderSiteRequestSuccess(data) {
  return {
    type: calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_SITE_REQUEST_SUCCESS */ .qY,
    payload: data
  };
}
function receiveReaderSiteRequestFailure(action, error) {
  return {
    type: calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_SITE_REQUEST_FAILURE */ .Fy,
    payload: action.payload,
    error
  };
}

/***/ }),

/***/ 70418:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "X": function() { return /* binding */ fields; }
/* harmony export */ });
const fields = ['ID', 'name', 'title', 'URL', 'icon', 'is_following', 'is_jetpack', 'description', 'is_private', 'feed_ID', 'feed_URL', 'capabilities', 'prefer_feed', 'subscribers_count', 'options', // have to include this to get options at all
'subscription', 'is_blocked', 'unseen_count'];

/***/ }),

/***/ 53761:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, queuedRequests, lastFetched */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(50118);
/* harmony import */ var calypso_lib_url__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(47307);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(71085);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(95884);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(5259);







function handleRequestFailure(state, action) {
  // 410 means site moved - site used to be on wpcom but is no longer
  const handledStatusCodes = [403, 404, 410];

  if (action.error && !(0,lodash__WEBPACK_IMPORTED_MODULE_0__.includes)(handledStatusCodes, action.error.statusCode)) {
    return state;
  }

  return { ...state,
    [action.payload.ID]: {
      ID: action.payload.ID,
      is_error: true,
      error: action.error
    }
  };
}

function adaptSite(attributes) {
  // this also ends up cloning attributes, which is important since we mutate it
  attributes = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(attributes, ['meta', 'subscription']);

  if (attributes.URL) {
    attributes.domain = (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_1__/* .withoutHttp */ .ce)(attributes.URL);
    attributes.slug = attributes.domain.replace(/\//g, '::');
  }

  attributes.title = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.trim)(attributes.name) || attributes.domain;

  if (attributes.description) {
    attributes.description = (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_2__/* .decodeEntities */ .S)(attributes.description);
  } // If a WordPress.com site has a mapped domain create a `wpcom_url`
  // attribute to allow site selection with either domain.


  if (attributes.options && attributes.options.is_mapped_domain && !attributes.is_jetpack) {
    attributes.wpcom_url = (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_1__/* .withoutHttp */ .ce)(attributes.options.unmapped_url);
  } // If a site has an `is_redirect` property use the `unmapped_url`
  // for the slug and domain to match the wordpress.com original site.


  if (attributes.options && attributes.options.is_redirect) {
    attributes.slug = (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_1__/* .withoutHttp */ .ce)(attributes.options.unmapped_url);
    attributes.domain = attributes.slug;
  }

  return attributes;
}

function handleRequestSuccess(state, action) {
  const site = adaptSite(action.payload); // TODO do we need to normalize site entries somehow?

  return { ...state,
    [action.payload.ID]: site
  };
}

const itemsReducer = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_SITE_BLOCKS_RECEIVE */ .zF:
      {
        if (!action.payload || !action.payload.sites) {
          return state;
        }

        const newBlocks = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.keyBy)(action.payload.sites, 'ID'); // Prefer existing state if we have it - site details provided by blocks are limited (only name, URL)

        return { ...newBlocks,
          ...state
        };
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_SITE_REQUEST_SUCCESS */ .qY:
      return handleRequestSuccess(state, action);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_SITE_REQUEST_FAILURE */ .Fy:
      return handleRequestFailure(state, action);
  }

  return state;
};

const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_5__/* .readerSitesSchema */ .u, (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_6__/* .withPersistence */ .$)(itemsReducer, {
  // remove errors from the serialized state
  serialize: state => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omitBy)(state, 'is_error')
}));
function queuedRequests() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_SITE_REQUEST */ .LW:
      return { ...state,
        [action.payload.ID]: true
      };

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_SITE_REQUEST_SUCCESS */ .qY:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_SITE_REQUEST_FAILURE */ .Fy:
      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state, action.payload.ID);
  }

  return state;
}
const lastFetched = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_3__/* .READER_SITE_REQUEST_SUCCESS */ .qY:
      return { ...state,
        [action.payload.ID]: Date.now()
      };
  }

  return state;
};
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_7__/* .combineReducers */ .U)({
  items,
  queuedRequests,
  lastFetched
}));

/***/ }),

/***/ 5259:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "u": function() { return /* binding */ readerSitesSchema; }
/* harmony export */ });
/* harmony import */ var calypso_state_sites_schema__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(43056);
 // based on the normal site endpoint schema with a few extra properties

const readerSitesSchema = { ...calypso_state_sites_schema__WEBPACK_IMPORTED_MODULE_0__/* .sitesSchema */ .K,
  patternProperties: { ...calypso_state_sites_schema__WEBPACK_IMPORTED_MODULE_0__/* .sitesSchema.patternProperties */ .K.patternProperties,
    ['^\\d+$']: { ...calypso_state_sites_schema__WEBPACK_IMPORTED_MODULE_0__/* .sitesSchema.patternProperties["^\\d+$"] */ .K.patternProperties["^\\d+$"],
      properties: { ...calypso_state_sites_schema__WEBPACK_IMPORTED_MODULE_0__/* .sitesSchema.patternProperties["^\\d+$"].properties */ .K.patternProperties["^\\d+$"].properties,
        feed_ID: {
          type: 'number'
        },
        subscription: {
          type: 'object'
        },
        is_blocked: {
          type: 'boolean'
        },
        organization_id: {
          type: 'number'
        },
        unseen_count: {
          type: 'number'
        }
      }
    }
  }
};

/***/ }),

/***/ 58311:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_g": function() { return /* binding */ shouldSiteBeFetched; }
/* harmony export */ });
/* unused harmony exports getSite, getSiteByFeedUrl */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_reader_init__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(35929);


const DAY_IN_MILLIS = 24 * 60 * 1000 * 1000;
/**
 * Returns true if we should fetch the site
 *
 * @param  {object}  state  Global state tree
 * @param  {number}  siteId The site ID
 * @returns {boolean}        Whether site should be fetched
 */

function shouldSiteBeFetched(state, siteId) {
  const isNotQueued = !state.reader.sites.queuedRequests[siteId];
  const isMissing = !getSite(state, siteId);
  return isNotQueued && (isMissing || isStale(state, siteId));
}

function isStale(state, siteId) {
  const lastFetched = state.reader.sites.lastFetched[siteId];

  if (!lastFetched) {
    return true;
  }

  return lastFetched <= Date.now() - DAY_IN_MILLIS;
}
/**
 * Returns a site object
 *
 * @param  {object}  state  Global state tree
 * @param  {number}  siteId The site ID
 * @returns {object}        Site
 */


function getSite(state, siteId) {
  return state.reader.sites.items[siteId];
}
function getSiteByFeedUrl(state, feedUrl) {
  return find(state.reader.sites.items, {
    feed_URL: feedUrl
  });
}

/***/ }),

/***/ 83530:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, PENDING_ITEMS_DEFAULT, pendingItems, selected, isRequesting, lastPage, pageHandle */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var moment__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(76292);
/* harmony import */ var moment__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(moment__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(77327);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(95884);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(15960);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(86115);







const takeWhile = (array, predicate) => {
  const [x, ...xs] = array;

  if (array.length > 0 && predicate(x)) {
    return [x, ...takeWhile(xs, predicate)];
  }

  return [];
};

const takeRightWhile = (array, predicate) => {
  return takeWhile([...array].reverse(), predicate);
};
/*
 * Contains a list of post-keys representing the items of a stream.
 */


const items = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  let action = arguments.length > 1 ? arguments[1] : undefined;
  let streamItems;
  let gap;
  let newState;
  let newXPosts;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_STREAMS_PAGE_RECEIVE */ .pu:
      gap = action.payload.gap;
      streamItems = action.payload.streamItems;

      if (gap) {
        const beforeGap = takeWhile(state, postKey => !(0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keysAreEqual */ .NK)(postKey, gap));
        const afterGap = takeRightWhile(state, postKey => !(0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keysAreEqual */ .NK)(postKey, gap)); // after query param is inclusive, so we need to drop duplicate post

        if ((0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keysAreEqual */ .NK)((0,lodash__WEBPACK_IMPORTED_MODULE_0__.last)(streamItems), afterGap[0])) {
          streamItems.pop();
        } // gap was empty


        if (streamItems.length === 0) {
          return [...beforeGap, ...afterGap];
        } // create a new gap if we still need one


        let nextGap = [];
        const from = gap.from;
        const to = moment__WEBPACK_IMPORTED_MODULE_1___default()((0,lodash__WEBPACK_IMPORTED_MODULE_0__.last)(streamItems).date);

        if (!from.isSame(to)) {
          nextGap = [{
            isGap: true,
            from,
            to
          }];
        }

        return (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .combineXPosts */ .E)([...beforeGap, ...streamItems, ...nextGap, ...afterGap]);
      } // add the `streamItems` to state, but only ones that aren't already there


      newState = streamItems.reduce((accuState, streamItem) => {
        const isNew = !accuState.some(accuItem => (0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keysAreEqual */ .NK)(accuItem, streamItem));
        return isNew ? [...accuState, streamItem] : accuState;
      }, state); // Find any x-posts

      newXPosts = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.filter)(streamItems, postKey => postKey.xPostMetadata);

      if (!newXPosts) {
        return newState;
      } // Filter out duplicate x-posts


      return (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .combineXPosts */ .E)(newState);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_STREAMS_SHOW_UPDATES */ .c7:
      return (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .combineXPosts */ .E)([...action.payload.items, ...state]);

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_DISMISS_POST */ .K1:
      {
        const postKey = action.payload.postKey;
        const indexToRemove = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.findIndex)(state, item => (0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keysAreEqual */ .NK)(item, postKey));

        if (indexToRemove === -1) {
          return state;
        }

        const updatedState = [...state];
        updatedState[indexToRemove] = updatedState.pop(); // set the dismissed post location to the last item from the recs stream

        return updatedState;
      }
  }

  return state;
};
const PENDING_ITEMS_DEFAULT = {
  lastUpdated: null,
  items: []
};
/*
 * Contains new items in the stream that we've learned about since initial render
 * but don't want to display just yet.
 * This is the data backing the orange "${number} new posts" pill.
 */

const pendingItems = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : PENDING_ITEMS_DEFAULT;
  let action = arguments.length > 1 ? arguments[1] : undefined;
  let streamItems;
  let maxDate;
  let minDate;
  let newItems;
  let newXPosts;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_STREAMS_PAGE_RECEIVE */ .pu:
      streamItems = action.payload.streamItems;

      if (streamItems.length === 0) {
        return state;
      }

      maxDate = moment__WEBPACK_IMPORTED_MODULE_1___default()(streamItems[0].date);

      if (state.lastUpdated && maxDate.isSameOrBefore(state.lastUpdated)) {
        return state;
      }

      return { ...state,
        lastUpdated: maxDate
      };

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_STREAMS_UPDATES_RECEIVE */ .RN:
      streamItems = action.payload.streamItems;

      if (streamItems.length === 0) {
        return state;
      }

      maxDate = moment__WEBPACK_IMPORTED_MODULE_1___default()(streamItems[0].date);
      minDate = moment__WEBPACK_IMPORTED_MODULE_1___default()((0,lodash__WEBPACK_IMPORTED_MODULE_0__.last)(streamItems).date); // only retain posts that are newer than ones we already have

      if (state.lastUpdated) {
        streamItems = streamItems.filter(item => moment__WEBPACK_IMPORTED_MODULE_1___default()(item.date).isAfter(state.lastUpdated));
      }

      if (streamItems.length === 0) {
        return state;
      }

      newItems = [...streamItems]; // Find any x-posts and filter out duplicates

      newXPosts = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.filter)(newItems, postKey => postKey.xPostMetadata);

      if (newXPosts) {
        newItems = (0,_utils__WEBPACK_IMPORTED_MODULE_4__/* .combineXPosts */ .E)(newItems);
      } // there is a gap if the oldest item in the poll is newer than last update time


      if (state.lastUpdated && minDate.isAfter(state.lastUpdated)) {
        newItems.push({
          isGap: true,
          from: state.lastUpdated,
          to: minDate
        });
      }

      return {
        lastUpdated: maxDate,
        items: newItems
      };

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_STREAMS_SHOW_UPDATES */ .c7:
      return { ...state,
        items: []
      };
  }

  return state;
};
/*
 * Contains which postKey is currently selected.
 * This is relevant for keyboard navigation
 */

const selected = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;
  let idx;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_STREAMS_SELECT_ITEM */ ._7:
      return action.payload.postKey;

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_STREAMS_SELECT_NEXT_ITEM */ .l0:
      idx = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.findIndex)(action.payload.items, item => (0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keysAreEqual */ .NK)(item, state));
      return idx === action.payload.items.length - 1 ? state : action.payload.items[idx + 1];

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_STREAMS_SELECT_PREV_ITEM */ .rC:
      idx = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.findIndex)(action.payload.items, item => (0,calypso_reader_post_key__WEBPACK_IMPORTED_MODULE_3__/* .keysAreEqual */ .NK)(item, state));
      return idx === 0 ? state : action.payload.items[idx - 1];
  }

  return state;
};
/*
 * Contains whether or not a request for a new page is in flight.
 * Most parts of Calypso don't need this data, but streams still do since we can't infer the status
 * from current state. Its possible to have a list of post-keys as the state, and yet be fetching another page.
 *
 * isRequesting data is mostly used for whether or not to render placeholders
 */

const isRequesting = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  // this has become a lie! its not really whether we are requesting, just if we need to show
  // placeholders at the bottom of the stream
  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_STREAMS_PAGE_REQUEST */ .CI:
      return state || !action.payload.isPoll && !action.payload.isGap;

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_STREAMS_PAGE_RECEIVE */ .pu:
      return false;
  }

  return state;
};
/*
 * Contains whether or not a stream is at its end.
 * This data is used to tell our infinite-list components
 * to render its 'end-of-stream' and stop making requests for more data.
 */

const lastPage = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_STREAMS_PAGE_RECEIVE */ .pu) {
    return action.payload.streamItems.length === 0;
  }

  return state;
};
/*
 * Contains the query params needed to be able to fetch the next page.
 * This usually gets handed to the request for more stream items
 */

const pageHandle = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_2__/* .READER_STREAMS_PAGE_RECEIVE */ .pu && action.payload.pageHandle && !action.payload.isPoll && !action.payload.gap) {
    return action.payload.pageHandle;
  }

  return state;
};
const streamReducer = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_5__/* .combineReducers */ .U)({
  items,
  pendingItems,
  selected,
  lastPage,
  isRequesting,
  pageHandle
});
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_6__/* .keyedReducer */ .J)('payload.streamKey', streamReducer));

/***/ }),

/***/ 86115:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "E": function() { return /* binding */ combineXPosts; }
/* harmony export */ });
/* unused harmony export addDuplicateXPostToPostKey */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_reader_stream_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(46310);


/**
 * Add the post URL from a duplicate x-post to an existing post key
 *
 * @param {object} postKey1 First post key
 * @param {object} postKey2 Second (duplicate) post key
 * @returns {object} Post key
 */

const addDuplicateXPostToPostKey = (postKey1, postKey2) => {
  return { ...postKey1,
    // Add the URL from the second post key
    xPostUrls: Array.isArray(postKey1.xPostUrls) ? [...postKey1.xPostUrls, postKey2.url] : [postKey2.url]
  };
};
/**
 * Combine adjacent x-posts that refer to the same original post
 *
 * @param {Array} postKeys Array of post key objects
 * @returns {Array} Array of post key objects
 */

const combineXPosts = postKeys => postKeys.reduce((accumulator, postKey) => {
  const lastPostKey = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.last)(accumulator);

  if ((0,calypso_reader_stream_utils__WEBPACK_IMPORTED_MODULE_1__/* .sameXPost */ .qb)(lastPostKey, postKey)) {
    accumulator[accumulator.length - 1] = addDuplicateXPostToPostKey(lastPostKey, postKey);
  } else {
    accumulator.push(postKey);
  }

  return accumulator;
}, []);

/***/ }),

/***/ 49054:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, requesting */
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(95884);


/**
 * Tracks all known image objects, indexed by tag name.
 *
 * @param  {Array} state  Current state
 * @param  {object} action Action payload
 * @returns {Array}        Updated state
 */

function items() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_0__/* .READER_TAG_IMAGES_RECEIVE */ .Ep) {
    let images = action.images;

    if (state[action.tag]) {
      images = state[action.tag].concat(action.images);
    }

    return { ...state,
      [action.tag]: images
    };
  }

  return state;
}
/**
 * Returns the updated requesting state after an action has been dispatched.
 * Requesting state tracks whether a request is in progress.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action object
 * @returns {object}        Updated state
 */

function requesting() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_0__/* .READER_TAG_IMAGES_REQUEST */ .hB:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_0__/* .READER_TAG_IMAGES_REQUEST_SUCCESS */ ._i:
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_0__/* .READER_TAG_IMAGES_REQUEST_FAILURE */ .Jx:
      return { ...state,
        [action.tag]: action.type === calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_0__/* .READER_TAG_IMAGES_REQUEST */ .hB
      };
  }

  return state;
}
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .combineReducers */ .U)({
  items,
  requesting
}));

/***/ }),

/***/ 84668:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(78772);


/*
 * since the api always returns the whole list of followed tags unpaginated, both read/tags*,
 * we can do a full replace instead of merge
 *
 * the shape of a tag is { id, url, title, displayName, isFollowing }.
 */

/* harmony default export */ __webpack_exports__["Z"] = (function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_TAGS_RECEIVE */ .fY:
      {
        const tags = action.payload;
        const resetFollowingData = action.meta.resetFollowingData;

        if (!resetFollowingData) {
          return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, state, (0,lodash__WEBPACK_IMPORTED_MODULE_0__.keyBy)(tags, 'id'));
        }

        const allTagsUnfollowed = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.mapValues)(state, tag => ({ ...tag,
          isFollowing: false
        }));
        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, allTagsUnfollowed, (0,lodash__WEBPACK_IMPORTED_MODULE_0__.keyBy)(tags, 'id'));
      }

    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_1__/* .READER_UNFOLLOW_TAG_RECEIVE */ .tN:
      {
        const removedTag = action.payload;
        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, state, {
          [removedTag]: {
            isFollowing: false
          }
        });
      }
  }

  return state;
});

/***/ }),

/***/ 64805:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(95884);
/* harmony import */ var _images_reducer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(49054);
/* harmony import */ var _items_reducer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(84668);



/* harmony default export */ __webpack_exports__["Z"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .combineReducers */ .U)({
  images: _images_reducer__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP,
  items: _items_reducer__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z
}));

/***/ }),

/***/ 39493:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export items */
/* harmony import */ var calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(78772);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(95884);


/**
 * Tracks mappings between embedUrls (iframe.src) --> thumbnails
 * Here is what the state tree may look like:
 *
 *   thumbnails: {
 *     items: {
 *       'https://www.youtube.com/watch?v=syWk7P3SPMQ': https://img.youtube.com/vi/syWk7P3SPMQ/mqdefault.jpg,
 *       ...
 *     },
 *     requesting: {
 *       'https://www.youtube.com/watch?v=syWk7P3SPMQ': false,
 *       ...
 *     }
 *   }
 *
 *
 * @param  {Array} state  Current state
 * @param  {object} action Action payload
 * @returns {Array}        Updated state
 */

function items() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_reader_action_types__WEBPACK_IMPORTED_MODULE_0__/* .READER_THUMBNAIL_RECEIVE */ .CE:
      return { ...state,
        [action.embedUrl]: action.thumbnailUrl
      };
  }

  return state;
}
/* harmony default export */ __webpack_exports__["Z"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .combineReducers */ .U)({
  items
}));

/***/ }),

/***/ 9044:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "P": function() { return /* binding */ setStore; },
/* harmony export */   "x": function() { return /* binding */ registerReducer; }
/* harmony export */ });
/* harmony import */ var _add_reducer__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(86398);

let currentAddReducer;
const reducerRegistrationQueue = [];
function setStore(store, getStoredState) {
  // Clear any previously added reducers when replacing an existing store.
  if (currentAddReducer) {
    (0,_add_reducer__WEBPACK_IMPORTED_MODULE_0__/* .clear */ .Z)();
  }

  currentAddReducer = (0,_add_reducer__WEBPACK_IMPORTED_MODULE_0__/* .addReducerToStore */ .l)(store, getStoredState); // Synchronously add all pending reducers.
  // These include reducers registered to previous stores, since their code has
  // already been loaded.

  for (const [key, reducer] of reducerRegistrationQueue) {
    currentAddReducer(key, reducer);
  }
}
function registerReducer(key, reducer) {
  if (currentAddReducer) {
    // Register immediately.
    currentAddReducer(key, reducer);
  } // Add to queue, for future stores.


  reducerRegistrationQueue.push([key, reducer]);
}

/***/ }),

/***/ 30963:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getCurrentLocaleSlug; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_ui_init__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(91789);


/**
 * Gets the current ui locale slug
 *
 * @param {object} state - global redux state
 * @returns {string} current state value
 */

function getCurrentLocaleSlug(state) {
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(state, 'ui.language.localeSlug', null);
}

/***/ }),

/***/ 96767:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export default */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_selectors_is_site_wpforteams__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(28879);


/**
 * Returns the P2 hub blog id for the site. If the site is a hub the id will be
 * the same as the site id.
 *
 * @param {object} state Global state tree
 * @param {number} siteId the site ID
 * @returns {?number} Blog ID of the site's hub if it is a P2 – otherwise null.
 */

function getP2HubBlogId(state, siteId) {
  if (!isSiteWPForTeams(state, siteId)) {
    return null;
  }

  return get(state, ['sites', 'items', siteId, 'options', 'p2_hub_blog_id'], null);
}

/***/ }),

/***/ 87720:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getPrimarySiteId; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_current_user_selectors__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36747);


/**
 * Returns the current user's primary site's ID.
 *
 * @param  {object}  state Global state tree
 * @returns {?number}       The current user's primary site's ID
 */

function getPrimarySiteId(state) {
  const currentUser = (0,calypso_state_current_user_selectors__WEBPACK_IMPORTED_MODULE_1__/* .getCurrentUser */ .ts)(state);
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(currentUser, 'primary_blog', null);
}

/***/ }),

/***/ 53843:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getRawSite; }
/* harmony export */ });
/* harmony import */ var calypso_state_selectors_get_sites_items__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(37480);


/**
 * Returns a raw site object by its ID.
 */
function getRawSite(state, siteId) {
  return (0,calypso_state_selectors_get_sites_items__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state)[siteId] || null;
}

/***/ }),

/***/ 23047:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export default */
/* harmony import */ var calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(53843);

/**
 * Returns a site's URL or null if the site doesn't exist or the URL is unknown
 *
 * @param  {object}  state  Global state tree
 * @param  {number}  siteId Site ID
 * @returns {?string}        URL of site if known
 */

function getSiteUrl(state, siteId) {
  const site = getRawSite(state, siteId);
  return (site === null || site === void 0 ? void 0 : site.URL) ?? null;
}

/***/ }),

/***/ 37480:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getSitesItems; }
/* harmony export */ });
const EMPTY_SITES = Object.freeze({});

/**
 * Returns site items object or empty object.
 */
function getSitesItems(state) {
  return state.sites.items || EMPTY_SITES;
}

/***/ }),

/***/ 16193:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export hasCancelableUserPurchases */
/* harmony import */ var calypso_state_purchases_selectors__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(76678);
/* harmony import */ var calypso_state_purchases_init__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(65811);


/**
 * Does the user have any current purchases that can be canceled (i.e. purchases other than premium themes)?
 *
 * Note: there is an is_cancelable flag on the purchase object, but it returns true for premium themes.
 *
 * @param  {object}  state       global state
 * @returns {boolean} if the user currently has any purchases that can be canceled.
 */

const hasCancelableUserPurchases = state => {
  const purchases = (0,calypso_state_purchases_selectors__WEBPACK_IMPORTED_MODULE_1__/* .getUserPurchases */ .I)(state);
  return purchases && purchases.some(purchase => purchase.isRefundable || purchase.productSlug !== 'premium_theme');
};
/* harmony default export */ __webpack_exports__["Z"] = (hasCancelableUserPurchases);

/***/ }),

/***/ 28879:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export default */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Returns true if site is a WP for Teams site, false if not and null if unknown
 *
 * @param  {object}   state  Global state tree
 * @param  {number}   siteId Site ID
 * @returns {?boolean}        Whether site is a WP for Teams site
 */

function isSiteWPForTeams(state, siteId) {
  return get(state, ['sites', 'items', siteId, 'options', 'is_wpforteams_site'], null);
}

/***/ }),

/***/ 87697:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_": function() { return /* binding */ SerializationResult; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(56666);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);



/**
 * Helper class for holding results of state serialization
 * Accumulates the state tree for "root" and any number of custom "storage keys"
 * Each storage key is then saved as a separate record in IndexedDB
 */
class SerializationResult {
  constructor() {
    let results = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(this, "results", void 0);

    this.results = results;
  }

  get() {
    return this.results;
  }

  root() {
    return this.results.root;
  }

  addRootResult(reducerKey, result) {
    return this.addResult('root', reducerKey, result);
  }

  addKeyResult(storageKey, result) {
    return this.addResult(storageKey, null, result);
  }

  addResult(storageKey, reducerKey, result) {
    if (result instanceof SerializationResult) {
      (0,lodash__WEBPACK_IMPORTED_MODULE_0__.forEach)(result.results, (resultState, resultKey) => {
        if (resultKey === 'root') {
          this.addResult(storageKey, reducerKey, resultState);
        } else {
          this.addResult(resultKey, null, resultState);
        }
      });
    } else if (reducerKey) {
      if (!this.results[storageKey]) {
        this.results[storageKey] = {};
      }

      this.results[storageKey][reducerKey] = result;
    } else {
      this.results[storageKey] = result;
    }
  }

}

/***/ }),

/***/ 40540:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "BU": function() { return /* binding */ requestSites; },
/* harmony export */   "LV": function() { return /* binding */ requestSite; }
/* harmony export */ });
/* unused harmony exports receiveDeletedSite, receiveSite, receiveSites, deleteSite, sitePluginUpdated, updateSiteFrontPage, updateSiteMigrationMeta */
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var calypso_lib_wp__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(72429);
/* harmony import */ var calypso_me_purchases_paths__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(1422);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_current_user_actions__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(91668);
/* harmony import */ var calypso_state_selectors_get_p2_hub_blog_id__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(96767);
/* harmony import */ var calypso_state_selectors_get_site_url__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(23047);
/* harmony import */ var calypso_state_sites_constants__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(84465);












/**
 * Returns a thunk that dispatches an action object to be used in signalling that a site has been
 * deleted. It also re-fetches the current user.
 *
 * @param  {number} siteId  ID of deleted site
 * @returns {Function}        Action thunk
 */

function receiveDeletedSite(siteId) {
  return dispatch => {
    dispatch({
      type: SITE_DELETE_RECEIVE,
      siteId
    });
    dispatch(fetchCurrentUser());
  };
}
/**
 * Returns an action object to be used in signalling that a site object has
 * been received.
 *
 * @param  {object} site Site received
 * @returns {object}      Action object
 */

function receiveSite(site) {
  return {
    type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_8__/* .SITE_RECEIVE */ .UUJ,
    site
  };
}
/**
 * Returns an action object to be used in signalling that site objects have
 * been received.
 *
 * @param  {object[]} sites Sites received
 * @returns {object}         Action object
 */

function receiveSites(sites) {
  return {
    type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_8__/* .SITES_RECEIVE */ .xLe,
    sites
  };
}
/**
 * Triggers a network request to request all visible sites
 *
 * @returns {Function}        Action thunk
 */

function requestSites() {
  return dispatch => {
    dispatch({
      type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_8__/* .SITES_REQUEST */ .M4_
    });
    const siteFilter = (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('site_filter');
    return calypso_lib_wp__WEBPACK_IMPORTED_MODULE_2__/* ["default"].me */ .Z.me().sites({
      apiVersion: '1.2',
      site_visibility: 'all',
      include_domain_only: true,
      site_activity: 'active',
      fields: calypso_state_sites_constants__WEBPACK_IMPORTED_MODULE_7__/* .SITE_REQUEST_FIELDS */ .U,
      options: calypso_state_sites_constants__WEBPACK_IMPORTED_MODULE_7__/* .SITE_REQUEST_OPTIONS */ .x,
      filters: siteFilter.length > 0 ? siteFilter.join(',') : undefined
    }).then(response => {
      dispatch(receiveSites(response.sites));
      dispatch({
        type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_8__/* .SITES_REQUEST_SUCCESS */ .KSQ
      });
    }).catch(error => {
      dispatch({
        type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_8__/* .SITES_REQUEST_FAILURE */ .eTV,
        error
      });
    });
  };
}
/**
 * Returns a function which, when invoked, triggers a network request to fetch
 * a site.
 *
 * @param {number|string} siteFragment Site ID or slug
 * @returns {Function}              Action thunk
 */

function requestSite(siteFragment) {
  function doRequest(forceWpcom) {
    const query = {
      apiVersion: '1.2'
    };

    if (forceWpcom) {
      query.force = 'wpcom';
    }

    const siteFilter = (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('site_filter');

    if (siteFilter.length > 0) {
      query.filters = siteFilter.join(',');
    }

    return calypso_lib_wp__WEBPACK_IMPORTED_MODULE_2__/* ["default"].site */ .Z.site(siteFragment).get(query);
  }

  return dispatch => {
    dispatch({
      type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_8__/* .SITE_REQUEST */ .hJk,
      siteId: siteFragment
    });
    const result = doRequest(false).catch(error => {
      // if there is Jetpack JSON API module error, retry with force: 'wpcom'
      if ((error === null || error === void 0 ? void 0 : error.status) === 403 && (error === null || error === void 0 ? void 0 : error.message) === 'API calls to this blog have been disabled.' || (error === null || error === void 0 ? void 0 : error.status) === 400 && (error === null || error === void 0 ? void 0 : error.name) === 'ApiNotFoundError') {
        return doRequest(true);
      }

      return Promise.reject(error);
    });
    result.then(site => {
      // If we can't manage the site, don't add it to state.
      if (site && site.capabilities) {
        dispatch(receiveSite((0,lodash__WEBPACK_IMPORTED_MODULE_1__.omit)(site, '_headers')));
      }

      dispatch({
        type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_8__/* .SITE_REQUEST_SUCCESS */ .Mvd,
        siteId: siteFragment
      });
    }).catch(() => {
      dispatch({
        type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_8__/* .SITE_REQUEST_FAILURE */ .uuM,
        siteId: siteFragment
      });
    });
    return result;
  };
}
const siteDeletionNoticeId = 'site-delete';
const siteDeletionNoticeOptions = {
  duration: 5000,
  id: siteDeletionNoticeId
};
/**
 * Returns a function which, when invoked, triggers a network request to delete
 * a site.
 *
 * @param  {number}   siteId Site ID
 * @returns {Function}        Action thunk
 */

function deleteSite(siteId) {
  return (dispatch, getState) => {
    const siteDomain = getSiteDomain(getState(), siteId);
    dispatch(successNotice(translate('%(siteDomain)s is being deleted.', {
      args: {
        siteDomain
      }
    }), siteDeletionNoticeOptions));
    return wpcom.req.post(`/sites/${siteId}/delete`).then(() => {
      dispatch(receiveDeletedSite(siteId));
      dispatch(successNotice(translate('%(siteDomain)s has been deleted.', {
        args: {
          siteDomain
        }
      }), siteDeletionNoticeOptions));
    }).catch(error => {
      if (error.error === 'active-subscriptions') {
        dispatch(errorNotice(translate('You must cancel any active subscriptions prior to deleting your site.'), {
          id: siteDeletionNoticeId,
          showDismiss: false,
          button: translate('Manage Purchases'),
          href: purchasesRoot
        }));
        return;
      }

      if (error.error === 'p2-hub-has-spaces') {
        const hubId = getP2HubBlogId(getState(), siteId);
        const hubUrl = getSiteUrl(getState(), hubId);
        dispatch(errorNotice(translate('Your P2 Workspace has P2s. You must delete all P2s in this workspace before you can delete it.'), {
          id: siteDeletionNoticeId,
          showDismiss: false,
          button: translate('Manage P2s'),
          href: hubUrl
        }));
        return;
      }

      dispatch(errorNotice(error.message, siteDeletionNoticeOptions));
    });
  };
}
const sitePluginUpdated = siteId => ({
  type: SITE_PLUGIN_UPDATED,
  siteId
});
/**
 * Returns an action object to be used to update the site front page options.
 *
 * @param  {number} siteId Site ID
 * @param  {object} frontPageOptions Object containing the three optional front page options.
 * @param  {string} [frontPageOptions.show_on_front] What to show in homepage. Can be 'page' or 'posts'.
 * @param  {number} [frontPageOptions.page_on_front] If `show_on_front = 'page'`, the front page ID.
 * @param  {number} [frontPageOptions.page_for_posts] If `show_on_front = 'page'`, the posts page ID.
 * @returns {object} Action object
 */

const updateSiteFrontPage = (siteId, frontPageOptions) => async dispatch => {
  try {
    const response = await wpcom.req.post(`/sites/${siteId}/homepage`, {
      is_page_on_front: isPageOnFront(frontPageOptions.show_on_front),
      page_on_front_id: frontPageOptions.page_on_front,
      page_for_posts_id: frontPageOptions.page_for_posts
    });
    dispatch({
      type: SITE_FRONT_PAGE_UPDATE,
      siteId,
      frontPageOptions: {
        show_on_front: response.is_page_on_front ? 'page' : 'posts',
        page_on_front: parseInt(response.page_on_front_id, 10),
        page_for_posts: parseInt(response.page_for_posts_id, 10)
      }
    });
  } catch {}
};

function isPageOnFront(showOnFront) {
  switch (showOnFront) {
    case 'page':
      return true;

    case 'posts':
      return false;

    default:
      return undefined;
  }
}
/**
 * Returns an action object to be used to update the site migration status.
 *
 * @param  {number} siteId Site ID
 * @param  {string} migrationStatus The status of the migration.
 * @param {string} lastModified Optional timestamp from the migration DB record
 * @returns {object} Action object
 */


const updateSiteMigrationMeta = function (siteId, migrationStatus) {
  let lastModified = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  return {
    siteId,
    type: SITE_MIGRATION_STATUS_UPDATE,
    migrationStatus,
    lastModified
  };
};

/***/ }),

/***/ 92546:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, requesting */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(95884);



const createRequestingReducer = requesting => (state, _ref) => {
  let {
    siteId
  } = _ref;
  return { ...state,
    [siteId]: requesting
  };
};

const items = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .SITE_CONNECTION_STATUS_RECEIVE */ .tvw:
      {
        const {
          siteId,
          status
        } = action;
        return { ...state,
          [siteId]: status
        };
      }
  }

  return state;
};
const requesting = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .SITE_CONNECTION_STATUS_REQUEST */ .U5d:
      return createRequestingReducer(true)(state, action);

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .SITE_CONNECTION_STATUS_REQUEST_FAILURE */ .QLz:
      return createRequestingReducer(false)(state, action);

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .SITE_CONNECTION_STATUS_REQUEST_SUCCESS */ .D5g:
      return createRequestingReducer(false)(state, action);
  }

  return state;
};
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .combineReducers */ .U)({
  items,
  requesting
}));

/***/ }),

/***/ 84465:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "U": function() { return /* binding */ SITE_REQUEST_FIELDS; },
/* harmony export */   "x": function() { return /* binding */ SITE_REQUEST_OPTIONS; }
/* harmony export */ });
const SITE_REQUEST_FIELDS = ['ID', 'URL', 'capabilities', 'icon', 'is_multisite', 'is_private', 'is_coming_soon', 'is_vip', 'jetpack', 'jetpack_modules', 'name', 'options', 'plan', 'products', 'single_user_site', 'visible', 'lang', 'launch_status', 'site_migration', 'site_owner', 'is_core_site_editor_enabled', 'is_wpcom_atomic', 'description'].join();
const SITE_REQUEST_OPTIONS = ['admin_url', 'advanced_seo_front_page_description', 'advanced_seo_title_formats', 'allowed_file_types', 'anchor_podcast', 'created_at', 'default_comment_status', 'default_ping_status', 'default_post_format', 'design_type', 'editing_toolkit_is_active', 'frame_nonce', 'gmt_offset', 'has_pending_automated_transfer', 'is_automated_transfer', 'is_cloud_eligible', 'is_domain_only', 'is_mapped_domain', 'is_redirect', 'is_wpcom_atomic', 'is_wpcom_store', 'is_wpforteams_site', 'p2_hub_blog_id', 'jetpack_frame_nonce', 'jetpack_version', 'main_network_site', 'page_on_front', 'page_for_posts', 'podcasting_archive', 'podcasting_category_id', 'publicize_permanently_disabled', 'show_on_front', 'site_segment', 'software_version', 'timezone', 'updated_at', 'upgraded_filetypes_enabled', 'unmapped_url', 'verification_services_codes', 'videopress_enabled', 'woocommerce_is_active', 'wordads', 'site_creation_flow', 'is_difm_lite_in_progress', 'difm_lite_site_options', 'site_intent'].join();

/***/ }),

/***/ 26171:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, updatingPrivacy, requesting, errors */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(95884);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(35743);
/* eslint-disable no-case-declarations */




/**
 * Returns a copy of the domains state object with some modifications
 *
 * @param {object} state - current state
 * @param {number} siteId - site ID
 * @param {string} domain - domain name
 * @param {object} modifyDomainProperties - object with modified site domain properties
 * @returns {any} - new copy of the state
 */

const modifySiteDomainObjectImmutable = (state, siteId, domain, modifyDomainProperties) => {
  // Find the domain we want to update
  const targetDomain = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.find)(state[siteId], {
    domain: domain
  });
  const domainIndex = state[siteId].indexOf(targetDomain); // Copy as we shouldn't mutate original state

  const newDomains = [...state[siteId]]; // Update privacy

  newDomains.splice(domainIndex, 1, Object.assign({}, targetDomain, modifyDomainProperties));
  return Object.assign({}, state, {
    [siteId]: newDomains
  });
};
/**
 * Domains `Reducer` function
 *
 * @param {object} state - current state
 * @param {object} action - domains action
 * @returns {object} updated state
 */


const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_1__/* .itemsSchema */ .d, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;
  const {
    siteId
  } = action;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .SITE_DOMAINS_RECEIVE */ .t2O:
      return Object.assign({}, state, {
        [siteId]: action.domains
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_PRIVACY_ENABLE_SUCCESS */ .DGo:
      return modifySiteDomainObjectImmutable(state, siteId, action.domain, {
        privateDomain: true,
        contactInfoDisclosed: false
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_PRIVACY_DISABLE_SUCCESS */ .ON1:
      return modifySiteDomainObjectImmutable(state, siteId, action.domain, {
        privateDomain: false,
        contactInfoDisclosed: false
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_CONTACT_INFO_DISCLOSE_SUCCESS */ .tGX:
      return modifySiteDomainObjectImmutable(state, siteId, action.domain, {
        privateDomain: false,
        contactInfoDisclosed: true
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_CONTACT_INFO_REDACT_SUCCESS */ .HYG:
      return modifySiteDomainObjectImmutable(state, siteId, action.domain, {
        privateDomain: false,
        contactInfoDisclosed: false
      });
  }

  return state;
});
/**
 * Updating privacy reducer
 *
 * Figure out if we're in the middle of privacy modification command
 *
 * @param {object} state - current state
 * @param {object} action - action
 * @returns {any} - new state
 */

const updatingPrivacy = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_PRIVACY_ENABLE */ .sBg:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_PRIVACY_ENABLE_SUCCESS */ .DGo:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_PRIVACY_ENABLE_FAILURE */ .zVI:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_PRIVACY_DISABLE */ .HCR:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_PRIVACY_DISABLE_SUCCESS */ .ON1:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_PRIVACY_DISABLE_FAILURE */ .T6o:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_CONTACT_INFO_DISCLOSE */ .w6q:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_CONTACT_INFO_DISCLOSE_SUCCESS */ .tGX:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_CONTACT_INFO_DISCLOSE_FAILURE */ .M5U:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_CONTACT_INFO_REDACT */ .K1T:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_CONTACT_INFO_REDACT_SUCCESS */ .HYG:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_CONTACT_INFO_REDACT_FAILURE */ .sQe:
      return Object.assign({}, state, {
        [action.siteId]: {
          [action.domain]: [calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_PRIVACY_ENABLE */ .sBg, calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_PRIVACY_DISABLE */ .HCR, calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_CONTACT_INFO_DISCLOSE */ .w6q, calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .DOMAIN_CONTACT_INFO_REDACT */ .K1T].indexOf(action.type) !== -1
        }
      });
  }

  return state;
};
/**
 * `Reducer` function which handles request/response actions
 * to/from WP REST-API
 *
 * @param {object} state - current state
 * @param {object} action - domains action
 * @returns {object} updated state
 */

const requesting = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .SITE_DOMAINS_REQUEST */ .wOJ:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .SITE_DOMAINS_REQUEST_SUCCESS */ .RI4:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .SITE_DOMAINS_REQUEST_FAILURE */ .dyA:
      return Object.assign({}, state, {
        [action.siteId]: action.type === calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .SITE_DOMAINS_REQUEST */ .wOJ
      });
  }

  return state;
};
/**
 * `Reducer` function which handles ERRORs REST-API response actions
 *
 * @param {object} state - current state
 * @param {object} action - domains action
 * @returns {object} updated state
 */

const errors = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .SITE_DOMAINS_REQUEST */ .wOJ:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .SITE_DOMAINS_REQUEST_SUCCESS */ .RI4:
      return Object.assign({}, state, {
        [action.siteId]: null
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .SITE_DOMAINS_REQUEST_FAILURE */ .dyA:
      return Object.assign({}, state, {
        [action.siteId]: action.error
      });
  }

  return state;
};
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_4__/* .combineReducers */ .U)({
  errors,
  items,
  requesting,
  updatingPrivacy
}));

/***/ }),

/***/ 35743:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "d": function() { return /* binding */ itemsSchema; }
/* harmony export */ });
const itemsSchema = {
  type: 'object',
  additionalProperties: false,
  patternProperties: {
    '^\\d+$': {
      type: 'array',
      items: {
        type: 'object',
        required: ['domain'],
        properties: {
          aftermarketAuction: {
            type: 'boolean'
          },
          autoRenewalDate: {
            type: 'string'
          },
          autoRenewing: {
            type: 'boolean'
          },
          blogId: {
            type: 'number'
          },
          canSetAsPrimary: {
            type: 'boolean'
          },
          currentUserCanManage: {
            type: 'boolean'
          },
          canManageDnsRecords: {
            type: 'boolean'
          },
          canManageNameServers: {
            type: 'boolean'
          },
          canUpdateContactInfo: {
            type: 'boolean'
          },
          cannotManageDnsRecordsReason: {
            type: ['null', 'string']
          },
          cannotManageNameServersReason: {
            type: ['null', 'string']
          },
          cannotUpdateContactInfoReason: {
            type: ['null', 'string']
          },
          domain: {
            type: 'string'
          },
          expired: {
            type: 'boolean'
          },
          expiry: {
            type: ['null', 'string']
          },
          expirySoon: {
            type: 'boolean'
          },
          googleAppsSubscription: {
            type: 'object'
          },
          titanMailSubscription: {
            type: 'object'
          },
          hasRegistration: {
            type: 'boolean'
          },
          hasWpcomNameservers: {
            type: 'boolean'
          },
          hasZone: {
            type: 'boolean'
          },
          isPendingIcannVerification: {
            type: 'boolean'
          },
          isPendingRenewal: {
            type: 'boolean'
          },
          isPremium: {
            type: 'boolean'
          },
          isPrimary: {
            type: 'boolean'
          },
          isSubdomain: {
            type: 'boolean'
          },
          isWPCOMDomain: {
            type: 'boolean'
          },
          manualTransferRequired: {
            type: 'boolean'
          },
          name: {
            type: 'string'
          },
          owner: {
            type: 'string',
            optional: true
          },
          partnerDomain: {
            type: 'boolean'
          },
          pendingRegistration: {
            type: 'boolean'
          },
          pendingRegistrationTime: {
            type: 'string'
          },
          pointsToWpcom: {
            type: 'boolean'
          },
          registrar: {
            type: 'string'
          },
          registrationDate: {
            type: 'string'
          },
          subscriptionId: {
            type: ['null', 'string']
          },
          supportsDomainConnect: {
            type: 'boolean',
            optional: true
          },
          supportsGdprConsentManagement: {
            type: 'boolean',
            optional: true
          },
          type: {
            type: 'string'
          },
          transferStartDate: {
            type: ['null', 'string']
          },
          transferEndDate: {
            type: ['null', 'string']
          }
        }
      }
    }
  }
};

/***/ }),

/***/ 22900:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "E": function() { return /* binding */ featuresReducer; }
/* harmony export */ });
/* unused harmony export initialSiteState */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);

const initialSiteState = {
  data: null,
  error: null,
  hasLoadedFromServer: false,
  isRequesting: false
};
/**
 * Returns a new state with the given attributes updated for the specified site.
 *
 * @param {object} state current state
 * @param {number} siteId identifier of the site
 * @param {object} attributes list of attributes and their values
 * @returns {object} the new state
 */

function updateSiteState(state, siteId, attributes) {
  return Object.assign({}, state, {
    [siteId]: Object.assign({}, initialSiteState, state[siteId], attributes)
  });
}

function featuresReducer() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let {
    type,
    siteId,
    features,
    error
  } = arguments.length > 1 ? arguments[1] : undefined;

  switch (type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .SITE_FEATURES_FETCH */ .fa4:
      return updateSiteState(state, siteId, {
        error: null,
        isRequesting: true
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .SITE_FEATURES_FETCH_COMPLETED */ .xNf:
      return updateSiteState(state, siteId, {
        error: null,
        hasLoadedFromServer: true,
        isRequesting: false,
        data: features
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .SITE_FEATURES_FETCH_FAILED */ .YCt:
      return updateSiteState(state, siteId, {
        error: error,
        isRequesting: false
      });
  }

  return state;
}

/***/ }),

/***/ 56733:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "P": function() { return /* reexport safe */ _use_site_option__WEBPACK_IMPORTED_MODULE_1__.Z; }
/* harmony export */ });
/* harmony import */ var _use_selected_site_selector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(47437);
/* harmony import */ var _use_site_option__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(6826);



/***/ }),

/***/ 47437:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export default */
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4792);



/**
 * Wraps useSelector and closes over the getSelectedSiteId step when using selected site selectors.
 *
 * Usage:
 *
 *   useSelectedSiteSelector( isJetpackSite );
 *   useSelectedSiteSelector( getPlansForFeature, FEATURE_WP_SUBDOMAIN );
 *
 * @param selector A selector that takes state, a site id and any additional params.
 * @returns The result of the selector applied to application state.
 */
function useSelectedSiteSelector(selector) {
  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  return useSelector(state => selector(state, getSelectedSiteId(state), ...args));
}

/***/ }),

/***/ 6826:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4792);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(20834);
/* harmony import */ var _selectors_get_site_option__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(27246);



/**
 * Returns a site option for a site
 *
 * @param optionName The option you want to query
 * @returns The value of that option or null
 */

const useSiteOption = optionName => {
  const selectedSiteId = (0,react_redux__WEBPACK_IMPORTED_MODULE_0__/* .useSelector */ .v9)(calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z);
  const siteOption = (0,react_redux__WEBPACK_IMPORTED_MODULE_0__/* .useSelector */ .v9)(state => (0,_selectors_get_site_option__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, selectedSiteId || 0, optionName));
  return siteOption;
};

/* harmony default export */ __webpack_exports__["Z"] = (useSiteOption);

/***/ }),

/***/ 96829:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports requestStatus, items */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(15960);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(95884);
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(11900);




const mapResponseObject = _ref => {
  let {
    currency_code,
    discount_percentage,
    formatted_price,
    ineligible_reason,
    product_id,
    product_slug,
    raw_price
  } = _ref;
  return {
    currencyCode: currency_code,
    discountPercentage: discount_percentage,
    formattedPrice: formatted_price,
    ineligibleReason: ineligible_reason,
    productId: product_id,
    productSlug: product_slug,
    rawPrice: raw_price
  };
};

const createIntroOfferMap = payload => {
  const map = {};
  payload.forEach(payloadIntroOffer => {
    map[payloadIntroOffer.product_id] = mapResponseObject(payloadIntroOffer);
  });
  return map;
};

const requestStatus = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .keyedReducer */ .J)('siteId', (state, _ref2) => {
  let {
    type
  } = _ref2;

  switch (type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .SITE_INTRO_OFFER_REQUEST */ .Frv:
      return _types__WEBPACK_IMPORTED_MODULE_0__/* .RequestStatus.Pending */ .e.Pending;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .SITE_INTRO_OFFER_REQUEST_SUCCESS */ .lfH:
      return _types__WEBPACK_IMPORTED_MODULE_0__/* .RequestStatus.Success */ .e.Success;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .SITE_INTRO_OFFER_REQUEST_FAILURE */ .Byq:
      return _types__WEBPACK_IMPORTED_MODULE_0__/* .RequestStatus.Failed */ .e.Failed;
  }

  return state;
});
const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .keyedReducer */ .J)('siteId', (state, _ref3) => {
  let {
    type,
    payload
  } = _ref3;

  switch (type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .SITE_INTRO_OFFER_RECEIVE */ .Kmp:
      return payload ? createIntroOfferMap(payload) : undefined;
  }

  return state;
});
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__/* .combineReducers */ .U)({
  requestStatus,
  items
}));

/***/ }),

/***/ 11900:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "e": function() { return /* binding */ RequestStatus; }
/* harmony export */ });
let RequestStatus;

(function (RequestStatus) {
  RequestStatus["Pending"] = "pending";
  RequestStatus["Success"] = "success";
  RequestStatus["Failed"] = "failed";
})(RequestStatus || (RequestStatus = {}));

/***/ }),

/***/ 20152:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "z": function() { return /* binding */ plans; }
/* harmony export */ });
/* unused harmony export initialSiteState */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);


const initialSiteState = {
  data: null,
  error: null,
  hasLoadedFromServer: false,
  isRequesting: false
};
/**
 * Returns a new state with the given attributes updated for the specified site.
 *
 * @param {object} state current state
 * @param {number} siteId identifier of the site
 * @param {object} attributes list of attributes and their values
 * @returns {object} the new state
 */

function updateSiteState(state, siteId, attributes) {
  return Object.assign({}, state, {
    [siteId]: Object.assign({}, initialSiteState, state[siteId], attributes)
  });
}

function plans() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .SITE_PLANS_FETCH */ .gNn:
      return updateSiteState(state, action.siteId, {
        error: null,
        isRequesting: true
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .SITE_PLANS_FETCH_COMPLETED */ .Rmh:
      return updateSiteState(state, action.siteId, {
        error: null,
        hasLoadedFromServer: true,
        isRequesting: false,
        data: action.plans
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .SITE_PLANS_FETCH_FAILED */ .$MQ:
      return updateSiteState(state, action.siteId, {
        error: action.error,
        isRequesting: false
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .SITE_PLANS_REMOVE */ .XLI:
      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state, action.siteId);
  }

  return state;
}

/***/ }),

/***/ 42935:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "R": function() { return /* binding */ products; }
/* harmony export */ });
/* unused harmony export initialSiteState */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);

const initialSiteState = {
  data: null,
  error: null,
  hasLoadedFromServer: false,
  isRequesting: false
};
/**
 * Returns a new state with the given attributes updated for the specified site.
 *
 * @param {object} state current state
 * @param {number} siteId identifier of the site
 * @param {object} attributes list of attributes and their values
 * @returns {object} the new state
 */

function updateSiteState(state, siteId, attributes) {
  return Object.assign({}, state, {
    [siteId]: Object.assign({}, initialSiteState, state[siteId], attributes)
  });
}

function products() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .SITE_PRODUCTS_FETCH */ .eO9:
      return updateSiteState(state, action.siteId, {
        error: null,
        isRequesting: true
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .SITE_PRODUCTS_FETCH_COMPLETED */ .S3d:
      return updateSiteState(state, action.siteId, {
        error: null,
        hasLoadedFromServer: true,
        isRequesting: false,
        data: action.products
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .SITE_PRODUCTS_FETCH_FAILED */ .whB:
      return updateSiteState(state, action.siteId, {
        error: action.error,
        isRequesting: false
      });
  }

  return state;
}

/***/ }),

/***/ 82139:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports items, requestingAll, requesting, hasAllSitesList, jetpackSiteDisconnected */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_themes_action_types__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(46505);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(95884);
/* harmony import */ var _connection_reducer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(92546);
/* harmony import */ var _domains_reducer__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(26171);
/* harmony import */ var _features_reducer__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(22900);
/* harmony import */ var _intro_offers_reducer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(96829);
/* harmony import */ var _plans_reducer__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(20152);
/* harmony import */ var _products_reducer__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(42935);
/* harmony import */ var _schema__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(43056);











/**
 * Tracks all known site objects, indexed by site ID.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const items = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_8__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_7__/* .sitesSchema */ .K, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (state === null && action.type !== calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITE_RECEIVE */ .UUJ && action.type !== calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITES_RECEIVE */ .xLe) {
    return null;
  }

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .WORDADS_SITE_APPROVE_REQUEST_SUCCESS */ .Khp:
      {
        const prevSite = state[action.siteId];

        if (prevSite) {
          return Object.assign({}, state, {
            [action.siteId]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, prevSite, {
              options: {
                wordads: true
              }
            })
          });
        }

        return state;
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITE_RECEIVE */ .UUJ:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITES_RECEIVE */ .xLe:
      {
        // Normalize incoming site(s) to array
        const sites = action.site ? [action.site] : action.sites; // SITES_RECEIVE occurs when we receive the entire set of user
        // sites (replace existing state). Otherwise merge into state.

        const initialNextState = calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITES_RECEIVE */ .xLe === action.type ? {} : state;
        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(sites, (memo, site) => {
          // Bypass if site object hasn't changed
          if ((0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEqual)(memo[site.ID], site)) {
            return memo;
          } // Avoid mutating state


          if (memo === state) {
            memo = { ...state
            };
          }

          memo[site.ID] = site;
          return memo;
        }, initialNextState || {});
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITE_DELETE_RECEIVE */ .SYS:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .JETPACK_DISCONNECT_RECEIVE */ .Oh9:
      return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state, action.siteId);

    case calypso_state_themes_action_types__WEBPACK_IMPORTED_MODULE_10__/* .THEME_ACTIVATE_SUCCESS */ .hX:
      {
        const {
          siteId,
          themeStylesheet
        } = action;
        const site = state[siteId];

        if (!site) {
          break;
        }

        return { ...state,
          [siteId]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, site, {
            options: {
              theme_slug: themeStylesheet
            }
          })
        };
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITE_SETTINGS_UPDATE */ .rZJ:
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITE_SETTINGS_RECEIVE */ .KBY:
      {
        const {
          siteId,
          settings
        } = action;
        const site = state[siteId];

        if (!site) {
          return state;
        }

        let nextSite = site;
        return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(['blog_public', 'wpcom_public_coming_soon', 'wpcom_coming_soon', 'site_icon'], (memo, key) => {
          // A site settings update may or may not include the icon or blog_public property.
          // If not, we should simply return state unchanged.
          if (!settings.hasOwnProperty(key)) {
            return memo;
          }

          switch (key) {
            case 'blog_public':
              {
                const isPrivate = parseInt(settings.blog_public, 10) === -1;

                if (site.is_private === isPrivate) {
                  return memo;
                }

                nextSite = { ...nextSite,
                  is_private: isPrivate
                };
                break;
              }

            case 'wpcom_coming_soon':
            case 'wpcom_public_coming_soon':
              {
                const isComingSoon = parseInt(settings.wpcom_public_coming_soon, 10) === 1 || parseInt(settings.wpcom_coming_soon, 10) === 1;

                if (site.is_coming_soon === isComingSoon) {
                  return memo;
                }

                nextSite = { ...nextSite,
                  is_coming_soon: isComingSoon
                };
                break;
              }

            case 'site_icon':
              {
                const mediaId = settings.site_icon; // Return unchanged if next icon matches current value,
                // accounting for the fact that a non-existent icon property is
                // equivalent to setting the media icon as null

                if (!site.icon && null === mediaId || site.icon && site.icon.media_id === mediaId) {
                  return memo;
                }

                if (null === mediaId) {
                  // Unset icon
                  nextSite = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(nextSite, 'icon');
                } else {
                  // Update icon, intentionally removing reference to the URL,
                  // shifting burden of URL lookup to selector
                  nextSite = { ...nextSite,
                    icon: {
                      media_id: mediaId
                    }
                  };
                }

                break;
              }
          }

          if (memo === state) {
            memo = { ...state
            };
          }

          memo[siteId] = nextSite;
          return memo;
        }, state);
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .MEDIA_DELETE */ .aqr:
      {
        const {
          siteId,
          mediaIds
        } = action;
        const siteIconId = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(state[siteId], 'icon.media_id');

        if (siteIconId && (0,lodash__WEBPACK_IMPORTED_MODULE_0__.includes)(mediaIds, siteIconId)) {
          return { ...state,
            [siteId]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state[siteId], 'icon')
          };
        }

        return state;
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITE_PLUGIN_UPDATED */ .U0$:
      {
        const {
          siteId
        } = action;
        const siteUpdates = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(state[siteId], 'updates');

        if (!siteUpdates) {
          return state;
        }

        return { ...state,
          [siteId]: { ...state[siteId],
            updates: { ...siteUpdates,
              plugins: siteUpdates.plugins - 1,
              total: siteUpdates.total - 1
            }
          }
        };
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITE_FRONT_PAGE_UPDATE */ .uvG:
      {
        const {
          siteId,
          frontPageOptions
        } = action;
        const site = state[siteId];

        if (!site) {
          break;
        }

        return { ...state,
          [siteId]: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, site, {
            options: { ...frontPageOptions
            }
          })
        };
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITE_MIGRATION_STATUS_UPDATE */ .lTr:
      {
        const {
          siteId,
          migrationStatus,
          lastModified
        } = action;
        const site = state[siteId];

        if (!site) {
          return state;
        }

        const siteMigrationMeta = state[siteId].site_migration || {};
        const newMeta = {
          status: migrationStatus
        };

        if (lastModified) {
          newMeta.last_modified = lastModified;
        }

        return { ...state,
          [siteId]: { ...state[siteId],
            site_migration: (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, siteMigrationMeta, newMeta)
          }
        };
      }
  }

  return state;
});
/**
 * Returns the updated requesting state after an action has been dispatched.
 * Requesting state tracks whether a network request is in progress for all
 * sites.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action object
 * @returns {object}        Updated state
 */

const requestingAll = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITES_REQUEST */ .M4_:
      return true;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITES_REQUEST_FAILURE */ .eTV:
      return false;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITES_REQUEST_SUCCESS */ .KSQ:
      return false;
  }

  return state;
};
/**
 * Returns the updated requesting state after an action has been dispatched.
 * Requesting state tracks whether a network request is in progress for a site.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action object
 * @returns {object}        Updated state
 */

const requesting = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITE_REQUEST */ .hJk:
      {
        const {
          siteId
        } = action;
        return { ...state,
          [siteId]: true
        };
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITE_REQUEST_FAILURE */ .uuM:
      {
        const {
          siteId
        } = action;
        return { ...state,
          [siteId]: false
        };
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITE_REQUEST_SUCCESS */ .Mvd:
      {
        const {
          siteId
        } = action;
        return { ...state,
          [siteId]: false
        };
      }
  }

  return state;
};
/**
 * Tracks whether all sites have been fetched.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action object
 * @returns {object}        Updated state
 */

const hasAllSitesList = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_8__/* .withSchemaValidation */ .G)(_schema__WEBPACK_IMPORTED_MODULE_7__/* .hasAllSitesListSchema */ .W, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .SITES_RECEIVE */ .xLe:
      return true;
  }

  return state;
});
/**
 * Returns the updated disconnected state after an action has been dispatched.
 * Tracks whether a network request is completed or not.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action object
 * @returns {object}        Updated state
 */

const jetpackSiteDisconnected = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .JETPACK_SITE_DISCONNECT_REQUEST */ .ftJ:
      {
        return false;
      }

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_9__/* .JETPACK_DISCONNECT_RECEIVE */ .Oh9:
      {
        return true;
      }
  }

  return state;
};
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_11__/* .combineReducers */ .U)({
  connection: _connection_reducer__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP,
  domains: _domains_reducer__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP,
  requestingAll,
  introOffers: _intro_offers_reducer__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .ZP,
  items,
  plans: _plans_reducer__WEBPACK_IMPORTED_MODULE_5__/* .plans */ .z,
  products: _products_reducer__WEBPACK_IMPORTED_MODULE_6__/* .products */ .R,
  features: _features_reducer__WEBPACK_IMPORTED_MODULE_3__/* .featuresReducer */ .E,
  requesting,
  hasAllSitesList,
  jetpackSiteDisconnected
}));

/***/ }),

/***/ 43056:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "K": function() { return /* binding */ sitesSchema; },
/* harmony export */   "W": function() { return /* binding */ hasAllSitesListSchema; }
/* harmony export */ });
const sitesSchema = {
  type: 'object',
  patternProperties: {
    //be careful to escape regexes properly
    '^\\d+$': {
      type: 'object',
      required: ['ID', 'name'],
      properties: {
        ID: {
          type: 'number'
        },
        name: {
          type: 'string'
        },
        URL: {
          type: 'string'
        },
        jetpack: {
          type: 'boolean'
        },
        icon: {
          type: 'object',
          properties: {
            img: {
              type: 'string'
            },
            ico: {
              type: 'string'
            },
            media_id: {
              type: 'number'
            }
          }
        },
        visible: {
          type: 'boolean'
        },
        is_private: {
          type: 'boolean'
        },
        is_vip: {
          type: 'boolean'
        },
        options: {
          type: 'object'
        },
        meta: {
          type: 'object'
        },
        is_multisite: {
          type: 'boolean'
        },
        capabilities: {
          type: 'object',
          patternProperties: {
            '^[a-z_]+$': {
              type: 'boolean'
            }
          }
        },
        plan: {
          type: 'object',
          required: ['product_id', 'product_slug'],
          properties: {
            product_id: {
              type: ['number', 'string']
            },
            product_slug: {
              type: 'string'
            },
            product_name_short: {
              type: ['string', 'null']
            },
            expired: {
              type: 'boolean'
            },
            user_is_owner: {
              type: 'boolean'
            },
            is_free: {
              type: 'boolean'
            }
          }
        },
        single_user_site: {
          type: 'boolean'
        },
        updates: {
          type: 'object',
          properties: {
            jp_version: {
              type: 'string'
            },
            plugins: {
              type: 'number'
            },
            themes: {
              type: 'number'
            },
            total: {
              type: 'number'
            },
            translations: {
              type: 'number'
            },
            wordpress: {
              type: 'number'
            },
            wp_version: {
              type: 'string'
            }
          }
        },
        lang: {
          type: 'string'
        }
      }
    }
  },
  additionalProperties: false
};
const hasAllSitesListSchema = {
  type: ['boolean', 'null']
};

/***/ }),

/***/ 31716:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ canJetpackSiteAutoUpdateFiles; }
/* harmony export */ });
/* harmony import */ var _can_jetpack_site_update_files__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(75134);
/* harmony import */ var _get_site_option__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(27246);
/* harmony import */ var _is_jetpack_site__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(60222);



/**
 * Determines if a Jetpack site can auto update its files.
 * This function checks if the given Jetpack site can update its files and if the automatic updater is enabled.
 * Returns null if the site is not known or is not a Jetpack site.
 *
 * @param {object} state Global state tree
 * @param {number} siteId Site ID
 * @returns {?boolean} true if the site can auto update
 */

function canJetpackSiteAutoUpdateFiles(state, siteId) {
  if (!(0,_is_jetpack_site__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteId)) {
    return null;
  }

  if (!(0,_can_jetpack_site_update_files__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteId)) {
    return false;
  }

  const fileModDisabled = (0,_get_site_option__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId, 'file_mod_disabled');

  if (fileModDisabled && fileModDisabled.includes('automatic_updater_disabled')) {
    return false;
  }

  return true;
}

/***/ }),

/***/ 75134:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ canJetpackSiteUpdateFiles; }
/* harmony export */ });
/* harmony import */ var _get_site_option__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(27246);
/* harmony import */ var _is_jetpack_site__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(60222);
/* harmony import */ var _is_jetpack_site_secondary_network_site__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(57481);



/**
 * Determines if a Jetpack site can update its files.
 * Returns null if the site is not known or is not a Jetpack site.
 *
 * @param   {object}   state  Global state tree
 * @param   {number}   siteId Site ID
 * @returns {?boolean}        True if the site can update its file
 */

function canJetpackSiteUpdateFiles(state, siteId) {
  if (!(0,_is_jetpack_site__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteId)) {
    return null;
  }

  const isMultiNetwork = (0,_get_site_option__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteId, 'is_multi_network');

  if (isMultiNetwork) {
    return false;
  }

  if ((0,_is_jetpack_site_secondary_network_site__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId)) {
    return false;
  }

  const fileModDisabled = (0,_get_site_option__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteId, 'file_mod_disabled');

  if (!fileModDisabled) {
    return true;
  }

  return !fileModDisabled.includes('disallow_file_mods') && !fileModDisabled.includes('has_no_file_system_write_access');
}

/***/ }),

/***/ 20336:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getCustomizerUrl; }
/* harmony export */ });
/* harmony import */ var calypso_lib_url__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(40822);
/* harmony import */ var calypso_my_sites_customize_panels__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(77270);
/* harmony import */ var _get_site_admin_url__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(96666);
/* harmony import */ var _get_site_slug__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(64802);
/* harmony import */ var _is_jetpack_site__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(60222);





/**
 * Returns the customizer URL for a site, or null if it cannot be determined.
 *
 * @param   {object}  state        Global state tree
 * @param   {?number} siteId       Site ID
 * @param   {?string} [panel]        Optional panel to autofocus
 * @param   {?string} [returnUrl]    Optional return url for when the user closes the customizer
 * @param   {?string} [guide]        Optional parameter to show a help guide in the customizer. possible values:
 *                                 'add-menu' and 'social-media' show custom guides, any other value shows the default guide
 * @returns {string}               Customizer URL
 */

function getCustomizerUrl(state, siteId, panel, returnUrl, guide) {
  if (!(0,_is_jetpack_site__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteId)) {
    const siteSlug = (0,_get_site_slug__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId);
    const url = [''].concat(['customize', panel, siteSlug].filter(Boolean)).join('/');
    return (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)({
      return: returnUrl,
      guide
    }, url);
  }

  const adminUrl = (0,_get_site_admin_url__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(state, siteId, 'customize.php');

  if (!adminUrl) {
    return null;
  }

  if (!returnUrl && 'undefined' !== typeof window) {
    returnUrl = window.location.href;
  }

  return (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)({
    return: returnUrl,
    ...(0,calypso_my_sites_customize_panels__WEBPACK_IMPORTED_MODULE_0__/* .getCustomizerFocus */ .t)(panel),
    guide
  }, adminUrl);
}

/***/ }),

/***/ 15199:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getJetpackComputedAttributes; }
/* harmony export */ });
/* harmony import */ var _can_jetpack_site_auto_update_files__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(31716);
/* harmony import */ var _can_jetpack_site_update_files__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(75134);
/* harmony import */ var _is_jetpack_site__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(60222);
/* harmony import */ var _is_jetpack_site_main_network_site__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(47020);
/* harmony import */ var _is_jetpack_site_secondary_network_site__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(57481);





function getJetpackComputedAttributes(state, siteId) {
  if (!(0,_is_jetpack_site__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteId)) {
    return {};
  }

  return {
    canAutoupdateFiles: (0,_can_jetpack_site_auto_update_files__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteId),
    canUpdateFiles: (0,_can_jetpack_site_update_files__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId),
    isMainNetworkSite: (0,_is_jetpack_site_main_network_site__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(state, siteId),
    isSecondaryNetworkSite: (0,_is_jetpack_site_secondary_network_site__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(state, siteId)
  };
}

/***/ }),

/***/ 96666:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getSiteAdminUrl; }
/* harmony export */ });
/* harmony import */ var _get_site_option__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(27246);

/**
 * Returns the url to the wp-admin area for a site, or null if the admin URL
 * for the site cannot be determined.
 *
 * @see https://developer.wordpress.org/reference/functions/get_admin_url/
 * @param  {object}  state  Global state tree
 * @param  {?number}  siteId Site ID
 * @param  {?string} path   Admin screen path
 * @returns {?string}        Admin URL
 */

function getSiteAdminUrl(state, siteId) {
  let path = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : '';
  const adminUrl = (0,_get_site_option__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteId, 'admin_url');

  if (!adminUrl) {
    return null;
  }

  return adminUrl + path.replace(/^\//, '');
}

/***/ }),

/***/ 14012:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_state_selectors_get_sites_items__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(37480);
/* harmony import */ var _get_site_slug__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(64802);



/**
 * Returns a site object by its slug.
 *
 * @param  {object}  state     Global state tree
 * @param  {string}  siteSlug  Site URL
 * @returns {?object}           Site object
 */

/* harmony default export */ __webpack_exports__["Z"] = ((0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .createSelector */ .P1)((state, siteSlug) => {
  const sites = Object.values((0,calypso_state_selectors_get_sites_items__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state));
  return sites.find(site => (0,_get_site_slug__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, site.ID) === siteSlug) ?? null;
}, state => [(0,calypso_state_selectors_get_sites_items__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state)]));

/***/ }),

/***/ 29926:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_lib_site_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(72537);
/* harmony import */ var calypso_state_selectors_get_sites_items__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(37480);



/**
 * Returns a filtered array of WordPress.com site IDs where a Jetpack site
 * exists in the set of sites with the same URL.
 *
 * @param  {object}   state Global state tree
 * @returns {number[]}       WordPress.com site IDs with collisions
 */

/* harmony default export */ __webpack_exports__["Z"] = ((0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .createSelector */ .P1)(state => {
  const sitesItems = Object.values((0,calypso_state_selectors_get_sites_items__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state));
  return (0,calypso_lib_site_utils__WEBPACK_IMPORTED_MODULE_1__/* .getJetpackSiteCollisions */ .Cm)(sitesItems);
}, calypso_state_selectors_get_sites_items__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z));

/***/ }),

/***/ 84810:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getSiteComputedAttributes; }
/* harmony export */ });
/* harmony import */ var calypso_lib_url__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(47307);
/* harmony import */ var calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(53843);
/* harmony import */ var _get_site_domain__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(65663);
/* harmony import */ var _get_site_option__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(27246);
/* harmony import */ var _get_site_options__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(2062);
/* harmony import */ var _get_site_slug__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(64802);
/* harmony import */ var _get_site_title__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(40877);
/* harmony import */ var _is_jetpack_site__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(60222);
/* harmony import */ var _is_site_conflicting__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(91608);









/**
 * Returns computed properties of the site object.
 *
 * @param    {object}      state    Global state tree
 * @param    {number}      siteId   Site ID
 * @returns  {?object}              Site computed properties or null
 */

function getSiteComputedAttributes(state, siteId) {
  const site = (0,calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteId);

  if (!site) {
    return null;
  }

  const computedAttributes = {
    domain: (0,_get_site_domain__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteId),
    options: (0,_get_site_options__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId),
    slug: (0,_get_site_slug__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(state, siteId),
    title: (0,_get_site_title__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(state, siteId)
  }; // If a WordPress.com site has a mapped domain create a `wpcom_url`
  // attribute to allow site selection with either domain.

  if ((0,_get_site_option__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(state, siteId, 'is_mapped_domain') && !(0,_is_jetpack_site__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(state, siteId)) {
    computedAttributes.wpcom_url = (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_7__/* .withoutHttp */ .ce)((0,_get_site_option__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(state, siteId, 'unmapped_url'));
  } // we only need to use the unmapped URL for conflicting sites


  if ((0,_is_site_conflicting__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)(state, siteId)) {
    computedAttributes.URL = (0,_get_site_option__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(state, siteId, 'unmapped_url');
  }

  return computedAttributes;
}

/***/ }),

/***/ 65663:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getSiteDomain; }
/* harmony export */ });
/* harmony import */ var calypso_lib_url__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(47307);
/* harmony import */ var calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(53843);
/* harmony import */ var _get_site_option__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(27246);
/* harmony import */ var _get_site_slug__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(64802);
/* harmony import */ var _is_site_conflicting__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(91608);





/**
 * Returns the domain for a site, or null if the site is unknown.
 *
 * @param  {object}  state  Global state tree
 * @param  {number}  siteId Site ID
 * @returns {?string}        Site domain
 */

function getSiteDomain(state, siteId) {
  if ((0,_get_site_option__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteId, 'is_redirect') || (0,_is_site_conflicting__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId)) {
    return (0,_get_site_slug__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(state, siteId);
  }

  const site = (0,calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteId);

  if (!site) {
    return null;
  }

  return (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_4__/* .withoutHttp */ .ce)(site.URL);
}

/***/ }),

/***/ 27246:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getSiteOption; }
/* harmony export */ });
/* harmony import */ var _get_site_options__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(2062);

/**
 * Returns a site option for a site
 *
 * @param  {object}  state  Global state tree
 * @param  {?number}  siteId Site ID
 * @param  {string}  optionName The option key
 * @returns {*}  The value of that option or null
 */

function getSiteOption(state, siteId, optionName) {
  const options = (0,_get_site_options__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteId);
  return (options === null || options === void 0 ? void 0 : options[optionName]) ?? null;
}

/***/ }),

/***/ 2062:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(53843);

const EMPTY_OPTIONS = Object.freeze({});
/**
 * Returns the site options
 *
 * @param    {object}    state    Global state tree
 * @param    {number}    siteId   Site ID
 * @returns  {?object}            Site options or null
 */

/* harmony default export */ __webpack_exports__["Z"] = ((state, siteId) => {
  const site = (0,calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteId);

  if (!site) {
    return null;
  }

  return site.options || EMPTY_OPTIONS;
});

/***/ }),

/***/ 64802:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_lib_url__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(47307);
/* harmony import */ var calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(53843);
/* harmony import */ var calypso_state_selectors_get_sites_items__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(37480);
/* harmony import */ var _get_site_option__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(27246);
/* harmony import */ var _get_site_options__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(2062);
/* harmony import */ var _is_site_conflicting__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(91608);







/**
 * Returns the slug for a site, or null if the site is unknown.
 *
 * @param  {object}  state  Global state tree
 * @param  {number}  siteId Site ID
 * @returns {?string}        Site slug
 */

/* harmony default export */ __webpack_exports__["Z"] = ((0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .createSelector */ .P1)((state, siteId) => {
  const site = (0,calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteId);

  if (!site) {
    return null;
  }

  if ((0,_get_site_option__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(state, siteId, 'is_redirect') || (0,_is_site_conflicting__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(state, siteId)) {
    return (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_5__/* .withoutHttp */ .ce)((0,_get_site_option__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(state, siteId, 'unmapped_url'));
  }

  return (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_5__/* .urlToSlug */ .nq)(site.URL);
}, (state, siteId) => [(0,calypso_state_selectors_get_sites_items__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state), (0,_get_site_options__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(state, siteId)]));

/***/ }),

/***/ 40877:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getSiteTitle; }
/* harmony export */ });
/* harmony import */ var calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(53843);
/* harmony import */ var _get_site_domain__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(65663);


/**
 * Returns a title by which the site can be canonically referenced. Uses the
 * site's name if available, falling back to its domain. Returns null if the
 * site is not known.
 *
 * @param  {object}  state  Global state tree
 * @param  {?number}  siteId Site ID
 * @returns {?string}        Site title
 */

function getSiteTitle(state, siteId) {
  const site = (0,calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteId);

  if (!site) {
    return null;
  }

  if (site.name) {
    return site.name.trim();
  }

  return (0,_get_site_domain__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteId);
}

/***/ }),

/***/ 78871:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getSite; }
/* harmony export */ });
/* harmony import */ var calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(53843);
/* harmony import */ var _get_jetpack_computed_attributes__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(15199);
/* harmony import */ var _get_site_by_slug__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(14012);
/* harmony import */ var _get_site_computed_attributes__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(84810);




/**
 * Memoization cache for the `getSite` selector
 */

let getSiteCache = new WeakMap();
/**
 * Returns a normalized site object by its ID or site slug.
 *
 * @param  {object}  state  Global state tree
 * @param  {number|string}  siteIdOrSlug Site ID or site slug
 * @returns {import('calypso/state/ui/selectors/site-data').SiteData|null|undefined}        Site object
 */

function getSite(state, siteIdOrSlug) {
  const rawSite = (0,calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteIdOrSlug) || (0,_get_site_by_slug__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteIdOrSlug);

  if (!rawSite) {
    return null;
  } // Use the rawSite object itself as a WeakMap key


  const cachedSite = getSiteCache.get(rawSite);

  if (cachedSite) {
    return cachedSite;
  }

  const site = { ...rawSite,
    ...(0,_get_site_computed_attributes__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, rawSite.ID),
    ...(0,_get_jetpack_computed_attributes__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(state, rawSite.ID)
  }; // Once the `rawSite` object becomes outdated, i.e., state gets updated with a newer version
  // and no more references are held, the key will be automatically removed from the WeakMap.

  getSiteCache.set(rawSite, site);
  return site;
}

getSite.clearCache = () => {
  getSiteCache = new WeakMap();
};

/***/ }),

/***/ 79791:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ hasAllSitesList; }
/* harmony export */ });
/**
 * Returns whether all sites have been fetched.
 *
 * @param {object}    state  Global state tree
 * @returns {boolean}        Request State
 */
function hasAllSitesList(state) {
  return !!state.sites.hasAllSitesList;
}

/***/ }),

/***/ 47020:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ isJetpackSiteMainNetworkSite; }
/* harmony export */ });
/* harmony import */ var calypso_lib_url__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(47307);
/* harmony import */ var calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(53843);
/* harmony import */ var _get_site_option__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(27246);
/* harmony import */ var _is_jetpack_site__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(60222);




/**
 * Determines if a site is the main site in a Network
 * True if it is either in a non multi-site configuration
 * or if its url matches the `main_network_site` url option.
 * Returns null if the site is not known or is not a Jetpack site.
 *
 * @param {object} state Global state tree
 * @param {number} siteId Site ID
 * @returns {?boolean} true if the site is the main site
 */

function isJetpackSiteMainNetworkSite(state, siteId) {
  const site = (0,calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteId);

  if (!site || !(0,_is_jetpack_site__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteId)) {
    return null;
  }

  if (!site.is_multisite) {
    return false;
  }

  const unmappedUrl = (0,_get_site_option__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId, 'unmapped_url');
  const mainNetworkSite = (0,_get_site_option__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId, 'main_network_site');

  if (!unmappedUrl || !mainNetworkSite) {
    return false;
  } // Compare unmapped_url with the main_network_site to see if is the main network site.


  return (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_3__/* .withoutHttp */ .ce)(unmappedUrl) === (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_3__/* .withoutHttp */ .ce)(mainNetworkSite);
}

/***/ }),

/***/ 57481:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ isJetpackSiteSecondaryNetworkSite; }
/* harmony export */ });
/* harmony import */ var calypso_lib_url__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(47307);
/* harmony import */ var calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(53843);
/* harmony import */ var _get_site_option__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(27246);
/* harmony import */ var _is_jetpack_site__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(60222);




/**
 * Determines if a Jetpack site is a secondary network site.
 * Returns null if the site is not known or is not a Jetpack site.
 *
 * @param {object} state Global state tree
 * @param {number} siteId Site ID
 * @returns {?boolean} true if the site is a secondary network site
 */

function isJetpackSiteSecondaryNetworkSite(state, siteId) {
  const site = (0,calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteId);

  if (!site || !(0,_is_jetpack_site__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteId)) {
    return null;
  }

  if (!site.is_multisite) {
    return false;
  }

  const unmappedUrl = (0,_get_site_option__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId, 'unmapped_url');
  const mainNetworkSite = (0,_get_site_option__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId, 'main_network_site');

  if (!unmappedUrl || !mainNetworkSite) {
    return false;
  } // Compare unmapped_url with the main_network_site to see if is not the main network site.


  return (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_3__/* .withoutHttp */ .ce)(unmappedUrl) !== (0,calypso_lib_url__WEBPACK_IMPORTED_MODULE_3__/* .withoutHttp */ .ce)(mainNetworkSite);
}

/***/ }),

/***/ 60222:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ isJetpackSite; }
/* harmony export */ });
/* harmony import */ var calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(53843);

/**
 * Returns true if site is a Jetpack site, false if the site is hosted on
 * WordPress.com, or null if the site is unknown.
 *
 * @param  {object}   state  Global state tree
 * @param  {?number}   siteId Site ID
 * @returns {?boolean}        Whether site is a Jetpack site
 */

function isJetpackSite(state, siteId) {
  const site = (0,calypso_state_selectors_get_raw_site__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state, siteId);

  if (!site) {
    return null;
  }

  return site.jetpack;
}

/***/ }),

/***/ 58863:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ isRequestingSite; }
/* harmony export */ });
/**
 * Returns true if a network request is in progress to fetch the specified, or
 * false otherwise.
 *
 * @param  {object}           state  Global state tree
 * @param  {(number|string)}  siteId Site ID or slug
 * @returns {boolean}          Whether request is in progress
 */
function isRequestingSite(state, siteId) {
  return !!state.sites.requesting[siteId];
}

/***/ }),

/***/ 52239:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ isRequestingSites; }
/* harmony export */ });
/**
 * Returns true if we are requesting all sites.
 *
 * @param {object}    state  Global state tree
 * @returns {boolean}        Request State
 */
function isRequestingSites(state) {
  return !!state.sites.requestingAll;
}

/***/ }),

/***/ 83377:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(78871);
/* harmony import */ var calypso_state_sites_selectors_is_jetpack_site__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(60222);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(20834);





/**
 * Returns true if the current site is a simple site
 *
 * @param  {object}   state         Global state tree
 * @returns {?boolean}               Whether the current site is a simple site or not
 */
/* harmony default export */ __webpack_exports__["Z"] = ((0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .createSelector */ .P1)(function (state) {
  let siteId = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : (0,calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state);
  const site = (0,calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state, siteId);
  return !!site && !site.is_wpcom_atomic && !(0,calypso_state_sites_selectors_is_jetpack_site__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(state, siteId);
}, function (state) {
  let siteId = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : (0,calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state);
  return [(0,calypso_state_sites_selectors_is_jetpack_site__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(state, siteId)];
}));

/***/ }),

/***/ 91608:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ isSiteConflicting; }
/* harmony export */ });
/* harmony import */ var _get_site_collisions__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(29926);

/**
 * Returns true if a collision exists for the specified WordPress.com site ID.
 *
 * @param  {object}  state  Global state tree
 * @param  {number}  siteId Site ID
 * @returns {boolean}        Whether collision exists
 */

function isSiteConflicting(state, siteId) {
  return (0,_get_site_collisions__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state).includes(siteId);
}

/***/ }),

/***/ 46505:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "hX": function() { return /* binding */ THEME_ACTIVATE_SUCCESS; },
/* harmony export */   "K6": function() { return /* binding */ THEMES_REQUEST_SUCCESS; }
/* harmony export */ });
/* unused harmony exports ACTIVE_THEME_REQUEST, ACTIVE_THEME_REQUEST_FAILURE, ACTIVE_THEME_REQUEST_SUCCESS, RECOMMENDED_THEMES_FAIL, RECOMMENDED_THEMES_FETCH, RECOMMENDED_THEMES_SUCCESS, THEME_ACCEPT_AUTO_LOADING_HOMEPAGE_WARNING, THEME_ACTIVATE, THEME_ACTIVATE_FAILURE, THEMES_UPDATE, THEMES_UPDATE_FAILURE, THEMES_UPDATE_SUCCESS, THEME_BACK_PATH_SET, THEME_CLEAR_ACTIVATED, THEME_DELETE, THEME_DELETE_FAILURE, THEME_DELETE_SUCCESS, THEME_FILTERS_ADD, THEME_FILTERS_REQUEST, THEME_HIDE_AUTO_LOADING_HOMEPAGE_WARNING, THEME_INSTALL, THEME_INSTALL_FAILURE, THEME_INSTALL_SUCCESS, THEME_PREVIEW_OPTIONS, THEME_PREVIEW_STATE, THEME_REQUEST, THEME_REQUEST_FAILURE, THEME_REQUEST_SUCCESS, THEME_SHOW_AUTO_LOADING_HOMEPAGE_WARNING, THEME_TRANSFER_INITIATE_FAILURE, THEME_TRANSFER_INITIATE_PROGRESS, THEME_TRANSFER_INITIATE_REQUEST, THEME_TRANSFER_INITIATE_SUCCESS, THEME_TRANSFER_STATUS_FAILURE, THEME_TRANSFER_STATUS_RECEIVE, THEME_UPLOAD_CLEAR, THEME_UPLOAD_FAILURE, THEME_UPLOAD_PROGRESS, THEME_UPLOAD_START, THEME_UPLOAD_SUCCESS, THEMES_BOOKMARK_SET, THEMES_REQUEST, THEMES_REQUEST_FAILURE, TRENDING_THEMES_FAIL, TRENDING_THEMES_FETCH, TRENDING_THEMES_SUCCESS */
/**
 * Please keep this list alphabetized!
 */
const ACTIVE_THEME_REQUEST = 'ACTIVE_THEME_REQUEST';
const ACTIVE_THEME_REQUEST_FAILURE = 'ACTIVE_THEME_REQUEST_FAILURE';
const ACTIVE_THEME_REQUEST_SUCCESS = 'ACTIVE_THEME_REQUEST_SUCCESS';
const RECOMMENDED_THEMES_FAIL = 'RECOMMENDED_THEMES_FAIL';
const RECOMMENDED_THEMES_FETCH = 'RECOMMENDED_THEMES_FETCH';
const RECOMMENDED_THEMES_SUCCESS = 'RECOMMENDED_THEMES_SUCCESS';
const THEME_ACCEPT_AUTO_LOADING_HOMEPAGE_WARNING = 'THEME_ACCEPT_AUTO_LOADING_HOMEPAGE_WARNING';
const THEME_ACTIVATE = 'THEME_ACTIVATE';
const THEME_ACTIVATE_FAILURE = 'THEME_ACTIVATE_FAILURE';
const THEME_ACTIVATE_SUCCESS = 'THEME_ACTIVATE_SUCCESS';
const THEMES_UPDATE = 'THEMES_UPDATE';
const THEMES_UPDATE_FAILURE = 'THEMES_UPDATE_FAILURE';
const THEMES_UPDATE_SUCCESS = 'THEMES_UPDATE_SUCCESS';
const THEME_BACK_PATH_SET = 'THEME_BACK_PATH_SET';
const THEME_CLEAR_ACTIVATED = 'THEME_CLEAR_ACTIVATED';
const THEME_DELETE = 'THEME_DELETE';
const THEME_DELETE_FAILURE = 'THEME_DELETE_FAILURE';
const THEME_DELETE_SUCCESS = 'THEME_DELETE_SUCCESS';
const THEME_FILTERS_ADD = 'THEME_FILTERS_ADD';
const THEME_FILTERS_REQUEST = 'THEME_FILTERS_REQUEST';
const THEME_HIDE_AUTO_LOADING_HOMEPAGE_WARNING = 'THEME_HIDE_AUTO_LOADING_HOMEPAGE_WARNING';
const THEME_INSTALL = 'THEME_INSTALL';
const THEME_INSTALL_FAILURE = 'THEME_INSTALL_FAILURE';
const THEME_INSTALL_SUCCESS = 'THEME_INSTALL_SUCCESS';
const THEME_PREVIEW_OPTIONS = 'THEME_PREVIEW_OPTIONS';
const THEME_PREVIEW_STATE = 'THEME_PREVIEW_STATE';
const THEME_REQUEST = 'THEME_REQUEST';
const THEME_REQUEST_FAILURE = 'THEME_REQUEST_FAILURE';
const THEME_REQUEST_SUCCESS = 'THEME_REQUEST_SUCCESS';
const THEME_SHOW_AUTO_LOADING_HOMEPAGE_WARNING = 'THEME_SHOW_AUTO_LOADING_HOMEPAGE_WARNING';
const THEME_TRANSFER_INITIATE_FAILURE = 'THEME_TRANSFER_INITIATE_FAILURE';
const THEME_TRANSFER_INITIATE_PROGRESS = 'THEME_TRANSFER_INITIATE_PROGRESS';
const THEME_TRANSFER_INITIATE_REQUEST = 'THEME_TRANSFER_INITIATE_REQUEST';
const THEME_TRANSFER_INITIATE_SUCCESS = 'THEME_TRANSFER_INITIATE_SUCCESS';
const THEME_TRANSFER_STATUS_FAILURE = 'THEME_TRANSFER_STATUS_FAILURE';
const THEME_TRANSFER_STATUS_RECEIVE = 'THEME_TRANSFER_STATUS_RECEIVE';
const THEME_UPLOAD_CLEAR = 'THEME_UPLOAD_CLEAR';
const THEME_UPLOAD_FAILURE = 'THEME_UPLOAD_FAILURE';
const THEME_UPLOAD_PROGRESS = 'THEME_UPLOAD_PROGRESS';
const THEME_UPLOAD_START = 'THEME_UPLOAD_START';
const THEME_UPLOAD_SUCCESS = 'THEME_UPLOAD_SUCCESS';
const THEMES_BOOKMARK_SET = 'THEMES_BOOKMARK_SET';
const THEMES_REQUEST = 'THEMES_REQUEST';
const THEMES_REQUEST_FAILURE = 'THEMES_REQUEST_FAILURE';
const THEMES_REQUEST_SUCCESS = 'THEMES_REQUEST_SUCCESS';
const TRENDING_THEMES_FAIL = 'TRENDING_THEMES_FAIL';
const TRENDING_THEMES_FETCH = 'TRENDING_THEMES_FETCH';
const TRENDING_THEMES_SUCCESS = 'TRENDING_THEMES_SUCCESS';

/***/ }),

/***/ 50425:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_themes_action_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(46505);



const relevantAnalyticsEvents = ['calypso_themeshowcase_theme_click'];
const relevantTypes = {
  // to catch all actions of a type:
  // ACTION_TYPE,
  // to catch actions of a type that match some criterion:
  // ACTION_TYPE: ( action ) => isValid( action.data )
  GUIDED_TOUR_UPDATE: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .GUIDED_TOUR_UPDATE */ .H6A,
  THEMES_REQUEST_SUCCESS: calypso_state_themes_action_types__WEBPACK_IMPORTED_MODULE_2__/* .THEMES_REQUEST_SUCCESS */ .K6,
  ROUTE_SET: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .ROUTE_SET */ .RSp,
  SITE_SETTINGS_RECEIVE: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .SITE_SETTINGS_RECEIVE */ .KBY
};

const hasRelevantAnalytics = action => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(action, 'meta.analytics', []).some(record => relevantAnalyticsEvents.includes(record.payload.name));

const isRelevantActionType = action => relevantTypes.hasOwnProperty(action.type) && (typeof relevantTypes[action.type] !== 'function' || relevantTypes[action.type](action));

const overSome = checks => item => checks.some(check => check(item));

const isRelevantAction = overSome([isRelevantActionType, hasRelevantAnalytics]);

const newAction = action => ({ ...action,
  timestamp: Date.now()
});

const maybeAdd = (state, action) => action ? [...state, action].slice(-50) : state;

/* harmony default export */ __webpack_exports__["Z"] = (function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  let action = arguments.length > 1 ? arguments[1] : undefined;
  return isRelevantAction(action) ? maybeAdd(state, newAction(action)) : state;
});

/***/ }),

/***/ 71799:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "B": function() { return /* binding */ setSelectedSiteId; }
/* harmony export */ });
/* unused harmony export setAllSitesSelected */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_ui_init__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(91789);


/**
 * Returns an action object to be used in signalling that a site has been set
 * as selected.
 *
 * @param {number | null} siteId Site ID
 * @returns {{type: string, siteId: number}} Action object
 */

function setSelectedSiteId(siteId) {
  return {
    type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .SELECTED_SITE_SET */ .bgv,
    siteId
  };
}
/**
 * Returns an action object to be used in signalling that all sites have been
 * set as selected.
 *
 * @returns {object} Action object
 */

function setAllSitesSelected() {
  return {
    type: SELECTED_SITE_SET,
    siteId: null
  };
}

/***/ }),

/***/ 46117:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);

/* harmony default export */ __webpack_exports__["Z"] = (function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let {
    type
  } = arguments.length > 1 ? arguments[1] : undefined;
  return type === calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .APP_BANNER_DISMISSED */ .JYg ? true : state;
});

/***/ }),

/***/ 1184:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);

/* harmony default export */ __webpack_exports__["Z"] = (function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
  let {
    type,
    isVisible
  } = arguments.length > 1 ? arguments[1] : undefined;
  return type === calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .APP_BANNER_TOGGLE_VISIBILITY */ .Fux ? isVisible : state;
});

/***/ }),

/***/ 57718:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export upgradeIntent */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(95884);


const upgradeIntent = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .withSchemaValidation */ .G)({
  type: 'string'
}, function () {
  var _action$section;

  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type !== calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .SECTION_SET */ .IK5) {
    return state;
  }

  if (action.isLoading || !((_action$section = action.section) !== null && _action$section !== void 0 && _action$section.name)) {
    // Leave the intent alone until the new section is fully loaded
    return state;
  }

  if (['checkout', 'checkout-pending', 'checkout-thank-you', 'plans'].includes(action.section.name)) {
    // Leave the intent alone for sections that should not clear it
    return state;
  }

  if (['plugins', 'themes', 'hosting'].includes(action.section.name)) {
    return action.section.name;
  } // Clear the intent when any other section is loaded


  return '';
});
/* harmony default export */ __webpack_exports__["Z"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_2__/* .combineReducers */ .U)({
  upgradeIntent
}));

/***/ }),

/***/ 87316:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);

/* harmony default export */ __webpack_exports__["Z"] = (function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let {
    type,
    value
  } = arguments.length > 1 ? arguments[1] : undefined;
  return type === calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .HELP_CENTER_VISIBLE */ .xm0 ? value : state;
});

/***/ }),

/***/ 91789:
/***/ (function(__unused_webpack_module, __unused_webpack___webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9044);
/* harmony import */ var _reducer__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(74307);


(0,calypso_state_redux_store__WEBPACK_IMPORTED_MODULE_0__/* .registerReducer */ .x)(['ui'], _reducer__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP);

/***/ }),

/***/ 28958:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ language; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);


const initialState = {
  localeSlug: (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('i18n_default_locale_slug'),
  localeVariant: null
};
/**
 * Tracks the state of the ui locale
 *
 * @param {object} state  Current state
 * @param {object} action Action payload
 * @returns {object} Updated state
 */

function language() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .LOCALE_SET */ .JqF:
      return {
        localeSlug: action.localeSlug,
        localeVariant: action.localeVariant
      };

    default:
      return state;
  }
}

/***/ }),

/***/ 48659:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ layoutFocus; }
/* harmony export */ });
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);

const initialState = {
  current: 'content',
  next: null
};
function layoutFocus() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .LAYOUT_FOCUS_SET */ .kUt:
      if (action.area === state.current) {
        return state;
      }

      return Object.assign({}, state, {
        current: action.area
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .LAYOUT_NEXT_FOCUS_SET */ .vO0:
      if (action.area === state.next) {
        return state;
      }

      return Object.assign({}, state, {
        next: action.area
      });

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .LAYOUT_NEXT_FOCUS_ACTIVATE */ .XTm:
      {
        // If we don't have a change queued, set it to `content`. This avoids
        // having to set the focus to content on all navigation links because it
        // becomes the default after focus has shifted.
        let next = state.next;

        if (!next && state.current !== 'content') {
          next = 'content';
        }

        if (!next) {
          return state;
        }

        return Object.assign({}, state, {
          current: next,
          next: null
        });
      }
  }

  return state;
}

/***/ }),

/***/ 31175:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);

/* harmony default export */ __webpack_exports__["Z"] = (function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
  let {
    type,
    isVisible
  } = arguments.length > 1 ? arguments[1] : undefined;
  return type === calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .MASTERBAR_TOGGLE_VISIBILITY */ .NnF ? isVisible : state;
});

/***/ }),

/***/ 30592:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export view */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(95884);


const view = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .MEDIA_MODAL_VIEW_SET */ .WkZ:
      return action.view;
  }

  return state;
};
/* harmony default export */ __webpack_exports__["Z"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .combineReducers */ .U)({
  view
}));

/***/ }),

/***/ 45405:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export postTypeList */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);

const initialState = {
  postIdWithActiveSharePanel: null
};
const postTypeList = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .POST_TYPE_LIST_SHARE_PANEL_HIDE */ .KF6:
      return { ...state,
        postIdWithActiveSharePanel: null
      };

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .POST_TYPE_LIST_SHARE_PANEL_TOGGLE */ .WYe:
      if (state.postIdWithActiveSharePanel === action.postGlobalId) {
        return { ...state,
          postIdWithActiveSharePanel: null
        };
      }

      return { ...state,
        postIdWithActiveSharePanel: action.postGlobalId
      };
  }

  return state;
};
/* harmony default export */ __webpack_exports__["Z"] = (postTypeList);

/***/ }),

/***/ 37508:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports currentPreviewSiteId, currentPreviewUrl */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(95884);


function currentPreviewSiteId() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .PREVIEW_URL_SET */ .dGx:
      return action.siteId ?? null;
  }

  return state;
}
function currentPreviewUrl() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .PREVIEW_URL_SET */ .dGx:
      return action.url;

    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .PREVIEW_URL_CLEAR */ .kLL:
      return null;
  }

  return state;
}
/* harmony default export */ __webpack_exports__["ZP"] = ((0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .combineReducers */ .U)({
  currentPreviewSiteId,
  currentPreviewUrl
}));

/***/ }),

/***/ 74307:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports selectedSiteId, siteSelectionInitialized, isSectionLoading, isNotificationsOpen, reducer */
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(29398);
/* harmony import */ var calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(95884);
/* harmony import */ var _action_log_reducer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(50425);
/* harmony import */ var _app_banner_dismissed_reducer__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(46117);
/* harmony import */ var _app_banner_visibility_reducer__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(1184);
/* harmony import */ var _checkout_reducer__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(57718);
/* harmony import */ var _help_center_visible_reducer__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(87316);
/* harmony import */ var _language_reducer__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(28958);
/* harmony import */ var _layout_focus_reducer__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(48659);
/* harmony import */ var _masterbar_visibility_reducer__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(31175);
/* harmony import */ var _media_modal_reducer__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(30592);
/* harmony import */ var _post_type_list_reducer__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(45405);
/* harmony import */ var _preview_reducer__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(37508);
/* harmony import */ var _section_reducer__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(77027);















/**
 * Tracks the currently selected site ID.
 *
 * @param  {object} state  Current state
 * @param  {object} action Action payload
 * @returns {object}        Updated state
 */

const selectedSiteId = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .withSchemaValidation */ .G)({
  type: ['number', 'null']
}, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .SELECTED_SITE_SET */ .bgv:
      return action.siteId || null;
  }

  return state;
});
const siteSelectionInitialized = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_1__/* .withSchemaValidation */ .G)({
  type: 'boolean'
}, function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .SELECTED_SITE_SET */ .bgv:
      return true;
  }

  return state;
});
function isSectionLoading() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .SECTION_LOADING_SET */ .Nq:
      return action.isSectionLoading;
  }

  return state;
}
/**
 * Tracks if the notifications panel is open
 *
 * @param   {object} state       Current state
 * @param   {object} action      Action payload
 * @param   {string} action.type The action type identifier. In this case it's looking for NOTIFICATIONS_PANEL_TOGGLE
 * @returns {object}             Updated state
 */

function isNotificationsOpen() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let {
    type
  } = arguments.length > 1 ? arguments[1] : undefined;

  if (type === calypso_state_action_types__WEBPACK_IMPORTED_MODULE_2__/* .NOTIFICATIONS_PANEL_TOGGLE */ .hxz) {
    return !state;
  }

  return state;
}
const reducer = (0,calypso_state_utils__WEBPACK_IMPORTED_MODULE_3__/* .combineReducers */ .U)({
  actionLog: _action_log_reducer__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z,
  appBannerVisibility: _app_banner_visibility_reducer__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z,
  appBannerDismissed: _app_banner_dismissed_reducer__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z,
  helpCenterVisible: _help_center_visible_reducer__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z,
  checkout: _checkout_reducer__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z,
  isSectionLoading,
  isNotificationsOpen,
  language: _language_reducer__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z,
  layoutFocus: _layout_focus_reducer__WEBPACK_IMPORTED_MODULE_10__/* ["default"] */ .Z,
  masterbarVisibility: _masterbar_visibility_reducer__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z,
  mediaModal: _media_modal_reducer__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z,
  postTypeList: _post_type_list_reducer__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .Z,
  preview: _preview_reducer__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .ZP,
  section: _section_reducer__WEBPACK_IMPORTED_MODULE_15__/* ["default"] */ .Z,
  selectedSiteId,
  siteSelectionInitialized
});

/* harmony default export */ __webpack_exports__["ZP"] = ((0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .withStorageKey */ .xi)('ui', reducer));

/***/ }),

/***/ 9817:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "z": function() { return /* binding */ setSection; }
/* harmony export */ });
/* unused harmony export setSectionLoading */
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_ui_init__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(91789);


function setSection(section) {
  let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  const action = { ...options,
    type: calypso_state_action_types__WEBPACK_IMPORTED_MODULE_1__/* .SECTION_SET */ .IK5
  };

  if (section) {
    action.section = section;
  }

  return action;
}
function setSectionLoading(isSectionLoading) {
  return {
    type: SECTION_LOADING_SET,
    isSectionLoading
  };
}

/***/ }),

/***/ 77027:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ section; }
/* harmony export */ });
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40211);
 //TODO: do we really want to mix strings and booleans?

function section() {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_0__/* .SECTION_SET */ .IK5:
      return action.section !== undefined ? action.section : state;
  }

  return state;
}

/***/ }),

/***/ 73041:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getSectionName; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _get_section__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(75149);


/**
 * Returns the current section name.
 *
 * @param  {object}  state Global state tree
 * @returns {?string}       Current section name
 */

function getSectionName(state) {
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)((0,_get_section__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state), 'name', null);
}

/***/ }),

/***/ 75149:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getSection; }
/* harmony export */ });
/* harmony import */ var calypso_state_ui_init__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(91789);

/**
 * Returns the current section.
 *
 * @param  {object}  state Global state tree
 * @returns {object}        Current section
 */

function getSection(state) {
  return state.ui.section || false;
}

/***/ }),

/***/ 20834:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getSelectedSiteId; }
/* harmony export */ });
/* harmony import */ var calypso_state_ui_init__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(91789);

/**
 * Returns the currently selected site ID.
 *
 * @param  {object}  state Global state tree
 * @returns {?number}       Selected site ID
 */

function getSelectedSiteId(state) {
  return state.ui.selectedSiteId;
}

/***/ }),

/***/ 17014:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getSelectedSite; }
/* harmony export */ });
/* harmony import */ var calypso_state_sites_selectors_get_site__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(78871);
/* harmony import */ var _get_selected_site_id__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20834);


/**
 * @typedef { import("./site-data").SiteData } SiteData
 */

/**
 * Returns the site object for the currently selected site.
 *
 * @param  {object}  state  Global state tree
 * @returns {SiteData|null}        Selected site
 */

function getSelectedSite(state) {
  const siteId = (0,_get_selected_site_id__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(state);

  if (!siteId) {
    return null;
  }

  return (0,calypso_state_sites_selectors_get_site__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(state, siteId);
}

/***/ }),

/***/ 90924:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "f": function() { return /* binding */ addReducerEnhancer; }
/* harmony export */ });
const addReducerEnhancer = nextCreator => (reducer, initialState) => {
  const nextStore = nextCreator(reducer, initialState);
  let currentReducer = reducer;

  function addReducer(keys, subReducer) {
    currentReducer = currentReducer.addReducer(keys, subReducer);
    this.replaceReducer(currentReducer);
  }

  function getCurrentReducer() {
    return currentReducer;
  }

  return { ...nextStore,
    addReducer,
    getCurrentReducer
  };
};

/***/ }),

/***/ 15960:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "J": function() { return /* binding */ keyedReducer; }
/* harmony export */ });
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_state_serialization_result__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(87697);
/* harmony import */ var _serialize__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(69909);
/* harmony import */ var _with_persistence__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(71085);





/**
 * Creates a super-reducer as a map of reducers over keyed objects
 *
 * Use this when wanting to write reducers that operate
 * on a single object as if it lived in isolation when
 * really it lives in a map of similar objects referenced
 * by some predesignated key or id. This could be used
 * for example when reducing properties on a site object
 * wherein we have many sites keyed by site id.
 *
 * Note! This will only apply the supplied reducer to
 * the item referenced by the supplied key in the action.
 *
 * If no key exists whose name matches the given lodash style keyPath
 * then this super-reducer will abort and return the
 * previous state.
 *
 * The keyed reducer implements the `serialize` and `deserialize` methods and makes sure
 * that Calypso state persistence works as expected (ignoring empty and initial state,
 * serialization into multiple storage keys etc.)
 *
 * @example
 * const age = ( state = 0, action ) =>
 *     GROW === action.type
 *         ? state + 1
 *         : state
 *
 * const title = ( state = 'grunt', action ) =>
 *     PROMOTION === action.type
 *         ? action.title
 *         : state
 *
 * const userReducer = combineReducers( {
 *     age,
 *     title,
 * } )
 *
 * export default keyedReducer( 'username', userReducer )
 *
 * dispatch( { type: GROW, username: 'hunter02' } )
 *
 * state.users === {
 *     hunter02: {
 *         age: 1,
 *         title: 'grunt',
 *     }
 * }
 * @param {string} keyPath lodash-style path to the key in action referencing item in state map
 * @param {Function} reducer applied to referenced item in state map
 * @returns {Function} super-reducer applying reducer over map of keyed items
 */
const keyedReducer = (keyPath, reducer) => {
  // some keys are invalid
  if ('string' !== typeof keyPath) {
    throw new TypeError(`Key name passed into \`keyedReducer\` must be a string but I detected a ${typeof keyPath}`);
  }

  if (!keyPath.length) {
    throw new TypeError('Key name passed into `keyedReducer` must have a non-zero length but I detected an empty string');
  }

  if ('function' !== typeof reducer) {
    throw new TypeError(`Reducer passed into \`keyedReducer\` must be a function but I detected a ${typeof reducer}`);
  }

  const initialState = reducer(undefined, {
    type: '@@calypso/INIT'
  });

  const combinedReducer = function () {
    let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    let action = arguments.length > 1 ? arguments[1] : undefined;
    // don't allow coercion of key name: null => 0
    const itemKey = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(action, keyPath, undefined); // if the action doesn't contain a valid reference
    // then return without any updates

    if (null === itemKey || undefined === itemKey) {
      return state;
    } // pass the old sub-state from that item into the reducer
    // we need this to update state and also to compare if
    // we had any changes, thus the initialState


    const oldItemState = state[itemKey];
    const newItemState = reducer(oldItemState, action); // and do nothing if the new sub-state matches the old sub-state

    if (newItemState === oldItemState) {
      return state;
    } // remove key from state if setting to undefined or back to initial state
    // if it didn't exist anyway, then do nothing.


    if (undefined === newItemState || (0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEqual)(newItemState, initialState)) {
      return state.hasOwnProperty(itemKey) ? (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omit)(state, itemKey) : state;
    } // otherwise immutably update the super-state


    return { ...state,
      [itemKey]: newItemState
    };
  };

  return (0,_with_persistence__WEBPACK_IMPORTED_MODULE_2__/* .withPersistence */ .$)(combinedReducer, {
    serialize: state => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(state, (result, itemValue, itemKey) => {
      const serializedValue = (0,_serialize__WEBPACK_IMPORTED_MODULE_3__/* .serialize */ .q)(reducer, itemValue);

      if (serializedValue !== undefined && !(0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEqual)(serializedValue, initialState)) {
        if (!result) {
          // instantiate the result object only when it's going to have at least one property
          result = new calypso_state_serialization_result__WEBPACK_IMPORTED_MODULE_1__/* .SerializationResult */ ._();
        }

        result.addRootResult(itemKey, serializedValue);
      }

      return result;
    }, undefined),
    deserialize: persisted => (0,lodash__WEBPACK_IMPORTED_MODULE_0__.omitBy)((0,lodash__WEBPACK_IMPORTED_MODULE_0__.mapValues)(persisted, item => (0,_serialize__WEBPACK_IMPORTED_MODULE_3__/* .deserialize */ .v)(reducer, item)), a => a === undefined || (0,lodash__WEBPACK_IMPORTED_MODULE_0__.isEqual)(a, initialState))
  });
};

/***/ }),

/***/ 95884:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "U": function() { return /* binding */ combineReducers; }
/* harmony export */ });
/* unused harmony export addReducer */
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var redux__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(18717);
/* harmony import */ var calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(40211);
/* harmony import */ var calypso_state_serialization_result__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(87697);
/* harmony import */ var _serialize__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(69909);

 // eslint-disable-line no-restricted-imports





/**
 * Create a new reducer from original `reducers` by adding a new `reducer` at `keyPath`
 *
 * @param origReducer Original reducer to copy `storageKey` and other flags from
 * @param reducers Object with reducer names as keys and reducer functions as values that
 *   is used as parameter to `combineReducers` (the original Redux one and our extension, too).
 * @returns The function to be attached as `addReducer` method to the
 *   result of `combineReducers`.
 */
function addReducer(origReducer, reducers) {
  return (keyPath, reducer) => {
    // extract the first key from keyPath and dive recursively into the reducer tree
    const [key, ...restKeys] = keyPath;
    const existingReducer = reducers[key];
    let newReducer; // if there is an existing reducer at this path, we'll recursively call `addReducer`
    // until we reach the final destination in the tree.

    if (existingReducer) {
      // we reached the final destination in the tree and another reducer already lives there!
      if (restKeys.length === 0) {
        throw new Error(`Reducer with key '${key}' is already registered`);
      }

      if (!existingReducer.addReducer) {
        throw new Error("New reducer can be added only into a reducer created with 'combineReducers'");
      }

      newReducer = existingReducer.addReducer(restKeys, reducer);
    } else {
      // for the remaining keys in the keyPath, create a nested reducer:
      // if `restKeys` is `[ 'a', 'b', 'c']`, then the result of this `reduceRight` is:
      // ```js
      // combineReducers( {
      //   a: combineReducers ( {
      //     b: combineReducers( {
      //       c: reducer
      //     } )
      //   })
      // })
      // ```
      newReducer = restKeys.reduceRight((subreducer, subkey) => combineReducers({
        [subkey]: subreducer
      }), reducer);
    }

    const newCombinedReducer = combineReducers({ ...reducers,
      [key]: newReducer
    }); // Preserve the storageKey of the updated reducer

    newCombinedReducer.storageKey = origReducer.storageKey;
    return newCombinedReducer;
  };
}
/**
 * Returns a single reducer function that ensures that persistence is opt-in and that
 * has support for adding reducers dynamically.
 *
 * @example
 * ```js
 * const age = ( state = 0, action ) =>
 *     GROW === action.type
 *         ? state + 1
 *         : state
 * const height = ( state = 150, action ) =>
 *     GROW === action.type
 *         ? state + 1
 *         : state
 *
 * const combinedReducer = combineReducers( {
 *     age,
 *     height
 * } );
 *
 * // returns `{ age: 0, height: 150 }`, the initial state
 * deserialize( combinedReducer, { age: 6, height: 123 } );
 * // returns `undefined`, no serialization
 * serialize( combinedReducer, { age: 6, height: 123 } );
 * // returns `{ age: 7, height: 124 }`, handling a normal action
 * combinedReducer( { age:  6, height: 123 } ), { type: GROW } );
 * ```
 *
 * Persistence must be enabled explicitly with the `withPersistence` helper.
 * @example
 * ```js
 * const date = withPersistence(
 *   ( state = new Date( 0 ), action ) => {
 *     switch ( action.type ) {
 *       case 'GROW':
 *         return new Date( state.getTime() + 1 );
 *       default:
 *         return state;
 *   },
 *   {
 *     serialize: state => state.getTime(),
 *     deserialize: persisted => {
 *       if ( isValidStateWithSchema( persisted, schema ) ) {
 *         return new Date( persisted );
 *       }
 *       return new Date( 0 );
 *     },
 *   }
 * );
 *
 * const combinedReducer = combineReducers( {
 *     date,
 *     height
 * } );
 *
 * deserialize( combinedReducer, { date: -5, height: -5 } ); // { date: new Date( 0 ), height: 150 };
 * deserialize( combinedReducer, { date: -5, height: 123 } ); // { date: new Date( 0 ), height: 150 };
 * deserialize( combinedReducer, { date:  6, height: 123 } ); // { date: new Date( 6 ), height: 150 };
 * serialize( combinedReducer, { date: new Date( 6 ), height: 123 } ); // { date: 6 };
 * combinedReducer( { date: new Date( 6 ), height: 123 } ), { type: GROW } ); // { date: new Date( 7 ), height: 124 };
 * ```
 * @param reducers - object containing the reducers to merge
 * @returns - Returns the combined reducer function
 */

function combineReducers(reducers) {
  const combined = (0,redux__WEBPACK_IMPORTED_MODULE_2__/* .combineReducers */ .UY)(reducers);

  const combinedReducer = (state, action) => {
    switch (action.type) {
      case calypso_state_action_types__WEBPACK_IMPORTED_MODULE_3__/* .APPLY_STORED_STATE */ .gm2:
        return applyStoredState(reducers, state, action);

      default:
        return combined(state, action);
    }
  };

  combinedReducer.serialize = state => serializeState(reducers, state);

  combinedReducer.deserialize = persisted => deserializeState(reducers, persisted);

  combinedReducer.addReducer = addReducer(combinedReducer, reducers);
  combinedReducer.getStorageKeys = getStorageKeys(reducers);
  return combinedReducer;
}

function applyStoredState(reducers, state, action) {
  let hasChanged = false;
  const nextState = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.mapValues)(reducers, (reducer, key) => {
    // Replace the value for the key we want to init with action.storedState.
    if (reducer.storageKey === action.storageKey) {
      hasChanged = true;
      return action.storedState;
    } // Descend into nested state levels, possibly the storageKey will be found there?


    const prevStateForKey = (0,lodash__WEBPACK_IMPORTED_MODULE_0__.get)(state, key);
    const nextStateForKey = reducer(prevStateForKey, action);
    hasChanged = hasChanged || nextStateForKey !== prevStateForKey;
    return nextStateForKey;
  }); // return identical state if the stored state didn't get applied in this reducer

  return hasChanged ? nextState : state;
}

function getStorageKeys(reducers) {
  return function* () {
    for (const reducer of Object.values(reducers)) {
      if (reducer.storageKey) {
        yield {
          storageKey: reducer.storageKey,
          reducer
        };
      }

      if (reducer.getStorageKeys) {
        yield* reducer.getStorageKeys();
      }
    }
  };
} // State serialization is very similar to running a reducer on the state, except some behaviors
// that are slightly different from `combineReducers` from Redux:
// - `undefined` is a valid value returned from `serialize()`, but `combineReducers`
//   would throw an exception when seeing it.
// - if a particular subreducer serializes to `undefined`, then that property won't be included
//   in the result object at all.
// - if none of the subreducers produced anything to persist, the combined result will be
//   `undefined` rather than an empty object.
// - if the state to serialize is `undefined` (happens when some key in state is missing)
//   the serialized value is `undefined` and there's no need to reduce anything.


function serializeState(reducers, state) {
  if (state === undefined) {
    return undefined;
  }

  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.reduce)(reducers, (result, reducer, reducerKey) => {
    const serialized = (0,_serialize__WEBPACK_IMPORTED_MODULE_4__/* .serialize */ .q)(reducer, state[reducerKey]);

    if (serialized !== undefined) {
      if (!result) {
        // instantiate the result object only when it's going to have at least one property
        result = new calypso_state_serialization_result__WEBPACK_IMPORTED_MODULE_1__/* .SerializationResult */ ._();
      }

      if (reducer.storageKey) {
        result.addKeyResult(reducer.storageKey, serialized);
      } else {
        result.addRootResult(reducerKey, serialized);
      }
    }

    return result;
  }, undefined);
}

function deserializeState(reducers, persisted) {
  return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.mapValues)(reducers, (reducer, reducerKey) => (0,_serialize__WEBPACK_IMPORTED_MODULE_4__/* .deserialize */ .v)(reducer, persisted === null || persisted === void 0 ? void 0 : persisted[reducerKey]));
}

/***/ }),

/***/ 29398:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "G": function() { return /* binding */ withSchemaValidation; }
/* harmony export */ });
/* unused harmony export isValidStateWithSchema */
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);
/* harmony import */ var _wordpress_warning__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(12560);
/* harmony import */ var _wordpress_warning__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_warning__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var is_my_json_valid__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(60772);
/* harmony import */ var is_my_json_valid__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(is_my_json_valid__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _serialize__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(69909);
/* harmony import */ var _with_persistence__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(71085);






function isValidStateWithSchema(state, schema, debugInfo) {
  const validate = is_my_json_valid__WEBPACK_IMPORTED_MODULE_2___default()(schema, {
    greedy: "production" !== 'production',
    verbose: "production" !== 'production'
  });
  const valid = validate(state);

  if (!valid && "production" !== 'production') {}

  return valid;
}

function isValidSerializedState(schema, reducer, state) {
  // The stored state is often equal to initial state of the reducer. Because initial state
  // is always valid, we can validate much faster by just comparing the two states. The full
  // JSON schema check is much slower and we do it only on nontrivial states.
  // Note that we need to serialize the initial state to make a correct check. For reducers
  // with custom persistence, the initial state can be arbitrary non-serializable object. We
  // need to compare two serialized objects.
  const serializedInitialState = (0,_serialize__WEBPACK_IMPORTED_MODULE_4__/* .serialize */ .q)(reducer, (0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .getInitialState */ .aY)(reducer));

  if ((0,lodash__WEBPACK_IMPORTED_MODULE_3__.isEqual)(state, serializedInitialState)) {
    return true;
  }

  return isValidStateWithSchema(state, schema);
}
/**
 * Creates a schema-validating reducer
 *
 * Use this to wrap simple reducers with a schema-based validation check when loading
 * the initial state from persistent storage.
 *
 * The wrapped reducer implements the `deserialize` method and checks if the persisted state
 * is a valid state. If yes, it returns the persisted state (and calls the inner reducer's
 * `deserialize` method if defined). Otherwise it returns the initial state of the inner reducer.
 *
 * @example
 * ```js
 * const ageReducer = ( state = 0, action ) => GROW === action.type ? state + 1 : state
 *
 * const schema = { type: 'number', minimum: 0 }
 *
 * export const age = withSchemaValidation( schema, ageReducer );
 *
 * expect( deserialize( ageReducer, -5 ) ).toBe( -5 ); // no schema check
 * expect( deserialize( age, -5 ) ).toBe( 0 ); // schema check failed, return initial state
 * expect( deserialize( age,  23 ) ).toBe( 23 ); // schema check passed
 * ```
 * @param {object} schema JSON-schema description of state
 * @param {Function} reducer normal reducer from ( state, action ) to new state
 * @returns {import('redux').Reducer} wrapped reducer handling validation on `.deserialize()`
 */


const withSchemaValidation = (schema, reducer) => {
  if (false) {} // Add default identity-mapping persistence to the wrapped reducer. Prevent
  // it to default to no-persistence.


  const persistingReducer = (0,_with_persistence__WEBPACK_IMPORTED_MODULE_5__/* .withPersistence */ .$)(reducer);
  return (0,_with_persistence__WEBPACK_IMPORTED_MODULE_5__/* .withPersistence */ .$)(persistingReducer, {
    deserialize(persisted) {
      if (persisted === undefined) {
        // If the state is not present in the stored data, initialize it with the
        // initial state.
        return (0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .getInitialState */ .aY)(persistingReducer);
      } // If the stored state fails JSON schema validation, treat it as if it was
      // `undefined`, i.e., ignore it and replace with initial state.


      if (!isValidSerializedState(schema, persistingReducer, persisted)) {
        return (0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .getInitialState */ .aY)(persistingReducer);
      } // Otherwise, if the state is valid, deserialize it with the inner reducer.


      return (0,_serialize__WEBPACK_IMPORTED_MODULE_4__/* .deserialize */ .v)(persistingReducer, persisted);
    }

  });
};

/***/ }),

/***/ 69909:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "q": function() { return /* binding */ serialize; },
/* harmony export */   "v": function() { return /* binding */ deserialize; }
/* harmony export */ });
/* harmony import */ var _automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(83685);

function serialize(reducer, state) {
  if (!reducer.serialize) {
    return undefined;
  }

  return reducer.serialize(state);
}
function deserialize(reducer, persisted) {
  if (!reducer.deserialize) {
    return (0,_automattic_state_utils__WEBPACK_IMPORTED_MODULE_0__/* .getInitialState */ .aY)(reducer);
  }

  return reducer.deserialize(persisted);
}

/***/ }),

/***/ 71085:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "$": function() { return /* binding */ withPersistence; }
/* harmony export */ });
/**
 * Add persistence support to a reducer, with optional custom serialization methods
 *
 * @param reducer Reducer to add persistence to
 * @param options Object with optional custom serialization methods
 * @param options.serialize Custom serialization method
 * @param options.deserialize Custom deserialization method
 */
function withPersistence(reducer) {
  let {
    serialize,
    deserialize
  } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  const wrappedReducer = reducer.bind(null);

  wrappedReducer.serialize = serialize || reducer.serialize || (state => state);

  wrappedReducer.deserialize = deserialize || reducer.deserialize || (persisted => persisted);

  return wrappedReducer;
}

/***/ }),

/***/ 36115:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "vX": function() { return /* reexport safe */ _utils_do_not_track__WEBPACK_IMPORTED_MODULE_0__.Z; },
/* harmony export */   "ts": function() { return /* reexport safe */ _utils_current_user__WEBPACK_IMPORTED_MODULE_1__.t; },
/* harmony export */   "P6": function() { return /* reexport safe */ _tracks__WEBPACK_IMPORTED_MODULE_3__.P6; },
/* harmony export */   "w2": function() { return /* reexport safe */ _tracks__WEBPACK_IMPORTED_MODULE_3__.w2; },
/* harmony export */   "jN": function() { return /* reexport safe */ _tracks__WEBPACK_IMPORTED_MODULE_3__.jN; },
/* harmony export */   "$A": function() { return /* reexport safe */ _tracks__WEBPACK_IMPORTED_MODULE_3__.$A; },
/* harmony export */   "MB": function() { return /* reexport safe */ _tracks__WEBPACK_IMPORTED_MODULE_3__.MB; },
/* harmony export */   "di": function() { return /* reexport safe */ _tracks__WEBPACK_IMPORTED_MODULE_3__.di; },
/* harmony export */   "MR": function() { return /* reexport safe */ _tracks__WEBPACK_IMPORTED_MODULE_3__.MR; },
/* harmony export */   "lH": function() { return /* reexport safe */ _tracks__WEBPACK_IMPORTED_MODULE_3__.lH; }
/* harmony export */ });
/* harmony import */ var _utils_do_not_track__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(21694);
/* harmony import */ var _utils_current_user__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36209);
/* harmony import */ var _page_view_params__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(29377);
/* harmony import */ var _tracks__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(59792);
/* harmony import */ var _train_tracks__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(73722);
/**
 * Re-export
 */






/***/ }),

/***/ 29377:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "i": function() { return /* binding */ getPageViewParams; }
/* harmony export */ });
/* unused harmony export getMostRecentUrlPath */
// We use this module state to track url paths submitted to recordTracksPageView
// `lib/analytics/index.js` also reuses it for timing.record
let mostRecentUrlPath = null; // pathCounter is used to keep track of the order of calypso_page_view Tracks events.

let pathCounter = 0;

if (typeof window !== 'undefined') {
  window.addEventListener('popstate', function () {
    // throw away our URL value if the user used the back/forward buttons
    mostRecentUrlPath = null;
  });
}

function getPageViewParams(urlPath) {
  const params = {
    last_pageview_path_with_count: `${mostRecentUrlPath}(${pathCounter.toString()})`,
    this_pageview_path_with_count: `${urlPath}(${pathCounter + 1})`
  }; // Record this path.

  mostRecentUrlPath = urlPath;
  pathCounter++;
  return params;
}
/**
 * Gets the url path which was set on the last call to getPageViewParams() and stored in module state
 * mostRecentUrlPath will be null if the page was refreshed or getPageViewParams() has not been called
 */

function getMostRecentUrlPath() {
  return mostRecentUrlPath;
}

/***/ }),

/***/ 59792:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "lH": function() { return /* binding */ pushEventToTracksQueue; },
/* harmony export */   "MR": function() { return /* binding */ analyticsEvents; },
/* harmony export */   "di": function() { return /* binding */ getTracksAnonymousUserId; },
/* harmony export */   "MB": function() { return /* binding */ initializeAnalytics; },
/* harmony export */   "$A": function() { return /* binding */ identifyUser; },
/* harmony export */   "jN": function() { return /* binding */ recordTracksEvent; },
/* harmony export */   "P6": function() { return /* binding */ recordTracksPageView; },
/* harmony export */   "w2": function() { return /* binding */ recordTracksPageViewWithPageParams; }
/* harmony export */ });
/* unused harmony export getTracksLoadPromise */
/* harmony import */ var events__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(22699);
/* harmony import */ var events__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(events__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_load_script__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(84898);
/* harmony import */ var cookie__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(13421);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _page_view_params__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(29377);
/* harmony import */ var _utils_current_user__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(36209);
/* harmony import */ var _utils_debug__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(19358);
/* harmony import */ var _utils_do_not_track__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(21694);
/* eslint-disable @typescript-eslint/no-explicit-any */









/**
 * Tracks uses a bunch of special query params that should not be used as property name
 * See internal Nosara repo?
 */
const TRACKS_SPECIAL_PROPS_NAMES = (/* unused pure expression or super */ null && (['geo', 'message', 'request', 'geocity', 'ip']));
const EVENT_NAME_EXCEPTIONS = ['a8c_cookie_banner_ok', // WooCommerce Onboarding / Connection Flow.
'wcadmin_storeprofiler_create_jetpack_account', 'wcadmin_storeprofiler_connect_store', 'wcadmin_storeprofiler_login_jetpack_account', 'wcadmin_storeprofiler_payment_login', 'wcadmin_storeprofiler_payment_create_account', // Checkout
'calypso_checkout_switch_to_p_24', 'calypso_checkout_composite_p24_submit_clicked'];

let _superProps; // Added to all Tracks events.


let _loadTracksResult = Promise.resolve(); // default value for non-BOM environments.


if (typeof document !== 'undefined') {
  _loadTracksResult = (0,_automattic_load_script__WEBPACK_IMPORTED_MODULE_1__/* .loadScript */ .ve)('//stats.wp.com/w.js?63');
}

function createRandomId() {
  let randomBytesLength = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 9;

  if (typeof window === 'undefined') {
    return '';
  } // 9 * 4/3 = 12
  // this is to avoid getting padding of a random byte string when it is base64 encoded


  let randomBytes;

  if (window.crypto && window.crypto.getRandomValues) {
    randomBytes = new Uint8Array(randomBytesLength);
    window.crypto.getRandomValues(randomBytes);
  } else {
    randomBytes = (0,lodash__WEBPACK_IMPORTED_MODULE_3__.times)(randomBytesLength, () => Math.floor(Math.random() * 256));
  }

  return window.btoa(String.fromCharCode(...randomBytes));
}

function getUrlParameter(name) {
  if (typeof window === 'undefined') {
    return '';
  }

  name = name.replace(/[[]/g, '\\[').replace(/[\]]/g, '\\]');
  const regex = new RegExp('[\\?&]' + name + '=([^&#]*)');
  const results = regex.exec(window.location.search);
  return results === null ? '' : decodeURIComponent(results[1].replace(/\+/g, ' '));
}

function checkForBlockedTracks() {
  // Proceed only after the tracks script load finished and failed.
  // Calling this function from `initialize` ensures current user is set.
  // This detects stats blocking, and identifies by `getCurrentUser()`, URL, or cookie.
  return _loadTracksResult.catch(() => {
    let _ut;

    let _ui;

    const currentUser = (0,_utils_current_user__WEBPACK_IMPORTED_MODULE_5__/* .getCurrentUser */ .t)();

    if (currentUser && currentUser.ID) {
      _ut = 'wpcom:user_id';
      _ui = currentUser.ID;
    } else {
      _ut = getUrlParameter('_ut') || 'anon';
      _ui = getUrlParameter('_ui');

      if (!_ui) {
        const cookies = cookie__WEBPACK_IMPORTED_MODULE_2__.parse(document.cookie);

        if (cookies.tk_ai) {
          _ui = cookies.tk_ai;
        } else {
          const randomIdLength = 18; // 18 * 4/3 = 24 (base64 encoded chars).

          _ui = createRandomId(randomIdLength);
          document.cookie = cookie__WEBPACK_IMPORTED_MODULE_2__.serialize('tk_ai', _ui);
        }
      }
    }

    (0,_utils_debug__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)('Loading /nostats.js', {
      _ut,
      _ui
    });
    return (0,_automattic_load_script__WEBPACK_IMPORTED_MODULE_1__/* .loadScript */ .ve)('/nostats.js?_ut=' + encodeURIComponent(_ut) + '&_ui=' + encodeURIComponent(_ui));
  });
}
/**
 * Returns a promise that marks whether and when the external Tracks script loads.
 */


function getTracksLoadPromise() {
  return _loadTracksResult;
}
function pushEventToTracksQueue(args) {
  if (typeof window !== 'undefined') {
    window._tkq = window._tkq || [];

    window._tkq.push(args);
  }
}
const analyticsEvents = new events__WEBPACK_IMPORTED_MODULE_0__.EventEmitter();
/**
 * Returns the anoymous id stored in the `tk_ai` cookie
 *
 * @returns The Tracks anonymous user id
 */

function getTracksAnonymousUserId() {
  const cookies = cookie__WEBPACK_IMPORTED_MODULE_2__.parse(document.cookie);
  return cookies.tk_ai;
}
function initializeAnalytics(currentUser, superProps) {
  // Update super props.
  if ('function' === typeof superProps) {
    (0,_utils_debug__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)('superProps', superProps);
    _superProps = superProps;
  } // Identify current user.


  if ('object' === typeof currentUser) {
    (0,_utils_debug__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)('identifyUser', currentUser);
    identifyUser(currentUser);
  } // Tracks blocked?


  (0,_utils_debug__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)('checkForBlockedTracks');
  return checkForBlockedTracks();
}
function identifyUser(userData) {
  // Ensure object.
  if ('object' !== typeof userData) {
    (0,_utils_debug__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)('Invalid userData.', userData);
    return; // Not possible.
  } // Set current user.


  const currentUser = (0,_utils_current_user__WEBPACK_IMPORTED_MODULE_5__/* .setCurrentUser */ .l)(userData);

  if (!currentUser) {
    (0,_utils_debug__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)('Insufficient userData.', userData);
    return; // Not possible.
  } // Tracks user identification.


  (0,_utils_debug__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)('Tracks identifyUser.', currentUser);
  pushEventToTracksQueue(['identifyUser', currentUser.ID, currentUser.username]);
}
function recordTracksEvent(eventName, eventProperties) {
  eventProperties = eventProperties || {};

  if (false) {}

  (0,_utils_debug__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)('Record event "%s" called with props %o', eventName, eventProperties);

  if (!eventName.startsWith('calypso_') && !(0,lodash__WEBPACK_IMPORTED_MODULE_3__.includes)(EVENT_NAME_EXCEPTIONS, eventName)) {
    (0,_utils_debug__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)('- Event name must be prefixed by "calypso_" or added to `EVENT_NAME_EXCEPTIONS`');
    return;
  }

  if (_superProps) {
    const superProperties = _superProps(eventProperties);

    eventProperties = { ...eventProperties,
      ...superProperties
    }; // assign to a new object so we don't modify the argument
  } // Remove properties that have an undefined value
  // This allows a caller to easily remove properties from the recorded set by setting them to undefined


  eventProperties = (0,lodash__WEBPACK_IMPORTED_MODULE_3__.omitBy)(eventProperties, prop => typeof prop === 'undefined');
  (0,_utils_debug__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)('Recording event "%s" with actual props %o', eventName, eventProperties);
  pushEventToTracksQueue(['recordEvent', eventName, eventProperties]);
  analyticsEvents.emit('record-event', eventName, eventProperties);
}
function recordTracksPageView(urlPath, params) {
  (0,_utils_debug__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)('Recording pageview in tracks.', urlPath, params);
  let eventProperties = {
    do_not_track: (0,_utils_do_not_track__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)() ? 1 : 0,
    path: urlPath
  }; // Add calypso build timestamp if set

  const build_timestamp = typeof window !== 'undefined' && window.BUILD_TIMESTAMP;

  if (build_timestamp) {
    eventProperties = Object.assign(eventProperties, {
      build_timestamp
    });
  } // add optional path params


  if (params) {
    eventProperties = Object.assign(eventProperties, params);
  } // Record all `utm` marketing parameters as event properties on the page view event
  // so we can analyze their performance with our analytics tools


  if (typeof window !== 'undefined' && window.location) {
    const urlParams = new URL(window.location.href).searchParams;
    const utmParamEntries = urlParams && Array.from(urlParams.entries()).filter(_ref => {
      let [key] = _ref;
      return key.startsWith('utm_');
    });
    const utmParams = utmParamEntries ? Object.fromEntries(utmParamEntries) : {};
    eventProperties = Object.assign(eventProperties, utmParams);
  }

  recordTracksEvent('calypso_page_view', eventProperties);
}
function recordTracksPageViewWithPageParams(urlPath, params) {
  const pageViewParams = (0,_page_view_params__WEBPACK_IMPORTED_MODULE_4__/* .getPageViewParams */ .i)(urlPath);
  recordTracksPageView(urlPath, Object.assign(params || {}, pageViewParams));
}

/***/ }),

/***/ 73722:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports recordTrainTracksRender, recordTrainTracksInteract, getNewRailcarId */
/* harmony import */ var _tracks__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(59792);


function recordTrainTracksRender(_ref) {
  let {
    railcarId,
    uiAlgo,
    uiPosition,
    fetchAlgo,
    result,
    query
  } = _ref;
  recordTracksEvent('calypso_traintracks_render', {
    railcar: railcarId,
    ui_algo: uiAlgo,
    ui_position: uiPosition,
    fetch_algo: fetchAlgo,
    rec_result: result,
    fetch_query: query
  });
}
function recordTrainTracksInteract(_ref2) {
  let {
    railcarId,
    action
  } = _ref2;
  recordTracksEvent('calypso_traintracks_interact', {
    railcar: railcarId,
    action
  });
}
function getNewRailcarId() {
  let suffix = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'recommendation';
  return `${uuid().replace(/-/g, '')}-${suffix}`;
}

/***/ }),

/***/ 36209:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "t": function() { return /* binding */ getCurrentUser; },
/* harmony export */   "l": function() { return /* binding */ setCurrentUser; }
/* harmony export */ });
/* harmony import */ var _hash_pii__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(40004);

/**
 * Module variables
 */

let _currentUser;

/**
 * Gets current user.
 *
 * @returns Current user.
 */
function getCurrentUser() {
  return _currentUser;
}
/**
 * Sets current user, (stored in javascript memory).
 *
 * @param currentUser the user data for the current user
 * @returns Current user.
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any

function setCurrentUser(currentUser) {
  if (!currentUser.ID || isNaN(parseInt(currentUser.ID, 10)) || !currentUser.username || !currentUser.email) {
    return; // Invalid user data.
  }

  _currentUser = {
    ID: parseInt(currentUser.ID, 10),
    username: currentUser.username,
    email: currentUser.email,
    hashedPii: {
      ID: (0,_hash_pii__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(currentUser.ID),
      username: (0,_hash_pii__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(currentUser.username.toLowerCase().replace(/\s/g, '')),
      email: (0,_hash_pii__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(currentUser.email.toLowerCase().replace(/\s/g, ''))
    }
  };
  return _currentUser;
}

/***/ }),

/***/ 19358:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Module variables
 */

/* harmony default export */ __webpack_exports__["Z"] = (debug__WEBPACK_IMPORTED_MODULE_0___default()('calypso:analytics'));

/***/ }),

/***/ 21694:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getDoNotTrack; }
/* harmony export */ });
/* harmony import */ var _debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(19358);

/**
 * Whether Do Not Track is enabled in the user's browser.
 *
 * @returns true if Do Not Track is enabled in the user's browser.
 */

function getDoNotTrack() {
  const result = Boolean(typeof window !== 'undefined' && ( // Internet Explorer 11 uses window.doNotTrack rather than navigator.doNotTrack.
  // Safari 7.1.3+ uses window.doNotTrack rather than navigator.doNotTrack.
  // MDN ref: https://developer.mozilla.org/en-US/docs/Web/API/navigator/doNotTrack#Browser_compatibility
  window.doNotTrack === '1' || window.navigator && window.navigator.doNotTrack === '1'));
  (0,_debug__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(`Do Not Track: ${result}`);
  return result;
}

/***/ }),

/***/ 40004:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ hashPii; }
/* harmony export */ });
/* harmony import */ var hash_js_lib_hash_sha_256__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(68032);
/* harmony import */ var hash_js_lib_hash_sha_256__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(hash_js_lib_hash_sha_256__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Hashes users' Personally Identifiable Information using SHA256
 *
 * @param data Data to be hashed
 * @returns SHA256 in hex string format
 */

function hashPii(data) {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  return hash_js_lib_hash_sha_256__WEBPACK_IMPORTED_MODULE_0___default()().update(data.toString()).digest('hex');
}

/***/ }),

/***/ 29770:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
// TODO: Revisit whether it is useful for the Desktop app to override the following properties:
// signup_url, login_url, logout_url and discover_logged_out_redirect_url
const config = {
  env: 'production',
  env_id: 'desktop',
  client_slug: 'desktop',
  readerFollowingSource: 'desktop',
  boom_analytics_key: 'desktop',
  google_recaptcha_site_key: '6LdoXcAUAAAAAM61KvdgP8xwnC19YuzAiOWn5Wtn'
};
const features = {
  desktop: true,
  'desktop-promo': false,
  'sign-in-with-apple': false,
  // Note: there is also a sign-in-with-apple/redirect flag
  // that may/may not be relevant to override for the Desktop app.
  'signup/social': false,
  'login/magic-login': false,
  'bilmur-script': false
};
/* harmony default export */ __webpack_exports__["Z"] = (data => {
  data = Object.assign(data, config);

  if (data.features) {
    data.features = Object.assign(data.features, features);
  }

  if (window.electron && window.electron.features) {
    data.features = Object.assign(data.features, window.electron.features);
  }

  return data;
});

/***/ }),

/***/ 20899:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_k": function() { return /* binding */ isEnabled; }
/* harmony export */ });
/* unused harmony exports isCalypsoLive, enabledFeatures, enable, disable */
/* harmony import */ var _automattic_create_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(90544);
/* harmony import */ var cookie__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(13421);
/* harmony import */ var _desktop__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(29770);




/**
 * Manages config flags for various deployment builds
 *
 * @module config/index
 */
if ('undefined' === typeof window || !window.configData) {
  throw new ReferenceError('No configuration was found: please see packages/calypso-config/README.md for more information');
}

const isDesktop = window.electron !== undefined;
let configData;

if (isDesktop) {
  configData = (0,_desktop__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(window.configData);
} else {
  configData = window.configData;
} // calypso.live matches
// hash-abcd1234.calypso.live matches
// calypso.live.com doesn't match


const CALYPSO_LIVE_REGEX = /^([a-zA-Z0-9-]+\.)?calypso\.live$/; // check if the current browser location is *.calypso.live

function isCalypsoLive() {
  return typeof window !== 'undefined' && CALYPSO_LIVE_REGEX.test(window.location.host);
}

function applyFlags(flagsString, modificationMethod) {
  const flags = flagsString.split(',');
  flags.forEach(flagRaw => {
    const flag = flagRaw.replace(/^[-+]/, '');
    const enabled = !/^-/.test(flagRaw);

    if (configData.features) {
      configData.features[flag] = enabled; // eslint-disable-next-line no-console

      console.log('%cConfig flag %s via %s: %s', 'font-weight: bold;', enabled ? 'enabled' : 'disabled', modificationMethod, flag);
    }
  });
}

const flagEnvironments = ['wpcalypso', 'horizon', 'stage', 'jetpack-cloud-stage'];

if ( false || flagEnvironments.includes(configData.env_id) || isCalypsoLive()) {
  const cookies = cookie__WEBPACK_IMPORTED_MODULE_1__.parse(document.cookie);

  if (cookies.flags) {
    applyFlags(cookies.flags, 'cookie');
  }

  try {
    const session = window.sessionStorage.getItem('flags');

    if (session) {
      applyFlags(session, 'sessionStorage');
    }
  } catch (e) {// in private context, accessing session storage can throw
  }

  const match = document.location.search && document.location.search.match(/[?&]flags=([^&]+)(&|$)/);

  if (match) {
    applyFlags(decodeURIComponent(match[1]), 'URL');
  }
}

const configApi = (0,_automattic_create_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(configData);
/* harmony default export */ __webpack_exports__["ZP"] = (configApi);
const isEnabled = configApi.isEnabled;
const enabledFeatures = configApi.enabledFeatures;
const enable = configApi.enable;
const disable = configApi.disable;

/***/ }),

/***/ 88691:
/***/ (function(__unused_webpack_module, __unused_webpack___webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var core_js_modules_es_typed_array_set_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(65688);
/* harmony import */ var core_js_modules_es_typed_array_set_js__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_es_typed_array_set_js__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var core_js_modules_web_immediate_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(46106);
/* harmony import */ var core_js_modules_web_immediate_js__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(core_js_modules_web_immediate_js__WEBPACK_IMPORTED_MODULE_1__);



/***/ }),

/***/ 21862:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "wJ_": function() { return /* binding */ FEATURE_WP_SUBDOMAIN; },
/* harmony export */   "Ai8": function() { return /* binding */ FEATURE_BLOG_DOMAIN; },
/* harmony export */   "Eb2": function() { return /* binding */ FEATURE_CUSTOM_DOMAIN; },
/* harmony export */   "gqo": function() { return /* binding */ FEATURE_JETPACK_ESSENTIAL; },
/* harmony export */   "c74": function() { return /* binding */ FEATURE_JETPACK_ADVANCED; },
/* harmony export */   "jDM": function() { return /* binding */ FEATURE_FREE_THEMES; },
/* harmony export */   "Zaf": function() { return /* binding */ FEATURE_1GB_STORAGE; },
/* harmony export */   "KlX": function() { return /* binding */ FEATURE_3GB_STORAGE; },
/* harmony export */   "W4b": function() { return /* binding */ FEATURE_6GB_STORAGE; },
/* harmony export */   "E5t": function() { return /* binding */ FEATURE_13GB_STORAGE; },
/* harmony export */   "SLH": function() { return /* binding */ FEATURE_50GB_STORAGE; },
/* harmony export */   "gI6": function() { return /* binding */ FEATURE_200GB_STORAGE; },
/* harmony export */   "U_2": function() { return /* binding */ FEATURE_COMMUNITY_SUPPORT; },
/* harmony export */   "n_S": function() { return /* binding */ FEATURE_EMAIL_SUPPORT; },
/* harmony export */   "dmM": function() { return /* binding */ FEATURE_EMAIL_LIVE_CHAT_SUPPORT_BUSINESS_DAYS; },
/* harmony export */   "IhT": function() { return /* binding */ FEATURE_EMAIL_LIVE_CHAT_SUPPORT_ALL_DAYS; },
/* harmony export */   "vkU": function() { return /* binding */ FEATURE_LIVE_CHAT_SUPPORT_ALL_DAYS; },
/* harmony export */   "N5t": function() { return /* binding */ FEATURE_LIVE_CHAT_SUPPORT_BUSINESS_DAYS; },
/* harmony export */   "HPg": function() { return /* binding */ FEATURE_EMAIL_FORWARDING_EXTENDED_LIMIT; },
/* harmony export */   "J8D": function() { return /* binding */ FEATURE_PREMIUM_SUPPORT; },
/* harmony export */   "oGd": function() { return /* binding */ FEATURE_BASIC_DESIGN; },
/* harmony export */   "MOV": function() { return /* binding */ FEATURE_ADVANCED_DESIGN; },
/* harmony export */   "Vms": function() { return /* binding */ FEATURE_GOOGLE_ANALYTICS; },
/* harmony export */   "$G1": function() { return /* binding */ FEATURE_CLOUDFLARE_ANALYTICS; },
/* harmony export */   "ggN": function() { return /* binding */ FEATURE_GOOGLE_MY_BUSINESS; },
/* harmony export */   "Tez": function() { return /* binding */ FEATURE_LIVE_CHAT_SUPPORT; },
/* harmony export */   "Xk_": function() { return /* binding */ FEATURE_NO_ADS; },
/* harmony export */   "iTE": function() { return /* binding */ FEATURE_VIDEO_UPLOADS; },
/* harmony export */   "QNW": function() { return /* binding */ FEATURE_VIDEO_UPLOADS_JETPACK_PRO; },
/* harmony export */   "XMd": function() { return /* binding */ FEATURE_AUDIO_UPLOADS; },
/* harmony export */   "Ej": function() { return /* binding */ FEATURE_WORDADS_INSTANT; },
/* harmony export */   "Q3C": function() { return /* binding */ FEATURE_NO_BRANDING; },
/* harmony export */   "B2h": function() { return /* binding */ FEATURE_ADVANCED_SEO; },
/* harmony export */   "xjj": function() { return /* binding */ FEATURE_UPLOAD_PLUGINS; },
/* harmony export */   "V09": function() { return /* binding */ FEATURE_INSTALL_PLUGINS; },
/* harmony export */   "Tmz": function() { return /* binding */ FEATURE_UPLOAD_THEMES; },
/* harmony export */   "Zjz": function() { return /* binding */ FEATURE_REPUBLICIZE; },
/* harmony export */   "Vml": function() { return /* binding */ FEATURE_SIMPLE_PAYMENTS; },
/* harmony export */   "Uwp": function() { return /* binding */ FEATURE_ALL_FREE_FEATURES; },
/* harmony export */   "igx": function() { return /* binding */ FEATURE_ALL_FREE_FEATURES_JETPACK; },
/* harmony export */   "VyO": function() { return /* binding */ FEATURE_ALL_PERSONAL_FEATURES; },
/* harmony export */   "Z5U": function() { return /* binding */ FEATURE_ALL_PREMIUM_FEATURES; },
/* harmony export */   "PUy": function() { return /* binding */ FEATURE_ALL_PREMIUM_FEATURES_JETPACK; },
/* harmony export */   "jSq": function() { return /* binding */ FEATURE_ADVANCED_CUSTOMIZATION; },
/* harmony export */   "vEX": function() { return /* binding */ FEATURE_UPLOAD_THEMES_PLUGINS; },
/* harmony export */   "MCU": function() { return /* binding */ FEATURE_FREE_DOMAIN; },
/* harmony export */   "Q1W": function() { return /* binding */ FEATURE_FREE_BLOG_DOMAIN; },
/* harmony export */   "fhe": function() { return /* binding */ FEATURE_EMAIL_SUPPORT_SIGNUP; },
/* harmony export */   "SZ6": function() { return /* binding */ FEATURE_MONETISE; },
/* harmony export */   "Tx8": function() { return /* binding */ FEATURE_EARN_AD; },
/* harmony export */   "sYz": function() { return /* binding */ FEATURE_WP_SUBDOMAIN_SIGNUP; },
/* harmony export */   "ljn": function() { return /* binding */ FEATURE_ADVANCED_SEO_TOOLS; },
/* harmony export */   "vqo": function() { return /* binding */ FEATURE_ADVANCED_SEO_EXPANDED_ABBR; },
/* harmony export */   "R2o": function() { return /* binding */ FEATURE_FREE_THEMES_SIGNUP; },
/* harmony export */   "EBu": function() { return /* binding */ FEATURE_MEMBERSHIPS; },
/* harmony export */   "EDT": function() { return /* binding */ FEATURE_PREMIUM_CONTENT_BLOCK; },
/* harmony export */   "q4V": function() { return /* binding */ FEATURE_HOSTING; },
/* harmony export */   "fp6": function() { return /* binding */ PREMIUM_DESIGN_FOR_STORES; },
/* harmony export */   "cWM": function() { return /* binding */ FEATURE_SFTP_DATABASE; },
/* harmony export */   "_3A": function() { return /* binding */ FEATURE_SITE_BACKUPS_AND_RESTORE; },
/* harmony export */   "QfP": function() { return /* binding */ FEATURE_PREMIUM_THEMES; },
/* harmony export */   "oaT": function() { return /* binding */ FEATURE_FREE_PROFESSIONAL_EMAIL_TRIAL; },
/* harmony export */   "$NZ": function() { return /* binding */ FEATURE_BLANK; },
/* harmony export */   "wwD": function() { return /* binding */ FEATURE_STANDARD_SECURITY_TOOLS; },
/* harmony export */   "rlg": function() { return /* binding */ FEATURE_SITE_STATS; },
/* harmony export */   "F$l": function() { return /* binding */ FEATURE_TRAFFIC_TOOLS; },
/* harmony export */   "gRD": function() { return /* binding */ FEATURE_MANAGE; },
/* harmony export */   "V37": function() { return /* binding */ FEATURE_SPAM_AKISMET_PLUS; },
/* harmony export */   "s1f": function() { return /* binding */ FEATURE_OFFSITE_BACKUP_VAULTPRESS_DAILY; },
/* harmony export */   "_sL": function() { return /* binding */ FEATURE_OFFSITE_BACKUP_VAULTPRESS_REALTIME; },
/* harmony export */   "nsi": function() { return /* binding */ FEATURE_BACKUP_ARCHIVE_30; },
/* harmony export */   "L2_": function() { return /* binding */ FEATURE_BACKUP_ARCHIVE_UNLIMITED; },
/* harmony export */   "$PM": function() { return /* binding */ FEATURE_BACKUP_STORAGE_SPACE_UNLIMITED; },
/* harmony export */   "Rp9": function() { return /* binding */ FEATURE_AUTOMATED_RESTORES; },
/* harmony export */   "$QL": function() { return /* binding */ FEATURE_EASY_SITE_MIGRATION; },
/* harmony export */   "zQV": function() { return /* binding */ FEATURE_MALWARE_SCANNING_DAILY; },
/* harmony export */   "vQ$": function() { return /* binding */ FEATURE_MALWARE_SCANNING_DAILY_AND_ON_DEMAND; },
/* harmony export */   "E30": function() { return /* binding */ FEATURE_ONE_CLICK_THREAT_RESOLUTION; },
/* harmony export */   "m1c": function() { return /* binding */ FEATURE_AUTOMATIC_SECURITY_FIXES; },
/* harmony export */   "wUt": function() { return /* binding */ FEATURE_ACTIVITY_LOG; },
/* harmony export */   "ALM": function() { return /* binding */ FEATURE_FREE_WORDPRESS_THEMES; },
/* harmony export */   "okS": function() { return /* binding */ FEATURE_SEO_PREVIEW_TOOLS; },
/* harmony export */   "$xY": function() { return /* binding */ FEATURE_ACCEPT_PAYMENTS; },
/* harmony export */   "$23": function() { return /* binding */ FEATURE_SHIPPING_CARRIERS; },
/* harmony export */   "Xif": function() { return /* binding */ FEATURE_UNLIMITED_PRODUCTS_SERVICES; },
/* harmony export */   "Do2": function() { return /* binding */ FEATURE_ECOMMERCE_MARKETING; },
/* harmony export */   "$vg": function() { return /* binding */ FEATURE_PREMIUM_CUSTOMIZABE_THEMES; },
/* harmony export */   "kI": function() { return /* binding */ FEATURE_ALL_BUSINESS_FEATURES; },
/* harmony export */   "DwI": function() { return /* binding */ FEATURE_BACKUP_DAILY_V2; },
/* harmony export */   "csF": function() { return /* binding */ FEATURE_BACKUP_REALTIME_V2; },
/* harmony export */   "afj": function() { return /* binding */ FEATURE_PRODUCT_BACKUP_DAILY_V2; },
/* harmony export */   "HpB": function() { return /* binding */ FEATURE_PRODUCT_BACKUP_REALTIME_V2; },
/* harmony export */   "w7L": function() { return /* binding */ FEATURE_SCAN_V2; },
/* harmony export */   "oIe": function() { return /* binding */ FEATURE_PRODUCT_SCAN_DAILY_V2; },
/* harmony export */   "XgZ": function() { return /* binding */ FEATURE_PRODUCT_SCAN_REALTIME_V2; },
/* harmony export */   "CtJ": function() { return /* binding */ FEATURE_ANTISPAM_V2; },
/* harmony export */   "n$d": function() { return /* binding */ FEATURE_ACTIVITY_LOG_1_YEAR_V2; },
/* harmony export */   "dZ$": function() { return /* binding */ FEATURE_PRODUCT_SEARCH_V2; },
/* harmony export */   "X2I": function() { return /* binding */ FEATURE_PLAN_SECURITY_DAILY; },
/* harmony export */   "rDn": function() { return /* binding */ FEATURE_CRM_V2; },
/* harmony export */   "$4": function() { return /* binding */ FEATURE_COLLECT_PAYMENTS_V2; },
/* harmony export */   "V1k": function() { return /* binding */ FEATURE_JETPACK_BACKUP_DAILY; },
/* harmony export */   "TBQ": function() { return /* binding */ FEATURE_JETPACK_BACKUP_DAILY_MONTHLY; },
/* harmony export */   "s4b": function() { return /* binding */ FEATURE_JETPACK_BACKUP_REALTIME; },
/* harmony export */   "TZT": function() { return /* binding */ FEATURE_JETPACK_BACKUP_REALTIME_MONTHLY; },
/* harmony export */   "$pY": function() { return /* binding */ FEATURE_JETPACK_BACKUP_T1_YEARLY; },
/* harmony export */   "mX4": function() { return /* binding */ FEATURE_JETPACK_BACKUP_T1_MONTHLY; },
/* harmony export */   "tS0": function() { return /* binding */ FEATURE_JETPACK_BACKUP_T2_YEARLY; },
/* harmony export */   "L2R": function() { return /* binding */ FEATURE_JETPACK_BACKUP_T2_MONTHLY; },
/* harmony export */   "V1I": function() { return /* binding */ FEATURE_JETPACK_SCAN_DAILY; },
/* harmony export */   "FR0": function() { return /* binding */ FEATURE_JETPACK_SCAN_DAILY_MONTHLY; },
/* harmony export */   "zrQ": function() { return /* binding */ FEATURE_JETPACK_ANTI_SPAM; },
/* harmony export */   "T$h": function() { return /* binding */ FEATURE_JETPACK_ANTI_SPAM_MONTHLY; },
/* harmony export */   "lv3": function() { return /* binding */ FEATURE_JETPACK_SEARCH; },
/* harmony export */   "ewW": function() { return /* binding */ FEATURE_JETPACK_SEARCH_MONTHLY; },
/* harmony export */   "GwK": function() { return /* binding */ FEATURE_JETPACK_VIDEOPRESS; },
/* harmony export */   "w6W": function() { return /* binding */ FEATURE_JETPACK_VIDEOPRESS_MONTHLY; },
/* harmony export */   "liF": function() { return /* binding */ FEATURE_JETPACK_CRM; },
/* harmony export */   "DJ3": function() { return /* binding */ FEATURE_JETPACK_CRM_MONTHLY; },
/* harmony export */   "puh": function() { return /* binding */ FEATURE_JETPACK_1TB_BACKUP_STORAGE; },
/* harmony export */   "xlk": function() { return /* binding */ FEATURE_JETPACK_REAL_TIME_MALWARE_SCANNING; },
/* harmony export */   "VZW": function() { return /* binding */ FEATURE_JETPACK_PRODUCT_BACKUP; },
/* harmony export */   "sQp": function() { return /* binding */ FEATURE_JETPACK_PRODUCT_VIDEOPRESS; },
/* harmony export */   "lYf": function() { return /* binding */ FEATURE_JETPACK_ALL_BACKUP_SECURITY_FEATURES; },
/* harmony export */   "$mN": function() { return /* binding */ FEATURE_P2_3GB_STORAGE; },
/* harmony export */   "JqD": function() { return /* binding */ FEATURE_P2_UNLIMITED_USERS; },
/* harmony export */   "bHF": function() { return /* binding */ FEATURE_P2_UNLIMITED_POSTS_PAGES; },
/* harmony export */   "XZZ": function() { return /* binding */ FEATURE_P2_SIMPLE_SEARCH; },
/* harmony export */   "vje": function() { return /* binding */ FEATURE_P2_CUSTOMIZATION_OPTIONS; },
/* harmony export */   "S_M": function() { return /* binding */ FEATURE_P2_13GB_STORAGE; },
/* harmony export */   "yjN": function() { return /* binding */ FEATURE_P2_ADVANCED_SEARCH; },
/* harmony export */   "iC0": function() { return /* binding */ FEATURE_P2_VIDEO_SHARING; },
/* harmony export */   "rdd": function() { return /* binding */ FEATURE_P2_MORE_FILE_TYPES; },
/* harmony export */   "bJv": function() { return /* binding */ FEATURE_P2_PRIORITY_CHAT_EMAIL_SUPPORT; },
/* harmony export */   "ops": function() { return /* binding */ FEATURE_P2_ACTIVITY_OVERVIEW; },
/* harmony export */   "FiJ": function() { return /* binding */ FEATURE_MANAGED_HOSTING; },
/* harmony export */   "c__": function() { return /* binding */ FEATURE_UNLIMITED_TRAFFIC; },
/* harmony export */   "x_7": function() { return /* binding */ FEATURE_PAYMENT_BLOCKS; },
/* harmony export */   "fDA": function() { return /* binding */ FEATURE_TITAN_EMAIL; },
/* harmony export */   "SsD": function() { return /* binding */ FEATURE_UNLIMITED_ADMINS; },
/* harmony export */   "O05": function() { return /* binding */ FEATURE_WOOCOMMERCE; },
/* harmony export */   "hH1": function() { return /* binding */ FEATURE_SOCIAL_MEDIA_TOOLS; },
/* harmony export */   "Ly9": function() { return /* binding */ WPCOM_FEATURES_ANTISPAM; },
/* harmony export */   "FNU": function() { return /* binding */ WPCOM_FEATURES_ATOMIC; },
/* harmony export */   "DEy": function() { return /* binding */ WPCOM_FEATURES_BACKUPS; },
/* harmony export */   "n26": function() { return /* binding */ WPCOM_FEATURES_INSTALL_PURCHASED_PLUGINS; },
/* harmony export */   "ikw": function() { return /* binding */ WPCOM_FEATURES_SCAN; }
/* harmony export */ });
/* unused harmony exports FEATURE_SET_PRIMARY_CUSTOM_DOMAIN, FEATURE_UNLIMITED_STORAGE, FEATURE_EMAIL_LIVE_CHAT_SUPPORT, FEATURE_SFTP, FEATURE_VIDEO_UPLOADS_JETPACK_PREMIUM, FEATURE_INSTALL_THEMES, FEATURE_PERFORMANCE, FEATURE_ALL_PERSONAL_FEATURES_JETPACK, FEATURE_DONATIONS, FEATURE_RECURRING_PAYMENTS, FEATURE_PREMIUM_CONTENT_CONTAINER, FEATURE_SECURITY_SETTINGS, FEATURE_WOOP, FEATURE_SEARCH, FEATURE_SEARCH_V2, FEATURE_VIDEO_HOSTING_V2, FEATURE_CRM_INTEGRATED_WITH_WORDPRESS, FEATURE_CRM_LEADS_AND_FUNNEL, FEATURE_CRM_PROPOSALS_AND_INVOICES, FEATURE_CRM_TRACK_TRANSACTIONS, FEATURE_CRM_NO_CONTACT_LIMITS, FEATURE_SECURE_STORAGE_V2, FEATURE_ONE_CLICK_RESTORE_V2, FEATURE_ONE_CLICK_FIX_V2, FEATURE_INSTANT_EMAIL_V2, FEATURE_AKISMET_V2, FEATURE_SPAM_BLOCK_V2, FEATURE_SPAM_10K_PER_MONTH, FEATURE_FILTERING_V2, FEATURE_LANGUAGE_SUPPORT_V2, FEATURE_SPELLING_CORRECTION_V2, FEATURE_SUPPORTS_WOOCOMMERCE_V2, FEATURE_JETPACK_VIDEOPRESS_EDITOR, FEATURE_JETPACK_VIDEOPRESS_STORAGE, FEATURE_JETPACK_VIDEOPRESS_UNBRANDED, FEATURE_CLOUD_CRITICAL_CSS, FEATURE_JETPACK_10GB_BACKUP_STORAGE, FEATURE_JETPACK_1_YEAR_ARCHIVE_ACTIVITY_LOG, FEATURE_JETPACK_30_DAY_ARCHIVE_ACTIVITY_LOG, FEATURE_JETPACK_REAL_TIME_CLOUD_BACKUPS, FEATURE_UNLIMITED_USERS, FEATURE_UNLIMITED_POSTS_PAGES, FEATURE_ADDITIONAL_SITES, WPCOM_FEATURES_AKISMET, WPCOM_FEATURES_BACKUPS_RESTORE, WPCOM_FEATURES_CDN, WPCOM_FEATURES_CLASSIC_SEARCH, WPCOM_FEATURES_CLOUDFLARE_CDN, WPCOM_FEATURES_FULL_ACTIVITY_LOG, WPCOM_FEATURES_INSTALL_PLUGINS, WPCOM_FEATURES_INSTANT_SEARCH, WPCOM_FEATURES_LIVE_SUPPORT, WPCOM_FEATURES_MANAGE_PLUGINS, WPCOM_FEATURES_NO_ADVERTS, WPCOM_FEATURES_NO_WPCOM_BRANDING, WPCOM_FEATURES_PREMIUM_THEMES, WPCOM_FEATURES_PRIORITY_SUPPORT, WPCOM_FEATURES_REAL_TIME_BACKUPS, WPCOM_FEATURES_SEO_PREVIEW_TOOLS, WPCOM_FEATURES_UPLOAD_AUDIO_FILES, WPCOM_FEATURES_UPLOAD_PLUGINS, WPCOM_FEATURES_UPLOAD_VIDEO_FILES, WPCOM_FEATURES_VAULTPRESS_BACKUPS, WPCOM_FEATURES_VIDEOPRESS, WPCOM_FEATURES_VIDEOPRESS_UNLIMITED_STORAGE, WPCOM_FEATURES_VIDEO_HOSTING, WPCOM_FEATURES_WORDADS, WPCOM_FEATURES_CUSTOM_DESIGN */
/* harmony import */ var _jetpack__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(90892);

const FEATURE_WP_SUBDOMAIN = 'wordpress-subdomain';
const FEATURE_BLOG_DOMAIN = 'blog-domain';
const FEATURE_CUSTOM_DOMAIN = 'custom-domain';
const FEATURE_SET_PRIMARY_CUSTOM_DOMAIN = 'set-primary-custom-domain';
const FEATURE_JETPACK_ESSENTIAL = 'jetpack-essential';
const FEATURE_JETPACK_ADVANCED = 'jetpack-advanced';
const FEATURE_FREE_THEMES = 'free-themes';
const FEATURE_1GB_STORAGE = '1gb-storage';
const FEATURE_3GB_STORAGE = '3gb-storage';
const FEATURE_6GB_STORAGE = '6gb-storage';
const FEATURE_13GB_STORAGE = '13gb-storage';
const FEATURE_50GB_STORAGE = '50gb-storage';
const FEATURE_200GB_STORAGE = '200gb-storage';
const FEATURE_UNLIMITED_STORAGE = 'unlimited-storage';
const FEATURE_COMMUNITY_SUPPORT = 'community-support';
const FEATURE_EMAIL_SUPPORT = 'email-support';
const FEATURE_EMAIL_LIVE_CHAT_SUPPORT = 'email-live-chat-support';
const FEATURE_EMAIL_LIVE_CHAT_SUPPORT_BUSINESS_DAYS = 'email-live-chat-support-business-days';
const FEATURE_EMAIL_LIVE_CHAT_SUPPORT_ALL_DAYS = 'email-live-chat-support-all-days';
const FEATURE_LIVE_CHAT_SUPPORT_ALL_DAYS = 'live-chat-support-all-days';
const FEATURE_LIVE_CHAT_SUPPORT_BUSINESS_DAYS = 'live-chat-support-business-days';
const FEATURE_EMAIL_FORWARDING_EXTENDED_LIMIT = 'email-forwarding-extended-limit';
const FEATURE_PREMIUM_SUPPORT = 'priority-support';
const FEATURE_BASIC_DESIGN = 'basic-design';
const FEATURE_ADVANCED_DESIGN = 'advanced-design';
const FEATURE_GOOGLE_ANALYTICS = 'google-analytics';
const FEATURE_CLOUDFLARE_ANALYTICS = 'cloudflare-analytics';
const FEATURE_GOOGLE_MY_BUSINESS = 'google-my-business';
const FEATURE_SFTP = 'sftp';
const FEATURE_LIVE_CHAT_SUPPORT = 'live-chat-support';
const FEATURE_NO_ADS = 'no-adverts';
const FEATURE_VIDEO_UPLOADS = 'video-upload';
const FEATURE_VIDEO_UPLOADS_JETPACK_PREMIUM = 'video-upload-jetpack-premium';
const FEATURE_VIDEO_UPLOADS_JETPACK_PRO = 'video-upload-jetpack-pro';
const FEATURE_AUDIO_UPLOADS = 'audio-upload';
const FEATURE_WORDADS_INSTANT = 'wordads-instant';
const FEATURE_NO_BRANDING = 'no-wp-branding';
const FEATURE_ADVANCED_SEO = 'advanced-seo';
const FEATURE_UPLOAD_PLUGINS = 'upload-plugins';
const FEATURE_INSTALL_PLUGINS = 'install-plugins';
const FEATURE_INSTALL_THEMES = 'install-themes';
const FEATURE_UPLOAD_THEMES = 'upload-themes';
const FEATURE_PERFORMANCE = 'performance';
const FEATURE_REPUBLICIZE = 'republicize';
const FEATURE_SIMPLE_PAYMENTS = 'simple-payments';
const FEATURE_ALL_FREE_FEATURES = 'all-free-features';
const FEATURE_ALL_FREE_FEATURES_JETPACK = 'all-free-features-jetpack';
const FEATURE_ALL_PERSONAL_FEATURES = 'all-personal-features';
const FEATURE_ALL_PERSONAL_FEATURES_JETPACK = 'all-personal-features-jetpack';
const FEATURE_ALL_PREMIUM_FEATURES = 'all-premium-features';
const FEATURE_ALL_PREMIUM_FEATURES_JETPACK = 'all-premium-features-jetpack';
const FEATURE_ADVANCED_CUSTOMIZATION = 'advanced-customization';
const FEATURE_UPLOAD_THEMES_PLUGINS = 'upload-themes-and-plugins';
const FEATURE_FREE_DOMAIN = 'free-custom-domain';
const FEATURE_FREE_BLOG_DOMAIN = 'free-blog-domain';
const FEATURE_EMAIL_SUPPORT_SIGNUP = 'email-support-signup';
const FEATURE_MONETISE = 'monetise-your-site';
const FEATURE_EARN_AD = 'earn-ad-revenue';
const FEATURE_WP_SUBDOMAIN_SIGNUP = 'wordpress-subdomain-signup';
const FEATURE_ADVANCED_SEO_TOOLS = 'advanced-seo-tools';
const FEATURE_ADVANCED_SEO_EXPANDED_ABBR = 'advanced-seo-expanded-abbreviation';
const FEATURE_FREE_THEMES_SIGNUP = 'free-themes-signup';
const FEATURE_MEMBERSHIPS = 'memberships';
const FEATURE_DONATIONS = 'donations';
const FEATURE_RECURRING_PAYMENTS = 'recurring-payments'; // This is a legacy alias, FEATURE_PREMIUM_CONTENT_CONTAINER should be used instead.

const FEATURE_PREMIUM_CONTENT_BLOCK = 'premium-content-block';
const FEATURE_PREMIUM_CONTENT_CONTAINER = 'premium-content/container';
const FEATURE_HOSTING = 'hosting';
const PREMIUM_DESIGN_FOR_STORES = 'premium-design-for-stores';
const FEATURE_SFTP_DATABASE = 'sftp-and-database-access';
const FEATURE_SITE_BACKUPS_AND_RESTORE = 'site-backups-and-restore';
const FEATURE_SECURITY_SETTINGS = 'security-settings';
const FEATURE_WOOP = 'woop';
const FEATURE_PREMIUM_THEMES = 'unlimited-premium-themes';
const FEATURE_FREE_PROFESSIONAL_EMAIL_TRIAL = 'free-professional-email-trial'; // Jetpack features constants

const FEATURE_BLANK = 'blank-feature';
const FEATURE_STANDARD_SECURITY_TOOLS = 'standard-security-tools';
const FEATURE_SITE_STATS = 'site-stats';
const FEATURE_TRAFFIC_TOOLS = 'traffic-tools';
const FEATURE_MANAGE = 'jetpack-manage';
const FEATURE_SPAM_AKISMET_PLUS = 'spam-akismet-plus';
const FEATURE_OFFSITE_BACKUP_VAULTPRESS_DAILY = 'offsite-backup-vaultpress-daily';
const FEATURE_OFFSITE_BACKUP_VAULTPRESS_REALTIME = 'offsite-backup-vaultpress-realtime';
const FEATURE_BACKUP_ARCHIVE_30 = 'backup-archive-30';
const FEATURE_BACKUP_ARCHIVE_UNLIMITED = 'backup-archive-unlimited';
const FEATURE_BACKUP_STORAGE_SPACE_UNLIMITED = 'backup-storage-space-unlimited';
const FEATURE_AUTOMATED_RESTORES = 'automated-restores';
const FEATURE_EASY_SITE_MIGRATION = 'easy-site-migration';
const FEATURE_MALWARE_SCANNING_DAILY = 'malware-scanning-daily';
const FEATURE_MALWARE_SCANNING_DAILY_AND_ON_DEMAND = 'malware-scanning-daily-and-on-demand';
const FEATURE_ONE_CLICK_THREAT_RESOLUTION = 'one-click-threat-resolution';
const FEATURE_AUTOMATIC_SECURITY_FIXES = 'automatic-security-fixes';
const FEATURE_ACTIVITY_LOG = 'site-activity-log';
const FEATURE_FREE_WORDPRESS_THEMES = 'free-wordpress-themes';
const FEATURE_SEO_PREVIEW_TOOLS = 'seo-preview-tools';
const FEATURE_SEARCH = 'search';
const FEATURE_ACCEPT_PAYMENTS = 'accept-payments';
const FEATURE_SHIPPING_CARRIERS = 'shipping-carriers';
const FEATURE_UNLIMITED_PRODUCTS_SERVICES = 'unlimited-products-service';
const FEATURE_ECOMMERCE_MARKETING = 'ecommerce-marketing';
const FEATURE_PREMIUM_CUSTOMIZABE_THEMES = 'premium-customizable-themes';
const FEATURE_ALL_BUSINESS_FEATURES = 'all-business-features';
const FEATURE_BACKUP_DAILY_V2 = 'backup-daily-v2';
const FEATURE_BACKUP_REALTIME_V2 = 'backup-realtime-v2';
const FEATURE_PRODUCT_BACKUP_DAILY_V2 = 'product-backup-daily-v2';
const FEATURE_PRODUCT_BACKUP_REALTIME_V2 = 'product-backup-realtime-v2';
const FEATURE_SCAN_V2 = 'scan-v2';
const FEATURE_PRODUCT_SCAN_DAILY_V2 = 'product-scan-daily-v2';
const FEATURE_PRODUCT_SCAN_REALTIME_V2 = 'product-scan-realtime-v2';
const FEATURE_ANTISPAM_V2 = 'antispam-v2';
const FEATURE_ACTIVITY_LOG_1_YEAR_V2 = 'activity-log-1-year-v2';
const FEATURE_SEARCH_V2 = 'search-v2';
const FEATURE_PRODUCT_SEARCH_V2 = 'product-search-v2';
const FEATURE_PLAN_SECURITY_DAILY = 'security-daily';
const FEATURE_VIDEO_HOSTING_V2 = 'video-hosting-v2';
const FEATURE_CRM_V2 = 'crm-v2';
const FEATURE_CRM_INTEGRATED_WITH_WORDPRESS = 'crm-integrated-with-wordpress';
const FEATURE_CRM_LEADS_AND_FUNNEL = 'crm-leads-and-funnel';
const FEATURE_CRM_PROPOSALS_AND_INVOICES = 'crm-proposals-and-invoices';
const FEATURE_CRM_TRACK_TRANSACTIONS = 'crm-track-transactions';
const FEATURE_CRM_NO_CONTACT_LIMITS = 'crm-no-contact-limits';
const FEATURE_COLLECT_PAYMENTS_V2 = 'collect-payments-v2';
const FEATURE_SECURE_STORAGE_V2 = 'secure-storage-v2';
const FEATURE_ONE_CLICK_RESTORE_V2 = 'one-click-restore-v2';
const FEATURE_ONE_CLICK_FIX_V2 = 'one-click-fix-v2';
const FEATURE_INSTANT_EMAIL_V2 = 'instant-email-v2';
const FEATURE_AKISMET_V2 = 'akismet-v2';
const FEATURE_SPAM_BLOCK_V2 = 'spam-block-v2';
const FEATURE_SPAM_10K_PER_MONTH = 'spam-block-10k';
const FEATURE_FILTERING_V2 = 'filtering-v2';
const FEATURE_LANGUAGE_SUPPORT_V2 = 'language-support-v2';
const FEATURE_SPELLING_CORRECTION_V2 = 'spelling-correction-v2';
const FEATURE_SUPPORTS_WOOCOMMERCE_V2 = 'supports-woocommerce-v2';
const FEATURE_JETPACK_BACKUP_DAILY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_BACKUP_DAILY */ .K$;
const FEATURE_JETPACK_BACKUP_DAILY_MONTHLY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_BACKUP_DAILY_MONTHLY */ .Sj;
const FEATURE_JETPACK_BACKUP_REALTIME = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_BACKUP_REALTIME */ .JD;
const FEATURE_JETPACK_BACKUP_REALTIME_MONTHLY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_BACKUP_REALTIME_MONTHLY */ .AY;
const FEATURE_JETPACK_BACKUP_T1_YEARLY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_BACKUP_T1_YEARLY */ .oe;
const FEATURE_JETPACK_BACKUP_T1_MONTHLY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_BACKUP_T1_MONTHLY */ .rx;
const FEATURE_JETPACK_BACKUP_T2_YEARLY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_BACKUP_T2_YEARLY */ .EI;
const FEATURE_JETPACK_BACKUP_T2_MONTHLY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_BACKUP_T2_MONTHLY */ .uL;
const FEATURE_JETPACK_SCAN_DAILY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_SCAN */ .pE;
const FEATURE_JETPACK_SCAN_DAILY_MONTHLY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_SCAN_MONTHLY */ .sY;
const FEATURE_JETPACK_ANTI_SPAM = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_ANTI_SPAM */ .Sm;
const FEATURE_JETPACK_ANTI_SPAM_MONTHLY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_ANTI_SPAM_MONTHLY */ .PF;
const FEATURE_JETPACK_SEARCH = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_SEARCH */ .DH;
const FEATURE_JETPACK_SEARCH_MONTHLY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_SEARCH_MONTHLY */ .XG;
const FEATURE_JETPACK_VIDEOPRESS = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_VIDEOPRESS */ .nN;
const FEATURE_JETPACK_VIDEOPRESS_MONTHLY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_VIDEOPRESS_MONTHLY */ .AK;
const FEATURE_JETPACK_VIDEOPRESS_EDITOR = 'jetpack-videopress-editor';
const FEATURE_JETPACK_VIDEOPRESS_STORAGE = 'jetpack-videopress-storage';
const FEATURE_JETPACK_VIDEOPRESS_UNBRANDED = 'jetpack-videopress-unbranded';
const FEATURE_JETPACK_CRM = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_CRM */ .Ve;
const FEATURE_JETPACK_CRM_MONTHLY = _jetpack__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_JETPACK_CRM_MONTHLY */ .vM;
const FEATURE_CLOUD_CRITICAL_CSS = 'cloud-critical-css'; // Jetpack tiered product features

const FEATURE_JETPACK_10GB_BACKUP_STORAGE = 'jetpack-10gb-backup-storage';
const FEATURE_JETPACK_1TB_BACKUP_STORAGE = 'jetpack-1tb-backup-storage';
const FEATURE_JETPACK_1_YEAR_ARCHIVE_ACTIVITY_LOG = 'jetpack-1-year-archive-activity-log';
const FEATURE_JETPACK_30_DAY_ARCHIVE_ACTIVITY_LOG = 'jetpack-30-day-archive-activity-log';
const FEATURE_JETPACK_REAL_TIME_CLOUD_BACKUPS = 'jetpack-real-time-cloud-backups';
const FEATURE_JETPACK_REAL_TIME_MALWARE_SCANNING = 'jetpack-real-time-malware-scanning';
const FEATURE_JETPACK_PRODUCT_BACKUP = 'jetpack-product-backup';
const FEATURE_JETPACK_PRODUCT_VIDEOPRESS = 'jetpack-product-videopress';
const FEATURE_JETPACK_ALL_BACKUP_SECURITY_FEATURES = 'jetpack-all-backup-security-features'; // P2 project features

const FEATURE_P2_3GB_STORAGE = 'p2-3gb-storage';
const FEATURE_P2_UNLIMITED_USERS = 'p2-unlimited-users';
const FEATURE_P2_UNLIMITED_POSTS_PAGES = 'p2-unlimited-posts-pages';
const FEATURE_P2_SIMPLE_SEARCH = 'p2-simple-search';
const FEATURE_P2_CUSTOMIZATION_OPTIONS = 'p2-customization-options';
const FEATURE_P2_13GB_STORAGE = 'p2-13gb-storage';
const FEATURE_P2_ADVANCED_SEARCH = 'p2-advanced-search';
const FEATURE_P2_VIDEO_SHARING = 'p2-video-sharing';
const FEATURE_P2_MORE_FILE_TYPES = 'p2-more-file-types';
const FEATURE_P2_PRIORITY_CHAT_EMAIL_SUPPORT = 'p2-priority-chat-email-support';
const FEATURE_P2_ACTIVITY_OVERVIEW = 'p2-activity-overview'; // New features Flexible and Pro plans introduced.

const FEATURE_MANAGED_HOSTING = 'managed-hosting';
const FEATURE_UNLIMITED_TRAFFIC = 'unlimited-traffic';
const FEATURE_UNLIMITED_USERS = 'unlimited-users';
const FEATURE_UNLIMITED_POSTS_PAGES = 'unlimited-posts-pages';
const FEATURE_PAYMENT_BLOCKS = 'payment-blocks';
const FEATURE_TITAN_EMAIL = 'titan-email';
const FEATURE_UNLIMITED_ADMINS = 'unlimited-admins';
const FEATURE_ADDITIONAL_SITES = 'additional-sites';
const FEATURE_WOOCOMMERCE = 'woocommerce';
const FEATURE_SOCIAL_MEDIA_TOOLS = 'social-media-tools'; // From class-wpcom-features.php in WPCOM

const WPCOM_FEATURES_AKISMET = 'akismet';
const WPCOM_FEATURES_ANTISPAM = 'antispam';
const WPCOM_FEATURES_ATOMIC = 'atomic';
const WPCOM_FEATURES_BACKUPS = 'backups';
const WPCOM_FEATURES_BACKUPS_RESTORE = 'restore';
const WPCOM_FEATURES_CDN = 'cdn';
const WPCOM_FEATURES_CLASSIC_SEARCH = 'search';
const WPCOM_FEATURES_CLOUDFLARE_CDN = 'cloudflare-cdn';
const WPCOM_FEATURES_FULL_ACTIVITY_LOG = 'full-activity-log';
const WPCOM_FEATURES_INSTALL_PLUGINS = 'install-plugins';
const WPCOM_FEATURES_INSTALL_PURCHASED_PLUGINS = 'install-purchased-plugins';
const WPCOM_FEATURES_INSTANT_SEARCH = 'instant-search';
const WPCOM_FEATURES_LIVE_SUPPORT = 'live_support';
const WPCOM_FEATURES_MANAGE_PLUGINS = 'manage-plugins';
const WPCOM_FEATURES_NO_ADVERTS = 'no-adverts/no-adverts.php';
const WPCOM_FEATURES_NO_WPCOM_BRANDING = 'no-wpcom-branding';
const WPCOM_FEATURES_PREMIUM_THEMES = 'premium-themes';
const WPCOM_FEATURES_PRIORITY_SUPPORT = 'priority_support';
const WPCOM_FEATURES_REAL_TIME_BACKUPS = 'real-time-backups';
const WPCOM_FEATURES_SCAN = 'scan';
const WPCOM_FEATURES_SEO_PREVIEW_TOOLS = 'seo-preview-tools';
const WPCOM_FEATURES_UPLOAD_AUDIO_FILES = 'upload-audio-files';
const WPCOM_FEATURES_UPLOAD_PLUGINS = 'upload-plugins';
const WPCOM_FEATURES_UPLOAD_VIDEO_FILES = 'upload-video-files';
const WPCOM_FEATURES_VAULTPRESS_BACKUPS = 'vaultpress-backups';
const WPCOM_FEATURES_VIDEOPRESS = 'videopress';
const WPCOM_FEATURES_VIDEOPRESS_UNLIMITED_STORAGE = 'videopress-unlimited-storage';
const WPCOM_FEATURES_VIDEO_HOSTING = 'video-hosting';
const WPCOM_FEATURES_WORDADS = 'wordads';
const WPCOM_FEATURES_CUSTOM_DESIGN = 'custom-design';

/***/ }),

/***/ 25432:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "tb": function() { return /* binding */ GSUITE_BASIC_SLUG; },
/* harmony export */   "y6": function() { return /* binding */ GSUITE_BUSINESS_SLUG; }
/* harmony export */ });
/* unused harmony exports GOOGLE_WORKSPACE_BUSINESS_STARTER_MONTHLY, GOOGLE_WORKSPACE_BUSINESS_STARTER_YEARLY, GSUITE_EXTRA_LICENSE_SLUG */
const GOOGLE_WORKSPACE_BUSINESS_STARTER_MONTHLY = 'wp_google_workspace_business_starter_monthly';
const GOOGLE_WORKSPACE_BUSINESS_STARTER_YEARLY = 'wp_google_workspace_business_starter_yearly';
const GSUITE_BASIC_SLUG = 'gapps';
const GSUITE_BUSINESS_SLUG = 'gapps_unlimited';
const GSUITE_EXTRA_LICENSE_SLUG = 'gapps_extra_license';

/***/ }),

/***/ 90892:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "mk": function() { return /* binding */ GROUP_JETPACK; },
/* harmony export */   "oe": function() { return /* binding */ PRODUCT_JETPACK_BACKUP_T1_YEARLY; },
/* harmony export */   "rx": function() { return /* binding */ PRODUCT_JETPACK_BACKUP_T1_MONTHLY; },
/* harmony export */   "EI": function() { return /* binding */ PRODUCT_JETPACK_BACKUP_T2_YEARLY; },
/* harmony export */   "uL": function() { return /* binding */ PRODUCT_JETPACK_BACKUP_T2_MONTHLY; },
/* harmony export */   "pE": function() { return /* binding */ PRODUCT_JETPACK_SCAN; },
/* harmony export */   "sY": function() { return /* binding */ PRODUCT_JETPACK_SCAN_MONTHLY; },
/* harmony export */   "Sm": function() { return /* binding */ PRODUCT_JETPACK_ANTI_SPAM; },
/* harmony export */   "PF": function() { return /* binding */ PRODUCT_JETPACK_ANTI_SPAM_MONTHLY; },
/* harmony export */   "DH": function() { return /* binding */ PRODUCT_JETPACK_SEARCH; },
/* harmony export */   "XG": function() { return /* binding */ PRODUCT_JETPACK_SEARCH_MONTHLY; },
/* harmony export */   "Ve": function() { return /* binding */ PRODUCT_JETPACK_CRM; },
/* harmony export */   "vM": function() { return /* binding */ PRODUCT_JETPACK_CRM_MONTHLY; },
/* harmony export */   "nN": function() { return /* binding */ PRODUCT_JETPACK_VIDEOPRESS; },
/* harmony export */   "AK": function() { return /* binding */ PRODUCT_JETPACK_VIDEOPRESS_MONTHLY; },
/* harmony export */   "K$": function() { return /* binding */ PRODUCT_JETPACK_BACKUP_DAILY; },
/* harmony export */   "JD": function() { return /* binding */ PRODUCT_JETPACK_BACKUP_REALTIME; },
/* harmony export */   "Sj": function() { return /* binding */ PRODUCT_JETPACK_BACKUP_DAILY_MONTHLY; },
/* harmony export */   "AY": function() { return /* binding */ PRODUCT_JETPACK_BACKUP_REALTIME_MONTHLY; },
/* harmony export */   "lj": function() { return /* binding */ PLAN_JETPACK_FREE; },
/* harmony export */   "ap": function() { return /* binding */ PLAN_JETPACK_PERSONAL; },
/* harmony export */   "ns": function() { return /* binding */ PLAN_JETPACK_PERSONAL_MONTHLY; },
/* harmony export */   "Xz": function() { return /* binding */ PLAN_JETPACK_PREMIUM; },
/* harmony export */   "p2": function() { return /* binding */ PLAN_JETPACK_PREMIUM_MONTHLY; },
/* harmony export */   "NJ": function() { return /* binding */ PLAN_JETPACK_BUSINESS; },
/* harmony export */   "yY": function() { return /* binding */ PLAN_JETPACK_BUSINESS_MONTHLY; },
/* harmony export */   "Et": function() { return /* binding */ PLAN_JETPACK_SECURITY_T1_YEARLY; },
/* harmony export */   "w2": function() { return /* binding */ PLAN_JETPACK_SECURITY_T1_MONTHLY; },
/* harmony export */   "s1": function() { return /* binding */ PLAN_JETPACK_SECURITY_T2_YEARLY; },
/* harmony export */   "aS": function() { return /* binding */ PLAN_JETPACK_SECURITY_T2_MONTHLY; },
/* harmony export */   "th": function() { return /* binding */ PLAN_JETPACK_COMPLETE; },
/* harmony export */   "JX": function() { return /* binding */ PLAN_JETPACK_COMPLETE_MONTHLY; },
/* harmony export */   "Vl": function() { return /* binding */ PLAN_JETPACK_SECURITY_DAILY; },
/* harmony export */   "Dl": function() { return /* binding */ PLAN_JETPACK_SECURITY_DAILY_MONTHLY; },
/* harmony export */   "jI": function() { return /* binding */ PLAN_JETPACK_SECURITY_REALTIME; },
/* harmony export */   "G$": function() { return /* binding */ PLAN_JETPACK_SECURITY_REALTIME_MONTHLY; },
/* harmony export */   "$U": function() { return /* binding */ JETPACK_LEGACY_PLANS; },
/* harmony export */   "jj": function() { return /* binding */ JETPACK_SECURITY_PLANS; }
/* harmony export */ });
/* unused harmony exports PRODUCT_JETPACK_BOOST, PRODUCT_JETPACK_BOOST_MONTHLY, PRODUCT_JETPACK_BACKUP, PRODUCT_JETPACK_SCAN_REALTIME, PRODUCT_JETPACK_SCAN_REALTIME_MONTHLY, PRODUCT_JETPACK_CRM_FREE, PRODUCT_JETPACK_CRM_FREE_MONTHLY, JETPACK_BACKUP_PRODUCTS_YEARLY, JETPACK_BACKUP_PRODUCTS_MONTHLY, JETPACK_BACKUP_PRODUCTS, JETPACK_BACKUP_T1_PRODUCTS, JETPACK_BOOST_PRODUCTS, JETPACK_SCAN_PRODUCTS, JETPACK_ANTI_SPAM_PRODUCTS, JETPACK_SEARCH_PRODUCTS, JETPACK_CRM_PRODUCTS, JETPACK_CRM_FREE_PRODUCTS, JETPACK_VIDEOPRESS_PRODUCTS, JETPACK_PRODUCTS_LIST, JETPACK_PRODUCTS_BY_TERM, JETPACK_PRODUCT_PRICE_MATRIX, JETPACK_PRODUCT_UPGRADE_MAP, JETPACK_LEGACY_PLANS_MAX_PLUGIN_VERSION, JETPACK_SECURITY_T1_PLANS, JETPACK_COMPLETE_PLANS, JETPACK_MONTHLY_PLANS, JETPACK_RESET_PLANS, JETPACK_RESET_PLANS_BY_TERM, JETPACK_PLANS, JETPACK_PLANS_BY_TERM, BEST_VALUE_PLANS, JETPACK_PLAN_UPGRADE_MAP, JETPACK_SECURITY_CATEGORY, JETPACK_PERFORMANCE_CATEGORY, JETPACK_GROWTH_CATEGORY, JETPACK_PRODUCT_CATEGORIES, JETPACK_BACKUP_PRODUCT_LANDING_PAGE_URL, JETPACK_SEARCH_PRODUCT_LANDING_PAGE_URL, JETPACK_SCAN_PRODUCT_LANDING_PAGE_URL, JETPACK_ANTI_SPAM_PRODUCT_LANDING_PAGE_URL, JETPACK_REDIRECT_CHECKOUT_TO_WPADMIN, JETPACK_REDIRECT_URL */
/* harmony import */ var _wpcom__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(77904);

const GROUP_JETPACK = 'GROUP_JETPACK'; // Products

const PRODUCT_JETPACK_BOOST = 'jetpack_boost_yearly';
const PRODUCT_JETPACK_BOOST_MONTHLY = 'jetpack_boost_monthly';
const PRODUCT_JETPACK_BACKUP = 'jetpack_backup';
const PRODUCT_JETPACK_BACKUP_T1_YEARLY = 'jetpack_backup_t1_yearly';
const PRODUCT_JETPACK_BACKUP_T1_MONTHLY = 'jetpack_backup_t1_monthly';
const PRODUCT_JETPACK_BACKUP_T2_YEARLY = 'jetpack_backup_t2_yearly';
const PRODUCT_JETPACK_BACKUP_T2_MONTHLY = 'jetpack_backup_t2_monthly';
const PRODUCT_JETPACK_SCAN = 'jetpack_scan';
const PRODUCT_JETPACK_SCAN_MONTHLY = 'jetpack_scan_monthly';
const PRODUCT_JETPACK_SCAN_REALTIME = 'jetpack_scan_realtime';
const PRODUCT_JETPACK_SCAN_REALTIME_MONTHLY = 'jetpack_scan_realtime_monthly';
const PRODUCT_JETPACK_ANTI_SPAM = 'jetpack_anti_spam';
const PRODUCT_JETPACK_ANTI_SPAM_MONTHLY = 'jetpack_anti_spam_monthly';
const PRODUCT_JETPACK_SEARCH = 'jetpack_search';
const PRODUCT_JETPACK_SEARCH_MONTHLY = 'jetpack_search_monthly';
const PRODUCT_JETPACK_CRM = 'jetpack_crm';
const PRODUCT_JETPACK_CRM_MONTHLY = 'jetpack_crm_monthly';
const PRODUCT_JETPACK_CRM_FREE = 'jetpack_crm_free';
const PRODUCT_JETPACK_CRM_FREE_MONTHLY = 'jetpack_crm_free_monthly';
const PRODUCT_JETPACK_VIDEOPRESS = 'jetpack_videopress';
const PRODUCT_JETPACK_VIDEOPRESS_MONTHLY = 'jetpack_videopress_monthly'; // Legacy Products

const PRODUCT_JETPACK_BACKUP_DAILY = 'jetpack_backup_daily';
const PRODUCT_JETPACK_BACKUP_REALTIME = 'jetpack_backup_realtime';
const PRODUCT_JETPACK_BACKUP_DAILY_MONTHLY = 'jetpack_backup_daily_monthly';
const PRODUCT_JETPACK_BACKUP_REALTIME_MONTHLY = 'jetpack_backup_realtime_monthly'; // Backup

const JETPACK_BACKUP_PRODUCTS_YEARLY = [PRODUCT_JETPACK_BACKUP_DAILY, PRODUCT_JETPACK_BACKUP_REALTIME, PRODUCT_JETPACK_BACKUP_T1_YEARLY, PRODUCT_JETPACK_BACKUP_T2_YEARLY];
const JETPACK_BACKUP_PRODUCTS_MONTHLY = [PRODUCT_JETPACK_BACKUP_DAILY_MONTHLY, PRODUCT_JETPACK_BACKUP_REALTIME_MONTHLY, PRODUCT_JETPACK_BACKUP_T1_MONTHLY, PRODUCT_JETPACK_BACKUP_T2_MONTHLY];
const JETPACK_BACKUP_PRODUCTS = [...JETPACK_BACKUP_PRODUCTS_YEARLY, ...JETPACK_BACKUP_PRODUCTS_MONTHLY];
const JETPACK_BACKUP_T1_PRODUCTS = [PRODUCT_JETPACK_BACKUP_T1_MONTHLY, PRODUCT_JETPACK_BACKUP_T1_YEARLY]; // Boost

const JETPACK_BOOST_PRODUCTS = [PRODUCT_JETPACK_BOOST, PRODUCT_JETPACK_BOOST_MONTHLY]; // Scan

const JETPACK_SCAN_PRODUCTS = [PRODUCT_JETPACK_SCAN, PRODUCT_JETPACK_SCAN_MONTHLY, PRODUCT_JETPACK_SCAN_REALTIME, PRODUCT_JETPACK_SCAN_REALTIME_MONTHLY]; // Anti-spam

const JETPACK_ANTI_SPAM_PRODUCTS = [PRODUCT_JETPACK_ANTI_SPAM, PRODUCT_JETPACK_ANTI_SPAM_MONTHLY]; // Search

const JETPACK_SEARCH_PRODUCTS = [PRODUCT_JETPACK_SEARCH, PRODUCT_JETPACK_SEARCH_MONTHLY, _wpcom__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_WPCOM_SEARCH */ .AY, _wpcom__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_WPCOM_SEARCH_MONTHLY */ .MY]; // CRM

const JETPACK_CRM_PRODUCTS = [PRODUCT_JETPACK_CRM, PRODUCT_JETPACK_CRM_MONTHLY];
const JETPACK_CRM_FREE_PRODUCTS = [PRODUCT_JETPACK_CRM_FREE, PRODUCT_JETPACK_CRM_FREE_MONTHLY]; // VideoPress

const JETPACK_VIDEOPRESS_PRODUCTS = [PRODUCT_JETPACK_VIDEOPRESS, PRODUCT_JETPACK_VIDEOPRESS_MONTHLY];
const JETPACK_PRODUCTS_LIST = [...JETPACK_BACKUP_PRODUCTS, ...JETPACK_BOOST_PRODUCTS, ...JETPACK_SCAN_PRODUCTS, ...JETPACK_ANTI_SPAM_PRODUCTS, ...JETPACK_SEARCH_PRODUCTS, ...JETPACK_VIDEOPRESS_PRODUCTS];
const JETPACK_PRODUCTS_BY_TERM = [{
  yearly: PRODUCT_JETPACK_BACKUP_DAILY,
  monthly: PRODUCT_JETPACK_BACKUP_DAILY_MONTHLY
}, {
  yearly: PRODUCT_JETPACK_BACKUP_REALTIME,
  monthly: PRODUCT_JETPACK_BACKUP_REALTIME_MONTHLY
}, {
  yearly: PRODUCT_JETPACK_SEARCH,
  monthly: PRODUCT_JETPACK_SEARCH_MONTHLY
}, {
  yearly: _wpcom__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_WPCOM_SEARCH */ .AY,
  monthly: _wpcom__WEBPACK_IMPORTED_MODULE_0__/* .PRODUCT_WPCOM_SEARCH_MONTHLY */ .MY
}, {
  yearly: PRODUCT_JETPACK_SCAN,
  monthly: PRODUCT_JETPACK_SCAN_MONTHLY
}, {
  yearly: PRODUCT_JETPACK_ANTI_SPAM,
  monthly: PRODUCT_JETPACK_ANTI_SPAM_MONTHLY
}, {
  yearly: PRODUCT_JETPACK_CRM,
  monthly: PRODUCT_JETPACK_CRM_MONTHLY
}, {
  yearly: PRODUCT_JETPACK_CRM_FREE,
  monthly: PRODUCT_JETPACK_CRM_FREE_MONTHLY
}, {
  yearly: PRODUCT_JETPACK_BACKUP_T1_YEARLY,
  monthly: PRODUCT_JETPACK_BACKUP_T1_MONTHLY
}, {
  yearly: PRODUCT_JETPACK_BACKUP_T2_YEARLY,
  monthly: PRODUCT_JETPACK_BACKUP_T2_MONTHLY
}, {
  yearly: PRODUCT_JETPACK_VIDEOPRESS,
  monthly: PRODUCT_JETPACK_VIDEOPRESS_MONTHLY
}, {
  yearly: PRODUCT_JETPACK_BOOST,
  monthly: PRODUCT_JETPACK_BOOST_MONTHLY
}];
const JETPACK_PRODUCT_PRICE_MATRIX = {
  [PRODUCT_JETPACK_BACKUP_DAILY]: {
    relatedProduct: PRODUCT_JETPACK_BACKUP_DAILY_MONTHLY,
    ratio: 12
  },
  [PRODUCT_JETPACK_BACKUP_REALTIME]: {
    relatedProduct: PRODUCT_JETPACK_BACKUP_REALTIME_MONTHLY,
    ratio: 12
  },
  [PRODUCT_JETPACK_BACKUP_T1_YEARLY]: {
    relatedProduct: PRODUCT_JETPACK_BACKUP_T1_MONTHLY,
    ratio: 12
  },
  [PRODUCT_JETPACK_BACKUP_T2_YEARLY]: {
    relatedProduct: PRODUCT_JETPACK_BACKUP_T2_MONTHLY,
    ratio: 12
  },
  [PRODUCT_JETPACK_BOOST]: {
    relatedProduct: PRODUCT_JETPACK_BOOST_MONTHLY,
    ratio: 12
  },
  [PRODUCT_JETPACK_SEARCH]: {
    relatedProduct: PRODUCT_JETPACK_SEARCH_MONTHLY,
    ratio: 12
  },
  [PRODUCT_JETPACK_SCAN]: {
    relatedProduct: PRODUCT_JETPACK_SCAN_MONTHLY,
    ratio: 12
  },
  [PRODUCT_JETPACK_ANTI_SPAM]: {
    relatedProduct: PRODUCT_JETPACK_ANTI_SPAM_MONTHLY,
    ratio: 12
  },
  [PRODUCT_JETPACK_VIDEOPRESS]: {
    relatedProduct: PRODUCT_JETPACK_VIDEOPRESS_MONTHLY,
    ratio: 12
  }
}; // Key/value: Superseding product/Products superseded (yearly terms)

const JETPACK_PRODUCT_UPGRADE_MAP = {
  [PRODUCT_JETPACK_BACKUP_T2_YEARLY]: [PRODUCT_JETPACK_BACKUP_T1_YEARLY],
  [PRODUCT_JETPACK_BACKUP_REALTIME]: [PRODUCT_JETPACK_BACKUP_DAILY]
}; // Plans

const PLAN_JETPACK_FREE = 'jetpack_free';
const PLAN_JETPACK_PERSONAL = 'jetpack_personal';
const PLAN_JETPACK_PERSONAL_MONTHLY = 'jetpack_personal_monthly';
const PLAN_JETPACK_PREMIUM = 'jetpack_premium';
const PLAN_JETPACK_PREMIUM_MONTHLY = 'jetpack_premium_monthly';
const PLAN_JETPACK_BUSINESS = 'jetpack_business';
const PLAN_JETPACK_BUSINESS_MONTHLY = 'jetpack_business_monthly';
const PLAN_JETPACK_SECURITY_T1_YEARLY = 'jetpack_security_t1_yearly';
const PLAN_JETPACK_SECURITY_T1_MONTHLY = 'jetpack_security_t1_monthly';
const PLAN_JETPACK_SECURITY_T2_YEARLY = 'jetpack_security_t2_yearly';
const PLAN_JETPACK_SECURITY_T2_MONTHLY = 'jetpack_security_t2_monthly';
const PLAN_JETPACK_COMPLETE = 'jetpack_complete';
const PLAN_JETPACK_COMPLETE_MONTHLY = 'jetpack_complete_monthly'; // Legacy Security Plans

const PLAN_JETPACK_SECURITY_DAILY = 'jetpack_security_daily';
const PLAN_JETPACK_SECURITY_DAILY_MONTHLY = 'jetpack_security_daily_monthly';
const PLAN_JETPACK_SECURITY_REALTIME = 'jetpack_security_realtime';
const PLAN_JETPACK_SECURITY_REALTIME_MONTHLY = 'jetpack_security_realtime_monthly'; // Legacy (before offer reset)

const JETPACK_LEGACY_PLANS = [PLAN_JETPACK_PERSONAL, PLAN_JETPACK_PERSONAL_MONTHLY, PLAN_JETPACK_BUSINESS, PLAN_JETPACK_BUSINESS_MONTHLY, PLAN_JETPACK_PREMIUM, PLAN_JETPACK_PREMIUM_MONTHLY];
const JETPACK_LEGACY_PLANS_MAX_PLUGIN_VERSION = '8.9.1'; // Jetpack versions prior to this one are not fully compatible with new plans
// Security

const JETPACK_SECURITY_PLANS = [PLAN_JETPACK_SECURITY_DAILY, PLAN_JETPACK_SECURITY_DAILY_MONTHLY, PLAN_JETPACK_SECURITY_REALTIME, PLAN_JETPACK_SECURITY_REALTIME_MONTHLY, PLAN_JETPACK_SECURITY_T1_YEARLY, PLAN_JETPACK_SECURITY_T1_MONTHLY, PLAN_JETPACK_SECURITY_T2_YEARLY, PLAN_JETPACK_SECURITY_T2_MONTHLY];
const JETPACK_SECURITY_T1_PLANS = [PLAN_JETPACK_SECURITY_T1_MONTHLY, PLAN_JETPACK_SECURITY_T1_YEARLY]; // Complete

const JETPACK_COMPLETE_PLANS = [PLAN_JETPACK_COMPLETE, PLAN_JETPACK_COMPLETE_MONTHLY];
const JETPACK_MONTHLY_PLANS = [PLAN_JETPACK_PREMIUM_MONTHLY, PLAN_JETPACK_BUSINESS_MONTHLY, PLAN_JETPACK_PERSONAL_MONTHLY, PLAN_JETPACK_SECURITY_DAILY_MONTHLY, PLAN_JETPACK_SECURITY_REALTIME_MONTHLY, PLAN_JETPACK_SECURITY_T1_MONTHLY, PLAN_JETPACK_SECURITY_T2_MONTHLY, PLAN_JETPACK_COMPLETE_MONTHLY];
const JETPACK_RESET_PLANS = [...JETPACK_SECURITY_PLANS, ...JETPACK_COMPLETE_PLANS];
const JETPACK_RESET_PLANS_BY_TERM = [{
  yearly: PLAN_JETPACK_COMPLETE,
  monthly: PLAN_JETPACK_COMPLETE_MONTHLY
}, {
  yearly: PLAN_JETPACK_SECURITY_DAILY,
  monthly: PLAN_JETPACK_SECURITY_DAILY_MONTHLY
}, {
  yearly: PLAN_JETPACK_SECURITY_REALTIME,
  monthly: PLAN_JETPACK_SECURITY_REALTIME_MONTHLY
}, {
  yearly: PLAN_JETPACK_SECURITY_T1_YEARLY,
  monthly: PLAN_JETPACK_SECURITY_T1_MONTHLY
}, {
  yearly: PLAN_JETPACK_SECURITY_T2_YEARLY,
  monthly: PLAN_JETPACK_SECURITY_T2_MONTHLY
}];
const JETPACK_PLANS = [PLAN_JETPACK_FREE, ...JETPACK_LEGACY_PLANS, ...JETPACK_RESET_PLANS];
const JETPACK_PLANS_BY_TERM = [{
  yearly: PLAN_JETPACK_BUSINESS,
  monthly: PLAN_JETPACK_BUSINESS_MONTHLY
}, {
  yearly: PLAN_JETPACK_PERSONAL,
  monthly: PLAN_JETPACK_PERSONAL_MONTHLY
}, {
  yearly: PLAN_JETPACK_PREMIUM,
  monthly: PLAN_JETPACK_PREMIUM_MONTHLY
}, ...JETPACK_RESET_PLANS_BY_TERM];
const BEST_VALUE_PLANS = [PLAN_JETPACK_PREMIUM, PLAN_JETPACK_PREMIUM_MONTHLY]; // Key/value: Superseding plan/Plans superseded (yearly terms)

const JETPACK_PLAN_UPGRADE_MAP = {
  [PLAN_JETPACK_SECURITY_T2_YEARLY]: [PLAN_JETPACK_SECURITY_T1_YEARLY],
  [PLAN_JETPACK_SECURITY_REALTIME]: [PLAN_JETPACK_SECURITY_DAILY],
  [PLAN_JETPACK_COMPLETE]: [PLAN_JETPACK_SECURITY_REALTIME, PLAN_JETPACK_SECURITY_DAILY, PLAN_JETPACK_SECURITY_T2_YEARLY, PLAN_JETPACK_SECURITY_T1_YEARLY]
}; // Categories

const JETPACK_SECURITY_CATEGORY = 'jetpack_security_category';
const JETPACK_PERFORMANCE_CATEGORY = 'jetpack_performance_category';
const JETPACK_GROWTH_CATEGORY = 'jetpack_growth_category';
const JETPACK_PRODUCT_CATEGORIES = [JETPACK_SECURITY_CATEGORY, JETPACK_PERFORMANCE_CATEGORY, JETPACK_GROWTH_CATEGORY]; // URL

const JETPACK_BACKUP_PRODUCT_LANDING_PAGE_URL = 'https://jetpack.com/upgrade/backup/';
const JETPACK_SEARCH_PRODUCT_LANDING_PAGE_URL = 'https://jetpack.com/upgrade/search/';
const JETPACK_SCAN_PRODUCT_LANDING_PAGE_URL = 'https://jetpack.com/upgrade/scan/';
const JETPACK_ANTI_SPAM_PRODUCT_LANDING_PAGE_URL = 'https://jetpack.com/upgrade/anti-spam/'; // If JETPACK_CLOUD_REDIRECT_CHECKOUT_TO_WPADMIN is true, checkout will redirect to the site's wp-admin,
// otherwise it will redirect to the JETPACK_REDIRECT_URL. Checkout references these constants in:
// client/my-sites/checkout/composite-checkout/hooks/use-get-thank-you-url/get-thank-you-page-url.ts

const JETPACK_REDIRECT_CHECKOUT_TO_WPADMIN = true;
const JETPACK_REDIRECT_URL = 'https://jetpack.com/redirect/?source=jetpack-checkout-thankyou';

/***/ }),

/***/ 73239:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ob": function() { return /* binding */ TERM_MONTHLY; },
/* harmony export */   "w$": function() { return /* binding */ TERM_ANNUALLY; },
/* harmony export */   "SU": function() { return /* binding */ TERM_BIENNIALLY; }
/* harmony export */ });
/* unused harmony exports TERMS_LIST, PLAN_MONTHLY_PERIOD, PLAN_ANNUAL_PERIOD, PLAN_BIENNIAL_PERIOD, PERIOD_LIST */
const TERM_MONTHLY = 'TERM_MONTHLY';
const TERM_ANNUALLY = 'TERM_ANNUALLY';
const TERM_BIENNIALLY = 'TERM_BIENNIALLY';
const TERMS_LIST = [TERM_MONTHLY, TERM_ANNUALLY, TERM_BIENNIALLY];
const PLAN_MONTHLY_PERIOD = 31;
const PLAN_ANNUAL_PERIOD = 365;
const PLAN_BIENNIAL_PERIOD = 730;
const PERIOD_LIST = [PLAN_MONTHLY_PERIOD, PLAN_ANNUAL_PERIOD, PLAN_BIENNIAL_PERIOD];

/***/ }),

/***/ 5085:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "UH": function() { return /* binding */ TYPE_FREE; },
/* harmony export */   "M6": function() { return /* binding */ TYPE_BLOGGER; },
/* harmony export */   "mV": function() { return /* binding */ TYPE_PERSONAL; },
/* harmony export */   "Kb": function() { return /* binding */ TYPE_PREMIUM; },
/* harmony export */   "Qj": function() { return /* binding */ TYPE_BUSINESS; },
/* harmony export */   "h7": function() { return /* binding */ TYPE_ECOMMERCE; },
/* harmony export */   "VH": function() { return /* binding */ TYPE_SECURITY_DAILY; },
/* harmony export */   "VP": function() { return /* binding */ TYPE_SECURITY_REALTIME; },
/* harmony export */   "w": function() { return /* binding */ TYPE_SECURITY_T1; },
/* harmony export */   "$h": function() { return /* binding */ TYPE_SECURITY_T2; },
/* harmony export */   "L7": function() { return /* binding */ TYPE_ALL; },
/* harmony export */   "QI": function() { return /* binding */ TYPE_P2_PLUS; },
/* harmony export */   "qC": function() { return /* binding */ TYPE_FLEXIBLE; },
/* harmony export */   "lY": function() { return /* binding */ TYPE_PRO; },
/* harmony export */   "xg": function() { return /* binding */ TYPE_STARTER; }
/* harmony export */ });
/* unused harmony export TYPES_LIST */
const TYPE_FREE = 'TYPE_FREE';
const TYPE_BLOGGER = 'TYPE_BLOGGER';
const TYPE_PERSONAL = 'TYPE_PERSONAL';
const TYPE_PREMIUM = 'TYPE_PREMIUM';
const TYPE_BUSINESS = 'TYPE_BUSINESS';
const TYPE_ECOMMERCE = 'TYPE_ECOMMERCE';
const TYPE_SECURITY_DAILY = 'TYPE_SECURITY_DAILY';
const TYPE_SECURITY_REALTIME = 'TYPE_SECURITY_REALTIME';
const TYPE_SECURITY_T1 = 'TYPE_SECURITY_T1';
const TYPE_SECURITY_T2 = 'TYPE_SECURITY_T2';
const TYPE_ALL = 'TYPE_ALL';
const TYPE_P2_PLUS = 'TYPE_P2_PLUS';
const TYPE_FLEXIBLE = 'TYPE_FLEXIBLE';
const TYPE_PRO = 'TYPE_PRO';
const TYPE_STARTER = 'TYPE_STARTER';
const TYPES_LIST = [TYPE_FREE, TYPE_BLOGGER, TYPE_PERSONAL, TYPE_PREMIUM, TYPE_BUSINESS, TYPE_ECOMMERCE, TYPE_SECURITY_DAILY, TYPE_SECURITY_REALTIME, TYPE_ALL, TYPE_P2_PLUS, TYPE_FLEXIBLE, TYPE_PRO, TYPE_STARTER];

/***/ }),

/***/ 77904:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "w9": function() { return /* binding */ GROUP_WPCOM; },
/* harmony export */   "AY": function() { return /* binding */ PRODUCT_WPCOM_SEARCH; },
/* harmony export */   "MY": function() { return /* binding */ PRODUCT_WPCOM_SEARCH_MONTHLY; },
/* harmony export */   "Wg": function() { return /* binding */ PLAN_BUSINESS_MONTHLY; },
/* harmony export */   "p7": function() { return /* binding */ PLAN_BUSINESS; },
/* harmony export */   "j2": function() { return /* binding */ PLAN_BUSINESS_2_YEARS; },
/* harmony export */   "OE": function() { return /* binding */ PLAN_PREMIUM_MONTHLY; },
/* harmony export */   "xf": function() { return /* binding */ PLAN_PREMIUM; },
/* harmony export */   "G6": function() { return /* binding */ PLAN_PREMIUM_2_YEARS; },
/* harmony export */   "wm": function() { return /* binding */ PLAN_PERSONAL_MONTHLY; },
/* harmony export */   "sy": function() { return /* binding */ PLAN_PERSONAL; },
/* harmony export */   "Qm": function() { return /* binding */ PLAN_PERSONAL_2_YEARS; },
/* harmony export */   "TW": function() { return /* binding */ PLAN_BLOGGER; },
/* harmony export */   "uS": function() { return /* binding */ PLAN_BLOGGER_2_YEARS; },
/* harmony export */   "lv": function() { return /* binding */ PLAN_ECOMMERCE_MONTHLY; },
/* harmony export */   "JA": function() { return /* binding */ PLAN_ECOMMERCE; },
/* harmony export */   "f3": function() { return /* binding */ PLAN_ECOMMERCE_2_YEARS; },
/* harmony export */   "_d": function() { return /* binding */ PLAN_FREE; },
/* harmony export */   "Ml": function() { return /* binding */ PLAN_P2_PLUS; },
/* harmony export */   "A2": function() { return /* binding */ PLAN_P2_FREE; },
/* harmony export */   "Cq": function() { return /* binding */ PLAN_WPCOM_FLEXIBLE; },
/* harmony export */   "_s": function() { return /* binding */ PLAN_WPCOM_PRO; },
/* harmony export */   "dU": function() { return /* binding */ PLAN_WPCOM_PRO_MONTHLY; },
/* harmony export */   "Id": function() { return /* binding */ PLAN_WPCOM_STARTER; }
/* harmony export */ });
/* unused harmony exports PRODUCT_NO_ADS, PRODUCT_WPCOM_UNLIMITED_THEMES, PRODUCT_WPCOM_CUSTOM_DESIGN, WPCOM_SEARCH_PRODUCTS, WPCOM_PRODUCTS, PLAN_HOST_BUNDLE, PLAN_WPCOM_ENTERPRISE, PLAN_CHARGEBACK, PLAN_VIP, WPCOM_PLANS, WPCOM_MONTHLY_PLANS, WPCOM_TRAFFIC_GUIDE, WPCOM_DIFM_LITE, PLAN_BUSINESS_ONBOARDING_EXPIRE, PLAN_BUSINESS_2Y_ONBOARDING_EXPIRE */
const GROUP_WPCOM = 'GROUP_WPCOM'; // Products

const PRODUCT_NO_ADS = 'no-adverts/no-adverts.php';
const PRODUCT_WPCOM_SEARCH = 'wpcom_search';
const PRODUCT_WPCOM_SEARCH_MONTHLY = 'wpcom_search_monthly';
const PRODUCT_WPCOM_UNLIMITED_THEMES = 'unlimited_themes';
const PRODUCT_WPCOM_CUSTOM_DESIGN = 'custom-design';
const WPCOM_SEARCH_PRODUCTS = [PRODUCT_WPCOM_SEARCH, PRODUCT_WPCOM_SEARCH_MONTHLY];
const WPCOM_PRODUCTS = [...WPCOM_SEARCH_PRODUCTS]; // Plans

const PLAN_BUSINESS_MONTHLY = 'business-bundle-monthly';
const PLAN_BUSINESS = 'business-bundle';
const PLAN_BUSINESS_2_YEARS = 'business-bundle-2y';
const PLAN_PREMIUM_MONTHLY = 'value_bundle_monthly';
const PLAN_PREMIUM = 'value_bundle';
const PLAN_PREMIUM_2_YEARS = 'value_bundle-2y';
const PLAN_PERSONAL_MONTHLY = 'personal-bundle-monthly';
const PLAN_PERSONAL = 'personal-bundle';
const PLAN_PERSONAL_2_YEARS = 'personal-bundle-2y';
const PLAN_BLOGGER = 'blogger-bundle';
const PLAN_BLOGGER_2_YEARS = 'blogger-bundle-2y';
const PLAN_ECOMMERCE_MONTHLY = 'ecommerce-bundle-monthly';
const PLAN_ECOMMERCE = 'ecommerce-bundle';
const PLAN_ECOMMERCE_2_YEARS = 'ecommerce-bundle-2y';
const PLAN_FREE = 'free_plan';
const PLAN_HOST_BUNDLE = 'host-bundle';
const PLAN_WPCOM_ENTERPRISE = 'wpcom-enterprise';
const PLAN_CHARGEBACK = 'chargeback';
const PLAN_VIP = 'vip';
const PLAN_P2_PLUS = 'wp_p2_plus_monthly';
const PLAN_P2_FREE = 'p2_free_plan'; // Not a real plan; it's a renamed WP.com Free for the P2 project.

const PLAN_WPCOM_FLEXIBLE = 'wpcom-flexible'; // Not a real plan; it's a renamed WP.com Free for the plans overhaul.

const PLAN_WPCOM_PRO = 'pro-plan';
const PLAN_WPCOM_PRO_MONTHLY = 'pro-plan-monthly';
const PLAN_WPCOM_STARTER = 'starter-plan';
const WPCOM_PLANS = [PLAN_BUSINESS_MONTHLY, PLAN_BUSINESS, PLAN_BUSINESS_2_YEARS, PLAN_PREMIUM_MONTHLY, PLAN_PREMIUM, PLAN_PREMIUM_2_YEARS, PLAN_PERSONAL_MONTHLY, PLAN_PERSONAL, PLAN_PERSONAL_2_YEARS, PLAN_BLOGGER, PLAN_BLOGGER_2_YEARS, PLAN_ECOMMERCE_MONTHLY, PLAN_ECOMMERCE, PLAN_ECOMMERCE_2_YEARS, PLAN_FREE, PLAN_HOST_BUNDLE, PLAN_WPCOM_ENTERPRISE, PLAN_CHARGEBACK, PLAN_VIP, PLAN_P2_PLUS, PLAN_P2_FREE, PLAN_WPCOM_FLEXIBLE, PLAN_WPCOM_PRO, PLAN_WPCOM_PRO_MONTHLY, PLAN_WPCOM_STARTER];
const WPCOM_MONTHLY_PLANS = [PLAN_BUSINESS_MONTHLY, PLAN_PREMIUM_MONTHLY, PLAN_PERSONAL_MONTHLY, PLAN_ECOMMERCE_MONTHLY, PLAN_WPCOM_PRO_MONTHLY];
const WPCOM_TRAFFIC_GUIDE = 'traffic-guide';
const WPCOM_DIFM_LITE = 'wp_difm_lite';
const PLAN_BUSINESS_ONBOARDING_EXPIRE = '2021-07-31T00:00:00+00:00';
const PLAN_BUSINESS_2Y_ONBOARDING_EXPIRE = '2022-07-31T00:00:00+00:00';

/***/ }),

/***/ 10128:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "M": function() { return /* binding */ isGSuiteProductSlug; }
/* harmony export */ });
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(25432);

/**
 * Determines whether the specified product slug is for G Suite Basic or Business.
 *
 * @param {string} productSlug - slug of the product
 * @returns {boolean} true if the slug refers to G Suite Basic or Business, false otherwise
 */

function isGSuiteProductSlug(productSlug) {
  return [_constants__WEBPACK_IMPORTED_MODULE_0__/* .GSUITE_BASIC_SLUG */ .tb, _constants__WEBPACK_IMPORTED_MODULE_0__/* .GSUITE_BUSINESS_SLUG */ .y6].includes(productSlug);
}

/***/ }),

/***/ 4112:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "pl": function() { return /* binding */ isWpComBusinessPlan; },
/* harmony export */   "$J": function() { return /* binding */ isWpComEcommercePlan; }
/* harmony export */ });
/* unused harmony exports getPlans, getPlansSlugs, getPlan, getPlanByPathSlug, getPlanPath, getPlanClass, planHasFeature, planHasAtLeastOneFeature, getAllFeaturesForPlan, planHasSuperiorFeature, shouldFetchSitePlans, getMonthlyPlanByYearly, getYearlyPlanByMonthly, getBiennialPlan, planLevelsMatch, isEcommercePlan, isProPlan, isBusinessPlan, isPremiumPlan, isPersonalPlan, isBloggerPlan, isFreePlan, isFlexiblePlan, isStarterPlan, isSecurityDailyPlan, isSecurityRealTimePlan, isSecurityT1Plan, isSecurityT2Plan, isCompletePlan, isWpComPlan, isWpComProPlan, isWpComPremiumPlan, isWpComPersonalPlan, isWpComBloggerPlan, isWpComFreePlan, isWpComAnnualPlan, isWpComBiennialPlan, isWpComMonthlyPlan, isJetpackBusinessPlan, isJetpackPremiumPlan, isJetpackPersonalPlan, isJetpackFreePlan, isJetpackOfferResetPlan, isP2PlusPlan, findFirstSimilarPlanKey, findSimilarPlansKeys, findPlansKeys, planMatches, calculateMonthlyPriceForPlan, calculateMonthlyPrice, getBillingMonthsForTerm, plansLink, applyTestFiltersToPlansList, applyTestFiltersToProductsList, getPlanTermLabel, getPopularPlanSpec, chooseDefaultCustomerType, planHasJetpackSearch, planHasJetpackClassicSearch */
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(5085);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(77904);
/* harmony import */ var _plans_list__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(25192);



function getPlans() {
  return PLANS_LIST;
}
function getPlansSlugs() {
  return Object.keys(getPlans());
}
function getPlan(planKey) {
  if (typeof planKey !== 'string') {
    if (Object.values(_plans_list__WEBPACK_IMPORTED_MODULE_0__/* .PLANS_LIST */ .E).includes(planKey)) {
      return planKey;
    }

    return undefined;
  }

  return _plans_list__WEBPACK_IMPORTED_MODULE_0__/* .PLANS_LIST */ .E[planKey];
}
function getPlanByPathSlug(pathSlug, group) {
  let plans = Object.values(PLANS_LIST);
  plans = plans.filter(p => group ? p.group === group : true);
  return plans.find(p => typeof p.getPathSlug === 'function' && p.getPathSlug() === pathSlug);
}
function getPlanPath(plan) {
  const retrievedPlan = getPlan(plan);

  const slug = (retrievedPlan === null || retrievedPlan === void 0 ? void 0 : retrievedPlan.getPathSlug) || (() => undefined);

  return slug();
}
function getPlanClass(planKey) {
  if (isFreePlan(planKey)) {
    return 'is-free-plan';
  }

  if (isFlexiblePlan(planKey)) {
    return 'is-flexible-plan';
  }

  if (isStarterPlan(planKey)) {
    return 'is-starter-plan';
  }

  if (isBloggerPlan(planKey)) {
    return 'is-blogger-plan';
  }

  if (isPersonalPlan(planKey)) {
    return 'is-personal-plan';
  }

  if (isPremiumPlan(planKey)) {
    return 'is-premium-plan';
  }

  if (isBusinessPlan(planKey)) {
    return 'is-business-plan';
  }

  if (isEcommercePlan(planKey)) {
    return 'is-ecommerce-plan';
  }

  if (isProPlan(planKey)) {
    return 'is-pro-plan';
  }

  if (isSecurityDailyPlan(planKey)) {
    return 'is-daily-security-plan';
  }

  if (isSecurityRealTimePlan(planKey)) {
    return 'is-realtime-security-plan';
  }

  if (isSecurityT1Plan(planKey)) {
    return 'is-security-t1';
  }

  if (isSecurityT2Plan(planKey)) {
    return 'is-security-t2';
  }

  if (isCompletePlan(planKey)) {
    return 'is-complete-plan';
  }

  return '';
}
/**
 * Determines if a plan has a specific feature.
 *
 * Collects features for a plan by calling all possible feature methods for the plan.
 */

function planHasFeature(plan, feature) {
  const allFeatures = getAllFeaturesForPlan(plan);
  return allFeatures.includes(feature);
}
/**
 * Determine if a plan has at least one of several features.
 */

function planHasAtLeastOneFeature(plan, features) {
  const allFeatures = getAllFeaturesForPlan(plan);
  return features.some(feature => allFeatures.includes(feature));
}
/**
 * Get all features for a plan
 *
 * Collects features for a plan by calling all possible feature methods for the plan.
 *
 * Returns an array of all the plan features (may have duplicates)
 */

function getAllFeaturesForPlan(plan) {
  const planObj = getPlan(plan);

  if (!planObj) {
    return [];
  }

  return [...('getPlanCompareFeatures' in planObj && planObj.getPlanCompareFeatures ? planObj.getPlanCompareFeatures() : []), ...('getPromotedFeatures' in planObj && planObj.getPromotedFeatures ? planObj.getPromotedFeatures() : []), ...('getSignupFeatures' in planObj && planObj.getSignupFeatures ? planObj.getSignupFeatures() : []), ...('getSignupCompareAvailableFeatures' in planObj && planObj.getSignupCompareAvailableFeatures ? planObj.getSignupCompareAvailableFeatures() : []), ...('getBlogSignupFeatures' in planObj && planObj.getBlogSignupFeatures ? planObj.getBlogSignupFeatures() : []), ...('getPortfolioSignupFeatures' in planObj && planObj.getPortfolioSignupFeatures ? planObj.getPortfolioSignupFeatures() : []), ...('getIncludedFeatures' in planObj && planObj.getIncludedFeatures ? planObj.getIncludedFeatures() : [])];
}
/**
 * Determines if a plan has a superior version of a specific feature.
 */

function planHasSuperiorFeature(plan, feature) {
  var _planConstantObj$getI;

  const planConstantObj = getPlan(plan);
  const features = (planConstantObj === null || planConstantObj === void 0 ? void 0 : (_planConstantObj$getI = planConstantObj.getInferiorFeatures) === null || _planConstantObj$getI === void 0 ? void 0 : _planConstantObj$getI.call(planConstantObj)) ?? [];
  return features.includes(feature);
}
function shouldFetchSitePlans(sitePlans) {
  return !sitePlans.hasLoadedFromServer && !sitePlans.isRequesting;
}
/**
 * Returns the monthly slug which corresponds to the provided yearly slug or "" if the slug is
 * not a recognized or cannot be converted.
 */

function getMonthlyPlanByYearly(planSlug) {
  const plan = getPlan(planSlug);

  if (plan && 'getMonthlySlug' in plan && plan.getMonthlySlug) {
    return plan.getMonthlySlug();
  }

  return findFirstSimilarPlanKey(planSlug, {
    term: TERM_MONTHLY
  }) || '';
}
/**
 * Returns the yearly slug which corresponds to the provided monthly slug or "" if the slug is
 * not a recognized or cannot be converted.
 */

function getYearlyPlanByMonthly(planSlug) {
  const plan = getPlan(planSlug);

  if (plan && 'getAnnualSlug' in plan && plan.getAnnualSlug) {
    return plan.getAnnualSlug();
  }

  return findFirstSimilarPlanKey(planSlug, {
    term: TERM_ANNUALLY
  }) || '';
}
/**
 * Returns the biennial slug which corresponds to the provided slug or "" if the slug is
 * not a recognized or cannot be converted.
 */

function getBiennialPlan(planSlug) {
  return findFirstSimilarPlanKey(planSlug, {
    term: TERM_BIENNIALLY
  }) || '';
}
/**
 * Returns true if plan "types" match regardless of their interval.
 *
 * For example (fake plans):
 *     planLevelsMatch( PRO_YEARLY, PRO_YEARLY ) => true
 *     planLevelsMatch( PRO_YEARLY, PRO_MONTHLY ) => true
 *     planLevelsMatch( PRO_YEARLY, PERSONAL_YEARLY ) => false
 */

function planLevelsMatch(planSlugA, planSlugB) {
  const planA = getPlan(planSlugA);
  const planB = getPlan(planSlugB);
  return Boolean(planA && planB && planA.type === planB.type && planA.group === planB.group);
}
function isEcommercePlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_ECOMMERCE
  });
}
function isProPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_PRO
  });
}
function isBusinessPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_BUSINESS
  });
}
function isPremiumPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_PREMIUM
  });
}
function isPersonalPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_PERSONAL
  });
}
function isBloggerPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_BLOGGER
  });
}
function isFreePlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_FREE
  });
}
function isFlexiblePlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_FLEXIBLE
  });
}
function isStarterPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_STARTER
  });
}
function isSecurityDailyPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_SECURITY_DAILY
  });
}
function isSecurityRealTimePlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_SECURITY_REALTIME
  });
}
function isSecurityT1Plan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_SECURITY_T1
  });
}
function isSecurityT2Plan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_SECURITY_T2
  });
}
function isCompletePlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_ALL
  });
}
function isWpComPlan(planSlug) {
  return planMatches(planSlug, {
    group: GROUP_WPCOM
  });
}
function isWpComBusinessPlan(planSlug) {
  return planMatches(planSlug, {
    type: _constants__WEBPACK_IMPORTED_MODULE_1__/* .TYPE_BUSINESS */ .Qj,
    group: _constants__WEBPACK_IMPORTED_MODULE_2__/* .GROUP_WPCOM */ .w9
  });
}
function isWpComEcommercePlan(planSlug) {
  return planMatches(planSlug, {
    type: _constants__WEBPACK_IMPORTED_MODULE_1__/* .TYPE_ECOMMERCE */ .h7,
    group: _constants__WEBPACK_IMPORTED_MODULE_2__/* .GROUP_WPCOM */ .w9
  });
}
function isWpComProPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_PRO,
    group: GROUP_WPCOM
  });
}
function isWpComPremiumPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_PREMIUM,
    group: GROUP_WPCOM
  });
}
function isWpComPersonalPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_PERSONAL,
    group: GROUP_WPCOM
  });
}
function isWpComBloggerPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_BLOGGER,
    group: GROUP_WPCOM
  });
}
function isWpComFreePlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_FREE,
    group: GROUP_WPCOM
  });
}
function isWpComAnnualPlan(planSlug) {
  return planMatches(planSlug, {
    term: TERM_ANNUALLY,
    group: GROUP_WPCOM
  });
}
function isWpComBiennialPlan(planSlug) {
  return planMatches(planSlug, {
    term: TERM_BIENNIALLY,
    group: GROUP_WPCOM
  });
}
function isWpComMonthlyPlan(planSlug) {
  return planMatches(planSlug, {
    term: TERM_MONTHLY,
    group: GROUP_WPCOM
  });
}
function isJetpackBusinessPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_BUSINESS,
    group: GROUP_JETPACK
  });
}
function isJetpackPremiumPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_PREMIUM,
    group: GROUP_JETPACK
  });
}
function isJetpackPersonalPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_PERSONAL,
    group: GROUP_JETPACK
  });
}
function isJetpackFreePlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_FREE,
    group: GROUP_JETPACK
  });
}
function isJetpackOfferResetPlan(planSlug) {
  return JETPACK_RESET_PLANS.includes(planSlug);
}
function isP2PlusPlan(planSlug) {
  return planMatches(planSlug, {
    type: TYPE_P2_PLUS
  });
}
function findFirstSimilarPlanKey(planKey, diff) {
  return findSimilarPlansKeys(planKey, diff)[0];
}
/**
 * A similar plan is one that has the same `type`, `group`, and `term` as first
 * argument, except for differences specified in the second argument.
 *
 * For example:
 *
 * > findSimilarPlansKeys( TYPE_BUSINESS, { term: TERM_BIENNIALLY } );
 * [PLAN_BUSINESS_2_YEARS]
 * > findSimilarPlansKeys( TYPE_JETPACK_BUSINESS_MONTHLY, { type: TYPE_ANNUALLY } );
 * [TYPE_JETPACK_BUSINESS]
 */

function findSimilarPlansKeys(planKey) {
  let diff = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  const plan = getPlan(planKey); // @TODO: make getPlan() throw an error on failure. This is going to be a larger change with a separate PR.

  if (!plan) {
    return [];
  }

  return findPlansKeys({
    type: plan.type,
    group: plan.group,
    term: plan.term,
    ...diff
  });
}
/**
 * Finds all keys of plans matching a query
 *
 * For example:
 *
 * > findPlansKeys( { term: TERM_BIENNIALLY } );
 * [PLAN_PERSONAL_2_YEARS, PLAN_PREMIUM_2_YEARS, PLAN_BUSINESS_2_YEARS]
 */

function findPlansKeys() {
  let query = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  const plans = getPlans();
  return Object.keys(plans).filter(k => planMatches(plans[k], query));
}
/**
 * Matches plan specified by `planKey` against `query`.
 * Only compares `type`, `group`, and `term` properties.
 *
 * For example:
 *
 * > planMatches( TYPE_BUSINESS, { term: TERM_ANNUALLY, group: GROUP_WPCOM, type: TYPE_BUSINESS } );
 * true
 *
 * > planMatches( TYPE_BUSINESS, { term: TERM_BIENNIALLY } );
 * false
 */

function planMatches(planKey) {
  let query = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  const acceptedKeys = ['type', 'group', 'term'];
  const unknownKeys = Object.keys(query).filter(key => !acceptedKeys.includes(key));

  if (unknownKeys.length) {
    throw new Error(`planMatches can only match against ${acceptedKeys.join(',')}, ` + `but unknown keys ${unknownKeys.join(',')} were passed.`);
  } // @TODO: make getPlan() throw an error on failure. This is going to be a larger change with a separate PR.


  const plan = getPlan(planKey);

  if (!plan) {
    return false;
  }

  if ((!('type' in query) || plan.type === query.type) && (!('group' in query) || plan.group === query.group) && (!('term' in query) || plan.term === query.term)) {
    return true;
  }

  return false;
}
function calculateMonthlyPriceForPlan(planSlug, termPrice) {
  const plan = getPlan(planSlug);

  if (!plan) {
    throw new Error(`Unknown plan: ${planSlug}`);
  }

  return calculateMonthlyPrice(plan.term, termPrice);
}
function calculateMonthlyPrice(term, termPrice) {
  const divisor = getBillingMonthsForTerm(term);
  return parseFloat((termPrice / divisor).toFixed(2));
}
function getBillingMonthsForTerm(term) {
  if (term === TERM_MONTHLY) {
    return 1;
  } else if (term === TERM_ANNUALLY) {
    return 12;
  } else if (term === TERM_BIENNIALLY) {
    return 24;
  }

  throw new Error(`Unknown term: ${term}`);
}
function plansLink(urlString, siteSlug, intervalType) {
  let forceIntervalType = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : false;
  const url = new URL(urlString, window.location.origin);

  if ('monthly' === intervalType || forceIntervalType) {
    url.pathname += '/' + intervalType;
  }

  if (siteSlug) {
    url.pathname += '/' + siteSlug;
  }

  if (urlString.startsWith('/')) {
    return url.pathname + url.search;
  }

  return url.toString();
}
function applyTestFiltersToPlansList(planName, abtest) {
  let extraArgs = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  const plan = getPlan(planName);

  if (!plan) {
    throw new Error(`Unknown plan: ${planName}`);
  }

  const filteredPlanConstantObj = { ...plan
  };
  const filteredPlanFeaturesConstantList = 'getPlanCompareFeatures' in plan && plan.getPlanCompareFeatures ? plan.getPlanCompareFeatures(abtest, extraArgs) : [];
  /* eslint-disable @typescript-eslint/no-empty-function */
  // these becomes no-ops when we removed some of the abtest overrides, but
  // we're leaving the code in place for future tests

  const removeDisabledFeatures = () => {};

  const updatePlanDescriptions = () => {};

  const updatePlanFeatures = () => {};
  /* eslint-enable */


  removeDisabledFeatures();
  updatePlanDescriptions();
  updatePlanFeatures();
  return { ...filteredPlanConstantObj,
    getPlanCompareFeatures: () => filteredPlanFeaturesConstantList
  };
}
function applyTestFiltersToProductsList(productName) {
  const product = getProductFromSlug(productName);

  if (typeof product === 'string') {
    throw new Error(`Unknown product ${productName} `);
  }

  const filteredProductConstantObj = { ...product
  };
  /* eslint-disable @typescript-eslint/no-empty-function */
  // these becomes no-ops when we removed some of the abtest overrides, but
  // we're leaving the code in place for future tests

  const removeDisabledFeatures = () => {};

  const updatePlanDescriptions = () => {};

  const updatePlanFeatures = () => {};
  /* eslint-enable */


  removeDisabledFeatures();
  updatePlanDescriptions();
  updatePlanFeatures();
  return { ...filteredProductConstantObj,
    getPlanCompareFeatures: () => []
  };
}
function getPlanTermLabel(planName, translate) {
  const plan = getPlan(planName);

  if (!plan || !plan.term) {
    return;
  }

  switch (plan.term) {
    case TERM_MONTHLY:
      return translate('Monthly subscription');

    case TERM_ANNUALLY:
      return translate('Annual subscription');

    case TERM_BIENNIALLY:
      return translate('Two year subscription');
  }
}
const getPopularPlanSpec = _ref => {
  let {
    customerType,
    isJetpack,
    availablePlans
  } = _ref;

  // Jetpack doesn't currently highlight "Popular" plans
  if (isJetpack) {
    return false;
  }

  if (availablePlans.length === 0) {
    return false;
  }

  const defaultPlan = getPlan(availablePlans[0]);

  if (!defaultPlan) {
    return false;
  }

  const group = GROUP_WPCOM;

  if (customerType === 'personal') {
    if (availablePlans.findIndex(isPremiumPlan) !== -1) {
      return {
        type: TYPE_PREMIUM,
        group
      };
    } // when customerType is not personal, default to business

  } else if (availablePlans.findIndex(isBusinessPlan) !== -1) {
    return {
      type: TYPE_BUSINESS,
      group
    };
  } // finally, just return the default one.


  return {
    type: defaultPlan.type,
    group
  };
};

function isValueTruthy(value) {
  return !!value;
}

const chooseDefaultCustomerType = _ref2 => {
  let {
    currentCustomerType,
    selectedPlan,
    currentPlan
  } = _ref2;

  if (currentCustomerType) {
    return currentCustomerType;
  }

  const group = GROUP_WPCOM;
  const businessPlanSlugs = [findPlansKeys({
    group,
    term: TERM_ANNUALLY,
    type: TYPE_PREMIUM
  })[0], findPlansKeys({
    group,
    term: TERM_BIENNIALLY,
    type: TYPE_PREMIUM
  })[0], findPlansKeys({
    group,
    term: TERM_ANNUALLY,
    type: TYPE_BUSINESS
  })[0], findPlansKeys({
    group,
    term: TERM_BIENNIALLY,
    type: TYPE_BUSINESS
  })[0], findPlansKeys({
    group,
    term: TERM_ANNUALLY,
    type: TYPE_ECOMMERCE
  })[0], findPlansKeys({
    group,
    term: TERM_BIENNIALLY,
    type: TYPE_ECOMMERCE
  })[0], findPlansKeys({
    group,
    term: TERM_ANNUALLY,
    type: TYPE_PRO
  })[0], findPlansKeys({
    group,
    term: TERM_BIENNIALLY,
    type: TYPE_PRO
  })[0]].map(planKey => getPlan(planKey)).filter(isValueTruthy).map(plan => plan.getStoreSlug());

  if (selectedPlan) {
    return businessPlanSlugs.includes(selectedPlan) ? 'business' : 'personal';
  } else if (currentPlan) {
    const isPlanInBusinessGroup = businessPlanSlugs.indexOf(currentPlan.product_slug) !== -1;
    return isPlanInBusinessGroup ? 'business' : 'personal';
  }

  return 'personal';
};
/**
 * Determines if a plan includes Jetpack Search by looking at the plan's features.
 */

const planHasJetpackSearch = planSlug => planHasFeature(planSlug, FEATURE_JETPACK_SEARCH) || planHasFeature(planSlug, FEATURE_JETPACK_SEARCH_MONTHLY);
/**
 * Determines if a plan includes Jetpack Search Classic by checking available plans.
 */

function planHasJetpackClassicSearch(plan) {
  return plan && (isJetpackBusiness(plan) || isBusiness(plan) || isEnterprise(plan) || isEcommerce(plan) || isPro(plan) || isVipPlan(plan));
}

/***/ }),

/***/ 25192:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "E": function() { return /* binding */ PLANS_LIST; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(20899);
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(11481);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(73239);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(21862);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(77904);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(5085);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(90892);





function isValueTruthy(value) {
  return !!value;
}

function compact(elements) {
  return elements.filter(isValueTruthy);
}

const WPComGetBillingTimeframe = () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('per month, billed annually');

const WPComGetBiennialBillingTimeframe = () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('/month, billed every two years');

const getAnnualTimeframe = () => ({
  term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_ANNUALLY */ .w$,
  getBillingTimeFrame: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('per year')
});

const getMonthlyTimeframe = () => ({
  term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_MONTHLY */ .ob,
  getBillingTimeFrame: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('per month, billed monthly')
});

const getDotcomPlanDetails = () => ({
  // Features only available for annual plans
  getAnnualPlansOnlyFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_DOMAIN */ .MCU, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_LIVE_CHAT_SUPPORT_ALL_DAYS */ .IhT, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_LIVE_CHAT_SUPPORT_BUSINESS_DAYS */ .dmM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_LIVE_CHAT_SUPPORT */ .Tez, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_LIVE_CHAT_SUPPORT_BUSINESS_DAYS */ .N5t, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_LIVE_CHAT_SUPPORT_ALL_DAYS */ .vkU]
});
/* eslint-disable wpcalypso/jsx-classname-namespace */


const plansDescriptionHeadingComponent = {
  components: {
    strong: (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("strong", {
      className: "plans__features plan-features__targeted-description-heading"
    })
  }
};
/* eslint-enable */

const getPlanBloggerDetails = () => ({ ...getDotcomPlanDetails(),
  group: _constants__WEBPACK_IMPORTED_MODULE_5__/* .GROUP_WPCOM */ .w9,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_BLOGGER */ .M6,
  getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Blogger'),
  // @TODO not updating copy for now, we need to update it after the first round of design {{{
  getAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for bloggers'),
  getBlogAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for bloggers'),
  getPortfolioAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for bloggers'),
  getStoreAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for bloggers'),
  getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('{{strong}}Best for bloggers:{{/strong}} Brand your blog with a custom .blog domain name, and remove all WordPress.com advertising. Receive additional storage space and customer support via email.', plansDescriptionHeadingComponent),
  getShortDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Brand your blog with a custom .blog domain name, and remove all WordPress.com advertising. Receive additional storage space and customer support via email.'),
  // }}}
  getPlanCompareFeatures: () => [// pay attention to ordering, shared features should align on /plan page
  _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BLOG_DOMAIN */ .Ai8, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ESSENTIAL */ .gqo, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT */ .n_S, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_THEMES */ .jDM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BASIC_DESIGN */ .oGd, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_6GB_STORAGE */ .W4b, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MEMBERSHIPS */ .EBu, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_CONTENT_BLOCK */ .EDT],
  getSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT_SIGNUP */ .fhe, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BLOG_DOMAIN */ .Ai8, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_FREE_FEATURES */ .Uwp],
  getBlogSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_BLOG_DOMAIN */ .Q1W, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT_SIGNUP */ .fhe, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_FREE_FEATURES */ .Uwp],
  getPortfolioSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_BLOG_DOMAIN */ .Q1W, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT_SIGNUP */ .fhe, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_FREE_FEATURES */ .Uwp],
  // Features not displayed but used for checking plan abilities
  getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_AUDIO_UPLOADS */ .XMd],
  getInferiorFeatures: () => []
});

const getPlanPersonalDetails = () => ({ ...getDotcomPlanDetails(),
  group: _constants__WEBPACK_IMPORTED_MODULE_5__/* .GROUP_WPCOM */ .w9,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_PERSONAL */ .mV,
  getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Personal'),
  getAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for personal use'),
  getBlogAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for personal use'),
  getPortfolioAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for personal use'),
  getStoreAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for personal use'),
  getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('{{strong}}Best for personal use:{{/strong}} Boost your' + ' website with a custom domain name, and remove all WordPress.com advertising. ' + 'Unlock unlimited, expert customer support via email.', plansDescriptionHeadingComponent),
  getShortDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Boost your website with a custom domain name, and remove all WordPress.com advertising. ' + 'Unlock unlimited, expert customer support via email.'),
  getPlanCompareFeatures: function (_) {
    let {
      isProfessionalEmailPromotionAvailable
    } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    return compact([// pay attention to ordering, shared features should align on /plan page
    _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, isProfessionalEmailPromotionAvailable && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_PROFESSIONAL_EMAIL_TRIAL */ .oaT, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_HOSTING */ .q4V, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ESSENTIAL */ .gqo, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT */ .n_S, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_THEMES */ .jDM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BASIC_DESIGN */ .oGd, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_6GB_STORAGE */ .W4b, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MEMBERSHIPS */ .EBu, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_CONTENT_BLOCK */ .EDT]);
  },
  getSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_DOMAIN */ .MCU, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT_SIGNUP */ .fhe, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_THEMES */ .jDM],
  getBlogSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_DOMAIN */ .MCU, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT_SIGNUP */ .fhe, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_FREE_FEATURES */ .Uwp],
  getPortfolioSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_DOMAIN */ .MCU, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT_SIGNUP */ .fhe, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_FREE_FEATURES */ .Uwp],
  getSignupCompareAvailableFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_HOSTING */ .q4V, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_COLLECT_PAYMENTS_V2 */ .$4, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT_SIGNUP */ .fhe],
  // Features not displayed but used for checking plan abilities
  getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_AUDIO_UPLOADS */ .XMd],
  getInferiorFeatures: () => []
});

const getPlanEcommerceDetails = () => ({ ...getDotcomPlanDetails(),
  group: _constants__WEBPACK_IMPORTED_MODULE_5__/* .GROUP_WPCOM */ .w9,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_ECOMMERCE */ .h7,
  getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('eCommerce'),
  getAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for online stores'),
  getBlogAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for online stores'),
  getPortfolioAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for online stores'),
  getStoreAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for online stores'),
  getDescription: () => {
    return i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('{{strong}}Best for online stores:{{/strong}} Sell products or services with this powerful, ' + 'all-in-one online store experience. This plan includes premium integrations and is extendable, ' + 'so it’ll grow with you as your business grows.', plansDescriptionHeadingComponent);
  },
  getShortDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Sell products or services with this powerful, ' + 'all-in-one online store experience. This plan includes premium integrations and is extendable, ' + 'so it’ll grow with you as your business grows.'),
  getTagline: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Learn more about everything included with eCommerce and take advantage of its powerful marketplace features.'),
  getPlanCompareFeatures: function (_) {
    let {
      isLoggedInMonthlyPricing,
      isProfessionalEmailPromotionAvailable
    } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    return compact([// pay attention to ordering, shared features should align on /plan page
    _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, isProfessionalEmailPromotionAvailable && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_PROFESSIONAL_EMAIL_TRIAL */ .oaT, isLoggedInMonthlyPricing && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_LIVE_CHAT_SUPPORT_ALL_DAYS */ .vkU, isLoggedInMonthlyPricing && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT */ .n_S, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_HOSTING */ .q4V, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ADVANCED */ .c74, !isLoggedInMonthlyPricing && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_LIVE_CHAT_SUPPORT_ALL_DAYS */ .IhT, (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* .isEnabled */ ._k)('themes/premium') ? _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_THEMES */ .QfP : null, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_DESIGN */ .MOV, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_200GB_STORAGE */ .gI6, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MEMBERSHIPS */ .EBu, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_CONTENT_BLOCK */ .EDT, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SIMPLE_PAYMENTS */ .Vml, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_REPUBLICIZE */ .Zjz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WORDADS_INSTANT */ .Ej, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_VIDEO_UPLOADS */ .iTE, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UPLOAD_PLUGINS */ .xjj, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UPLOAD_THEMES */ .Tmz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_BRANDING */ .Q3C, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ACCEPT_PAYMENTS */ .$xY, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SHIPPING_CARRIERS */ .$23, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UNLIMITED_PRODUCTS_SERVICES */ .Xif, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ECOMMERCE_MARKETING */ .Do2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_CUSTOMIZABE_THEMES */ .$vg]);
  },
  getPromotedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_200GB_STORAGE */ .gI6, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_DESIGN */ .MOV],
  getSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ACCEPT_PAYMENTS */ .$xY, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SHIPPING_CARRIERS */ .$23, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_BUSINESS_FEATURES */ .kI],
  getBlogSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ACCEPT_PAYMENTS */ .$xY, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SHIPPING_CARRIERS */ .$23, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_BUSINESS_FEATURES */ .kI],
  getPortfolioSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ACCEPT_PAYMENTS */ .$xY, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SHIPPING_CARRIERS */ .$23, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_BUSINESS_FEATURES */ .kI],
  getSignupCompareAvailableFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_HOSTING */ .q4V, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_COLLECT_PAYMENTS_V2 */ .$4, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT_SIGNUP */ .fhe, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_LIVE_CHAT_SUPPORT_ALL_DAYS */ .vkU, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EARN_AD */ .Tx8, (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* .isEnabled */ ._k)('themes/premium') ? _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_THEMES */ .QfP : null, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_INSTALL_PLUGINS */ .V09, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO_EXPANDED_ABBR */ .vqo, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SITE_BACKUPS_AND_RESTORE */ ._3A, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SFTP_DATABASE */ .cWM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ACCEPT_PAYMENTS */ .$xY, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SHIPPING_CARRIERS */ .$23, _constants__WEBPACK_IMPORTED_MODULE_4__/* .PREMIUM_DESIGN_FOR_STORES */ .fp6].filter(isValueTruthy),
  // Features not displayed but used for checking plan abilities
  getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_AUDIO_UPLOADS */ .XMd, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_MY_BUSINESS */ .ggN, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CLOUDFLARE_ANALYTICS */ .$G1, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_INSTALL_PURCHASED_PLUGINS */ .n26, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UPLOAD_THEMES_PLUGINS */ .vEX, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_FORWARDING_EXTENDED_LIMIT */ .HPg, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SEO_PREVIEW_TOOLS */ .okS, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ATOMIC */ .FNU, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_SCAN */ .ikw, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ANTISPAM */ .Ly9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_BACKUPS */ .DEy],
  getInferiorFeatures: () => []
});

const getPlanPremiumDetails = () => ({ ...getDotcomPlanDetails(),
  group: _constants__WEBPACK_IMPORTED_MODULE_5__/* .GROUP_WPCOM */ .w9,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_PREMIUM */ .Kb,
  getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Premium'),
  getAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for freelancers'),
  getBlogAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for freelancers'),
  getPortfolioAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for freelancers'),
  getStoreAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for freelancers'),
  getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('{{strong}}Best for freelancers:{{/strong}} Build a unique website with advanced design tools, CSS editing, lots of space for audio and video,' + ' Google Analytics support,' + ' and the ability to monetize your site with ads.', plansDescriptionHeadingComponent),
  getShortDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Build a unique website with advanced design tools, CSS editing, lots of space for audio and video,' + ' Google Analytics support,' + ' and the ability to monetize your site with ads.'),
  getPlanCompareFeatures: function (_) {
    let {
      isLoggedInMonthlyPricing,
      isProfessionalEmailPromotionAvailable
    } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    return compact([// pay attention to ordering, shared features should align on /plan page
    _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, isProfessionalEmailPromotionAvailable && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_PROFESSIONAL_EMAIL_TRIAL */ .oaT, isLoggedInMonthlyPricing && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_LIVE_CHAT_SUPPORT_BUSINESS_DAYS */ .N5t, isLoggedInMonthlyPricing && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT */ .n_S, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_HOSTING */ .q4V, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ESSENTIAL */ .gqo, !isLoggedInMonthlyPricing && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_LIVE_CHAT_SUPPORT_BUSINESS_DAYS */ .dmM, (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* .isEnabled */ ._k)('themes/premium') ? _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_THEMES */ .QfP : null, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_DESIGN */ .MOV, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_13GB_STORAGE */ .E5t, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MEMBERSHIPS */ .EBu, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_CONTENT_BLOCK */ .EDT, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SIMPLE_PAYMENTS */ .Vml, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_REPUBLICIZE */ .Zjz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WORDADS_INSTANT */ .Ej, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_VIDEO_UPLOADS */ .iTE]);
  },
  getPromotedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_DESIGN */ .MOV, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_13GB_STORAGE */ .E5t],
  getSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_LIVE_CHAT_SUPPORT_BUSINESS_DAYS */ .N5t, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_CUSTOMIZATION */ .jSq, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_PERSONAL_FEATURES */ .VyO],
  getBlogSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MONETISE */ .SZ6, (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* .isEnabled */ ._k)('themes/premium') ? _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_THEMES */ .QfP : null, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_PERSONAL_FEATURES */ .VyO].filter(isValueTruthy),
  getPortfolioSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_CUSTOMIZATION */ .jSq, (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* .isEnabled */ ._k)('themes/premium') ? _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_THEMES */ .QfP : null, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_PERSONAL_FEATURES */ .VyO].filter(isValueTruthy),
  getSignupCompareAvailableFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_HOSTING */ .q4V, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_COLLECT_PAYMENTS_V2 */ .$4, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT_SIGNUP */ .fhe, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_LIVE_CHAT_SUPPORT_BUSINESS_DAYS */ .N5t, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EARN_AD */ .Tx8, (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* .isEnabled */ ._k)('themes/premium') ? _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_THEMES */ .QfP : null, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms].filter(isValueTruthy),
  // Features not displayed but used for checking plan abilities
  getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_AUDIO_UPLOADS */ .XMd, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CLOUDFLARE_ANALYTICS */ .$G1, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_SCAN */ .ikw, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ANTISPAM */ .Ly9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_BACKUPS */ .DEy],
  getInferiorFeatures: () => []
});

const getPlanBusinessDetails = () => ({ ...getDotcomPlanDetails(),
  group: _constants__WEBPACK_IMPORTED_MODULE_5__/* .GROUP_WPCOM */ .w9,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_BUSINESS */ .Qj,
  getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Business'),
  getAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for small businesses'),
  getBlogAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for small businesses'),
  getPortfolioAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for small businesses'),
  getStoreAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('The plan for small businesses'),
  getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('{{strong}}Best for small businesses:{{/strong}} Power your' + ' business website with custom plugins and themes,' + ' 200 GB storage, and the ability to remove WordPress.com branding.', plansDescriptionHeadingComponent),
  getShortDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Power your business website with custom plugins and themes,' + ' 200 GB storage, and the ability to remove WordPress.com branding.'),
  getTagline: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Learn more about everything included with Business and take advantage of its professional features.'),
  getPlanCompareFeatures: function (_) {
    let {
      isLoggedInMonthlyPricing,
      isProfessionalEmailPromotionAvailable
    } = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    return compact([// pay attention to ordering, shared features should align on /plan page
    _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, isProfessionalEmailPromotionAvailable && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_PROFESSIONAL_EMAIL_TRIAL */ .oaT, isLoggedInMonthlyPricing && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_LIVE_CHAT_SUPPORT_ALL_DAYS */ .vkU, isLoggedInMonthlyPricing && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT */ .n_S, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_HOSTING */ .q4V, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ADVANCED */ .c74, !isLoggedInMonthlyPricing && _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_LIVE_CHAT_SUPPORT_ALL_DAYS */ .IhT, (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* .isEnabled */ ._k)('themes/premium') ? _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_THEMES */ .QfP : null, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_DESIGN */ .MOV, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_200GB_STORAGE */ .gI6, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MEMBERSHIPS */ .EBu, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_CONTENT_BLOCK */ .EDT, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SIMPLE_PAYMENTS */ .Vml, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_REPUBLICIZE */ .Zjz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WORDADS_INSTANT */ .Ej, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_VIDEO_UPLOADS */ .iTE, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UPLOAD_PLUGINS */ .xjj, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UPLOAD_THEMES */ .Tmz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_BRANDING */ .Q3C]);
  },
  getPromotedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_200GB_STORAGE */ .gI6, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_DESIGN */ .MOV, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_VIDEO_UPLOADS */ .iTE],
  getSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UPLOAD_THEMES_PLUGINS */ .vEX, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO_TOOLS */ .ljn, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_PREMIUM_FEATURES */ .Z5U],
  getBlogSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UPLOAD_THEMES_PLUGINS */ .vEX, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO_TOOLS */ .ljn, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_PREMIUM_FEATURES */ .Z5U],
  getPortfolioSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UPLOAD_THEMES_PLUGINS */ .vEX, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_200GB_STORAGE */ .gI6, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_PREMIUM_FEATURES */ .Z5U],
  getSignupCompareAvailableFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_HOSTING */ .q4V, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_COLLECT_PAYMENTS_V2 */ .$4, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT_SIGNUP */ .fhe, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_LIVE_CHAT_SUPPORT_ALL_DAYS */ .vkU, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EARN_AD */ .Tx8, (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* .isEnabled */ ._k)('themes/premium') ? _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_THEMES */ .QfP : null, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_INSTALL_PLUGINS */ .V09, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO_EXPANDED_ABBR */ .vqo, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SITE_BACKUPS_AND_RESTORE */ ._3A, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SFTP_DATABASE */ .cWM].filter(isValueTruthy),
  // Features not displayed but used for checking plan abilities
  getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_AUDIO_UPLOADS */ .XMd, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_MY_BUSINESS */ .ggN, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CLOUDFLARE_ANALYTICS */ .$G1, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_INSTALL_PURCHASED_PLUGINS */ .n26, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_FORWARDING_EXTENDED_LIMIT */ .HPg, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SEO_PREVIEW_TOOLS */ .okS, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ATOMIC */ .FNU, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_SCAN */ .ikw, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ANTISPAM */ .Ly9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_BACKUPS */ .DEy],
  getInferiorFeatures: () => []
});

const getPlanProDetails = () => ({ ...getDotcomPlanDetails(),
  group: _constants__WEBPACK_IMPORTED_MODULE_5__/* .GROUP_WPCOM */ .w9,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_PRO */ .lY,
  getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('WordPress Pro'),
  getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Unlock the full power of WordPress with plugins, custom themes and much more.'),
  getSubTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Unlimited features. Unbeatable value.'),
  getPlanCompareFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UNLIMITED_TRAFFIC */ .c__, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MANAGED_HOSTING */ .FiJ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_THEMES */ .jDM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_THEMES */ .QfP, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_INSTALL_PLUGINS */ .V09, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_INSTALL_PURCHASED_PLUGINS */ .n26, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_SUPPORT */ .J8D, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WOOCOMMERCE */ .O05, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_50GB_STORAGE */ .SLH, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_ADS */ .Xk_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UNLIMITED_ADMINS */ .SsD, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_VIDEO_UPLOADS */ .iTE, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PAYMENT_BLOCKS */ .x_7, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SOCIAL_MEDIA_TOOLS */ .hH1, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_TITAN_EMAIL */ .fDA, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MONETISE */ .SZ6, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SFTP_DATABASE */ .cWM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SITE_BACKUPS_AND_RESTORE */ ._3A, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ESSENTIAL */ .gqo, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SIMPLE_PAYMENTS */ .Vml, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WORDADS_INSTANT */ .Ej, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms],
  getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_DESIGN */ .MOV, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO_EXPANDED_ABBR */ .vqo, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_AUDIO_UPLOADS */ .XMd, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CLOUDFLARE_ANALYTICS */ .$G1, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_COLLECT_PAYMENTS_V2 */ .$4, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EARN_AD */ .Tx8, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_FORWARDING_EXTENDED_LIMIT */ .HPg, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_MY_BUSINESS */ .ggN, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_HOSTING */ .q4V, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MEMBERSHIPS */ .EBu, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_NO_BRANDING */ .Q3C, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_REPUBLICIZE */ .Zjz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_CONTENT_BLOCK */ .EDT, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SEO_PREVIEW_TOOLS */ .okS, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SFTP_DATABASE */ .cWM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SITE_BACKUPS_AND_RESTORE */ ._3A, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UPLOAD_PLUGINS */ .xjj, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UPLOAD_THEMES */ .Tmz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UPLOAD_THEMES_PLUGINS */ .vEX, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ATOMIC */ .FNU, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_SCAN */ .ikw, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ANTISPAM */ .Ly9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_BACKUPS */ .DEy]
});

const getJetpackPersonalDetails = () => ({
  group: _constants__WEBPACK_IMPORTED_MODULE_7__/* .GROUP_JETPACK */ .mk,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_PERSONAL */ .mV,
  getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Personal'),
  availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_FREE */ .lj].includes(plan),
  getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('{{strong}}Best for personal use:{{/strong}} Security essentials for your WordPress site, including ' + 'automated backups and priority support.', plansDescriptionHeadingComponent),
  getTagline: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Your data is being securely backed up and you have access to priority support.'),
  getPlanCardFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_DAILY_V2 */ .DwI, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ANTISPAM_V2 */ .CtJ],
  getBillingTimeFrame: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('per year'),
  getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_OFFSITE_BACKUP_VAULTPRESS_DAILY */ .s1f, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_ARCHIVE_30 */ .nsi, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_STORAGE_SPACE_UNLIMITED */ .$PM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_AUTOMATED_RESTORES */ .Rp9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SPAM_AKISMET_PLUS */ .V37, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EASY_SITE_MIGRATION */ .$QL, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_SUPPORT */ .J8D, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY */ .V1k, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY_MONTHLY */ .TBQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM */ .zrQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM_MONTHLY */ .T$h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SEO_PREVIEW_TOOLS */ .okS, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_OFFSITE_BACKUP_VAULTPRESS_DAILY */ .s1f, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SPAM_AKISMET_PLUS */ .V37, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ACTIVITY_LOG */ .wUt, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_SUPPORT */ .J8D, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_FREE_FEATURES_JETPACK */ .igx, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ANTISPAM */ .Ly9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_BACKUPS */ .DEy]
});

const getJetpackPremiumDetails = () => ({
  group: _constants__WEBPACK_IMPORTED_MODULE_7__/* .GROUP_JETPACK */ .mk,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_PREMIUM */ .Kb,
  availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_FREE */ .lj, _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PERSONAL */ .ap, _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PERSONAL_MONTHLY */ .ns].includes(plan),
  getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Premium'),
  getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('{{strong}}Best for small businesses:{{/strong}} Comprehensive, automated scanning for security vulnerabilities, ' + 'fast video hosting, and marketing automation.', plansDescriptionHeadingComponent),
  getTagline: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Your site is being secured and you have access to marketing tools and priority support.'),
  getPlanCardFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_DAILY_V2 */ .DwI, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SCAN_V2 */ .w7L, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ANTISPAM_V2 */ .CtJ],
  getIncludedFeatures: () => compact([// pay attention to ordering, shared features should align on /plan page
  _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_OFFSITE_BACKUP_VAULTPRESS_DAILY */ .s1f, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_ARCHIVE_30 */ .nsi, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_STORAGE_SPACE_UNLIMITED */ .$PM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_AUTOMATED_RESTORES */ .Rp9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SPAM_AKISMET_PLUS */ .V37, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EASY_SITE_MIGRATION */ .$QL, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_SUPPORT */ .J8D, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_REPUBLICIZE */ .Zjz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SIMPLE_PAYMENTS */ .Vml, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WORDADS_INSTANT */ .Ej, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_VIDEO_UPLOADS_JETPACK_PRO */ .QNW, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MALWARE_SCANNING_DAILY */ .zQV, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY */ .V1k, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY_MONTHLY */ .TBQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY */ .V1I, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY_MONTHLY */ .FR0, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM */ .zrQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM_MONTHLY */ .T$h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SEO_PREVIEW_TOOLS */ .okS, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_OFFSITE_BACKUP_VAULTPRESS_DAILY */ .s1f, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SPAM_AKISMET_PLUS */ .V37, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MALWARE_SCANNING_DAILY */ .zQV, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_AUTOMATIC_SECURITY_FIXES */ .m1c, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_VIDEO_UPLOADS_JETPACK_PRO */ .QNW, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WORDADS_INSTANT */ .Ej, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_FREE_FEATURES_JETPACK */ .igx, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_SCAN */ .ikw, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ANTISPAM */ .Ly9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_BACKUPS */ .DEy])
});

const getJetpackBusinessDetails = () => ({
  group: _constants__WEBPACK_IMPORTED_MODULE_7__/* .GROUP_JETPACK */ .mk,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_BUSINESS */ .Qj,
  getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Professional'),
  availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_FREE */ .lj, _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PREMIUM */ .Xz, _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PREMIUM_MONTHLY */ .p2, _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PERSONAL */ .ap, _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PERSONAL_MONTHLY */ .ns].includes(plan),
  getDescription: () => (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* .isEnabled */ ._k)('themes/premium') ? i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('{{strong}}Best for organizations:{{/strong}} The most powerful WordPress sites.', plansDescriptionHeadingComponent) : i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('{{strong}}Best for organizations:{{/strong}} The most powerful WordPress sites: real-time backups ' + 'and premium themes.', plansDescriptionHeadingComponent),
  getTagline: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('You have the full suite of security and performance tools.'),
  getPlanCardFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_REALTIME_V2 */ .csF, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PRODUCT_SCAN_REALTIME_V2 */ .XgZ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ANTISPAM_V2 */ .CtJ],
  getIncludedFeatures: () => compact([// pay attention to ordering, shared features should align on /plan page
  _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_OFFSITE_BACKUP_VAULTPRESS_REALTIME */ ._sL, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_ARCHIVE_UNLIMITED */ .L2_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_STORAGE_SPACE_UNLIMITED */ .$PM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_AUTOMATED_RESTORES */ .Rp9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SPAM_AKISMET_PLUS */ .V37, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EASY_SITE_MIGRATION */ .$QL, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_SUPPORT */ .J8D, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_REPUBLICIZE */ .Zjz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SIMPLE_PAYMENTS */ .Vml, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WORDADS_INSTANT */ .Ej, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_VIDEO_UPLOADS_JETPACK_PRO */ .QNW, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MALWARE_SCANNING_DAILY_AND_ON_DEMAND */ .vQ$, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ONE_CLICK_THREAT_RESOLUTION */ .E30, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_REALTIME */ .s4b, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_REALTIME_MONTHLY */ .TZT, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY */ .V1I, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY_MONTHLY */ .FR0, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM */ .zrQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM_MONTHLY */ .T$h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SEO_PREVIEW_TOOLS */ .okS, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_OFFSITE_BACKUP_VAULTPRESS_REALTIME */ ._sL, (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* .isEnabled */ ._k)('themes/premium') ? _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_THEMES */ .QfP : null, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ALL_PREMIUM_FEATURES_JETPACK */ .PUy, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_SCAN */ .ikw, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ANTISPAM */ .Ly9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_BACKUPS */ .DEy]),
  getInferiorFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY */ .V1k, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY_MONTHLY */ .TBQ]
});

const getPlanJetpackSecurityDailyDetails = () => ({
  group: _constants__WEBPACK_IMPORTED_MODULE_7__/* .GROUP_JETPACK */ .mk,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_SECURITY_DAILY */ .VH,
  getTitle: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('Security {{em}}Daily{{/em}}', {
    components: {
      em: (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("em", null)
    }
  }),
  availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_FREE */ .lj, ..._constants__WEBPACK_IMPORTED_MODULE_7__/* .JETPACK_LEGACY_PLANS */ .$U].includes(plan),
  getDescription: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('All of the essential Jetpack Security features in one package including Backup, Scan, Anti-spam and more.'),
  getTagline: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('Best for sites with occasional updates'),
  getPlanCardFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PRODUCT_BACKUP_DAILY_V2 */ .afj, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PRODUCT_SCAN_DAILY_V2 */ .oIe, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ANTISPAM_V2 */ .CtJ],
  getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY */ .V1k, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY_MONTHLY */ .TBQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY */ .V1I, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY_MONTHLY */ .FR0, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM */ .zrQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM_MONTHLY */ .T$h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_ARCHIVE_30 */ .nsi, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_REPUBLICIZE */ .Zjz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SEO_PREVIEW_TOOLS */ .okS, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SIMPLE_PAYMENTS */ .Vml, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WORDADS_INSTANT */ .Ej, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_SUPPORT */ .J8D, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_SCAN */ .ikw, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ANTISPAM */ .Ly9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_BACKUPS */ .DEy]
});

const getPlanJetpackSecurityRealtimeDetails = () => ({
  group: _constants__WEBPACK_IMPORTED_MODULE_7__/* .GROUP_JETPACK */ .mk,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_SECURITY_REALTIME */ .VP,
  getTitle: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('Security {{em}}Real-time{{/em}}', {
    components: {
      em: (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("em", {
        style: {
          whiteSpace: 'nowrap'
        }
      })
    }
  }),
  availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_FREE */ .lj, _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_DAILY */ .Vl, _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_DAILY_MONTHLY */ .Dl, ..._constants__WEBPACK_IMPORTED_MODULE_7__/* .JETPACK_LEGACY_PLANS */ .$U].includes(plan),
  getDescription: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('Get next-level protection with real-time backups, real-time scan and all essential security tools.'),
  getTagline: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('Best for sites with frequent updates'),
  getPlanCardFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PLAN_SECURITY_DAILY */ .X2I, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PRODUCT_BACKUP_REALTIME_V2 */ .HpB, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PRODUCT_SCAN_REALTIME_V2 */ .XgZ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ACTIVITY_LOG_1_YEAR_V2 */ .n$d],
  getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_REALTIME */ .s4b, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_REALTIME_MONTHLY */ .TZT, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY */ .V1I, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY_MONTHLY */ .FR0, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM */ .zrQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM_MONTHLY */ .T$h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_ARCHIVE_UNLIMITED */ .L2_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_VIDEO_UPLOADS_JETPACK_PRO */ .QNW, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_REPUBLICIZE */ .Zjz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SEO_PREVIEW_TOOLS */ .okS, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SIMPLE_PAYMENTS */ .Vml, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WORDADS_INSTANT */ .Ej, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_SUPPORT */ .J8D, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_SCAN */ .ikw, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ANTISPAM */ .Ly9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_BACKUPS */ .DEy],
  getInferiorFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY */ .V1k, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY_MONTHLY */ .TBQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_ARCHIVE_30 */ .nsi]
});

const getPlanJetpackSecurityT1Details = () => ({
  group: _constants__WEBPACK_IMPORTED_MODULE_7__/* .GROUP_JETPACK */ .mk,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_SECURITY_T1 */ .w,
  getTitle: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('Security'),
  availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_FREE */ .lj, ..._constants__WEBPACK_IMPORTED_MODULE_7__/* .JETPACK_LEGACY_PLANS */ .$U].includes(plan),
  getDescription: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('Easy-to-use, comprehensive WordPress site security including backups, malware scanning, and spam protection.'),
  getPlanCardFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_PRODUCT_BACKUP */ .VZW, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_REAL_TIME_MALWARE_SCANNING */ .xlk, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ANTISPAM_V2 */ .CtJ],
  getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_T1_YEARLY */ .$pY, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_T1_MONTHLY */ .mX4, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY */ .V1I, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY_MONTHLY */ .FR0, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM */ .zrQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM_MONTHLY */ .T$h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_ARCHIVE_UNLIMITED */ .L2_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_VIDEO_UPLOADS_JETPACK_PRO */ .QNW, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_REPUBLICIZE */ .Zjz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SEO_PREVIEW_TOOLS */ .okS, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SIMPLE_PAYMENTS */ .Vml, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WORDADS_INSTANT */ .Ej, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_SUPPORT */ .J8D, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_SCAN */ .ikw, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ANTISPAM */ .Ly9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_BACKUPS */ .DEy],
  getInferiorFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY */ .V1k, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY_MONTHLY */ .TBQ]
});

const getPlanJetpackSecurityT2Details = () => ({ ...getPlanJetpackSecurityT1Details(),
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_SECURITY_T2 */ .$h,
  getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_T2_YEARLY */ .tS0, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_T2_MONTHLY */ .L2R, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY */ .V1I, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY_MONTHLY */ .FR0, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM */ .zrQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM_MONTHLY */ .T$h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_ARCHIVE_UNLIMITED */ .L2_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_VIDEO_UPLOADS_JETPACK_PRO */ .QNW, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_REPUBLICIZE */ .Zjz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SEO_PREVIEW_TOOLS */ .okS, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SIMPLE_PAYMENTS */ .Vml, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WORDADS_INSTANT */ .Ej, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_SUPPORT */ .J8D, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_SCAN */ .ikw, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ANTISPAM */ .Ly9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_BACKUPS */ .DEy],
  getInferiorFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY */ .V1k, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY_MONTHLY */ .TBQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_ARCHIVE_30 */ .nsi]
});

const getPlanJetpackCompleteDetails = () => ({
  group: _constants__WEBPACK_IMPORTED_MODULE_7__/* .GROUP_JETPACK */ .mk,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_ALL */ .L7,
  getTitle: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('Complete', {
    context: 'Jetpack plan name'
  }),
  availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_FREE */ .lj, ..._constants__WEBPACK_IMPORTED_MODULE_7__/* .JETPACK_SECURITY_PLANS */ .jj, ..._constants__WEBPACK_IMPORTED_MODULE_7__/* .JETPACK_LEGACY_PLANS */ .$U].includes(plan),
  getDescription: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('Get the full power of Jetpack with all Security, Performance, Growth, and Design tools.'),
  getTagline: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('For best-in-class WordPress sites'),
  getPlanCardFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ALL_BACKUP_SECURITY_FEATURES */ .lYf, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_1TB_BACKUP_STORAGE */ .puh, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_PRODUCT_VIDEOPRESS */ .sQp, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PRODUCT_SEARCH_V2 */ .dZ$, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CRM_V2 */ .rDn],
  getIncludedFeatures: () => compact([_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_T2_YEARLY */ .tS0, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_T2_MONTHLY */ .L2R, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY */ .V1I, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY_MONTHLY */ .FR0, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM */ .zrQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ANTI_SPAM_MONTHLY */ .T$h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SEARCH */ .lv3, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SEARCH_MONTHLY */ .ewW, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_CRM */ .liF, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_CRM_MONTHLY */ .DJ3, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_ARCHIVE_UNLIMITED */ .L2_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_VIDEO_UPLOADS_JETPACK_PRO */ .QNW, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_VIDEOPRESS */ .GwK, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_VIDEOPRESS_MONTHLY */ .w6W, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_REPUBLICIZE */ .Zjz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SEO_PREVIEW_TOOLS */ .okS, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SIMPLE_PAYMENTS */ .Vml, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WORDADS_INSTANT */ .Ej, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* .isEnabled */ ._k)('themes/premium') ? _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_THEMES */ .QfP : null, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PREMIUM_SUPPORT */ .J8D, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_SCAN */ .ikw, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_ANTISPAM */ .Ly9, _constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_BACKUPS */ .DEy]),
  getInferiorFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY */ .V1k, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY_MONTHLY */ .TBQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BACKUP_ARCHIVE_30 */ .nsi]
}); // DO NOT import. Use `getPlan` instead.


const PLANS_LIST = {
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d]: {
    group: _constants__WEBPACK_IMPORTED_MODULE_5__/* .GROUP_WPCOM */ .w9,
    type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_FREE */ .UH,
    term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_ANNUALLY */ .w$,
    getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Free'),
    getAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for students'),
    getBlogAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for students'),
    getPortfolioAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for students'),
    getStoreAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for students'),
    getProductId: () => 1,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d,
    getPathSlug: () => 'beginner',
    getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Get a free website and be on your way to publishing your ' + 'first post in less than five minutes.'),
    getPlanCompareFeatures: () => [// pay attention to ordering, shared features should align on /plan page
    _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WP_SUBDOMAIN */ .wJ_, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_ESSENTIAL */ .gqo, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_COMMUNITY_SUPPORT */ .U_2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_THEMES */ .jDM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BASIC_DESIGN */ .oGd, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_3GB_STORAGE */ .KlX],
    getSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_COMMUNITY_SUPPORT */ .U_2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WP_SUBDOMAIN_SIGNUP */ .sYz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_THEMES_SIGNUP */ .R2o],
    getBlogSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_COMMUNITY_SUPPORT */ .U_2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WP_SUBDOMAIN_SIGNUP */ .sYz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_THEMES_SIGNUP */ .R2o],
    getPortfolioSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_COMMUNITY_SUPPORT */ .U_2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_WP_SUBDOMAIN_SIGNUP */ .sYz, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_THEMES_SIGNUP */ .R2o],
    getBillingTimeFrame: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('for life'),
    getIncludedFeatures: () => [],
    getInferiorFeatures: () => []
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW]: { ...getPlanBloggerDetails(),
    term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_ANNUALLY */ .w$,
    getBillingTimeFrame: WPComGetBillingTimeframe,
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d].includes(plan),
    getProductId: () => 1010,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW,
    getPathSlug: () => 'blogger'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS]: { ...getPlanBloggerDetails(),
    term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_BIENNIALLY */ .SU,
    getBillingTimeFrame: WPComGetBiennialBillingTimeframe,
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW].includes(plan),
    getProductId: () => 1030,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS,
    getPathSlug: () => 'blogger-2-years'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm]: { ...getPlanPersonalDetails(),
    ...getMonthlyTimeframe(),
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS].includes(plan),
    getProductId: () => 1019,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm,
    getPathSlug: () => 'personal-monthly'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL */ .sy]: { ...getPlanPersonalDetails(),
    term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_ANNUALLY */ .w$,
    getBillingTimeFrame: WPComGetBillingTimeframe,
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm].includes(plan),
    getProductId: () => 1009,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL */ .sy,
    getPathSlug: () => 'personal'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_2_YEARS */ .Qm]: { ...getPlanPersonalDetails(),
    term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_BIENNIALLY */ .SU,
    getBillingTimeFrame: WPComGetBiennialBillingTimeframe,
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL */ .sy].includes(plan),
    getProductId: () => 1029,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_2_YEARS */ .Qm,
    getPathSlug: () => 'personal-2-years'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_MONTHLY */ .OE]: { ...getPlanPremiumDetails(),
    ...getMonthlyTimeframe(),
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL */ .sy, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_2_YEARS */ .Qm].includes(plan),
    getProductId: () => 1013,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_MONTHLY */ .OE,
    getPathSlug: () => 'premium-monthly'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM */ .xf]: { ...getPlanPremiumDetails(),
    term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_ANNUALLY */ .w$,
    getBillingTimeFrame: WPComGetBillingTimeframe,
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL */ .sy, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_2_YEARS */ .Qm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_MONTHLY */ .OE, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_STARTER */ .Id].includes(plan),
    getProductId: () => 1003,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM */ .xf,
    getPathSlug: () => 'premium'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_2_YEARS */ .G6]: { ...getPlanPremiumDetails(),
    term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_BIENNIALLY */ .SU,
    getBillingTimeFrame: WPComGetBiennialBillingTimeframe,
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL */ .sy, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_2_YEARS */ .Qm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_MONTHLY */ .OE, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM */ .xf].includes(plan),
    getProductId: () => 1023,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_2_YEARS */ .G6,
    getPathSlug: () => 'premium-2-years'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS_MONTHLY */ .Wg]: { ...getPlanBusinessDetails(),
    ...getMonthlyTimeframe(),
    availableFor: plan => (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_1__/* .isEnabled */ ._k)('upgrades/wpcom-monthly-plans') && [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL */ .sy, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_2_YEARS */ .Qm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_MONTHLY */ .OE, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM */ .xf, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_2_YEARS */ .G6, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO_MONTHLY */ .dU].includes(plan),
    getProductId: () => 1018,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS_MONTHLY */ .Wg,
    getPathSlug: () => 'business-monthly'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS */ .p7]: { ...getPlanBusinessDetails(),
    term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_ANNUALLY */ .w$,
    getBillingTimeFrame: WPComGetBillingTimeframe,
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_STARTER */ .Id, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO */ ._s, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL */ .sy, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_2_YEARS */ .Qm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_MONTHLY */ .OE, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM */ .xf, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_2_YEARS */ .G6, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS_MONTHLY */ .Wg, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO_MONTHLY */ .dU].includes(plan),
    getProductId: () => 1008,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS */ .p7,
    getPathSlug: () => 'business'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS_2_YEARS */ .j2]: { ...getPlanBusinessDetails(),
    term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_BIENNIALLY */ .SU,
    getBillingTimeFrame: WPComGetBiennialBillingTimeframe,
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_STARTER */ .Id, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO */ ._s, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL */ .sy, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_2_YEARS */ .Qm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_MONTHLY */ .OE, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM */ .xf, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_2_YEARS */ .G6, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS */ .p7, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS_MONTHLY */ .Wg, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO_MONTHLY */ .dU].includes(plan),
    getProductId: () => 1028,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS_2_YEARS */ .j2,
    getPathSlug: () => 'business-2-years'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_ECOMMERCE_MONTHLY */ .lv]: { ...getPlanEcommerceDetails(),
    ...getMonthlyTimeframe(),
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL */ .sy, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_2_YEARS */ .Qm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_MONTHLY */ .OE, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM */ .xf, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_2_YEARS */ .G6, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS_MONTHLY */ .Wg, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS */ .p7, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS_2_YEARS */ .j2, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO_MONTHLY */ .dU].includes(plan),
    getProductId: () => 1021,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_ECOMMERCE_MONTHLY */ .lv,
    getPathSlug: () => 'ecommerce-monthly'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_ECOMMERCE */ .JA]: { ...getPlanEcommerceDetails(),
    term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_ANNUALLY */ .w$,
    getBillingTimeFrame: WPComGetBillingTimeframe,
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_STARTER */ .Id, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO */ ._s, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL */ .sy, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_2_YEARS */ .Qm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_MONTHLY */ .OE, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM */ .xf, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_2_YEARS */ .G6, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS_MONTHLY */ .Wg, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS */ .p7, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS_2_YEARS */ .j2, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_ECOMMERCE_MONTHLY */ .lv, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO_MONTHLY */ .dU].includes(plan),
    getProductId: () => 1011,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_ECOMMERCE */ .JA,
    getPathSlug: () => 'ecommerce'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_ECOMMERCE_2_YEARS */ .f3]: { ...getPlanEcommerceDetails(),
    term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_BIENNIALLY */ .SU,
    getBillingTimeFrame: WPComGetBiennialBillingTimeframe,
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_STARTER */ .Id, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO */ ._s, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER */ .TW, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BLOGGER_2_YEARS */ .uS, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_MONTHLY */ .wm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL */ .sy, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PERSONAL_2_YEARS */ .Qm, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_MONTHLY */ .OE, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM */ .xf, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_PREMIUM_2_YEARS */ .G6, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS_MONTHLY */ .Wg, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS */ .p7, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_BUSINESS_2_YEARS */ .j2, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_ECOMMERCE_MONTHLY */ .lv, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_ECOMMERCE */ .JA, _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO_MONTHLY */ .dU].includes(plan),
    getProductId: () => 1031,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_ECOMMERCE_2_YEARS */ .f3,
    getPathSlug: () => 'ecommerce-2-years'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_FREE */ .lj]: {
    term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_ANNUALLY */ .w$,
    group: _constants__WEBPACK_IMPORTED_MODULE_7__/* .GROUP_JETPACK */ .mk,
    type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_FREE */ .UH,
    getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Free'),
    getProductId: () => 2002,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_FREE */ .lj,
    getTagline: function () {
      let siteFeatures = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
      const hasSiteJetpackBackup = siteFeatures.some(feature => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY */ .V1k, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_DAILY_MONTHLY */ .TBQ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_REALTIME */ .s4b, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_REALTIME_MONTHLY */ .TZT, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_T1_YEARLY */ .$pY, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_T1_MONTHLY */ .mX4, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_T2_YEARLY */ .tS0, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_BACKUP_T2_MONTHLY */ .L2R].includes(feature));
      const hasSiteJetpackScan = siteFeatures.some(feature => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY */ .V1I, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SCAN_DAILY_MONTHLY */ .FR0].includes(feature));

      if (hasSiteJetpackBackup && hasSiteJetpackScan) {
        return i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Upgrade your site to access additional features, including spam protection and priority support.');
      } else if (hasSiteJetpackBackup) {
        return i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Upgrade your site to access additional features, including spam protection, security scanning, and priority support.');
      } else if (hasSiteJetpackScan) {
        return i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Upgrade your site to access additional features, including spam protection, backups, and priority support.');
      }

      return i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Upgrade your site for additional features, including spam protection, backups, security scanning, and priority support.');
    },
    getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('The features most needed by WordPress sites' + ' — perfectly packaged and optimized for everyone.'),
    getBillingTimeFrame: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('for life'),
    getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_STANDARD_SECURITY_TOOLS */ .wwD, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SITE_STATS */ .rlg, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_TRAFFIC_TOOLS */ .F$l, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MANAGE */ .gRD, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_ADVANCED_SEO */ .B2h, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SEO_PREVIEW_TOOLS */ .okS, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_WORDPRESS_THEMES */ .ALM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_SITE_STATS */ .rlg, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_STANDARD_SECURITY_TOOLS */ .wwD, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_TRAFFIC_TOOLS */ .F$l, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_BLANK */ .$NZ]
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PREMIUM */ .Xz]: { ...getJetpackPremiumDetails(),
    ...getAnnualTimeframe(),
    getProductId: () => 2000,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PREMIUM */ .Xz,
    getPathSlug: () => 'premium'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PREMIUM_MONTHLY */ .p2]: { ...getJetpackPremiumDetails(),
    ...getMonthlyTimeframe(),
    getProductId: () => 2003,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PREMIUM_MONTHLY */ .p2,
    getPathSlug: () => 'premium-monthly'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PERSONAL */ .ap]: { ...getJetpackPersonalDetails(),
    ...getAnnualTimeframe(),
    getProductId: () => 2005,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PERSONAL */ .ap,
    getPathSlug: () => 'jetpack-personal'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PERSONAL_MONTHLY */ .ns]: { ...getJetpackPersonalDetails(),
    ...getMonthlyTimeframe(),
    getProductId: () => 2006,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_PERSONAL_MONTHLY */ .ns,
    getPathSlug: () => 'jetpack-personal-monthly'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_BUSINESS */ .NJ]: { ...getJetpackBusinessDetails(),
    ...getAnnualTimeframe(),
    getProductId: () => 2001,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_BUSINESS */ .NJ,
    getPathSlug: () => 'professional'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_BUSINESS_MONTHLY */ .yY]: { ...getJetpackBusinessDetails(),
    ...getMonthlyTimeframe(),
    getProductId: () => 2004,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_BUSINESS_MONTHLY */ .yY,
    getPathSlug: () => 'professional-monthly'
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_DAILY */ .Vl]: { ...getPlanJetpackSecurityDailyDetails(),
    ...getAnnualTimeframe(),
    getMonthlySlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_DAILY_MONTHLY */ .Dl,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_DAILY */ .Vl,
    getPathSlug: () => 'security-daily',
    getProductId: () => 2010
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_DAILY_MONTHLY */ .Dl]: { ...getPlanJetpackSecurityDailyDetails(),
    ...getMonthlyTimeframe(),
    getAnnualSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_DAILY */ .Vl,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_DAILY_MONTHLY */ .Dl,
    getPathSlug: () => 'security-daily-monthly',
    getProductId: () => 2011
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_REALTIME */ .jI]: { ...getPlanJetpackSecurityRealtimeDetails(),
    ...getAnnualTimeframe(),
    getMonthlySlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_REALTIME_MONTHLY */ .G$,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_REALTIME */ .jI,
    getPathSlug: () => 'security-realtime',
    getProductId: () => 2012
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_REALTIME_MONTHLY */ .G$]: { ...getPlanJetpackSecurityRealtimeDetails(),
    ...getMonthlyTimeframe(),
    getAnnualSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_REALTIME */ .jI,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_REALTIME_MONTHLY */ .G$,
    getPathSlug: () => 'security-realtime-monthly',
    getProductId: () => 2013
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_COMPLETE */ .th]: { ...getPlanJetpackCompleteDetails(),
    ...getAnnualTimeframe(),
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_COMPLETE */ .th,
    getPathSlug: () => 'complete',
    getProductId: () => 2014
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_COMPLETE_MONTHLY */ .JX]: { ...getPlanJetpackCompleteDetails(),
    ...getMonthlyTimeframe(),
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_COMPLETE_MONTHLY */ .JX,
    getPathSlug: () => 'complete-monthly',
    getProductId: () => 2015
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_T1_YEARLY */ .Et]: { ...getPlanJetpackSecurityT1Details(),
    ...getAnnualTimeframe(),
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_T1_YEARLY */ .Et,
    getPathSlug: () => 'security-20gb-yearly',
    getProductId: () => 2016
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_T1_MONTHLY */ .w2]: { ...getPlanJetpackSecurityT1Details(),
    ...getMonthlyTimeframe(),
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_T1_MONTHLY */ .w2,
    getPathSlug: () => 'security-20gb-monthly',
    getProductId: () => 2017
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_T2_YEARLY */ .s1]: { ...getPlanJetpackSecurityT2Details(),
    ...getAnnualTimeframe(),
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_T2_YEARLY */ .s1,
    getPathSlug: () => 'security-1tb-yearly',
    getProductId: () => 2019
  },
  [_constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_T2_MONTHLY */ .aS]: { ...getPlanJetpackSecurityT2Details(),
    ...getMonthlyTimeframe(),
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_7__/* .PLAN_JETPACK_SECURITY_T2_MONTHLY */ .aS,
    getPathSlug: () => 'security-1tb-monthly',
    getProductId: () => 2020
  },
  [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_P2_PLUS */ .Ml]: {
    group: _constants__WEBPACK_IMPORTED_MODULE_5__/* .GROUP_WPCOM */ .w9,
    type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_P2_PLUS */ .QI,
    getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('P2+'),
    getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('{{strong}}Best for professionals:{{/strong}} Enhance your P2 with more space for audio and video, advanced search, an activity overview panel, and priority customer support.', plansDescriptionHeadingComponent),
    getShortDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Some short description'),
    getPlanCompareFeatures: () => [// pay attention to ordering, shared features should align on /plan page
    _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_P2_13GB_STORAGE */ .S_M, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_P2_ADVANCED_SEARCH */ .yjN, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_P2_VIDEO_SHARING */ .iC0, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_P2_MORE_FILE_TYPES */ .rdd, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_P2_PRIORITY_CHAT_EMAIL_SUPPORT */ .bJv, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_P2_ACTIVITY_OVERVIEW */ .ops],
    // TODO: update this once we put P2+ in the signup.
    getSignupFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_EMAIL_SUPPORT_SIGNUP */ .fhe],
    // TODO: no idea about this, copied from the WP.com Premium plan.
    // Features not displayed but used for checking plan abilities
    getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_AUDIO_UPLOADS */ .XMd, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SEARCH */ .lv3, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_JETPACK_SEARCH_MONTHLY */ .ewW],
    getInferiorFeatures: () => [],
    // TODO: Calypso requires this prop but we probably don't need it. Refactor Calypso?
    getAudience: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Best for bloggers'),
    ...getMonthlyTimeframe(),
    availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d].includes(plan),
    //TODO: only for P2 sites.
    getProductId: () => 1040,
    getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_P2_PLUS */ .Ml,
    getPathSlug: () => 'p2-plus',
    getBillingTimeFrame: () => (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .translate */ .Iu)('per user per month')
  }
};
PLANS_LIST[_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_P2_FREE */ .A2] = { ...PLANS_LIST[_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d],
  getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('{{strong}}Best for small groups:{{/strong}} All the features needed to share, discuss, review, and collaborate with your team in one spot, without interruptions.', plansDescriptionHeadingComponent),
  getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('P2 Free'),
  getPlanCompareFeatures: () => [// pay attention to ordering, shared features should align on /plan page
  _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_P2_3GB_STORAGE */ .$mN, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_P2_UNLIMITED_USERS */ .JqD, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_P2_UNLIMITED_POSTS_PAGES */ .bHF, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_P2_SIMPLE_SEARCH */ .XZZ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_P2_CUSTOMIZATION_OPTIONS */ .vje]
}; // Brand new WPCOM plans

PLANS_LIST[_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_STARTER */ .Id] = { ...getDotcomPlanDetails(),
  group: _constants__WEBPACK_IMPORTED_MODULE_5__/* .GROUP_WPCOM */ .w9,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_STARTER */ .xg,
  term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_ANNUALLY */ .w$,
  getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('WordPress Starter'),
  getProductId: () => 1033,
  getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_STARTER */ .Id,
  getPathSlug: () => 'starter',
  getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].hasTranslation */ .ZP.hasTranslation('Start with a custom domain name, simple payments, and extra storage.') || ['en', 'en-gb'].includes((0,i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* .getLocaleSlug */ .Yj)() || '') ? i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Start with a custom domain name, simple payments, and extra storage.') : i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Start your WordPress.com website. Limited functionality and storage.'),
  getSubTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Essential features. Freedom to grow.'),
  getBillingTimeFrame: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('per month, billed yearly'),
  getPlanCompareFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UNLIMITED_TRAFFIC */ .c__, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_MANAGED_HOSTING */ .FiJ, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_FREE_THEMES */ .jDM, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_CUSTOM_DOMAIN */ .Eb2, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_UNLIMITED_ADMINS */ .SsD, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_6GB_STORAGE */ .W4b, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_GOOGLE_ANALYTICS */ .Vms, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_PAYMENT_BLOCKS */ .x_7, _constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_TITAN_EMAIL */ .fDA],
  getIncludedFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .WPCOM_FEATURES_INSTALL_PURCHASED_PLUGINS */ .n26]
};
PLANS_LIST[_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_FLEXIBLE */ .Cq] = { // Inherits the free plan
  ...PLANS_LIST[_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d],
  group: _constants__WEBPACK_IMPORTED_MODULE_5__/* .GROUP_WPCOM */ .w9,
  type: _constants__WEBPACK_IMPORTED_MODULE_6__/* .TYPE_FLEXIBLE */ .qC,
  getTitle: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('WordPress Free'),
  getBillingTimeFrame: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('upgrade when you need'),
  getDescription: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('Start your free WordPress.com website. Limited functionality and storage.'),
  getPlanCompareFeatures: () => [_constants__WEBPACK_IMPORTED_MODULE_4__/* .FEATURE_1GB_STORAGE */ .Zaf]
};
PLANS_LIST[_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO */ ._s] = { ...getPlanProDetails(),
  term: _constants__WEBPACK_IMPORTED_MODULE_3__/* .TERM_ANNUALLY */ .w$,
  getProductId: () => 1032,
  getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO */ ._s,
  getPathSlug: () => 'pro',
  getBillingTimeFrame: () => i18n_calypso__WEBPACK_IMPORTED_MODULE_2__/* ["default"].translate */ .ZP.translate('per month, billed yearly')
};
PLANS_LIST[_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO_MONTHLY */ .dU] = { ...getPlanProDetails(),
  ...getMonthlyTimeframe(),
  availableFor: plan => [_constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_FREE */ ._d].includes(plan),
  getProductId: () => 1034,
  getStoreSlug: () => _constants__WEBPACK_IMPORTED_MODULE_5__/* .PLAN_WPCOM_PRO_MONTHLY */ .dU,
  getPathSlug: () => 'pro-monthly'
};

/***/ }),

/***/ 78038:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ format; }
/* harmony export */ });
/* harmony import */ var _url_type__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4174);

const BASE_URL = 'http://__domain__.invalid/';
/**
 * Format a URL as a particular type.
 * Does not support formatting invalid or path-relative URLs.
 *
 * @param url The URL to format.
 * @param urlType The URL type into which to format. If not provided, defaults to the same type as `url`, which effectively results in the URL being normalized.
 * @returns The formatted URL.
 */

function format(url, urlType) {
  let parsed;
  let originalType;

  if (!(url instanceof URL) && typeof url !== 'string') {
    throw new Error('`url` should be a string or URL instance');
  }

  if (url instanceof URL) {
    // The native URL object can only represent absolute URLs.
    parsed = url;
    originalType = _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.ABSOLUTE */ .a.ABSOLUTE;
  } else {
    originalType = (0,_url_type__WEBPACK_IMPORTED_MODULE_0__/* .determineUrlType */ .D)(url);

    if (originalType === _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.INVALID */ .a.INVALID) {
      throw new Error('Cannot format an invalid URL.');
    }

    if (originalType === _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.PATH_RELATIVE */ .a.PATH_RELATIVE) {
      throw new Error('Cannot format path-relative URLs.');
    }

    parsed = new URL(url, BASE_URL);
  }

  if (urlType === undefined) {
    urlType = originalType;
  }

  switch (urlType) {
    case _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.PATH_RELATIVE */ .a.PATH_RELATIVE:
      throw new Error('Cannot format into path-relative URLs.');

    case _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.PATH_ABSOLUTE */ .a.PATH_ABSOLUTE:
      return parsed.href.replace(parsed.origin, '');

    case _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.SCHEME_RELATIVE */ .a.SCHEME_RELATIVE:
      if (originalType === _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.PATH_ABSOLUTE */ .a.PATH_ABSOLUTE) {
        throw new Error('Cannot format a path-absolute URL as a scheme-relative URL.');
      }

      return parsed.href.replace(parsed.protocol, '');

    case _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.ABSOLUTE */ .a.ABSOLUTE:
      if (originalType !== _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.ABSOLUTE */ .a.ABSOLUTE) {
        throw new Error('Cannot format a partial URL as an absolute URL.');
      }

      return parsed.href;

    default:
      throw new Error(`Cannot format as \`${urlType}\` URL type.`);
  }
}

/***/ }),

/***/ 94668:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "F": function() { return /* binding */ safeImageUrl; }
/* harmony export */ });
/* harmony import */ var photon__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(28636);
/* harmony import */ var _url_parts__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(6261);


/**
 * Pattern matching URLs to be left unmodified.
 */

let REGEX_EXEMPT_URL;

if (typeof globalThis.location === 'object') {
  REGEX_EXEMPT_URL = new RegExp(`^(/(?!/)|data:image/[^;]+;|blob:${globalThis.location.origin}/)`);
} else {
  REGEX_EXEMPT_URL = /^(\/(?!\/)|data:image\/[^;]+;)/;
}
/**
 * Pattern matching Automattic-controlled hostnames
 */


const REGEXP_A8C_HOST = /^([-a-zA-Z0-9_]+\.)*(gravatar\.com|wordpress\.com|wp\.com|a8c\.com)$/;
/**
 * Query parameters to be treated as image dimensions
 */

const SIZE_PARAMS = ['w', 'h', 'resize', 'fit', 's'];
/**
 * Generate a safe version of the provided URL
 *
 * Images that Calypso uses have to be provided by a trusted TLS host. To do
 * this, we check the host of the URL against a list of allowed hosts, and run the image
 * through photon if the host name does not match.
 *
 * NOTE: This function will return `null` for external URLs with query strings,
 * because Photon itself does not support this!
 *
 * @param  url The URL to secure
 * @returns The secured URL, or `null` if we couldn't make it safe
 */

function safeImageUrl(url) {
  if (typeof url !== 'string') {
    return null;
  }

  if (url.length < 1) {
    return null;
  }

  if (REGEX_EXEMPT_URL.test(url)) {
    return url;
  }

  const parsedUrl = (0,_url_parts__WEBPACK_IMPORTED_MODULE_0__/* .getUrlParts */ .A)(url);

  if (REGEXP_A8C_HOST.test(parsedUrl.hostname)) {
    // Safely promote Automattic domains to HTTPS
    parsedUrl.protocol = 'https';
    return (0,_url_parts__WEBPACK_IMPORTED_MODULE_0__/* .getUrlFromParts */ .C)(parsedUrl).toString();
  } // If there's a query string, bail out because Photon doesn't support them on external URLs


  if (parsedUrl.search && (parsedUrl.host || parsedUrl.hostname || parsedUrl.origin)) {
    // If it's just size parameters, let's remove them
    SIZE_PARAMS.forEach(param => parsedUrl.searchParams.delete(param)); // Ditch authuser=0 if we find it - we see this on googleusercontent.com URLs and it doesn't affect the image output

    if (parsedUrl.searchParams.get('authuser') === '0') {
      parsedUrl.searchParams.delete('authuser');
    } // There are still parameters left, since they might be needed to retrieve the image, bail out


    if (Array.from(parsedUrl.searchParams).length) {
      return null;
    } // Ensure we're creating a new URL without the size parameters


    parsedUrl.search = ''; // Force https since if there's a missing protocol it'll throw an error

    if (!(parsedUrl !== null && parsedUrl !== void 0 && parsedUrl.protocol)) {
      parsedUrl.protocol = 'https';
    }

    url = (0,_url_parts__WEBPACK_IMPORTED_MODULE_0__/* .getUrlFromParts */ .C)(parsedUrl).toString();
  } // Photon doesn't support SVGs


  if (parsedUrl.pathname.endsWith('.svg')) {
    return null;
  }

  return (0,photon__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(url);
}

/***/ }),

/***/ 6261:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "A": function() { return /* binding */ getUrlParts; },
/* harmony export */   "C": function() { return /* binding */ getUrlFromParts; }
/* harmony export */ });
/* harmony import */ var _url_type__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4174);

const BASE_URL = `http://__domain__.invalid`;
const EMPTY_URL = Object.freeze({
  protocol: '',
  host: '',
  hostname: '',
  port: '',
  origin: '',
  pathname: '',
  hash: '',
  search: '',
  searchParams: new URLSearchParams(),
  username: '',
  password: ''
});
const URL_PART_KEYS = Object.keys(EMPTY_URL);

function pickUrlParts(parsedUrl) {
  let include = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : URL_PART_KEYS;
  const pickedUrl = { ...EMPTY_URL
  };
  include.forEach(name => {
    pickedUrl[name] = (parsedUrl === null || parsedUrl === void 0 ? void 0 : parsedUrl[name]) ?? EMPTY_URL[name];
  });
  return pickedUrl;
}
/**
 * Returns the various available URL parts.
 *
 * @param url the URL to analyze
 * @returns   the URL parts
 */


function getUrlParts(url) {
  const urlType = (0,_url_type__WEBPACK_IMPORTED_MODULE_0__/* .determineUrlType */ .D)(url); // Invalid URL; return empty URL parts.

  if (urlType === _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.INVALID */ .a.INVALID) {
    return { ...EMPTY_URL
    };
  }

  const parsed = url instanceof URL ? url : new URL(url, BASE_URL); // Absolute URL; pick all parts.

  if (urlType === _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.ABSOLUTE */ .a.ABSOLUTE) {
    return pickUrlParts(parsed);
  } // Scheme-relative URL; pick everything except the protocol and origin.


  if (urlType === _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.SCHEME_RELATIVE */ .a.SCHEME_RELATIVE) {
    return pickUrlParts(parsed, URL_PART_KEYS.filter(item => item !== 'protocol' && item !== 'origin'));
  } // Path-absolute or path-relative URL; pick only a few parts.


  const pathPartKeys = ['pathname', 'hash', 'search', 'searchParams'];
  const pathParts = pickUrlParts(parsed, pathPartKeys); // Path-relative URLs require special handling, because they cannot be transformed
  // into an absolute URL without potentially losing path information.
  // E.g. `../foo?bar=baz` becomes `<base>/foo?bar=baz` when fed to `new URL()`
  // with a base, losing the traversal into the parent directory.
  // We need to handle these with string functions instead.

  if (urlType === _url_type__WEBPACK_IMPORTED_MODULE_0__/* .URL_TYPE.PATH_RELATIVE */ .a.PATH_RELATIVE) {
    pathParts.pathname = url.split(/[?#]/, 1)[0];
  }

  return pathParts;
}
/**
 * Returns a URL object built from the provided URL parts.
 *
 * @param parts the provided URL parts.
 * @returns the generated URL object.
 */

function getUrlFromParts(parts) {
  var _parts$searchParams;

  if (!(parts !== null && parts !== void 0 && parts.protocol) && !(parts !== null && parts !== void 0 && parts.origin)) {
    throw new Error('getUrlFromParts: protocol missing.');
  }

  if (!parts.host && !parts.hostname && !parts.origin) {
    throw new Error('getUrlFromParts: host missing.');
  }

  const result = new URL(BASE_URL); // Apply 'origin' first, since it includes protocol, hostname, and port.

  if (parts.origin) {
    try {
      const origin = new URL(parts.origin);
      result.host = origin.host;
      result.protocol = origin.protocol;
    } catch {
      throw new Error('getUrlFromParts: invalid origin.');
    }
  } // Apply 'host' next, since it includes both hostname and port.


  result.host = parts.host || result.host; // Apply 'searchParams' object if it's specified.

  if ((_parts$searchParams = parts.searchParams) !== null && _parts$searchParams !== void 0 && _parts$searchParams.toString) {
    result.search = parts.searchParams.toString();
  }

  for (const part of URL_PART_KEYS) {
    if (part !== 'host' && part !== 'origin' && part !== 'searchParams') {
      const value = parts[part]; // Avoid some implementation bugs, e.g. https://bugs.webkit.org/show_bug.cgi?id=127958.

      if (value && value !== result[part]) {
        result[part] = value;
      }
    }
  }

  return result;
}

/***/ }),

/***/ 4174:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "a": function() { return /* binding */ URL_TYPE; },
/* harmony export */   "D": function() { return /* binding */ determineUrlType; }
/* harmony export */ });
// For complete definitions of these classifications, see:
// https://url.spec.whatwg.org/#urls
let URL_TYPE;

(function (URL_TYPE) {
  URL_TYPE["ABSOLUTE"] = "ABSOLUTE";
  URL_TYPE["SCHEME_RELATIVE"] = "SCHEME_RELATIVE";
  URL_TYPE["PATH_ABSOLUTE"] = "PATH_ABSOLUTE";
  URL_TYPE["PATH_RELATIVE"] = "PATH_RELATIVE";
  URL_TYPE["INVALID"] = "INVALID";
})(URL_TYPE || (URL_TYPE = {}));

const BASE_HOSTNAME = '__domain__.invalid';
const BASE_URL = `http://${BASE_HOSTNAME}`;
/**
 * Determine the type of a URL, with regards to its completeness.
 *
 * @param url the URL to analyze
 * @returns the type of the URL
 */

function determineUrlType(url) {
  // Check for expected parameter types.
  if (!(url instanceof URL) && typeof url !== 'string') {
    return URL_TYPE.INVALID;
  } // As a URL, the empty string means "the current resource".


  if (url === '') {
    return URL_TYPE.PATH_RELATIVE;
  } // The native URL object can only represent absolute URLs.


  if (url instanceof URL) {
    return URL_TYPE.ABSOLUTE;
  }

  let parsed;

  try {
    // If we can parse the URL without a base, it's an absolute URL.
    // The polyfill works differently, however, so we need to take that into account.
    // See https://github.com/webcomponents/polyfills/issues/241
    parsed = new URL(url);

    if (parsed.protocol && parsed.protocol !== ':') {
      return URL_TYPE.ABSOLUTE;
    }
  } catch {// Do nothing.
  }

  try {
    parsed = new URL(url, BASE_URL);
  } catch {
    // If it can't be parsed even with a base URL, it's an invalid URL.
    return URL_TYPE.INVALID;
  } // The polyfill sometimes doesn't throw an exception for invalid URLs, instead
  // leaving the `pathname` blank (which it shouldn't be, at this point).


  if (parsed.pathname === '') {
    return URL_TYPE.INVALID;
  } // If we couldn't parse it without a base, but it didn't take the hostname we provided, that means
  // it's a protocol-relative URL.


  if (parsed.hostname !== BASE_HOSTNAME) {
    return URL_TYPE.SCHEME_RELATIVE;
  } // Otherwise, it's a relative URL of some sort.


  if (url.startsWith('/')) {
    return URL_TYPE.PATH_ABSOLUTE;
  }

  return URL_TYPE.PATH_RELATIVE;
}

/***/ }),

/***/ 43239:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(7896);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _style_scss__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(43261);






const isAnchor = props => !!props.href;

const cleanAnchorProps = _ref => {
  let {
    type,
    borderless,
    busy,
    className,
    compact,
    primary,
    scary,
    plain,
    ...anchorProps
  } = _ref;
  return anchorProps;
};

const cleanButtonProps = _ref2 => {
  let {
    type = 'button',
    borderless,
    busy,
    className,
    compact,
    primary,
    scary,
    plain,
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore Clean incorrect usage of the component
    rel,
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore Clean incorrect usage of the component
    href,
    // eslint-disable-next-line @typescript-eslint/ban-ts-comment
    // @ts-ignore Clean incorrect usage of the component
    target,
    ...buttonProps
  } = _ref2;
  return { ...buttonProps,
    type
  };
};

const Button = (props, ref) => {
  const classes = props.plain ? classnames__WEBPACK_IMPORTED_MODULE_1___default()('button-plain', props.className) : classnames__WEBPACK_IMPORTED_MODULE_1___default()('button', props.className, {
    'is-compact': props.compact,
    'is-primary': props.primary,
    'is-scary': props.scary,
    'is-busy': props.busy,
    'is-borderless': props.borderless
  });

  if (isAnchor(props)) {
    const anchorProps = cleanAnchorProps(props); // block referrers when external link

    const rel = anchorProps.target ? (anchorProps.rel || '').replace(/noopener|noreferrer/g, '') + ' noopener noreferrer' : anchorProps.rel;
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("a", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)({}, anchorProps, {
      rel: rel,
      className: classes,
      ref: ref
    }));
  }

  const buttonProps = cleanButtonProps(props);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("button", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)({}, buttonProps, {
    className: classes,
    ref: ref
  }));
};

const ButtonWithForwardedRef = /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_2__.forwardRef)(Button);
ButtonWithForwardedRef.defaultProps = {
  type: 'button'
};
/* harmony default export */ __webpack_exports__["Z"] = (ButtonWithForwardedRef);

/***/ }),

/***/ 98148:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(7896);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _gridicon__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(56399);
/* harmony import */ var _style_scss__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(53616);






const Card = (_ref, forwardedRef) => {
  let {
    children,
    className,
    compact,
    displayAsLink,
    highlight,
    tagName = 'div',
    href,
    target,
    ...props
  } = _ref;
  const elementClass = classnames__WEBPACK_IMPORTED_MODULE_0___default()('card', className, {
    'is-card-link': displayAsLink || href,
    'is-clickable': props.onClick,
    'is-compact': compact,
    'is-highlight': highlight
  }, highlight ? 'is-' + highlight : false);
  return href ? /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_1__.createElement)("a", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)({}, props, {
    href: href,
    target: target,
    className: elementClass,
    ref: forwardedRef
  }), /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_1__.createElement)(_gridicon__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, {
    className: "card__link-indicator",
    icon: target ? 'external' : 'chevron-right'
  }), children) : /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_1__.createElement)(tagName, { ...props,
    className: elementClass,
    ref: forwardedRef
  }, displayAsLink && /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_1__.createElement)(_gridicon__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, {
    className: "card__link-indicator",
    icon: target ? 'external' : 'chevron-right'
  }), children);
};

const ForwardedRefCard = /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_1__.forwardRef)(Card);
ForwardedRefCard.displayName = 'Card';
/* harmony default export */ __webpack_exports__["Z"] = (/*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_1__.memo)(ForwardedRefCard));

/***/ }),

/***/ 27136:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(56399);
/* harmony import */ var _style_scss__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(81712);





const FormInputValidation = _ref => {
  let {
    isError = false,
    isWarning,
    isHidden,
    className,
    text,
    icon,
    id,
    children
  } = _ref;
  const classes = classnames__WEBPACK_IMPORTED_MODULE_1___default()(className, {
    'form-input-validation': true,
    'is-warning': isWarning,
    'is-error': isError,
    'is-hidden': isHidden
  });
  const defaultIcon = isError || isWarning ? 'notice-outline' : 'checkmark';
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: classes,
    role: "alert"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", {
    id: id
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(___WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z, {
    size: 24,
    icon: icon ? icon : defaultIcon
  }), " ", text, children));
};

/* harmony default export */ __webpack_exports__["Z"] = (FormInputValidation);

/***/ }),

/***/ 56399:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(7896);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var gridicons_dist_util_icons_offset__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(32421);
/* harmony import */ var gridicons_dist_util_icons_offset__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(gridicons_dist_util_icons_offset__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var gridicons_svg_sprite_gridicons_svg__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(68785);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_4__);






const Gridicon = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4__.memo( /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_4__.forwardRef((props, ref) => {
  const {
    size = 24,
    icon,
    className,
    title,
    ...otherProps
  } = props;
  const isModulo18 = size % 18 === 0; // Using a missing icon doesn't produce any errors, just a blank icon, which is the exact intended behaviour.
  // This means we don't need to perform any checks on the icon name.

  const iconName = `gridicons-${icon}`;
  const iconClass = classnames__WEBPACK_IMPORTED_MODULE_1___default()('gridicon', iconName, className, {
    'needs-offset': isModulo18 && gridicons_dist_util_icons_offset__WEBPACK_IMPORTED_MODULE_2__.iconsThatNeedOffset.includes(iconName),
    'needs-offset-x': isModulo18 && gridicons_dist_util_icons_offset__WEBPACK_IMPORTED_MODULE_2__.iconsThatNeedOffsetX.includes(iconName),
    'needs-offset-y': isModulo18 && gridicons_dist_util_icons_offset__WEBPACK_IMPORTED_MODULE_2__.iconsThatNeedOffsetY.includes(iconName)
  });
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("svg", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 24 24",
    className: iconClass,
    height: size,
    width: size,
    ref: ref
  }, otherProps), title && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("title", null, title), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("use", {
    xlinkHref: `${gridicons_svg_sprite_gridicons_svg__WEBPACK_IMPORTED_MODULE_3__}#${iconName}`
  }));
}));
Gridicon.displayName = 'Gridicon';
/* harmony default export */ __webpack_exports__["Z"] = (Gridicon);

/***/ }),

/***/ 13668:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(65736);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _style_scss__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(32014);


const __ = _wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__.__;




const PaginationControl = _ref => {
  let {
    activePageIndex,
    numberOfPages,
    onChange,
    classNames,
    children
  } = _ref;
  const classes = classnames__WEBPACK_IMPORTED_MODULE_2___default()('pagination-control', classNames);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("ul", {
    className: classes,
    "aria-label": __('Pagination control')
  }, (0,lodash__WEBPACK_IMPORTED_MODULE_3__.times)(numberOfPages, index => (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("li", {
    key: `${numberOfPages}-${index}`,
    "aria-current": index === activePageIndex ? 'page' : undefined
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("button", {
    className: classnames__WEBPACK_IMPORTED_MODULE_2___default()('pagination-control__page', {
      'is-current': index === activePageIndex
    }),
    disabled: index === activePageIndex,
    "aria-label": (0,_wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__.sprintf)(
    /* translators: 1: current page number 2: total number of pages */
    __('Page %1$d of %2$d'), index + 1, numberOfPages),
    onClick: () => onChange(index)
  }))), children && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("li", {
    className: "pagination-control__last-item"
  }, children));
};

/* harmony default export */ __webpack_exports__["Z"] = (PaginationControl);

/***/ }),

/***/ 37499:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(7896);
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(56666);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(18373);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(13980);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_11___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_11__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(91850);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _root_child__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(88060);
/* harmony import */ var _util__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(51010);
/* harmony import */ var _style_scss__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(17228);













const noop = () => {};

class PopoverInner extends react__WEBPACK_IMPORTED_MODULE_3__.Component {
  constructor() {
    super(...arguments);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(this, "scheduledPositionUpdate", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(this, "scheduledFocus", null);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(this, "popoverNodeRef", /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_3__.createRef)());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(this, "popoverInnerNodeRef", /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_3__.createRef)());

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(this, "state", {
      left: -99999,
      top: -99999,
      positionClass: this.getPositionClass(this.props.position)
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(this, "onKeydown", event => {
      if (event.keyCode === 27) {
        const domContext = react_dom__WEBPACK_IMPORTED_MODULE_4___default().findDOMNode(this.props.context);

        if (domContext) {
          domContext.focus();
        }

        this.close(true);
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(this, "getTouchEvent", () => {
      if ('onpointerdown' in document) {
        return 'pointerdown';
      }

      if ('ontouchstart' in document) {
        return 'touchstart';
      }

      return 'click';
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(this, "onClickout", event => {
      const popoverContext = this.popoverInnerNodeRef.current;
      let shouldClose = popoverContext && !popoverContext.contains(event.target);

      if (shouldClose && this.props.context) {
        const domContext = react_dom__WEBPACK_IMPORTED_MODULE_4___default().findDOMNode(this.props.context);
        shouldClose = domContext && !domContext.contains(event.target);
      }

      if (shouldClose && this.props.ignoreContext) {
        const ignoreContext = react_dom__WEBPACK_IMPORTED_MODULE_4___default().findDOMNode(this.props.ignoreContext);
        shouldClose = ignoreContext && !ignoreContext.contains(event.target);
      }

      if (shouldClose) {
        this.close();
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(this, "onWindowChange", () => {
      this.setPosition();
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(this, "setPosition", () => {
      let position; // Do we have a custom position provided?

      if (this.props.customPosition) {
        position = Object.assign({
          // Use the default if positionClass hasn't been provided
          positionClass: this.getPositionClass(this.constructor.defaultProps.position)
        }, this.props.customPosition);
      } else {
        position = this.computePosition();
      }

      if (position) {
        this.setState(position);
      }
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(this, "handleOnMouseEnter", () => {
      const {
        onMouseEnter
      } = this.props;
      onMouseEnter === null || onMouseEnter === void 0 ? void 0 : onMouseEnter();
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(this, "handleOnMouseLeave", () => {
      const {
        onMouseLeave
      } = this.props;
      onMouseLeave === null || onMouseLeave === void 0 ? void 0 : onMouseLeave();
    });
  }

  componentDidMount() {
    this.bindListeners();
    this.setPosition();
    this.show();
  }

  componentDidUpdate() {
    // Update our position even when only our children change. To prevent infinite loops,
    // use `defer` and avoid scheduling a second update when one is already scheduled by
    // setting and checking `this.scheduledPositionUpdate`.
    // See https://github.com/Automattic/wp-calypso/commit/38e779cfebf6dd42bb30d8be7127951b0c531ae2
    if (this.scheduledPositionUpdate == null) {
      this.scheduledPositionUpdate = (0,lodash__WEBPACK_IMPORTED_MODULE_2__.defer)(() => {
        this.setPosition();
        this.scheduledPositionUpdate = null;
      });
    }
  }

  componentWillUnmount() {
    this.unbindListeners();
  }

  bindListeners() {
    this.bindClickoutHandler();
    this.bindEscKeyListener();
    this.bindReposition();
    (0,_util__WEBPACK_IMPORTED_MODULE_7__/* .bindWindowListeners */ .fN)();
  }

  unbindListeners() {
    this.unbindClickoutHandler();
    this.unbindEscKeyListener();
    this.unbindReposition();
    (0,_util__WEBPACK_IMPORTED_MODULE_7__/* .unbindWindowListeners */ .zR)(); // cancel the scheduled reposition when the Popover is being removed from DOM

    if (this.scheduledPositionUpdate != null) {
      window.clearTimeout(this.scheduledPositionUpdate);
      this.scheduledPositionUpdate = null;
    } // cancel the scheduled focus when we're hiding the Popover before the task had a chance to run


    if (this.scheduledFocus != null) {
      window.clearTimeout(this.scheduledFocus);
      this.scheduledFocus = null;
    }
  } // --- ESC key ---


  bindEscKeyListener() {
    if (this.props.closeOnEsc) {
      document.addEventListener('keydown', this.onKeydown, true);
    }
  }

  unbindEscKeyListener() {
    if (this.props.closeOnEsc) {
      document.removeEventListener('keydown', this.onKeydown, true);
    }
  }

  // --- click outside ---
  bindClickoutHandler() {
    // run the listener in the capture phase, to run before the React click handler that
    // runs in the bubble phase. Sometimes, the React UI handler for a click closes its
    // UI element and removes the event target from DOM. Running the clickout handler after
    // that would fail to evaluate correctly if the `event.target` (already removed from DOM)
    // is a DOM child of the popover's DOM element.
    document.addEventListener(this.getTouchEvent(), this.onClickout, true);
  }

  unbindClickoutHandler() {
    document.removeEventListener(this.getTouchEvent(), this.onClickout, true);
  }

  // --- window `scroll` and `resize` ---
  bindReposition() {
    window.addEventListener('scroll', this.onWindowChange, true);
    window.addEventListener('resize', this.onWindowChange, true);
  }

  unbindReposition() {
    window.removeEventListener('scroll', this.onWindowChange, true);
    window.removeEventListener('resize', this.onWindowChange, true);
  }

  focusPopover() {
    // Defer the focus a bit to make sure that the popover already has the final position.
    // Initially, after first render, the popover is positioned outside the screen, at
    // { top: -9999, left: -9999 } where it already has dimensions. These dimensions are measured
    // and used to calculate the final position.
    // Focusing the element while it's off the screen would cause unwanted scrolling.
    this.scheduledFocus = (0,lodash__WEBPACK_IMPORTED_MODULE_2__.defer)(() => {
      if (this.popoverNodeRef.current) {
        this.popoverNodeRef.current.focus();
      }

      this.scheduledFocus = null;
    });
  }

  getPositionClass(position) {
    return `is-${position.replace(/\s+/g, '-')}`;
  }
  /**
   * Adjusts position swapping left and right values
   * when right-to-left directionality is found.
   *
   * @param {string} position Original position
   * @returns {string} Adjusted position
   */


  adjustRtlPosition(position) {
    if (this.props.isRtl) {
      switch (position) {
        case 'top right':
        case 'right top':
          return 'top left';

        case 'right':
          return 'left';

        case 'bottom right':
        case 'right bottom':
          return 'bottom left';

        case 'bottom left':
        case 'left bottom':
          return 'bottom right';

        case 'left':
          return 'right';

        case 'top left':
        case 'left top':
          return 'top right';
      }
    }

    return position;
  }
  /**
   * Computes the position of the Popover in function
   * of its main container and the target.
   *
   * @returns {object} reposition parameters
   */


  computePosition() {
    const {
      position,
      relativePosition
    } = this.props;
    const domContainer = this.popoverInnerNodeRef.current;
    const domContext = react_dom__WEBPACK_IMPORTED_MODULE_4___default().findDOMNode(this.props.context);

    if (!domContext) {
      return null;
    }

    let suggestedPosition = position;

    if (this.props.autoRtl) {
      suggestedPosition = this.adjustRtlPosition(suggestedPosition);
    }

    if (this.props.autoPosition) {
      suggestedPosition = (0,_util__WEBPACK_IMPORTED_MODULE_7__/* .suggested */ .X6)(suggestedPosition, domContainer, domContext);
    }

    const reposition = Object.assign({}, (0,_util__WEBPACK_IMPORTED_MODULE_7__/* .constrainLeft */ .Ou)((0,_util__WEBPACK_IMPORTED_MODULE_7__/* .offset */ .cv)(suggestedPosition, domContainer, domContext, relativePosition), domContainer), {
      positionClass: this.getPositionClass(suggestedPosition)
    });
    return reposition;
  }

  getStylePosition() {
    const {
      left,
      top
    } = this.state;
    return {
      left,
      top
    };
  }

  show() {
    if (this.props.focusOnShow) {
      this.focusPopover();
    }

    this.props.onShow();
  }

  close() {
    let wasCanceled = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
    this.props.onClose(wasCanceled);
  }

  render() {
    if (!this.props.context) {
      return null;
    }

    const classes = classnames__WEBPACK_IMPORTED_MODULE_1___default()('popover', this.props.className, this.state.positionClass);
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      ref: this.popoverNodeRef,
      "aria-label": this.props['aria-label'],
      id: this.props.id,
      role: "tooltip",
      tabIndex: "-1",
      style: this.getStylePosition(),
      className: classes,
      onMouseEnter: this.handleOnMouseEnter,
      onMouseLeave: this.handleOnMouseLeave
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      className: "popover__arrow"
    }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      ref: this.popoverInnerNodeRef,
      className: "popover__inner"
    }, this.props.children));
  }

} // Wrapping children inside `<RootChild>` changes the timing of lifecycles and setting refs,
// because the children are rendered inside `RootChild`'s `componentDidMount`, later than
// usual. That's why we need this wrapper that removes `RootChild` from the inner component
// and simplifies its complicated lifecycle logic.
//
// We also use the outer component to manage the `show` state that can be delayed behind
// the outer `isVisible` prop by the `showDelay` timeout. One consequence is that the `RootChild`
// is created on show and destroyed on hide, making sure that the last shown popover will be
// also the last DOM element inside `document.body`, ensuring that it has a higher z-index.


(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(PopoverInner, "defaultProps", {
  autoPosition: true,
  autoRtl: true,
  className: '',
  closeOnEsc: true,
  isRtl: false,
  focusOnShow: true,
  position: 'top',
  onShow: noop,
  onClose: noop,
  onMouseEnter: noop,
  onMouseLeave: noop
});

function Popover(_ref) {
  let {
    isVisible = false,
    showDelay = 0,
    ...props
  } = _ref;
  const isRtl = (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_8__/* .useRtl */ .V)();
  const [show, setShow] = (0,react__WEBPACK_IMPORTED_MODULE_3__.useState)(isVisible); // If `showDelay` is non-zero, the hide -> show transition will be delayed and will not
  // happen immediately after the new value of `isVisible` is received.

  (0,react__WEBPACK_IMPORTED_MODULE_3__.useEffect)(() => {
    if (showDelay > 0 && show !== isVisible && isVisible) {
      const showDelayTimer = setTimeout(() => {
        setShow(true);
      }, showDelay);
      return () => {
        clearTimeout(showDelayTimer);
      };
    }
  }, [showDelay, isVisible, show]); // sync the `isVisible` flag to `show` state immediately, unless it's a hide -> show transition
  // and `showDelay` is non-zero. In that case, the hide -> show transition will be delayed by
  // the `useEffect` hook.

  if (show !== isVisible && (showDelay === 0 || !isVisible)) {
    setShow(isVisible);
  }

  if (!show) {
    return null;
  }

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_root_child__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(PopoverInner, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_10__/* ["default"] */ .Z)({}, props, {
    isRtl: isRtl
  })));
} // We accept DOM elements and React component instances as the `context` prop.
// In case of a React component instance, we'll find the DOM element with `findDOMNode`.


const PropTypeElement = prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOfType([prop_types__WEBPACK_IMPORTED_MODULE_11___default().instanceOf(react__WEBPACK_IMPORTED_MODULE_3__.Component), prop_types__WEBPACK_IMPORTED_MODULE_11___default().instanceOf(typeof window !== 'undefined' ? window.Element : Object)]);
Popover.propTypes = {
  autoPosition: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),
  autoRtl: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),
  className: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),
  closeOnEsc: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),
  id: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().string),
  context: PropTypeElement,
  ignoreContext: PropTypeElement,
  isVisible: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),
  focusOnShow: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().bool),
  position: prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOf(['top', 'top right', 'right', 'bottom right', 'bottom', 'bottom left', 'left', 'top left']),
  showDelay: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number),
  onShow: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func),
  onClose: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().func),
  relativePosition: prop_types__WEBPACK_IMPORTED_MODULE_11___default().shape({
    left: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number)
  }),
  // Bypass position calculations and provide custom position values
  customPosition: prop_types__WEBPACK_IMPORTED_MODULE_11___default().shape({
    top: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number),
    left: (prop_types__WEBPACK_IMPORTED_MODULE_11___default().number),
    positionClass: prop_types__WEBPACK_IMPORTED_MODULE_11___default().oneOf(['top', 'right', 'bottom', 'left'])
  })
};
/* harmony default export */ __webpack_exports__["Z"] = (Popover);

/***/ }),

/***/ 51010:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "fN": function() { return /* binding */ bindWindowListeners; },
/* harmony export */   "zR": function() { return /* binding */ unbindWindowListeners; },
/* harmony export */   "X6": function() { return /* binding */ suggested; },
/* harmony export */   "cv": function() { return /* binding */ offset; },
/* harmony export */   "Ou": function() { return /* binding */ constrainLeft; }
/* harmony export */ });
// inspired by https://github.com/jkroso/viewport
function updateViewport() {
  const viewport = {};
  viewport.top = window.scrollY;
  viewport.left = window.scrollX;
  viewport.width = window.innerWidth;
  viewport.height = window.innerHeight;
  viewport.right = viewport.left + viewport.width;
  viewport.bottom = viewport.top + viewport.height;
  return viewport;
}

const opposite = {
  top: 'bottom',
  bottom: 'top',
  left: 'right',
  right: 'left'
};
const adjacent = {
  top: 'right',
  left: 'top',
  bottom: 'left',
  right: 'bottom'
};
let _viewport = null;
let _windowEventsRefCount = 0;

function getViewport() {
  if (!_viewport) {
    // initialize on first use
    _viewport = updateViewport();
  }

  return _viewport;
}

function onViewportChange() {
  _viewport = updateViewport();
}

function bindWindowListeners() {
  if (_windowEventsRefCount++ > 0) {
    return;
  } // don't debounce these because they don't so any work that requires layout


  window.addEventListener('resize', onViewportChange, true);
  window.addEventListener('scroll', onViewportChange, true);
}
function unbindWindowListeners() {
  if (--_windowEventsRefCount > 0) {
    return;
  }

  window.removeEventListener('resize', onViewportChange, true);
  window.removeEventListener('scroll', onViewportChange, true);
}
function suggested(pos, el, target) {
  const viewport = getViewport();
  const targetPosition = target.getBoundingClientRect();
  const h = el.clientHeight;
  const w = el.clientWidth; // see where we have spare room

  const room = {
    top: targetPosition.top - h,
    bottom: viewport.height - targetPosition.bottom - h,
    left: targetPosition.left - w,
    right: viewport.width - targetPosition.right - w
  };
  const arrayPositions = pos.split(/\s+/);
  const [pos0] = arrayPositions;
  let [, pos1] = arrayPositions;
  const primary = choosePrimary(pos0, room);

  if (pos1 === primary || pos1 === opposite[primary]) {
    pos1 = null;
  }

  return chooseSecondary(primary, pos1, el, target, w, h) || pos;
}

function choosePrimary(prefered, room) {
  // top, bottom, left, right in order of preference
  const order = [prefered, opposite[prefered], adjacent[prefered], opposite[adjacent[prefered]]];
  let best = -Infinity;
  let bestPos;

  for (let i = 0, len = order.length; i < len; i++) {
    const _prefered = order[i];
    const space = room[_prefered]; // the first side it fits completely

    if (space > 0) {
      return _prefered;
    } // less chopped of than other sides


    if (space > best) {
      best = space, bestPos = prefered;
    }
  }

  return bestPos;
}

function chooseSecondary(primary, prefered, el, target, w, h) {
  const viewport = getViewport(); // top, top left, top right in order of preference

  const isVertical = primary === 'top' || primary === 'bottom';
  const order = prefered ? [isVertical ? `${primary} ${prefered}` : `${prefered} ${primary}`, primary, isVertical ? `${primary} ${opposite[prefered]}` : `${opposite[prefered]} ${primary}`] : [primary, isVertical ? `${primary} ${adjacent[primary]}` : `${adjacent[primary]} ${primary}`, isVertical ? `${primary} ${opposite[adjacent[primary]]}` : `${opposite[adjacent[primary]]} ${primary}`];
  let bestPos;
  let best = 0;
  const max = w * h;

  for (let i = 0, len = order.length; i < len; i++) {
    const pos = order[i];
    const off = offset(pos, el, target);
    const offRight = off.left + w;
    const offBottom = off.top + h;
    const yVisible = Math.min(off.top < viewport.top ? offBottom - viewport.top : viewport.bottom - off.top, h);
    const xVisible = Math.min(off.left < viewport.left ? offRight - viewport.left : viewport.right - off.left, w);
    const area = xVisible * yVisible; // the first position that shows all the tip

    if (area === max) {
      return pos;
    } // shows more of the tip than the other positions


    if (area > best) {
      best = area, bestPos = pos;
    }
  }

  return bestPos;
}

function offset(pos, el, target, relativePosition) {
  const pad = 15;
  const tipRect = el.getBoundingClientRect();

  if (!tipRect) {
    throw new Error('could not get bounding client rect of Tip element');
  }

  const ew = tipRect.width;
  const eh = tipRect.height;
  const targetRect = target.getBoundingClientRect();

  if (!targetRect) {
    throw new Error('could not get bounding client rect of `target`');
  }

  const tw = targetRect.width;
  const th = targetRect.height;

  const to = _offset(targetRect, document);

  if (!to) {
    throw new Error('could not determine page offset of `target`');
  }

  let _pos = {};

  switch (pos) {
    case 'top':
      _pos = {
        top: to.top - eh,
        left: relativePosition && relativePosition.left ? to.left + relativePosition.left : to.left + tw / 2 - ew / 2
      };
      break;

    case 'bottom':
      _pos = {
        top: to.top + th,
        left: relativePosition && relativePosition.left ? to.left + relativePosition.left : to.left + tw / 2 - ew / 2
      };
      break;

    case 'right':
      _pos = {
        top: to.top + th / 2 - eh / 2,
        left: to.left + tw
      };
      break;

    case 'left':
      _pos = {
        top: to.top + th / 2 - eh / 2,
        left: to.left - ew
      };
      break;

    case 'top left':
      _pos = {
        top: to.top - eh,
        left: to.left + tw / 2 - ew + pad
      };
      break;

    case 'top right':
      _pos = {
        top: to.top - eh,
        left: to.left + tw / 2 - pad
      };
      break;

    case 'bottom left':
      _pos = {
        top: to.top + th,
        left: to.left + tw / 2 - ew + pad
      };
      break;

    case 'bottom right':
      _pos = {
        top: to.top + th,
        left: to.left + tw / 2 - pad
      };
      break;

    case 'left top':
      _pos = {
        top: to.top + th / 2 - eh,
        left: to.left - ew
      };
      break;

    case 'left bottom':
      _pos = {
        top: to.top + th / 2,
        left: to.left - ew
      };
      break;

    case 'right top':
      _pos = {
        top: to.top + th / 2 - eh,
        left: to.left + tw
      };
      break;

    case 'right bottom':
      _pos = {
        top: to.top + th / 2,
        left: to.left + tw
      };
      break;

    default:
      throw new Error(`invalid position "${pos}"`);
  }

  return _pos;
}
/**
 * Extracted from `timoxley/offset`, but directly using a
 * TextRectangle instead of getting another version.
 *
 * @param {window.TextRectangle} box - result from a `getBoundingClientRect()` call
 * @param {window.Document} doc - Document instance to use
 * @returns {object} an object with `top` and `left` Number properties
 * @private
 */

function _offset(box, doc) {
  const body = doc.body || doc.getElementsByTagName('body')[0];
  const docEl = doc.documentElement || body.parentNode;
  const clientTop = docEl.clientTop || body.clientTop || 0;
  const clientLeft = docEl.clientLeft || body.clientLeft || 0;
  const scrollTop = window.pageYOffset || docEl.scrollTop;
  const scrollLeft = window.pageXOffset || docEl.scrollLeft;
  return {
    top: box.top + scrollTop - clientTop,
    left: box.left + scrollLeft - clientLeft
  };
}
/**
 * Constrain a left to keep the element in the window
 *
 * @param {object} off Proposed offset before constraining
 * @param {window.Element} el Element to be constained to viewport
 * @returns {number}    the best width
 */


function constrainLeft(off, el) {
  const viewport = getViewport();
  const ew = el.getBoundingClientRect().width;
  off.left = Math.max(0, Math.min(off.left, viewport.width - ew));
  return off;
}

/***/ }),

/***/ 88060:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(91850);
/* harmony import */ var react_dom__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react_dom__WEBPACK_IMPORTED_MODULE_1__);



const RootChild = _ref => {
  let {
    children
  } = _ref;
  // we can render the children only after the container DOM element has been created and added
  // to the DOM tree. And we can't create and append the element in component constructor because
  // there is no corresponding destructor that would safely remove it in case the render is not
  // committed by React.
  //
  // A seemingly possible approach is to create the element in constructor, render the portal into
  // it and then add it to `document.body` in `componentDidMount`. But that creates another subtle
  // bug: the portal is rendered into a DOM element that's not part of the DOM tree and therefore
  // is not part of layout and painting, and has no dimensions. Many component's lifecycles and
  // effect hooks rightfully assume that the element can be measured in `componentDidMount` or
  // `useEffect`.
  //
  // Another thing that fails inside a detached DOM element is accessing `iframe.contentWindow`.
  // The `contentWindow` is `null` until the `iframe` becomes active, i.e., is added to the DOM
  // tree. We access the `contentWindow` in `WebPreview`, for example.
  const [containerEl, setContainerEl] = (0,react__WEBPACK_IMPORTED_MODULE_0__.useState)(null);
  (0,react__WEBPACK_IMPORTED_MODULE_0__.useLayoutEffect)(() => {
    // create the container element and immediately trigger a rerender
    const element = document.createElement('div');
    document.body.appendChild(element);
    setContainerEl(element);
    return () => {
      document.body.removeChild(element);
    };
  }, []);

  if (!containerEl) {
    // don't render anything until the `containerEl` is created. That's the correct behavior
    // in SSR (no portals there, `RootChild` renders as empty).
    return null;
  }

  return /*#__PURE__*/react_dom__WEBPACK_IMPORTED_MODULE_1___default().createPortal(children, containerEl);
};

/* harmony default export */ __webpack_exports__["Z"] = (RootChild);

/***/ }),

/***/ 97493:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ ScreenReaderText; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _style_scss__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9723);


function ScreenReaderText(_ref) {
  let {
    children
  } = _ref;
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", {
    className: "screen-reader-text"
  }, children);
}

/***/ }),

/***/ 6010:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "$": function() { return /* binding */ Spinner; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(56666);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _style_scss__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(80418);





class Spinner extends react__WEBPACK_IMPORTED_MODULE_2__.PureComponent {
  render() {
    const className = classnames__WEBPACK_IMPORTED_MODULE_1___default()(this.props.baseClassName, this.props.className);
    const style = {
      width: this.props.size,
      height: this.props.size,
      fontSize: this.props.size // allows border-width to be specified in em units

    };
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      className: className
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      className: "spinner__outer",
      style: style
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      className: "spinner__inner"
    })));
  }

}

(0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)(Spinner, "defaultProps", {
  size: 20,
  baseClassName: 'spinner'
});

/***/ }),

/***/ 90544:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/**
 * Returns configuration value for given key
 *
 * If the requested key isn't defined in the configuration
 * data then this will report the failure with either an
 * error or a console warning.
 *
 * When in the 'development' NODE_ENV it will raise an error
 * to crash execution early. However, because many modules
 * call this function in the module-global scope a failure
 * here can not only crash that module but also entire
 * application flows as well as trigger unexpected and
 * unwanted behaviors. Therefore if the NODE_ENV is not
 * 'development' we will return `undefined` and log a message
 * to the console instead of halting the execution thread.
 *
 * The config files are loaded in sequence: _shared.json, {env}.json, {env}.local.json
 *
 * @see server/config/parser.js
 * @param data Configurat data.
 * @throws {ReferenceError} when key not defined in the config (NODE_ENV=development only)
 * @returns A function that gets the value of property named by the key
 */
const config = data => key => {
  if (key in data) {
    return data[key];
  }

  if (false) {} // display console error only in a browser
  // (not in tests, for example)


  if ('undefined' !== typeof window) {
    // eslint-disable-next-line no-console
    console.error('%cCore Error: ' + `%cCould not find config value for key %c${key}%c. ` + 'Please make sure that if you need it then it has a default value assigned in ' + '%cconfig/_shared.json' + '%c.', 'color: red; font-size: 120%', // error prefix
    'color: black;', // message
    'color: blue;', // key name
    'color: black;', // message
    'color: blue;', // config file reference
    'color: black' // message
    );
  }

  return undefined;
};
/**
 * Checks whether a specific feature is enabled.
 *
 * @param data the json environment configuration to use for getting config values
 * @returns A function that takes a feature name and returns true when the feature is enabled.
 */


const isEnabled = data => feature => data.features && !!data.features[feature] || false;
/**
 * Gets a list of all enabled features.
 *
 * @param data A set of config data (Not used by general users, is pre-filled via currying).
 * @returns List of enabled features (strings).
 */


const enabledFeatures = data => () => {
  if (!data.features) {
    return [];
  }

  return Object.entries(data.features).reduce((enabled, _ref) => {
    let [feature, isEnabled] = _ref;
    return isEnabled ? [...enabled, feature] : enabled;
  }, []);
};
/**
 * Enables a specific feature.
 *
 * @param data the json environment configuration to use for getting config values
 */


const enable = data => feature => {
  if (data.features) {
    data.features[feature] = true;
  }
};
/**
 * Disables a specific feature.
 *
 * @param data the json environment configuration to use for getting config values
 */


const disable = data => feature => {
  if (data.features) {
    data.features[feature] = false;
  }
};

/* harmony default export */ __webpack_exports__["Z"] = (data => {
  const configApi = config(data);
  configApi.isEnabled = isEnabled(data);
  configApi.enabledFeatures = enabledFeatures(data);
  configApi.enable = enable(data);
  configApi.disable = disable(data);
  return configApi;
});

/***/ }),

/***/ 85694:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_": function() { return /* binding */ generateAdminSections; }
/* harmony export */ });
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(65736);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_i18n__WEBPACK_IMPORTED_MODULE_0__);

const __ = _wordpress_i18n__WEBPACK_IMPORTED_MODULE_0__.__;
function generateAdminSections(siteSlug, customizerUrls, googleMailService, onboardingUrl) {
  return [{
    title: __('Add a new domain', "full-site-editing"),
    description: __('Set up your domain whether it’s registered with WordPress.com or elsewhere.'),
    link: `/domains/add/${siteSlug}`,
    synonyms: ['domains'],
    icon: 'domains'
  }, {
    title: __('Manage my domain settings', "full-site-editing"),
    description: __('Manage all domains linked to your account.', "full-site-editing"),
    link: `/domains/manage/${siteSlug}`,
    synonyms: ['domains'],
    icon: 'domains'
  }, {
    title: __('Change my site address', "full-site-editing"),
    link: `/domains/manage/${siteSlug}/edit/${siteSlug}`,
    synonyms: ['domains', 'domain'],
    icon: 'domains'
  }, {
    title: __('Add a site redirect', "full-site-editing"),
    description: __('Redirect your site to another domain.', "full-site-editing"),
    link: `/domains/add/site-redirect/${siteSlug}`,
    synonyms: ['domains', 'domain', 'forward'],
    icon: 'domains'
  }, {
    title: __('Change my password', "full-site-editing"),
    link: '/me/security',
    synonyms: ['update'],
    icon: 'cog'
  }, {
    title: __("Change my site's theme"),
    link: `/themes/${siteSlug}`,
    synonyms: ['switch', 'design'],
    icon: 'customize'
  }, {
    title: __("Customize my site's theme"),
    link: customizerUrls.root,
    synonyms: ['color', 'font', 'design', 'css', 'widgets'],
    icon: 'customize'
  }, {
    title: __('Change my homepage', "full-site-editing"),
    link: customizerUrls.homepage,
    synonyms: ['home', 'homepage'],
    icon: 'customize'
  }, {
    title: __('Edit my menu', "full-site-editing"),
    link: customizerUrls.menus,
    synonyms: ['menu'],
    icon: 'customize'
  }, {
    title: __('Set a site logo', "full-site-editing"),
    link: customizerUrls.identity,
    synonyms: ['logo', 'identity'],
    icon: 'customize'
  }, {
    title: __('Find a plan to suit my site', "full-site-editing"),
    link: `/plans/${siteSlug}`,
    synonyms: ['upgrade', 'business', 'professional', 'personal'],
    icon: 'plans'
  }, {
    title: __('Cancel my plan', "full-site-editing"),
    link: `/me/purchases`,
    synonyms: ['upgrade', 'business', 'professional', 'personal'],
    icon: 'plans'
  }, {
    title: __('Upgrade my plan', "full-site-editing"),
    link: `/plans/${siteSlug}`,
    synonyms: ['upgrade', 'business', 'professional', 'personal'],
    icon: 'plans'
  }, {
    /* translators: %(googleMailService)s can be either "G Suite" or "Google Workspace */
    title: (0,_wordpress_i18n__WEBPACK_IMPORTED_MODULE_0__.sprintf)(__('Cancel %s', "full-site-editing"), googleMailService),
    link: `/me/purchases`,
    synonyms: ['upgrade', 'business', 'professional', 'personal', 'google'],
    icon: 'plans'
  }, {
    title: __('Renew my plan', "full-site-editing"),
    link: `/plans/${siteSlug}`,
    synonyms: ['upgrade', 'business', 'professional', 'personal', 'plan'],
    icon: 'plans'
  }, {
    title: __('Renew my domain', "full-site-editing"),
    link: `/plans/${siteSlug}`,
    synonyms: ['domain', 'business', 'professional', 'personal', 'plan'],
    icon: 'plans'
  }, {
    title: __('View my site activity', "full-site-editing"),
    link: `/activity-log/${siteSlug}`,
    icon: 'history'
  }, {
    title: __("View my site's latest stats"),
    link: `/stats/day/${siteSlug}`,
    synonyms: ['analytics'],
    icon: 'stats-alt'
  }, {
    title: __('Upload an image, video, audio or document', "full-site-editing"),
    link: `/media/${siteSlug}`,
    synonyms: ['media', 'photo'],
    icon: 'image'
  }, {
    title: __('Import content from another site', "full-site-editing"),
    link: `/settings/import/${siteSlug}`,
    synonyms: ['medium', 'blogger', 'wix', 'squarespace'],
    icon: 'cloud-upload'
  }, {
    title: __('Earn money from my site', "full-site-editing"),
    description: __("By upgrading to the Premium plan, you'll be able to monetize your site through the WordAds program."),
    link: `/earn/${siteSlug}`,
    synonyms: ['monetize', 'wordads', 'premium'],
    icon: 'money'
  }, {
    title: __('Learn how to market my site', "full-site-editing"),
    link: `/marketing/tools/${siteSlug}`,
    synonyms: ['marketing', 'brand', 'logo', 'seo', 'tools', 'traffic'],
    icon: 'speaker'
  }, {
    title: __("Manage my site's users"),
    description: __('Invite new users and edit existing ones.', "full-site-editing"),
    link: `/people/team/${siteSlug}`,
    synonyms: ['administrator', 'editor', 'contributor', 'viewer', 'follower'],
    icon: 'user'
  }, {
    title: __('Invite new users to my site', "full-site-editing"),
    link: `/people/new/${siteSlug}`,
    synonyms: ['administrator', 'editor', 'contributor', 'viewer', 'follower'],
    icon: 'user'
  }, {
    title: __("Change my site's timezone"),
    link: `/settings/general/${siteSlug}#site-settings__blogtimezone`,
    synonyms: ['time', 'date'],
    icon: 'cog'
  }, {
    title: __('Launch my site', "full-site-editing"),
    description: __('Switch your site from private to public.', "full-site-editing"),
    link: `/settings/general/${siteSlug}#site-privacy-settings`,
    synonyms: ['private', 'public'],
    icon: 'cog'
  }, {
    title: __("Delete a site or a site's content"),
    description: __('Remove all posts, pages, and media, or delete a site completely.', "full-site-editing"),
    link: `/settings/general/${siteSlug}#site-tools__header`,
    icon: 'cog'
  }, {
    title: __('Set a site icon', "full-site-editing"),
    link: `/settings/general/${siteSlug}`,
    icon: 'cog',
    synonyms: ['logo']
  }, {
    title: __("Change my site's footer text"),
    description: __('You can customize your website by changing the footer credit in customizer.'),
    link: `/settings/general/${siteSlug}#site-settings__footer-credit-header`,
    synonyms: ['remove footer', 'update footer'],
    icon: 'cog'
  }, {
    title: __("Export my site's content and media library"),
    description: __('Export posts, pages and more from your site.', "full-site-editing"),
    link: `/settings/export/${siteSlug}`,
    synonyms: ['xml', 'images', 'migration', 'import', 'download'],
    icon: 'cog'
  }, {
    title: __('Manage sharing and social media connections', "full-site-editing"),
    link: `/sharing/${siteSlug}`,
    synonyms: ['facebook', 'twitter', 'twitter', 'tumblr', 'eventbrite'],
    icon: 'share'
  }, {
    title: __('Add sharing buttons to my site', "full-site-editing"),
    description: __('Allow readers to easily share your posts with others by adding sharing buttons throughout your site.'),
    link: `/sharing/buttons/${siteSlug}`,
    synonyms: ['like', 'reblog'],
    icon: 'share'
  }, {
    title: __('Install, manage, and search for site Plugins', "full-site-editing"),
    link: `/plugins/${siteSlug}`,
    synonyms: ['upload'],
    icon: 'plugins'
  }, {
    title: __('Approve or delete comments', "full-site-editing"),
    link: `/comments/all/${siteSlug}`,
    synonyms: ['spam', 'discussion', 'moderation', 'moderate'],
    icon: 'chat'
  }, {
    title: __('Manage how users can comment on my site', "full-site-editing"),
    link: `/settings/discussion/${siteSlug}`,
    synonyms: ['discussion', 'moderation', 'blocklist'],
    icon: 'cog'
  }, {
    title: __('Manage post categories', "full-site-editing"),
    link: `/settings/writing/${siteSlug}`,
    synonyms: ['post', 'category'],
    icon: 'cog'
  }, {
    title: __('Edit my site title, tagline, or logo', "full-site-editing"),
    link: `/settings/general/${siteSlug}`,
    synonyms: ['title', 'logo'],
    icon: 'cog'
  }, {
    title: __('Set up a podcast', "full-site-editing"),
    link: `/settings/writing/${siteSlug}#podcasting-details__link-header`,
    synonyms: ['podcast', 'radio', 'audio'],
    icon: 'cog'
  }, {
    title: __("Change my site's privacy settings"),
    link: `/settings/general/${siteSlug}#site-privacy-settings`,
    synonyms: ['privacy'],
    icon: 'cog'
  }, {
    title: __('Manage SEO and traffic settings', "full-site-editing"),
    link: `/settings/traffic/${siteSlug}`,
    synonyms: ['analytics', 'related', 'sitemap'],
    icon: 'cog'
  }, {
    title: __('Update my profile', "full-site-editing"),
    description: __('Update your name, profile image, and about text.', "full-site-editing"),
    link: '/me',
    synonyms: ['avatar'],
    icon: 'user'
  }, {
    title: __('Update my username or email address', "full-site-editing"),
    link: '/me/account',
    synonyms: ['user', 'account'],
    icon: 'cog'
  }, {
    title: __('Change the dashboard color scheme', "full-site-editing"),
    link: '/me/account#account__color_scheme',
    synonyms: ['theme'],
    icon: 'cog'
  }, {
    title: __('Switch the interface language', "full-site-editing"),
    description: __('Update the language of the interface you see across WordPress.com as a whole.'),
    link: '/me/account#account__language',
    synonyms: ['dashboard', 'change', 'language'],
    icon: 'cog'
  }, {
    title: __('Close my account permanently', "full-site-editing"),
    description: __('Delete all of your sites, and close your account completely.', "full-site-editing"),
    link: '/me/account/close',
    synonyms: ['delete'],
    icon: 'cog'
  }, {
    title: __('Change my account privacy settings', "full-site-editing"),
    link: '/me/privacy',
    synonyms: ['security', 'tracking'],
    icon: 'visible'
  }, {
    title: __('View my purchase and billing history', "full-site-editing"),
    link: '/me/purchases',
    synonyms: ['purchases', 'invoices', 'pending', 'payment', 'credit card'],
    icon: 'credit-card'
  }, {
    title: __('Download the WordPress.com app for my device', "full-site-editing"),
    description: __('Get WordPress apps for all your screens.', "full-site-editing"),
    link: '/me/get-apps',
    synonyms: ['android', 'iphone', 'mobile', 'desktop', 'phone'],
    icon: 'my-sites'
  }, {
    title: __('View my drafted posts', "full-site-editing"),
    link: `/posts/drafts/${siteSlug}`,
    synonyms: ['posts', 'draft'],
    icon: 'my-sites'
  }, {
    title: __('Manage my blog posts', "full-site-editing"),
    link: `/posts/${siteSlug}`,
    synonyms: ['lists', 'posts'],
    icon: 'my-sites'
  }, {
    title: __('New post', "full-site-editing"),
    description: __(`Create a new blog post on your site.`),
    link: `/post/${siteSlug}`,
    synonyms: ['lists', 'posts'],
    icon: 'my-sites'
  }, {
    title: __('View my drafted pages', "full-site-editing"),
    link: `/pages/drafts/${siteSlug}`,
    synonyms: ['pages', 'draft'],
    icon: 'my-sites'
  }, {
    title: __('Manage my pages', "full-site-editing"),
    link: `/pages/${siteSlug}`,
    synonyms: ['lists', 'pages'],
    icon: 'my-sites'
  }, {
    title: __('I cannot find my site on Google', "full-site-editing"),
    link: `/marketing/traffic/${siteSlug}`,
    synonyms: ['google', 'traffic', 'seo'],
    icon: 'speaker'
  }, {
    title: __('Verify my site with Google', "full-site-editing"),
    link: `/marketing/traffic/${siteSlug}`,
    synonyms: ['google', 'traffic', 'seo'],
    icon: 'cog'
  }, {
    title: __('Create a new site', "full-site-editing"),
    link: `${onboardingUrl}?ref=calypso-inline-help`,
    synonyms: ['site'],
    icon: 'cog'
  }, {
    title: __('View contact form messages', "full-site-editing"),
    link: `https://${siteSlug}/wp-admin/edit.php?post_type=feedback&calypsoify=1`,
    synonyms: ['contact', 'form'],
    icon: 'cog'
  }, {
    title: __('Portfolio projects (for those who have them active)', "full-site-editing"),
    link: `/types/jetpack-portfolio/${siteSlug}`,
    synonyms: ['portfolio'],
    icon: 'cog'
  }];
}

/***/ }),

/***/ 94514:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Sm": function() { return /* binding */ RESULT_TOUR; },
/* harmony export */   "fI": function() { return /* binding */ RESULT_VIDEO; },
/* harmony export */   "D_": function() { return /* binding */ SUPPORT_TYPE_CONTEXTUAL_HELP; },
/* harmony export */   "EE": function() { return /* binding */ SUPPORT_TYPE_API_HELP; },
/* harmony export */   "QZ": function() { return /* binding */ SUPPORT_TYPE_ADMIN_SECTION; },
/* harmony export */   "h_": function() { return /* binding */ SELL_INTENT; }
/* harmony export */ });
/* unused harmony exports RESULT_ARTICLE, VIEW_CONTACT, VIEW_RICH_RESULT, VIEW_FORUM, SUPPORT_BLOG_ID */
const RESULT_ARTICLE = 'article';
const RESULT_TOUR = 'tour';
const RESULT_VIDEO = 'video';
const VIEW_CONTACT = 'contact';
const VIEW_RICH_RESULT = 'richresult';
const VIEW_FORUM = 'forums';
const SUPPORT_BLOG_ID = 9619154;
const SUPPORT_TYPE_CONTEXTUAL_HELP = 'contextual_help';
const SUPPORT_TYPE_API_HELP = 'api_help';
const SUPPORT_TYPE_ADMIN_SECTION = 'admin_section';
const SELL_INTENT = 'sell_intent';

/***/ }),

/***/ 34923:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "r_": function() { return /* binding */ getContextResults; }
/* harmony export */ });
/* unused harmony exports defaultFallbackLinks, bloggerFallbackLinks, contextLinksForSection, videosForSection, toursForSection */
/* harmony import */ var _automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(47498);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(65736);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_i18n__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(94514);


const __ = _wordpress_i18n__WEBPACK_IMPORTED_MODULE_0__.__;


/**
 * Module variables
 */

/* eslint-disable inclusive-language/use-inclusive-words */
// All usage of the word "master" here refers to the verb (ie. "to learn"), not a synonym of "primary".
const defaultFallbackLinks = [{
  get link() {
    return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/do-i-need-a-website-a-blog-or-a-website-with-a-blog/');
  },

  post_id: 143180,

  get title() {
    return __('Do I Need a Website, a Blog, or a Website with a Blog?', "full-site-editing");
  },

  get description() {
    return __('If you’re building a brand new site, you might be wondering if you need a website, a blog, or a website with a blog. At WordPress.com, you can create all of these options easily, right in your dashboard.');
  }

}, {
  get link() {
    return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/business-plan/');
  },

  post_id: 134940,

  get title() {
    return __('Uploading custom plugins and themes', "full-site-editing");
  },

  get description() {
    return __('Learn more about installing a custom theme or plugin using the Business plan.', "full-site-editing");
  }

}, {
  get link() {
    return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/domains/');
  },

  post_id: 1988,

  get title() {
    return __('All About Domains', "full-site-editing");
  },

  get description() {
    return __('Set up your domain whether it’s registered with WordPress.com or elsewhere.', "full-site-editing");
  }

}, {
  get link() {
    return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/start/');
  },

  post_id: 81083,

  get title() {
    return __('Quick-Start Guide', "full-site-editing");
  },

  get description() {
    return __("Use our five-step checklist to get set up and ready to publish, no matter what kind of site you're building.");
  }

}, {
  get link() {
    return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/settings/privacy-settings/');
  },

  post_id: 1507,

  get title() {
    return __('Privacy Settings', "full-site-editing");
  },

  get description() {
    return __('Limit your site’s visibility or make it completely private.', "full-site-editing");
  }

}];
const bloggerFallbackLinks = [{
  get link() {
    return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/posts/');
  },

  get title() {
    return __('All about blog posts', "full-site-editing");
  }

}, {
  get link() {
    return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/subscriptions-and-newsletters/');
  },

  get title() {
    return __('Encourage visitors to subscribe to your content', "full-site-editing");
  }

}, {
  get link() {
    return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/publicize/');
  },

  get title() {
    return __('Share your content to social media automatically', "full-site-editing");
  }

}, {
  get link() {
    return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/sharing/');
  },

  get title() {
    return __('Encourage visitors to share your content', "full-site-editing");
  }

}, {
  get link() {
    return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/seo/');
  },

  get title() {
    return __('Learn about how to get noticed by search engines', "full-site-editing");
  }

}, {
  get link() {
    return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/site-verification-services/');
  },

  get title() {
    return __('Verify your site with Google and other services', "full-site-editing");
  }

}];
const contextLinksForSection = {
  stats: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/stats/');
    },

    post_id: 4454,

    get title() {
      return __('Understanding the Stats Page', "full-site-editing");
    },

    get description() {
      return __('Your stats page includes a bunch of nifty graphs, charts, and lists that show you how many ' + 'visits your site gets, what posts and pages are the most popular ones, and much more. Learn what it all means.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/getting-more-views-and-traffic/');
    },

    post_id: 3307,

    get title() {
      return __('Getting More Views and Traffic', "full-site-editing");
    },

    get description() {
      return __('Want more traffic? Here are some tips for attracting more visitors to your site.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/getting-more-views-and-traffic/');
    },

    post_id: 132186,

    get title() {
      return __('Increase Your Site Traffic', "full-site-editing");
    },

    get description() {
      return __('One of the most frequent questions our community members ask us — and themselves — ' + 'is how to get more traffic. Here are a few best practices.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/grow-your-community/');
    },

    post_id: 132190,

    get title() {
      return __('Grow Your Community', "full-site-editing");
    },

    get description() {
      return __('You’ve worked hard on building your site, now it’s time to explore the community and get noticed. Learn how.', "full-site-editing");
    }

  }],
  sharing: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/video-tutorials/', "full-site-editing");
    },

    post_id: 130825,

    get title() {
      return __('Integrate and Connect to Social Media', "full-site-editing");
    },

    get description() {
      return __('Start sharing your site and attract more traffic and visitors to your content! ' + 'Learn to activate and control the social media and sharing options on your website or blog through these videos.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/sharing/');
    },

    post_id: 7499,

    get title() {
      return __('Sharing Your Content', "full-site-editing");
    },

    get description() {
      return __('At the bottom of each post or page, you can include sharing buttons for your readers ' + 'to make it easier to share your content.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/instagram/');
    },

    post_id: 77589,

    get title() {
      return __('Using Instagram', "full-site-editing");
    },

    get description() {
      return __('Instagram is a simple way to capture, customize, ' + 'and share photos and short videos using your smartphone or other mobile device. Learn how to use it with your website!', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/twitter/');
    },

    post_id: 124,

    get title() {
      return __('Using Twitter', "full-site-editing");
    },

    get description() {
      return __('Twitter is a service for the exchange of brief messages, commonly ' + 'called "tweets", between users. Learn how to use it with your website!', "full-site-editing");
    }

  }],
  home: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-purchases/');
    },

    post_id: 111349,

    get title() {
      return __('Managing Purchases', "full-site-editing");
    },

    get description() {
      return __('Have a question or need to change something about a purchase you have made? Learn how.', "full-site-editing");
    }

  }],
  me: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-my-profile/');
    },

    post_id: 19775,

    get title() {
      return __('Managing Your Profile', "full-site-editing");
    },

    get description() {
      return __('Your profile is the information you’d like to be shown along with your ' + 'name when you publish content or comment on WordPress.com sites.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/gravatars/');
    },

    post_id: 1338,

    get title() {
      return __('Your Profile Picture', "full-site-editing");
    },

    get description() {
      return __('WordPress.com associates an Avatar with your email address. Gravatar ' + 'powers the user avatars on WordPress.com.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/close-account/');
    },

    post_id: 138080,

    get title() {
      return __('Account Closure', "full-site-editing");
    },

    get description() {
      return __('Need a fresh start? Learn how to close your account.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/change-your-username/');
    },

    post_id: 2116,

    get title() {
      return __('Change Your Username', "full-site-editing");
    },

    get description() {
      return __('You can change both your WordPress.com account username (the name you use to login) ' + 'and your display name (the name that is seen on your posts and comments). Learn how!', "full-site-editing");
    }

  }],
  account: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/change-your-username/');
    },

    get title() {
      return __('Change Your Username', "full-site-editing");
    },

    get description() {
      return __('You can change both your WordPress.com account username (the name you use to login) ' + 'and your display name (the name that is seen on your posts and comments). Learn how!', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/video-tutorials/manage-your-account/');
    },

    post_id: 185309,

    get title() {
      return __('Manage Your Account', "full-site-editing");
    },

    get description() {
      return __('Learn the ins and outs of managing your WordPress.com account and site.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/account-settings/');
    },

    post_id: 80368,

    get title() {
      return __('Edit Your Account Settings', "full-site-editing");
    },

    get description() {
      return __('You can review and edit basic account information in Account Settings. ', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/close-account/');
    },

    post_id: 143899,

    get title() {
      return __('Close Your Account', "full-site-editing");
    },

    get description() {
      return __('Learn how to permanently delete your WordPress.com account, and what it means for your website and data.', "full-site-editing");
    }

  }],
  security: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/security/two-step-authentication/');
    },

    post_id: 58847,

    get title() {
      return __('Two-Step Authentication', "full-site-editing");
    },

    get description() {
      return __('Your WordPress.com site is your home on the internet, and you want to keep that home safe. ' + 'Learn how to add an additional "lock" to your account!', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/account-recovery/');
    },

    post_id: 46365,

    get title() {
      return __('Account Recovery', "full-site-editing");
    },

    get description() {
      return __('At some point, you may run into a situation in which you’ve lost access to your account. Learn how to get back on track!', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/passwords/');
    },

    post_id: 89,

    get title() {
      return __('Passwords And How To Use Them', "full-site-editing");
    },

    get description() {
      return __('Passwords are very important to user accounts, and there may come a time when you need to change your password.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/third-party-applications/');
    },

    post_id: 17288,

    get title() {
      return __('Third Party Applications', "full-site-editing");
    },

    get description() {
      return __('WordPress.com allows you to connect with third-party applications that ' + 'extend your WordPress.com site in new and cool ways.', "full-site-editing");
    }

  }],
  purchases: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-purchases/');
    },

    post_id: 111349,

    get title() {
      return __('Managing Purchases, Renewals, and Cancellations', "full-site-editing");
    },

    get description() {
      return __('Have a question or need to change something about a purchase you have made? Learn how.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-purchases/#automatic-renewal');
    },

    post_id: 110924,

    get title() {
      return __('Subscriptions for Plans and Domains', "full-site-editing");
    },

    get description() {
      return __('Your WordPress.com plans and any domains you add to your sites are based ' + 'on a yearly subscription that renews automatically.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://en.support.wordpress.com/plan-features/');
    },

    post_id: 140323,

    get title() {
      return __('Explore the WordPress.com Plans', "full-site-editing");
    },

    get description() {
      return __("Upgrading your plan unlocks a ton of features! We'll help you pick the best fit for your needs and goals.", "full-site-editing");
    }

  }],
  'site-purchases': [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-purchases/');
    },

    post_id: 111349,

    get title() {
      return __('Managing Purchases, Renewals, and Cancellations', "full-site-editing");
    },

    get description() {
      return __('Have a question or need to change something about a purchase you have made? Learn how.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-purchases/#automatic-renewal');
    },

    post_id: 110924,

    get title() {
      return __('Subscriptions for Plans and Domains', "full-site-editing");
    },

    get description() {
      return __('Your WordPress.com plans and any domains you add to your sites are based ' + 'on a yearly subscription that renews automatically.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://en.support.wordpress.com/plan-features/');
    },

    post_id: 140323,

    get title() {
      return __('Explore the WordPress.com Plans', "full-site-editing");
    },

    get description() {
      return __("Upgrading your plan unlocks a ton of features! We'll help you pick the best fit for your needs and goals.", "full-site-editing");
    }

  }],
  'notification-settings': [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/notifications/');
    },

    post_id: 40992,

    get title() {
      return __('Notifications', "full-site-editing");
    },

    get description() {
      return __('Notifications help you stay on top of the activity on your site and all the things happening on ' + 'WordPress.com — learn how to use them.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/email-notifications/');
    },

    post_id: 9443,

    get title() {
      return __('Email Notifications', "full-site-editing");
    },

    get description() {
      return __('WordPress.com sends email notifications to the email address registered to your account. Learn how to manage them.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/following-comments/');
    },

    post_id: 4576,

    get title() {
      return __('Following Comments', "full-site-editing");
    },

    get description() {
      return __('When you leave a comment, you can automatically get email notifications for other new comments ' + "on the same post or page — you'll never be out of the loop.", "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/following/');
    },

    post_id: 4899,

    get title() {
      return __('Following Blogs', "full-site-editing");
    },

    get description() {
      return __('When you follow a blog on WordPress.com, new posts from that site will automatically appear in your Reader.', "full-site-editing");
    }

  }],
  media: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/media/');
    },

    post_id: 853,

    get title() {
      return __('The Media Library', "full-site-editing");
    },

    get description() {
      return __('The Media Library is where you can manage your images, audio, videos, and documents all in one place.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/finding-free-images-and-other-media/', "full-site-editing");
    },

    post_id: 78425,

    get title() {
      return __('Finding Free Images and other Media', "full-site-editing");
    },

    get description() {
      return __('Use free images (and other media) to make your pages and posts more interesting and engaging when on a budget!', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/wordpress-editor/blocks/image-block/');
    },

    post_id: 38830,

    get title() {
      return __('Add Media', "full-site-editing");
    },

    get description() {
      return __('Dress up your text-based posts and pages with individual images, image galleries, ' + 'slideshows, videos, and audio.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/videos/');
    },

    post_id: 4744,

    get title() {
      return __('Including Videos', "full-site-editing");
    },

    get description() {
      return __('Videos are a great way to enhance your site pages and blog posts. Learn how to include them.', "full-site-editing");
    }

  }],
  people: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/user-roles/');
    },

    post_id: 1221,

    get title() {
      return __('User Roles', "full-site-editing");
    },

    get description() {
      return __('User roles determine the access level or permissions of a person authorized to use a WordPress.com site.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/user-mentions/');
    },

    post_id: 91788,

    get title() {
      return __('User Mentions', "full-site-editing");
    },

    get description() {
      return __('User mentions are a great way to include other WordPress.com users within your ' + 'posts and comments.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://en.support.wordpress.com/user-roles/');
    },

    post_id: 2160,

    get title() {
      return __('Inviting Contributors, Followers, and Viewers', "full-site-editing");
    },

    get description() {
      return __('Invite contributors, followers, and viewers to collaborate with others and grow your audience!', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/followers/');
    },

    post_id: 5444,

    get title() {
      return __('Your Followers', "full-site-editing");
    },

    get description() {
      return __('When someone follows your site, each time you publish new content on your blog they ' + 'receive an update in their Reader, via email, or both depending on their settings.', "full-site-editing");
    }

  }],
  plugins: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/plugins/');
    },

    post_id: 2108,

    get title() {
      return __('Using Plugins', "full-site-editing");
    },

    get description() {
      return __('On WordPress.com, we include the most popular plugin functionality within our ' + 'sites automatically. Additionally, the Business plan allows you to choose from many ' + 'thousands of plugins, and install them on your site.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/plugins/#managing-plugins');
    },

    post_id: 134818,

    get title() {
      return __('Managing plugins', "full-site-editing");
    },

    get description() {
      return __('After you install a plugin, it will appear in a list at My Sites → Plugins.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/plugins/#installing-plugins');
    },

    post_id: 134719,

    get title() {
      return __('Adding Plugins', "full-site-editing");
    },

    get description() {
      return __('Along with all the tools and features built right into WordPress.com, the Business plan ' + 'allows you to install other plugins.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/business-plan/');
    },

    post_id: 134940,

    get title() {
      return __('Business Plan', "full-site-editing");
    },

    get description() {
      return __("When you want to build a one-of-a-kind website, it's time for WordPress.com Business: " + 'upload plugins and themes to create a truly tailored experience for your visitors.', "full-site-editing");
    }

  }],
  'posts-pages': [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/do-i-need-a-website-a-blog-or-a-website-with-a-blog/', "full-site-editing");
    },

    post_id: 143180,

    get title() {
      return __('Do I Need a Website, a Blog, or a Website with a Blog?', "full-site-editing");
    },

    get description() {
      return __('If you’re building a brand new site, you might be wondering if you need a website, a blog, or a website with a blog. At WordPress.com, you can create all of these options easily, right in your dashboard.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/five-step-website-setup/');
    },

    post_id: 100856,

    get title() {
      return __('Build Your Website in Five Steps', "full-site-editing");
    },

    get description() {
      return __('You’ve registered a website on WordPress.com. But now what? ' + 'Learn five steps that will get the framework of your new website all set up, ' + 'leaving it ready and waiting for your great content', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/pages/landing-pages/');
    },

    post_id: 124077,

    get title() {
      return __('Landing Pages', "full-site-editing");
    },

    get description() {
      return __('Landing pages are pages with a single purpose: encouraging your visitors to, for example, sign up for ' + 'a service, buy a product, or join a mailing list.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/posts/');
    },

    post_id: 84,

    get title() {
      return __('About Blog Posts', "full-site-editing");
    },

    get description() {
      return __('Posts are what make your blog a blog — they’re servings of content that are listed in reverse chronological order.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/posts/post-formats/');
    },

    post_id: 10382,

    get title() {
      return __('Post Formats', "full-site-editing");
    },

    get description() {
      return __('Learn how to make gallery, video, audio, and other post types pop with post formats. ', "full-site-editing");
    }

  }],
  'settings-writing': [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/settings/writing-settings/');
    },

    post_id: 1502,

    get title() {
      return __('Writing Settings', "full-site-editing");
    },

    get description() {
      return __('Learn how to manage categories, date format, content types, and more.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/posts/categories-vs-tags/');
    },

    post_id: 2135,

    get title() {
      return __('Categories vs. Tags', "full-site-editing");
    },

    get description() {
      return __('Learn the differences between categories and tags.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/feeds/');
    },

    post_id: 3589,

    get title() {
      return __('Feeds', "full-site-editing");
    },

    get description() {
      return __('A feed (often called RSS) is a stream of posts or comments that is updated when new content is published.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/portfolios/');
    },

    post_id: 84808,

    get title() {
      return __('Portfolios', "full-site-editing");
    },

    get description() {
      return __('To show off your portfolio separate from your blog posts and pages, the Portfolio content type will let you' + ' manage all your portfolio projects in one place.', "full-site-editing");
    }

  }],
  'settings-discussion': [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/settings/discussion-settings/');
    },

    post_id: 1504,

    get title() {
      return __('Discussion Settings', "full-site-editing");
    },

    get description() {
      return __('The Discussion Settings are used to control how visitors and other blogs interact with your site.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/comments/', "full-site-editing");
    },

    post_id: 5997,

    get title() {
      return __('Enable and Disable Comments for Future Posts', "full-site-editing");
    },

    get description() {
      return __('You can enable/disable comments on future posts by going into your Discussion settings. ', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/comments/');
    },

    post_id: 113,

    get title() {
      return __('Comments', "full-site-editing");
    },

    get description() {
      return __('Comments are a way for visitors to add feedback to your posts and pages.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/subscriptions-and-newsletters/');
    },

    post_id: 67810,

    get title() {
      return __('Subscriptions and Newsletters', "full-site-editing");
    },

    get description() {
      return __('Learn how readers can subscribe to your blog to receive email notifications of all of your posts.', "full-site-editing");
    }

  }],
  'settings-traffic': [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/getting-more-views-and-traffic/');
    },

    post_id: 3307,

    get title() {
      return __('Get More Views and Traffic', "full-site-editing");
    },

    get description() {
      return __('Want more traffic? Here are some tips for attracting more visitors to your site!', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/related-posts/');
    },

    post_id: 1545,

    get title() {
      return __('Related Posts', "full-site-editing");
    },

    get description() {
      return __('The Related Posts feature pulls relevant content from your blog to display at the bottom of your posts.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/site-verification-services/');
    },

    post_id: 5022,

    get title() {
      return __('Site Verification Services', "full-site-editing");
    },

    get description() {
      return __('Learn how to verify your WordPress.com site for the webmaster tools that many search engines provide.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/amp-accelerated-mobile-pages/');
    },

    post_id: 122516,

    get title() {
      return __('Accelerated Mobile Pages (AMP)', "full-site-editing");
    },

    get description() {
      return __('Accelerated Mobile Pages (AMP) allows browsers and apps to load your site more quickly on mobile devices. ' + 'By default, it is enabled for every WordPress.com site.', "full-site-editing");
    }

  }],
  'settings-security': [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/security/');
    },

    post_id: 10977,

    get title() {
      return __('Security', "full-site-editing");
    },

    get description() {
      return __('Learn what we do to help protect your site and your personal data, along with added steps ' + 'we recommend you take to do the same.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/comments/#unwanted-comments-and-comment-spam');
    },

    post_id: 5882,

    get title() {
      return __('Unwanted Comments and Comment Spam', "full-site-editing");
    },

    get description() {
      return __('There are many ways to protect your WordPress.com blogs from unwanted comments. Learn all about them!', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/security/#strong-password');
    },

    post_id: 35364,

    get title() {
      return __('Selecting A Strong Password', "full-site-editing");
    },

    get description() {
      return __('The weakest point in any security for your online accounts is usually your password. Learn how to select a strong one.', "full-site-editing");
    }

  }],
  settings: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/settings/');
    },

    post_id: 497,

    get title() {
      return __('Settings', "full-site-editing");
    },

    get description() {
      return __('The Settings menu of your site is where you will configure everything about how the blog works and functions.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/settings/general-settings/');
    },

    post_id: 1501,

    get title() {
      return __('General Settings', "full-site-editing");
    },

    get description() {
      return __('The General Settings let you control how your site is displayed, such as the ' + 'title, tagline, language, and visibility.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/site-icons/');
    },

    post_id: 1327,

    get title() {
      return __('Site Icons', "full-site-editing");
    },

    get description() {
      return __('A Site Icon is a unique icon for your site that is shown in your visitor’s browser tab ' + 'and other places around WordPress.com.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/five-step-blog-setup/');
    },

    post_id: 100846,

    get title() {
      return __('Five Steps to Your Great New Blog', "full-site-editing");
    },

    get description() {
      return __('Get ready to publish! Our five-step checklist walks you through all the fundamentals.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-purchases/');
    },

    post_id: 111349,

    get title() {
      return __('Managing Purchases, Renewals, and Cancellations', "full-site-editing");
    },

    get description() {
      return __('Have a question or need to change something about a purchase you have made? Learn how.', "full-site-editing");
    }

  }],
  themes: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/themes/');
    },

    post_id: 2278,

    get title() {
      return __('Themes: An Overview', "full-site-editing");
    },

    get description() {
      return __('A theme controls the general look and feel of your site including things like ' + 'page layout, widget locations, and default font.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/themes/child-themes', "full-site-editing");
    },

    post_id: 134704,

    get title() {
      return __('Child Themes', "full-site-editing");
    },

    get description() {
      return __("The only limit on your site is your vision — if the themes you see don't match that, it's " + 'time to go beyond them. Learn to use child themes to customize and extend your website.', "full-site-editing");
    }

  }],
  theme: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/themes/');
    },

    post_id: 134704,

    get title() {
      return __('Themes: An Overview', "full-site-editing");
    },

    get description() {
      return __('A theme controls the general look and feel of your site including things like ' + 'page layout, widget locations, and default font.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/themes/child-themes', "full-site-editing");
    },

    get title() {
      return __('Child Themes', "full-site-editing");
    },

    post_id: 134704,

    get description() {
      return __("The only limit on your site is your vision — if the themes you see don't match that, it's " + 'time to go beyond them. Learn to use child themes to customize and extend your website.', "full-site-editing");
    }

  }],
  plans: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://en.support.wordpress.com/plan-features/');
    },

    post_id: 140323,

    get title() {
      return __('Explore the WordPress.com Plans', "full-site-editing");
    },

    get description() {
      return __("Upgrading your plan unlocks a ton of features! We'll help you pick the best fit for your needs and goals.", "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/plan-features/');
    },

    post_id: 134698,

    get title() {
      return __('WordPress.com Plans', "full-site-editing");
    },

    get description() {
      return __('Learn about the capabilities and features that the different plans unlock for your site.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-purchases/#automatic-renewal');
    },

    post_id: 110924,

    get title() {
      return __('Subscriptions for Plans and Domains', "full-site-editing");
    },

    get description() {
      return __('Your WordPress.com plans and any domains you add to your sites are based on a yearly ' + 'subscription that renews automatically.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/jetpack/');
    },

    post_id: 115025,

    get title() {
      return __('Jetpack Plans', "full-site-editing");
    },

    get description() {
      return __('Learn about the free Jetpack plugin, its benefits, and the useful capabilities and features that a Jetpack plan unlocks.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-purchases/');
    },

    post_id: 111349,

    get title() {
      return __('Managing Purchases, Renewals, and Cancellations', "full-site-editing");
    },

    get description() {
      return __('Have a question or need to change something about a purchase you have made? Learn how.', "full-site-editing");
    }

  }],
  'gutenberg-editor': [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/wordpress-editor/');
    },

    post_id: 147594,

    get title() {
      return __('What are "Blocks"?', "full-site-editing");
    },

    get description() {
      return __('The WordPress Editor uses blocks to transform the way you create content: it turns a single document into a collection of discrete elements with explicit, easy-to-tweak structure.', "full-site-editing");
    }

  }, {
    intent: _constants__WEBPACK_IMPORTED_MODULE_2__/* .SELL_INTENT */ .h_,

    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/video-tutorials/video-tutorials-add-payments-features-to-your-site-with-our-guides/', "full-site-editing");
    },

    post_id: 175999,

    get title() {
      return __('The Payments Block', "full-site-editing");
    },

    get description() {
      return __("The Payments block is one of WordPress.com's payment blocks that allows you to accept payments for one-time, monthly recurring, or annual payments on your website.", "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/offline-editing/');
    },

    post_id: 3595,

    get title() {
      return __('Offline Editing', "full-site-editing");
    },

    get description() {
      return __('Learn how to create and edit content for your WordPress.com site even without being connected to the internet!', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/user-roles/');
    },

    post_id: 1221,

    get title() {
      return __('Inviting Contributors, Followers, and Viewers', "full-site-editing");
    },

    get description() {
      return __('Invite contributors, followers, and viewers to collaborate with others and grow your audience!', "full-site-editing");
    }

  }],
  reader: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/reader/');
    },

    post_id: 32011,

    get title() {
      return __('The Reader: An Overview', "full-site-editing");
    },

    get description() {
      return __('Read posts from all the sites you follow — even ones that aren’t on WordPress.com! ' + 'Discover great new reads and keep track of your comments and replies in one convenient place.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/following/');
    },

    post_id: 4899,

    get title() {
      return __('Follow Blogs', "full-site-editing");
    },

    get description() {
      return __('When you follow a blog on WordPress.com, new posts from that site will automatically appear in your Reader.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/topics/');
    },

    post_id: 2166,

    get title() {
      return __('Following Specific Topics in the Reader', "full-site-editing");
    },

    get description() {
      return __('Looking for posts on a specific topic? Besides following entire blogs, you can also follow posts on a specific subject ' + 'from across WordPress.com. You do this by adding the topic you’re interested in under the Tags heading in the Reader.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/grow-your-community/');
    },

    post_id: 132190,

    get title() {
      return __('Grow Your Community', "full-site-editing");
    },

    get description() {
      return __('You’ve worked hard on building your site, now it’s time to explore the community and get noticed.', "full-site-editing");
    }

  }],
  help: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wpcourses.com/');
    },

    post_id: 117437,

    get title() {
      return __('Blogging U.', "full-site-editing");
    },

    get description() {
      return __('Blogging U. courses deliver free expert advice, pro tips, and inspiration right to your ' + 'email inbox. Sign up now!', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/help-support-options/');
    },

    post_id: 149,

    get title() {
      return __('Help! Getting WordPress.com Support', "full-site-editing");
    },

    get description() {
      return __('WordPress.com offers a number of avenues for reaching helpful, individualized support.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/');
    },

    get title() {
      return __('All Support Articles', "full-site-editing");
    },

    get description() {
      return __('Looking to learn more about a feature? Our docs have all the details.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/learn/');
    },

    get title() {
      return __('Self-guided Online Tutorial', "full-site-editing");
    },

    get description() {
      return __('A step-by-step guide to getting familiar with the platform.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-purchases/');
    },

    post_id: 111349,

    get title() {
      return __('Managing Purchases, Renewals, and Cancellations', "full-site-editing");
    },

    get description() {
      return __('Have a question or need to change something about a purchase you have made? Learn how.', "full-site-editing");
    }

  }],
  comments: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/comments/');
    },

    post_id: 113,

    get title() {
      return __('Comments', "full-site-editing");
    },

    get description() {
      return __('Comments are a way for visitors to add feedback to your posts and pages.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/settings/discussion-settings/');
    },

    post_id: 5840,

    get title() {
      return __('Comment Display Options', "full-site-editing");
    },

    get description() {
      return __('You can control comment threading, paging, and comment order settings from the ' + 'Discussion Settings page in your site’s settings.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/comments/#unwanted-comments-and-comment-spam');
    },

    post_id: 5882,

    get title() {
      return __('Unwanted Comments and Comment Spam', "full-site-editing");
    },

    get description() {
      return __('There are many ways to protect your WordPress.com blogs from unwanted comments. Learn all about them!', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/comment-likes/');
    },

    post_id: 88757,

    get title() {
      return __('Comment Likes', "full-site-editing");
    },

    get description() {
      return __('Comment Likes: how to like others’ comments and control how Comment Likes appear on your site.', "full-site-editing");
    }

  }],
  hosting: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/sftp/');
    },

    post_id: 159771,

    get title() {
      return __('SFTP on WordPress.com', "full-site-editing");
    },

    get description() {
      return __("Access and edit your website's files directly by using an SFTP client.");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/phpmyadmin-and-mysql/');
    },

    post_id: 159822,

    get title() {
      return __('phpMyAdmin and MySQL', "full-site-editing");
    },

    get description() {
      return __('For the tech-savvy, manage your database with phpMyAdmin and run a wide range of operations with MySQL.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/php-version-switching/');
    },

    post_id: 160597,

    get title() {
      return __('PHP Version Switching', "full-site-editing");
    },

    get description() {
      return __('Sites on the Business Plan using custom plugins and/or custom themes and any site on the eCommerce Plan, now have the option to switch PHP versions.', "full-site-editing");
    }

  }],
  checkout: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/plan-features/');
    },

    post_id: 134698,

    get title() {
      return __('WordPress.com Plans', "full-site-editing");
    },

    get description() {
      return __('Learn about the capabilities and features that the different plans unlock for your site.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/jetpack/');
    },

    post_id: 115025,

    get title() {
      return __('Jetpack Plans', "full-site-editing");
    },

    get description() {
      return __('Learn about the free Jetpack plugin, its benefits, and the useful capabilities and features that a Jetpack plan unlocks.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-purchases/');
    },

    post_id: 111349,

    get title() {
      return __('Manage Purchases and Refund Policy', "full-site-editing");
    },

    get description() {
      return __('Have a question or need to change something about a purchase you have made? Learn how.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-purchases/#automatic-renewal');
    },

    post_id: 110924,

    get title() {
      return __('Subscriptions for Plans and Domains', "full-site-editing");
    },

    get description() {
      return __('Your WordPress.com plans and any domains you add to your sites are based on a yearly ' + 'subscription that renews automatically.', "full-site-editing");
    }

  }],
  domains: [{
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/add-email/');
    },

    post_id: 34087,

    get title() {
      return __('Add Email to your Domain', "full-site-editing");
    },

    get description() {
      return __('Want to use a custom email with your domain, such as info@yourgroovydomain.com? There are multiple ways to add email to your custom domain.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/domains/custom-dns/');
    },

    post_id: 6595,

    get title() {
      return __('Manage Custom DNS', "full-site-editing");
    },

    get description() {
      return __('Custom DNS records are special settings that change how your domain works. They allow you to connect your domain to third-party services that are not hosted on WordPress.com, such as an email provider.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/domains/transfer-domain-registration/', "full-site-editing");
    },

    post_id: 41298,

    get title() {
      return __('Transfer a Domain to Another Registrar', "full-site-editing");
    },

    get description() {
      return __('This article walks you through transferring your domain registration to another registrar. Your domain will need to be unlocked and privacy removed (if applicable) for the transfer.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/domain-connection-vs-domain-transfer/');
    },

    post_id: 157655,

    get title() {
      return __('Connect an Existing Domain', "full-site-editing");
    },

    get description() {
      return __('You can connect an existing domain you own that’s registered elsewhere by either mapping or transferring. Domain mapping lets you connect a domain while keeping it registered at the current registrar (where you purchased the domain from). Domain transferring moves the domain to WordPress.com so we become the new registrar.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/domains/');
    },

    post_id: 1988,

    get title() {
      return __('All about domains', "full-site-editing");
    },

    get description() {
      return __('A domain name is an address people use to visit your site. It tells the web browser where to look for your site. Just like a street address, a domain is how people visit your website online. And, like having a sign in front of your store, a custom domain name helps give your site a professional look.', "full-site-editing");
    }

  }, {
    get link() {
      return (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_1__/* .localizeUrl */ .aq)('https://wordpress.com/support/manage-purchases/');
    },

    post_id: 111349,

    get title() {
      return __('Managing Purchases, Renewals, and Cancellations', "full-site-editing");
    },

    get description() {
      return __('Have a question or need to change something about a purchase you have made? Learn how.', "full-site-editing");
    }

  }]
};
/*
source: https://www.youtube.com/playlist?list=PLQFhxUeNFfdKx9gO0a2mp9h8pKjb2y9la
run this in the console to get the videos into a more helpful format (also removes duplicates):
```JavaScript
data = {};
document.querySelectorAll('.yt-simple-endpoint.ytd-playlist-video-renderer').forEach( function( e ) {
	data[ new RegExp(/v=([^&]*)&/).exec( e.href )[1] ] = e.querySelector( '#video-title' ).innerHTML.trim();
} );
console.log( data );
```
*/

const videosForSection = {
  sharing: [{
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=YVelWG3hf3o',

    get title() {
      return __('Add Social Sharing Buttons to Your Website', "full-site-editing");
    },

    get description() {
      return __('Find out how to add social sharing buttons to your WordPress.com site, which you can also ' + 'do with a Jetpack-enabled WordPress site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=NcCe0ozmqFM',

    get title() {
      return __('Connect Your Blog to Facebook Using Publicize', "full-site-editing");
    },

    get description() {
      return __('Find out how to share blog posts directly on Facebook from your WordPress.com site, ' + 'which you can also do on a Jetpack-enabled WordPress site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=f44-4TgnWTs',

    get title() {
      return __('Display Your Instagram Feed on Your Website', "full-site-editing");
    },

    get description() {
      return __('Find out how to display your latest Instagram photos right on your WordPress.com site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=3rTooGV_mlg',

    get title() {
      return __('Set Up the Social Links Menu', "full-site-editing");
    },

    get description() {
      return __('Find out how to set up a social links menu on your WordPress.com or Jetpack-enabled WordPress site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=gmrOkkqMNlc',

    get title() {
      return __('Embed a Twitter Timeline in your Sidebar', "full-site-editing");
    },

    get description() {
      return __('Find out how to display your Twitter timeline on your WordPress.com or Jetpack-enabled WordPress site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=vy-U5saqG9A',

    get title() {
      return __('Set Up a Social Media Icons Widget', "full-site-editing");
    },

    get description() {
      return __('Find out how to set up the social media icons widget on your WordPress.com or Jetpack-enabled WordPress site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=N0GRBFRkzzs',

    get title() {
      return __('Embed a Tweet from Twitter in Your Website', "full-site-editing");
    },

    get description() {
      return __('Find out how to embed a Tweet in your content (including posts and pages) on your WordPress.com ' + 'or Jetpack-enabled WordPress website or blog.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=uVRji6bKJUE',

    get title() {
      return __('Embed an Instagram Photo in Your Website', "full-site-editing");
    },

    get description() {
      return __('Find out how to embed an Instagram photo in your content (including posts and pages) on your WordPress.com ' + 'or Jetpack-enabled WordPress website or blog.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=sKm3Q83JxM0',

    get title() {
      return __('Embed a Facebook Update in Your Website', "full-site-editing");
    },

    get description() {
      return __('Find out how to embed a Facebook update in your content (including posts, pages, and even comments) on your ' + 'WordPress.com or Jetpack-enabled WordPress website or blog.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=SBgNkre_b14',

    get title() {
      return __('Share Blog Posts Directly on Twitter', "full-site-editing");
    },

    get description() {
      return __('Find out how to share blog posts directly on Twitter from your WordPress.com or Jetpack-enabled WordPress site.', "full-site-editing");
    }

  }],
  settings: [{
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=0YCZ22k4SfQ',

    get title() {
      return __('Add a Site Logo', "full-site-editing");
    },

    get description() {
      return __('Find out how to add a custom logo to your WordPress.com site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=vucZ1uZ2NPo',

    get title() {
      return __('Update Your Website Title and Tagline', "full-site-editing");
    },

    get description() {
      return __('Find out how to update the Title and Tagline of your WordPress.com site, which you can also ' + 'do on your Jetpack-enabled WordPress site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=Y6iPsPwYD7g',

    get title() {
      return __('Change Your Privacy Settings', "full-site-editing");
    },

    get description() {
      return __('Find out how to change your website privacy settings on WordPress.com.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=bjxKGxW0MRA',

    get title() {
      return __('Add a Site Icon', "full-site-editing");
    },

    get description() {
      return __('Find out how to add a site icon on WordPress.com.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=z6fCtvLB0wM',

    get title() {
      return __('Create a Multilingual Site', "full-site-editing");
    },

    get description() {
      return __('Find out how to create a multilingual site on WordPress.com.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=D142Edhcpaw',

    get title() {
      return __('Customize Your Content Options', "full-site-editing");
    },

    get description() {
      return __('Find out how to customize your content options on select WordPress.com themes.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=Vyr-g5SEuIA',

    get title() {
      return __('Change Your Language Settings', "full-site-editing");
    },

    get description() {
      return __('Find out how to change your blog or website language and your interface language settings on WordPress.com.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=EUuEuW_LCrc',

    get title() {
      return __('Activate Free Email Forwarding', "full-site-editing");
    },

    get description() {
      return __('Find out how to activate free email forwarding from an address using a custom domain registered through WordPress.com.', "full-site-editing");
    }

  }],
  account: [{
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=aO-6yu3_xWQ',

    get title() {
      return __('Change Your Password', "full-site-editing");
    },

    get description() {
      return __('Find out how to change your account password on WordPress.com.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=qhsjkqFdDZo',

    get title() {
      return __('Change Your WordPress.com Username', "full-site-editing");
    },

    get description() {
      return __('Find out how to change your username on WordPress.com.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=Tyxu_xT6q1k',

    get title() {
      return __('Change Your WordPress.com Display Name', "full-site-editing");
    },

    get description() {
      return __('Find out how to change your display name on WordPress.com.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=07Nf8FkjO4o',

    get title() {
      return __('Change Your Account Email Address', "full-site-editing");
    },

    get description() {
      return __('Find out how to change your account email address on WordPress.com.', "full-site-editing");
    }

  }],
  customizer: [{
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=pf_ST7gvY8c',

    get title() {
      return __('Add a Custom Header Image', "full-site-editing");
    },

    get description() {
      return __('Find out how to add a custom header image to your WordPress.com website or blog.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=CY20IAtl2Ac',

    get title() {
      return __('Create a Custom Website Menu', "full-site-editing");
    },

    get description() {
      return __('Find out how to create a custom menu on your WordPress.com or Jetpack-enabled WordPress site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=2H_Jsgh2Z3Y',

    get title() {
      return __('Add a Widget', "full-site-editing");
    },

    get description() {
      return __('Find out how to add a widget to your WordPress.com website.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=ypFF4ONBfSQ',

    get title() {
      return __('Add a Custom Background', "full-site-editing");
    },

    get description() {
      return __('Find out how to add a custom background to your WordPress.com site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=b8EuJDrNeOA',

    get title() {
      return __('Change Your Site Fonts', "full-site-editing");
    },

    get description() {
      return __('Find out how to change the fonts on your WordPress.com website or blog.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=7VPgvxV78Kc',

    get title() {
      return __('Add a Gallery Widget', "full-site-editing");
    },

    get description() {
      return __('Find out how to add an image gallery widget to your WordPress.com website or blog.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=oDBuaBLrwF8',

    get title() {
      return __('Use Featured Content', "full-site-editing");
    },

    get description() {
      return __('Find out how to use the Featured Content option on your WordPress.com website or blog.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=3TqRr21zyiA',

    get title() {
      return __('Add an Image Widget', "full-site-editing");
    },

    get description() {
      return __('Find out how to add an image widget to your WordPress.com website or blog.', "full-site-editing");
    }

  }],
  'posts-pages': [{
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=3RPidSCQ0LI',

    get title() {
      return __('Create a Landing Page', "full-site-editing");
    },

    get description() {
      return __('Find out how to create a one-page website or landing page on your WordPress.com site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=4IkFQzl5nXc',

    get title() {
      return __('Set Up a Website in 5 Steps', "full-site-editing");
    },

    get description() {
      return __('Find out how to create a website on WordPress.com in five steps.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=mta6Y0o7yJk',

    get title() {
      return __('Set Up a Blog in 5 Steps', "full-site-editing");
    },

    get description() {
      return __('Find out how to create a blog on WordPress.com in five steps.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=Gx7YNX1Wk5U',

    get title() {
      return __('Create a Page', "full-site-editing");
    },

    get description() {
      return __('Find out how to create a page on your WordPress.com site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=mCfuh5bCOwM',

    get title() {
      return __('Create a Post', "full-site-editing");
    },

    get description() {
      return __('Find out how to create a post on WordPress.com.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=bEVHg6nopcs',

    get title() {
      return __('Use a Custom Menu in a Widget', "full-site-editing");
    },

    get description() {
      return __('Find out how to use a custom menu in a widget on your WordPress.com or Jetpack-enabled WordPress site.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=nAzdUOlFoBI',

    get title() {
      return __('Configure a Static Homepage', "full-site-editing");
    },

    get description() {
      return __('By default, your new WordPress.com website displays your latest posts. Find out how to create a static homepage instead.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=MPpVeMmDOhk',

    get title() {
      return __('Show Related Posts on Your WordPress Blog', "full-site-editing");
    },

    get description() {
      return __('Find out how to show related posts on your WordPress.com site, which you can also do on a Jetpack-enabled WordPress blog.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=JVnltCZUKC4',

    get title() {
      return __('Add Testimonials', "full-site-editing");
    },

    get description() {
      return __('Find out how to add testimonials to your WordPress.com website or blog.', "full-site-editing");
    }

  }, {
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=yH_gapAUGAA',

    get title() {
      return __('Change Your Post or Page Visibility Settings', "full-site-editing");
    },

    get description() {
      return __('Find out how to change your page or post visibility settings WordPress.com.', "full-site-editing");
    }

  }],
  media: [{
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=VjGnEHyqVqQ',

    get title() {
      return __('Add a Photo Gallery', "full-site-editing");
    },

    get description() {
      return __('Find out how to add a photo gallery on your WordPress.com and Jetpack-enabled website.', "full-site-editing");
    }

  }],
  themes: [{
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_VIDEO */ .fI,
    link: 'https://www.youtube.com/watch?v=yOfAuOb68Hc',

    get title() {
      return __('Change Your Website Theme on WordPress.com', "full-site-editing");
    },

    get description() {
      return __('Find out how to change your WordPress.com theme.', "full-site-editing");
    }

  }]
};
const toursForSection = {
  media: [{
    type: _constants__WEBPACK_IMPORTED_MODULE_2__/* .RESULT_TOUR */ .Sm,
    tour: 'mediaBasicsTour',
    key: 'tour:mediaBasicsTour',

    get title() {
      return __('Learn Media Library Basics', "full-site-editing");
    },

    get description() {
      return __('The Media Library is a useful tool to help you manage, search, and edit your photos, videos, documents, and other media.', "full-site-editing");
    }

  }]
};
function getContextResults(section, siteIntent) {
  var _videosForSection, _toursForSection;

  // Posts and Pages have a common help section
  if (section === 'posts' || section === 'pages') {
    section = 'posts-pages';
  }

  const fallbackLinks = siteIntent === 'write' ? bloggerFallbackLinks : defaultFallbackLinks; // make sure editorially to show at most one tour and one video at once
  // `first` is a safe-guard in case that fails

  const video = (_videosForSection = videosForSection[section]) === null || _videosForSection === void 0 ? void 0 : _videosForSection[0];
  const tour = (_toursForSection = toursForSection[section]) === null || _toursForSection === void 0 ? void 0 : _toursForSection[0];
  let links = contextLinksForSection[section] ?? fallbackLinks; // If true, still display fallback links in addition (as opposed to instead
  // of) the other context links.

  if (section === 'home' && Array.isArray(links)) {
    return [tour, video, ...fallbackLinks, ...links].filter(Boolean);
  } // Remove sell docs if not on a site with the 'sell' intent.


  if (section === 'gutenberg-editor' && siteIntent !== 'sell' && Array.isArray(links)) {
    links = links.filter(link => {
      return link.intent !== _constants__WEBPACK_IMPORTED_MODULE_2__/* .SELL_INTENT */ .h_;
    });
  }

  return [tour, video, ...links].filter(Boolean);
}

/***/ }),

/***/ 52865:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "setShowHelpCenter": function() { return /* binding */ setShowHelpCenter; },
/* harmony export */   "setDirectlyData": function() { return /* binding */ setDirectlyData; },
/* harmony export */   "setSite": function() { return /* binding */ setSite; },
/* harmony export */   "setSubject": function() { return /* binding */ setSubject; },
/* harmony export */   "setMessage": function() { return /* binding */ setMessage; },
/* harmony export */   "setPopup": function() { return /* binding */ setPopup; },
/* harmony export */   "resetPopup": function() { return /* binding */ resetPopup; },
/* harmony export */   "setUserDeclaredSiteUrl": function() { return /* binding */ setUserDeclaredSiteUrl; },
/* harmony export */   "setUserDeclaredSite": function() { return /* binding */ setUserDeclaredSite; },
/* harmony export */   "resetStore": function() { return /* binding */ resetStore; }
/* harmony export */ });
const setShowHelpCenter = show => ({
  type: 'HELP_CENTER_SET_SHOW',
  show
});
const setDirectlyData = data => ({
  type: 'HELP_CENTER_SET_DIRECTLY_DATA',
  data
});
const setSite = site => ({
  type: 'HELP_CENTER_SET_SITE',
  site
});
const setSubject = subject => ({
  type: 'HELP_CENTER_SET_SUBJECT',
  subject
});
const setMessage = message => ({
  type: 'HELP_CENTER_SET_MESSAGE',
  message
});
const setPopup = popup => ({
  type: 'HELP_CENTER_SET_POPUP',
  popup
});
const resetPopup = () => ({
  type: 'HELP_CENTER_RESET_POPUP'
});
const setUserDeclaredSiteUrl = url => ({
  type: 'HELP_CENTER_SET_USER_DECLARED_SITE_URL',
  url
});
const setUserDeclaredSite = site => ({
  type: 'HELP_CENTER_SET_USER_DECLARED_SITE',
  site
});
const resetStore = () => ({
  type: 'HELP_CENTER_RESET_STORE'
});

/***/ }),

/***/ 2193:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "L": function() { return /* binding */ STORE_KEY; }
/* harmony export */ });
const STORE_KEY = 'automattic/help-center';

/***/ }),

/***/ 17624:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "z": function() { return /* binding */ register; }
/* harmony export */ });
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_data_controls__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(23418);
/* harmony import */ var _wordpress_data_controls__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data_controls__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _actions__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(52865);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(2193);
/* harmony import */ var _reducer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(61654);
/* harmony import */ var _selectors__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(55601);






let isRegistered = false;
function register() {
  if (!isRegistered) {
    (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.registerStore)(_constants__WEBPACK_IMPORTED_MODULE_2__/* .STORE_KEY */ .L, {
      actions: _actions__WEBPACK_IMPORTED_MODULE_3__,
      reducer: _reducer__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z,
      // eslint-disable-line @typescript-eslint/no-explicit-any
      controls: _wordpress_data_controls__WEBPACK_IMPORTED_MODULE_1__.controls,
      selectors: _selectors__WEBPACK_IMPORTED_MODULE_5__,
      persist: ['site']
    });
    isRegistered = true;
  }

  return _constants__WEBPACK_IMPORTED_MODULE_2__/* .STORE_KEY */ .L;
}

/***/ }),

/***/ 61654:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_0__);


const showHelpCenter = (state, action) => {
  switch (action.type) {
    case 'HELP_CENTER_SET_SHOW':
      return action.show;
  }

  return state;
};

const directlyData = (state, action) => {
  switch (action.type) {
    case 'HELP_CENTER_SET_DIRECTLY_DATA':
      return action.data;
  }

  return state;
};

const site = (state, action) => {
  if (action.type === 'HELP_CENTER_RESET_STORE') {
    return undefined;
  } else if (action.type === 'HELP_CENTER_SET_SITE') {
    return action.site;
  }

  return state;
};

const subject = (state, action) => {
  if (action.type === 'HELP_CENTER_RESET_STORE') {
    return undefined;
  } else if (action.type === 'HELP_CENTER_SET_SUBJECT') {
    return action.subject;
  }

  return state;
};

const message = (state, action) => {
  if (action.type === 'HELP_CENTER_RESET_STORE') {
    return undefined;
  } else if (action.type === 'HELP_CENTER_SET_MESSAGE') {
    return action.message;
  }

  return state;
};

const userDeclaredSiteUrl = (state, action) => {
  if (action.type === 'HELP_CENTER_RESET_STORE') {
    return undefined;
  } else if (action.type === 'HELP_CENTER_SET_USER_DECLARED_SITE_URL') {
    return action.url;
  }

  return state;
};

const userDeclaredSite = (state, action) => {
  if (action.type === 'HELP_CENTER_RESET_STORE') {
    return undefined;
  } else if (action.type === 'HELP_CENTER_SET_USER_DECLARED_SITE') {
    return action.site;
  }

  return state;
};

const popup = (state, action) => {
  if (action.type === 'HELP_CENTER_SET_POPUP') {
    return action.popup;
  } else if (action.type === 'HELP_CENTER_RESET_POPUP' || action.type === 'HELP_CENTER_RESET_STORE') {
    return undefined;
  }

  return state;
};

const reducer = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.combineReducers)({
  directlyData,
  showHelpCenter,
  site,
  subject,
  message,
  userDeclaredSite,
  userDeclaredSiteUrl,
  popup
});
/* harmony default export */ __webpack_exports__["Z"] = (reducer);

/***/ }),

/***/ 55601:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "isHelpCenterShown": function() { return /* binding */ isHelpCenterShown; },
/* harmony export */   "getSite": function() { return /* binding */ getSite; },
/* harmony export */   "getSubject": function() { return /* binding */ getSubject; },
/* harmony export */   "getMessage": function() { return /* binding */ getMessage; },
/* harmony export */   "getUserDeclaredSiteUrl": function() { return /* binding */ getUserDeclaredSiteUrl; },
/* harmony export */   "getPopup": function() { return /* binding */ getPopup; },
/* harmony export */   "getDirectly": function() { return /* binding */ getDirectly; },
/* harmony export */   "getUserDeclaredSite": function() { return /* binding */ getUserDeclaredSite; }
/* harmony export */ });
const isHelpCenterShown = state => state.showHelpCenter;
const getSite = state => state.site;
const getSubject = state => state.subject;
const getMessage = state => state.message;
const getUserDeclaredSiteUrl = state => state.userDeclaredSiteUrl;
const getPopup = state => state.popup;
const getDirectly = state => state.directlyData;
const getUserDeclaredSite = state => state.userDeclaredSite;

/***/ }),

/***/ 63830:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "O": function() { return /* binding */ useHas3PC; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Cache the result for the entire session, since changing 3PC settings requires a refresh
 */

let result;
/**
 * Calls a widgets.wp.com endpoint from within an iframe to determine whether the user has 3rd party cookies allowed
 *
 * @returns true when cookies are allowed, false when not.
 */

function useHas3PC() {
  const [hasCookies, setHasCookies] = (0,react__WEBPACK_IMPORTED_MODULE_0__.useState)(Boolean(result));
  (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    const iframe = document.createElement('iframe');

    function handler(event) {
      const {
        data
      } = event;

      if (data.type === 'widgets.wp.com-cookie-check') {
        // cache the result
        result = data.result;
        setHasCookies(data.result);
        window.removeEventListener('message', handler);
        iframe.remove();
      }
    } // only inject the iframe if the result isn't already cached


    if (result === undefined) {
      iframe.src = 'https://widgets.wp.com/calypso-happychat/check-cookies.html';
      iframe.style.display = 'none';
      window.addEventListener('message', handler);
      document.body.appendChild(iframe);
      return () => window.removeEventListener('message', handler);
    }
  }, []);
  return {
    hasCookies,
    isLoading: result === undefined
  };
}

/***/ }),

/***/ 53762:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "R": function() { return /* binding */ useHasSeenWhatsNewModalQuery; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(82066);
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(18552);



const useHasSeenWhatsNewModalQuery = (siteId, isSimpleSite) => {
  const queryKey = 'has-seen-whats-new-modal';
  const {
    data,
    isLoading
  } = (0,react_query__WEBPACK_IMPORTED_MODULE_1__.useQuery)(queryKey, () => (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)({
    path: `/sites/${siteId}/block-editor/has-seen-whats-new-modal`,
    apiNamespace: 'wpcom/v2'
  }), {
    enabled: !!siteId && isSimpleSite,
    refetchOnWindowFocus: false
  });
  const queryClient = (0,react_query__WEBPACK_IMPORTED_MODULE_1__.useQueryClient)();
  const mutation = (0,react_query__WEBPACK_IMPORTED_MODULE_1__.useMutation)(_ref => {
    let {
      hasSeenWhatsNewModal
    } = _ref;
    return (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)({
      path: `/sites/${siteId}/block-editor/has-seen-whats-new-modal`,
      apiNamespace: 'wpcom/v2',
      method: 'post',
      body: {
        has_seen_whats_new_modal: hasSeenWhatsNewModal
      }
    });
  }, {
    onSuccess(data) {
      queryClient.setQueryData(queryKey, { ...data
      });
    }

  });
  const {
    mutateAsync
  } = mutation;
  const setHasSeenWhatsNewModal = (0,react__WEBPACK_IMPORTED_MODULE_0__.useCallback)(hasSeenWhatsNewModal => {
    return mutateAsync({
      hasSeenWhatsNewModal
    });
  }, [mutateAsync]);
  return {
    data,
    isLoading,
    setHasSeenWhatsNewModal
  };
};

/***/ }),

/***/ 34381:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "g": function() { return /* binding */ useSiteAnalysis; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var use_debounce__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(17127);
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(18552);




// a simple way to check if a string is host to save on API calls
function isHost(string) {
  if (string) {
    return string.length > 4 && Boolean(string === null || string === void 0 ? void 0 : string.match(/\w{2,}\.\w{2,16}/));
  }

  return false;
}
/**
 * Analyses a site to determine whether its a WPCOM site, and if yes, it would fetch and return the site information (SiteDetails).
 *
 * @param siteURL the site URL
 */


function useSiteAnalysis(siteURL) {
  const [analysis, setAnalysis] = (0,react__WEBPACK_IMPORTED_MODULE_0__.useState)();
  const [debouncedSiteUrl] = (0,use_debounce__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(siteURL, 500);
  (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    setAnalysis(undefined);

    if (!isHost(debouncedSiteUrl)) {
      return;
    }

    if (debouncedSiteUrl) {
      (async () => {
        try {
          var _analysis$platform_da;

          const analysis = await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)({
            path: `/imports/analyze-url?site_url=${encodeURIComponent(debouncedSiteUrl)}`,
            apiNamespace: 'wpcom/v2'
          });

          if ((_analysis$platform_da = analysis.platform_data) !== null && _analysis$platform_da !== void 0 && _analysis$platform_da.is_wpcom) {
            try {
              // if a wpcom site, get its info
              const site = await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)({
                path: '/sites/' + encodeURIComponent(debouncedSiteUrl),
                apiVersion: '1.1'
              });
              setAnalysis({
                site,
                result: 'WPCOM'
              });
            } catch (error) {
              // wpcom site, but not owned by user
              setAnalysis({
                result: 'NOT_OWNED_BY_USER'
              });
            }
          } else if (analysis.platform === 'wordpress') {
            setAnalysis({
              result: 'WPORG'
            });
          } else {
            setAnalysis({
              result: 'UNKNOWN'
            });
          }
        } catch (error) {
          setAnalysis({
            result: 'UNKNOWN'
          });
        }
      })();
    }
  }, [debouncedSiteUrl]);
  return { ...analysis,
    isLoading: !analysis
  };
}

/***/ }),

/***/ 45655:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "B": function() { return /* binding */ useSiteIntent; }
/* harmony export */ });
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(82066);
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(18552);


function useSiteIntent(siteId) {
  return (0,react_query__WEBPACK_IMPORTED_MODULE_0__.useQuery)('site-intent-' + siteId, async () => await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP)({
    path: `/sites/${encodeURIComponent(siteId)}/site-intent`,
    apiNamespace: 'wpcom/v2'
  }), {
    refetchOnWindowFocus: false,
    staleTime: Infinity,
    enabled: !!siteId
  });
}

/***/ }),

/***/ 28459:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "d": function() { return /* binding */ createActions; }
/* harmony export */ });
/* harmony import */ var _wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(93661);
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(52699);


function createActions(clientCreds) {
  const fetchSite = () => ({
    type: 'FETCH_SITE'
  });

  const fetchNewSite = () => ({
    type: 'FETCH_NEW_SITE'
  });

  const receiveNewSite = response => ({
    type: 'RECEIVE_NEW_SITE',
    response
  });

  const receiveNewSiteFailed = error => ({
    type: 'RECEIVE_NEW_SITE_FAILED',
    error
  });

  function* createSite(params) {
    yield fetchNewSite();

    try {
      const {
        authToken,
        ...providedParams
      } = params;
      const defaultParams = {
        client_id: clientCreds.client_id,
        client_secret: clientCreds.client_secret,
        // will find an available `*.wordpress.com` url based on the `blog_name`
        find_available_url: true,
        // Private site is default, but overridable, setting
        public: -1
      };
      const mergedParams = { ...defaultParams,
        ...providedParams,
        // Set to false because site validation should be a separate action
        validate: false
      };
      const newSite = yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
        path: '/sites/new',
        apiVersion: '1.1',
        method: 'post',
        body: mergedParams,
        token: authToken
      });
      yield receiveNewSite(newSite);
      return true;
    } catch (err) {
      yield receiveNewSiteFailed(err);
      return false;
    }
  }

  const receiveSite = (siteId, response) => ({
    type: 'RECEIVE_SITE',
    siteId,
    response
  });

  const receiveSiteTitle = (siteId, name) => ({
    type: 'RECEIVE_SITE_TITLE',
    siteId,
    name
  });

  const receiveSiteTagline = (siteId, tagline) => ({
    type: 'RECEIVE_SITE_TAGLINE',
    siteId,
    tagline
  });

  const receiveSiteVerticalId = (siteId, verticalId) => ({
    type: 'RECEIVE_SITE_VERTICAL_ID',
    siteId,
    verticalId
  });

  const receiveSiteFailed = (siteId, response) => ({
    type: 'RECEIVE_SITE_FAILED',
    siteId,
    response
  });

  const reset = () => ({
    type: 'RESET_SITE_STORE'
  });

  const resetNewSiteFailed = () => ({
    type: 'RESET_RECEIVE_NEW_SITE_FAILED'
  });

  const launchSiteStart = siteId => ({
    type: 'LAUNCH_SITE_START',
    siteId
  });

  const launchSiteSuccess = siteId => ({
    type: 'LAUNCH_SITE_SUCCESS',
    siteId
  });

  const launchSiteFailure = (siteId, error) => ({
    type: 'LAUNCH_SITE_FAILURE',
    siteId,
    error
  });

  function* launchSite(siteId) {
    yield launchSiteStart(siteId);

    try {
      yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
        path: `/sites/${siteId}/launch`,
        apiVersion: '1.1',
        method: 'post'
      });
      yield launchSiteSuccess(siteId);
    } catch (_) {
      yield launchSiteFailure(siteId, _types__WEBPACK_IMPORTED_MODULE_1__/* .SiteLaunchError.INTERNAL */ .Hc.INTERNAL);
    }
  } // TODO: move getCart and setCart to a 'cart' data-store


  function* getCart(siteId) {
    const success = yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
      path: '/me/shopping-cart/' + siteId,
      apiVersion: '1.1',
      method: 'GET'
    });
    return success;
  }

  const receiveSiteDomains = (siteId, domains) => ({
    type: 'RECEIVE_SITE_DOMAINS',
    siteId,
    domains
  });

  const receiveSiteSettings = (siteId, settings) => ({
    type: 'RECEIVE_SITE_SETTINGS',
    siteId,
    settings
  });

  const updateSiteSettings = (siteId, settings) => ({
    type: 'UPDATE_SITE_SETTINGS',
    siteId,
    settings
  });

  function* setCart(siteId, cartData) {
    const success = yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
      path: '/me/shopping-cart/' + siteId,
      apiVersion: '1.1',
      method: 'POST',
      body: cartData
    });
    return success;
  }

  const receiveSiteGlobalStyles = (siteId, globalStyles) => ({
    type: 'RECEIVE_SITE_GLOBAL_STYLES',
    siteId,
    globalStyles
  });

  function* getGlobalStyles(siteId, stylesheet) {
    const globalStyles = yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
      path: `/sites/${siteId}/global-styles/themes/${stylesheet}`,
      apiNamespace: 'wp/v2'
    });
    yield receiveSiteGlobalStyles(siteId, globalStyles);
    return globalStyles;
  }

  function* saveSiteSettings(siteId, settings) {
    try {
      // extract this into its own function as a generic settings setter
      yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
        path: `/sites/${encodeURIComponent(siteId)}/settings`,
        apiVersion: '1.4',
        body: settings,
        method: 'POST'
      });

      if ('blogname' in settings) {
        yield receiveSiteTitle(siteId, settings.blogname);
      }

      if ('blogdescription' in settings) {
        yield receiveSiteTagline(siteId, settings.blogdescription);
      }

      if ('site_vertical_id' in settings) {
        yield receiveSiteVerticalId(siteId, settings.site_vertical_id);
      }

      yield updateSiteSettings(siteId, settings);
    } catch (e) {}
  }

  function* setIntentOnSite(siteSlug, intent) {
    try {
      yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
        path: `/sites/${encodeURIComponent(siteSlug)}/site-intent`,
        apiNamespace: 'wpcom/v2',
        body: {
          site_intent: intent
        },
        method: 'POST'
      });
    } catch (e) {}
  }

  function* setGoalsOnSite(siteSlug, goals) {
    try {
      yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
        path: `/sites/${encodeURIComponent(siteSlug)}/site-goals`,
        apiNamespace: 'wpcom/v2',
        body: {
          site_goals: goals
        },
        method: 'POST'
      });
    } catch (e) {}
  }

  function* saveSiteTitle(siteId, blogname) {
    yield saveSiteSettings(siteId, {
      blogname
    });
  }

  function* saveSiteTagline(siteId, blogdescription) {
    yield saveSiteSettings(siteId, {
      blogdescription
    });
  }

  function* setThemeOnSite(siteSlug, theme) {
    yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
      path: `/sites/${siteSlug}/themes/mine`,
      apiVersion: '1.1',
      body: {
        theme: theme,
        dont_change_homepage: true
      },
      method: 'POST'
    });
  }

  function* setDesignOnSite(siteSlug, selectedDesign, siteVerticalId) {
    var _recipe$stylesheet;

    const {
      theme,
      recipe
    } = selectedDesign;
    yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
      path: `/sites/${siteSlug}/themes/mine`,
      apiVersion: '1.1',
      body: {
        theme: (recipe === null || recipe === void 0 ? void 0 : (_recipe$stylesheet = recipe.stylesheet) === null || _recipe$stylesheet === void 0 ? void 0 : _recipe$stylesheet.split('/')[1]) || theme,
        dont_change_homepage: true
      },
      method: 'POST'
    });
    /*
     * Anchor themes are set up directly via Headstart on the server side
     * so exclude them from theme setup.
     */

    const anchorDesigns = ['hannah', 'gilbert', 'riley'];

    if (anchorDesigns.indexOf(selectedDesign.template) < 0) {
      const response = yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
        path: `/sites/${encodeURIComponent(siteSlug)}/theme-setup`,
        apiNamespace: 'wpcom/v2',
        body: {
          trim_content: true,
          vertical_id: siteVerticalId || undefined,
          pattern_ids: recipe === null || recipe === void 0 ? void 0 : recipe.pattern_ids,
          header_pattern_ids: (recipe === null || recipe === void 0 ? void 0 : recipe.header_pattern_ids) || [],
          footer_pattern_ids: (recipe === null || recipe === void 0 ? void 0 : recipe.footer_pattern_ids) || []
        },
        method: 'POST'
      });
      return response;
    }
  }

  const setSiteSetupError = (error, message) => ({
    type: 'SET_SITE_SETUP_ERROR',
    error,
    message
  });

  const clearSiteSetupError = siteId => ({
    type: 'CLEAR_SITE_SETUP_ERROR',
    siteId
  });

  const atomicTransferStart = (siteId, softwareSet) => ({
    type: 'ATOMIC_TRANSFER_START',
    siteId,
    softwareSet
  });

  const atomicTransferSuccess = (siteId, softwareSet) => ({
    type: 'ATOMIC_TRANSFER_SUCCESS',
    siteId,
    softwareSet
  });

  const atomicTransferFailure = (siteId, softwareSet, error) => ({
    type: 'ATOMIC_TRANSFER_FAILURE',
    siteId,
    softwareSet,
    error
  });

  function* initiateAtomicTransfer(siteId, softwareSet) {
    yield atomicTransferStart(siteId, softwareSet);

    try {
      yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
        path: `/sites/${encodeURIComponent(siteId)}/atomic/transfers`,
        apiNamespace: 'wpcom/v2',
        method: 'POST',
        ...(softwareSet ? {
          body: {
            software_set: encodeURIComponent(softwareSet)
          }
        } : {})
      });
      yield atomicTransferSuccess(siteId, softwareSet);
    } catch (_) {
      yield atomicTransferFailure(siteId, softwareSet, _types__WEBPACK_IMPORTED_MODULE_1__/* .AtomicTransferError.INTERNAL */ .Hf.INTERNAL);
    }
  }

  const latestAtomicTransferStart = siteId => ({
    type: 'LATEST_ATOMIC_TRANSFER_START',
    siteId
  });

  const latestAtomicTransferSuccess = (siteId, transfer) => ({
    type: 'LATEST_ATOMIC_TRANSFER_SUCCESS',
    siteId,
    transfer
  });

  const latestAtomicTransferFailure = (siteId, error) => ({
    type: 'LATEST_ATOMIC_TRANSFER_FAILURE',
    siteId,
    error
  });

  function* requestLatestAtomicTransfer(siteId) {
    yield latestAtomicTransferStart(siteId);

    try {
      const transfer = yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
        path: `/sites/${encodeURIComponent(siteId)}/atomic/transfers/latest`,
        apiNamespace: 'wpcom/v2',
        method: 'GET'
      });
      yield latestAtomicTransferSuccess(siteId, transfer);
    } catch (err) {
      yield latestAtomicTransferFailure(siteId, err);
    }
  }

  const atomicSoftwareStatusStart = (siteId, softwareSet) => ({
    type: 'ATOMIC_SOFTWARE_STATUS_START',
    siteId,
    softwareSet
  });

  const atomicSoftwareStatusSuccess = (siteId, softwareSet, status) => ({
    type: 'ATOMIC_SOFTWARE_STATUS_SUCCESS',
    siteId,
    softwareSet,
    status
  });

  const atomicSoftwareStatusFailure = (siteId, softwareSet, error) => ({
    type: 'ATOMIC_SOFTWARE_STATUS_FAILURE',
    siteId,
    softwareSet,
    error
  });

  function* requestAtomicSoftwareStatus(siteId, softwareSet) {
    yield atomicSoftwareStatusStart(siteId, softwareSet);

    try {
      const status = yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
        path: `/sites/${encodeURIComponent(siteId)}/atomic/software/${encodeURIComponent(softwareSet)}`,
        apiNamespace: 'wpcom/v2',
        method: 'GET'
      });
      yield atomicSoftwareStatusSuccess(siteId, softwareSet, status);
    } catch (err) {
      yield atomicSoftwareStatusFailure(siteId, softwareSet, err);
    }
  }

  const atomicSoftwareInstallStart = (siteId, softwareSet) => ({
    type: 'ATOMIC_SOFTWARE_INSTALL_START',
    siteId,
    softwareSet
  });

  const atomicSoftwareInstallSuccess = (siteId, softwareSet) => ({
    type: 'ATOMIC_SOFTWARE_INSTALL_SUCCESS',
    siteId,
    softwareSet
  });

  const atomicSoftwareInstallFailure = (siteId, softwareSet, error) => ({
    type: 'ATOMIC_SOFTWARE_INSTALL_FAILURE',
    siteId,
    softwareSet,
    error
  });

  function* initiateSoftwareInstall(siteId, softwareSet) {
    yield atomicSoftwareInstallStart(siteId, softwareSet);

    try {
      yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_0__/* .wpcomRequest */ ._9)({
        path: `/sites/${encodeURIComponent(siteId)}/atomic/software/${encodeURIComponent(softwareSet)}`,
        apiNamespace: 'wpcom/v2',
        method: 'POST',
        body: {}
      });
      yield atomicSoftwareInstallSuccess(siteId, softwareSet);
    } catch (err) {
      yield atomicSoftwareInstallFailure(siteId, softwareSet, err);
    }
  }

  return {
    receiveSiteDomains,
    receiveSiteSettings,
    saveSiteTitle,
    saveSiteSettings,
    setIntentOnSite,
    setGoalsOnSite,
    receiveSiteTitle,
    fetchNewSite,
    fetchSite,
    receiveNewSite,
    receiveNewSiteFailed,
    resetNewSiteFailed,
    setThemeOnSite,
    setDesignOnSite,
    createSite,
    receiveSite,
    receiveSiteFailed,
    receiveSiteTagline,
    receiveSiteVerticalId,
    updateSiteSettings,
    saveSiteTagline,
    reset,
    launchSite,
    launchSiteStart,
    launchSiteSuccess,
    launchSiteFailure,
    getCart,
    setCart,
    getGlobalStyles,
    receiveSiteGlobalStyles,
    setSiteSetupError,
    clearSiteSetupError,
    initiateAtomicTransfer,
    atomicTransferStart,
    atomicTransferSuccess,
    atomicTransferFailure,
    latestAtomicTransferStart,
    latestAtomicTransferSuccess,
    latestAtomicTransferFailure,
    requestLatestAtomicTransfer,
    atomicSoftwareStatusStart,
    atomicSoftwareStatusSuccess,
    atomicSoftwareStatusFailure,
    requestAtomicSoftwareStatus,
    initiateSoftwareInstall,
    atomicSoftwareInstallStart,
    atomicSoftwareInstallSuccess,
    atomicSoftwareInstallFailure
  };
}

/***/ }),

/***/ 52005:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "L": function() { return /* binding */ STORE_KEY; }
/* harmony export */ });
const STORE_KEY = 'automattic/site';

/***/ }),

/***/ 52369:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "z2": function() { return /* binding */ register; }
/* harmony export */ });
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wpcom_request_controls__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(93661);
/* harmony import */ var _actions__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(28459);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(52005);
/* harmony import */ var _reducer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(2701);
/* harmony import */ var _resolvers__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(37862);
/* harmony import */ var _selectors__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(84309);









let isRegistered = false;
function register(clientCreds) {
  if (!isRegistered) {
    isRegistered = true;
    (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.registerStore)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L, {
      actions: (0,_actions__WEBPACK_IMPORTED_MODULE_2__/* .createActions */ .d)(clientCreds),
      controls: _wpcom_request_controls__WEBPACK_IMPORTED_MODULE_3__/* .controls */ .ai,
      reducer: _reducer__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .ZP,
      resolvers: _resolvers__WEBPACK_IMPORTED_MODULE_5__,
      selectors: _selectors__WEBPACK_IMPORTED_MODULE_6__
    });
  }

  return _constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L;
}

/***/ }),

/***/ 2701:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports newSiteData, newSiteError, isFetchingSite, fetchingSiteError, isFetchingSiteDetails, sites, sitesDomains, sitesSettings, sitesGlobalStyles, launchStatus, siteSetupErrors, atomicTransferStatus, latestAtomicTransferStatus, atomicSoftwareStatus, atomicSoftwareInstallStatus */
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(52699);



const newSiteData = (state, action) => {
  if (action.type === 'RECEIVE_NEW_SITE') {
    const {
      response
    } = action;
    return response.blog_details;
  } else if (action.type === 'RECEIVE_NEW_SITE_FAILED') {
    return undefined;
  } else if (action.type === 'RESET_SITE_STORE') {
    return undefined;
  }

  return state;
};
const newSiteError = (state, action) => {
  switch (action.type) {
    case 'FETCH_NEW_SITE':
    case 'RECEIVE_NEW_SITE':
    case 'RESET_SITE_STORE':
    case 'RESET_RECEIVE_NEW_SITE_FAILED':
      return undefined;

    case 'RECEIVE_NEW_SITE_FAILED':
      return {
        error: action.error.error,
        status: action.error.status,
        statusCode: action.error.statusCode,
        name: action.error.name,
        message: action.error.message
      };
  }

  return state;
};
const isFetchingSite = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case 'FETCH_NEW_SITE':
      return true;

    case 'RECEIVE_NEW_SITE':
    case 'RECEIVE_NEW_SITE_FAILED':
    case 'RESET_SITE_STORE':
    case 'RESET_RECEIVE_NEW_SITE_FAILED':
      return false;
  }

  return state;
};
const fetchingSiteError = (state, action) => {
  switch (action.type) {
    case 'RECEIVE_SITE_FAILED':
      return {
        error: action.response.error,
        message: action.response.message
      };
  }

  return state;
};
const isFetchingSiteDetails = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case 'FETCH_SITE':
      return true;

    case 'RECEIVE_SITE':
    case 'RECEIVE_SITE_FAILED':
      return false;
  }

  return state;
};
const sites = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === 'RECEIVE_SITE') {
    if (action.response) {
      return { ...state,
        [action.response.ID]: action.response
      };
    }

    return state;
  } else if (action.type === 'RECEIVE_SITE_FAILED') {
    const {
      [action.siteId]: idToBeRemoved,
      ...remainingState
    } = state;
    return { ...remainingState
    };
  } else if (action.type === 'RESET_SITE_STORE') {
    return {};
  } else if (action.type === 'RECEIVE_SITE_TITLE') {
    return { ...state,
      [action.siteId]: { ...state[action.siteId],
        name: action.name
      }
    };
  } else if (action.type === 'RECEIVE_SITE_TAGLINE') {
    return { ...state,
      [action.siteId]: { ...state[action.siteId],
        description: action.tagline ?? ''
      }
    };
  } else if (action.type === 'RECEIVE_SITE_VERTICAL_ID') {
    var _state$action$siteId;

    return { ...state,
      [action.siteId]: { ...state[action.siteId],
        options: { ...((_state$action$siteId = state[action.siteId]) === null || _state$action$siteId === void 0 ? void 0 : _state$action$siteId.options),
          site_vertical_id: action.verticalId
        }
      }
    };
  }

  return state;
};
const sitesDomains = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === 'RECEIVE_SITE_DOMAINS') {
    return { ...state,
      [action.siteId]: action.domains
    };
  }

  return state;
};
const sitesSettings = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === 'RECEIVE_SITE_SETTINGS') {
    return { ...state,
      [action.siteId]: action.settings
    };
  }

  if (action.type === 'UPDATE_SITE_SETTINGS') {
    return { ...state,
      [action.siteId]: { ...(state === null || state === void 0 ? void 0 : state[action.siteId]),
        ...action.settings
      }
    };
  }

  return state;
};
const sitesGlobalStyles = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === 'RECEIVE_SITE_GLOBAL_STYLES') {
    return { ...state,
      [action.siteId]: { ...(state === null || state === void 0 ? void 0 : state[action.siteId]),
        ...action.globalStyles
      }
    };
  }

  return state;
};
const launchStatus = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === 'LAUNCH_SITE_START') {
    return { ...state,
      [action.siteId]: {
        status: _types__WEBPACK_IMPORTED_MODULE_1__/* .SiteLaunchStatus.IN_PROGRESS */ .uS.IN_PROGRESS,
        errorCode: undefined
      }
    };
  }

  if (action.type === 'LAUNCH_SITE_SUCCESS') {
    return { ...state,
      [action.siteId]: {
        status: _types__WEBPACK_IMPORTED_MODULE_1__/* .SiteLaunchStatus.SUCCESS */ .uS.SUCCESS,
        errorCode: undefined
      }
    };
  }

  if (action.type === 'LAUNCH_SITE_FAILURE') {
    return { ...state,
      [action.siteId]: {
        status: _types__WEBPACK_IMPORTED_MODULE_1__/* .SiteLaunchStatus.FAILURE */ .uS.FAILURE,
        errorCode: action.error
      }
    };
  }

  return state;
};
const siteSetupErrors = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === 'SET_SITE_SETUP_ERROR') {
    const {
      error,
      message
    } = action;
    return {
      error,
      message
    };
  }

  if (action.type === 'CLEAR_SITE_SETUP_ERROR') {
    return {};
  }

  return state;
};
const atomicTransferStatus = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === 'ATOMIC_TRANSFER_START') {
    return { ...state,
      [action.siteId]: {
        status: _types__WEBPACK_IMPORTED_MODULE_1__/* .AtomicTransferStatus.IN_PROGRESS */ .bc.IN_PROGRESS,
        softwareSet: action.softwareSet,
        errorCode: undefined
      }
    };
  }

  if (action.type === 'ATOMIC_TRANSFER_SUCCESS') {
    return { ...state,
      [action.siteId]: {
        status: _types__WEBPACK_IMPORTED_MODULE_1__/* .AtomicTransferStatus.SUCCESS */ .bc.SUCCESS,
        softwareSet: action.softwareSet,
        errorCode: undefined
      }
    };
  }

  if (action.type === 'ATOMIC_TRANSFER_FAILURE') {
    return { ...state,
      [action.siteId]: {
        status: _types__WEBPACK_IMPORTED_MODULE_1__/* .AtomicTransferStatus.FAILURE */ .bc.FAILURE,
        softwareSet: action.softwareSet,
        errorCode: action.error
      }
    };
  }

  return state;
};
const latestAtomicTransferStatus = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === 'LATEST_ATOMIC_TRANSFER_START') {
    return { ...state,
      [action.siteId]: {
        status: _types__WEBPACK_IMPORTED_MODULE_1__/* .LatestAtomicTransferStatus.IN_PROGRESS */ .O.IN_PROGRESS,
        transfer: undefined,
        errorCode: undefined
      }
    };
  }

  if (action.type === 'LATEST_ATOMIC_TRANSFER_SUCCESS') {
    return { ...state,
      [action.siteId]: {
        status: _types__WEBPACK_IMPORTED_MODULE_1__/* .LatestAtomicTransferStatus.SUCCESS */ .O.SUCCESS,
        transfer: action.transfer,
        errorCode: undefined
      }
    };
  }

  if (action.type === 'LATEST_ATOMIC_TRANSFER_FAILURE') {
    return { ...state,
      [action.siteId]: {
        status: _types__WEBPACK_IMPORTED_MODULE_1__/* .LatestAtomicTransferStatus.FAILURE */ .O.FAILURE,
        transfer: undefined,
        errorCode: action.error
      }
    };
  }

  return state;
};
const atomicSoftwareStatus = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === 'ATOMIC_SOFTWARE_STATUS_START') {
    return { ...state,
      [action.siteId]: {
        [action.softwareSet]: {
          status: undefined,
          error: undefined
        }
      }
    };
  }

  if (action.type === 'ATOMIC_SOFTWARE_STATUS_SUCCESS') {
    return { ...state,
      [action.siteId]: {
        [action.softwareSet]: {
          status: action.status,
          error: undefined
        }
      }
    };
  }

  if (action.type === 'ATOMIC_SOFTWARE_STATUS_FAILURE') {
    return { ...state,
      [action.siteId]: {
        [action.softwareSet]: {
          status: undefined,
          error: action.error
        }
      }
    };
  }

  return state;
};
const atomicSoftwareInstallStatus = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let action = arguments.length > 1 ? arguments[1] : undefined;

  if (action.type === 'ATOMIC_SOFTWARE_INSTALL_START') {
    return { ...state,
      [action.siteId]: {
        [action.softwareSet]: {
          status: _types__WEBPACK_IMPORTED_MODULE_1__/* .AtomicSoftwareInstallStatus.IN_PROGRESS */ .sw.IN_PROGRESS,
          error: undefined
        }
      }
    };
  }

  if (action.type === 'ATOMIC_SOFTWARE_INSTALL_SUCCESS') {
    return { ...state,
      [action.siteId]: {
        [action.softwareSet]: {
          status: _types__WEBPACK_IMPORTED_MODULE_1__/* .AtomicSoftwareInstallStatus.SUCCESS */ .sw.SUCCESS,
          error: undefined
        }
      }
    };
  }

  if (action.type === 'ATOMIC_SOFTWARE_INSTALL_FAILURE') {
    return { ...state,
      [action.siteId]: {
        [action.softwareSet]: {
          status: _types__WEBPACK_IMPORTED_MODULE_1__/* .AtomicSoftwareInstallStatus.FAILURE */ .sw.FAILURE,
          error: action.error
        }
      }
    };
  }

  return state;
};
const newSite = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.combineReducers)({
  data: newSiteData,
  error: newSiteError,
  isFetching: isFetchingSite
});
const reducer = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.combineReducers)({
  isFetchingSiteDetails,
  newSite,
  fetchingSiteError,
  sites,
  launchStatus,
  sitesDomains,
  sitesSettings,
  sitesGlobalStyles,
  siteSetupErrors,
  atomicTransferStatus,
  latestAtomicTransferStatus,
  atomicSoftwareStatus,
  atomicSoftwareInstallStatus
});
/* harmony default export */ __webpack_exports__["ZP"] = (reducer);

/***/ }),

/***/ 37862:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "getSite": function() { return /* binding */ getSite; },
/* harmony export */   "getSiteDomains": function() { return /* binding */ getSiteDomains; },
/* harmony export */   "getSiteSettings": function() { return /* binding */ getSiteSettings; }
/* harmony export */ });
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(18552);
// wpcomRequest is a temporary rename while we're working on migrating generators to thunks


/**
 * Attempt to find a site based on its id, and if not return undefined.
 * We are currently ignoring error messages and silently failing if we can't find a
 * site. This could be extended in the future by retrieving the `error` and
 * `message` strings returned by the API.
 *
 * @param siteId {number}	The site to look up
 */
const getSite = siteId => async _ref => {
  let {
    dispatch
  } = _ref;
  dispatch.fetchSite();

  try {
    const existingSite = await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)({
      path: '/sites/' + encodeURIComponent(siteId),
      apiVersion: '1.1'
    });
    dispatch.receiveSite(siteId, existingSite);
  } catch (err) {
    dispatch.receiveSiteFailed(siteId, err);
  }
};
/**
 * Get all site domains
 *
 * @param siteId {number} The site id
 */

const getSiteDomains = siteId => async _ref2 => {
  let {
    dispatch
  } = _ref2;
  const result = await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)({
    path: '/sites/' + encodeURIComponent(siteId) + '/domains',
    apiVersion: '1.2'
  });
  dispatch.receiveSiteDomains(siteId, result === null || result === void 0 ? void 0 : result.domains);
};
/**
 * Get all site settings
 *
 * @param siteId {number} The site id
 */

const getSiteSettings = siteId => async _ref3 => {
  let {
    dispatch
  } = _ref3;
  const result = await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)({
    path: '/sites/' + encodeURIComponent(siteId) + '/settings',
    apiVersion: '1.4'
  });
  dispatch.receiveSiteSettings(siteId, result === null || result === void 0 ? void 0 : result.settings);
};

/***/ }),

/***/ 84309:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "getState": function() { return /* binding */ getState; },
/* harmony export */   "getNewSite": function() { return /* binding */ getNewSite; },
/* harmony export */   "getNewSiteError": function() { return /* binding */ getNewSiteError; },
/* harmony export */   "isFetchingSite": function() { return /* binding */ isFetchingSite; },
/* harmony export */   "getFetchingSiteError": function() { return /* binding */ getFetchingSiteError; },
/* harmony export */   "isFetchingSiteDetails": function() { return /* binding */ isFetchingSiteDetails; },
/* harmony export */   "isNewSite": function() { return /* binding */ isNewSite; },
/* harmony export */   "getSite": function() { return /* binding */ getSite; },
/* harmony export */   "getSiteIdBySlug": function() { return /* binding */ getSiteIdBySlug; },
/* harmony export */   "getSiteTitle": function() { return /* binding */ getSiteTitle; },
/* harmony export */   "getSiteVerticalId": function() { return /* binding */ getSiteVerticalId; },
/* harmony export */   "isSiteLaunched": function() { return /* binding */ isSiteLaunched; },
/* harmony export */   "isSiteLaunching": function() { return /* binding */ isSiteLaunching; },
/* harmony export */   "isSiteAtomic": function() { return /* binding */ isSiteAtomic; },
/* harmony export */   "isSiteWPForTeams": function() { return /* binding */ isSiteWPForTeams; },
/* harmony export */   "getSiteDomains": function() { return /* binding */ getSiteDomains; },
/* harmony export */   "getSiteSettings": function() { return /* binding */ getSiteSettings; },
/* harmony export */   "getSiteGlobalStyles": function() { return /* binding */ getSiteGlobalStyles; },
/* harmony export */   "getSiteSetupError": function() { return /* binding */ getSiteSetupError; },
/* harmony export */   "getSiteOptions": function() { return /* binding */ getSiteOptions; },
/* harmony export */   "getSiteOption": function() { return /* binding */ getSiteOption; },
/* harmony export */   "getPrimarySiteDomain": function() { return /* binding */ getPrimarySiteDomain; },
/* harmony export */   "getSiteSubdomain": function() { return /* binding */ getSiteSubdomain; },
/* harmony export */   "getSiteLatestAtomicTransfer": function() { return /* binding */ getSiteLatestAtomicTransfer; },
/* harmony export */   "getSiteLatestAtomicTransferError": function() { return /* binding */ getSiteLatestAtomicTransferError; },
/* harmony export */   "getAtomicSoftwareStatus": function() { return /* binding */ getAtomicSoftwareStatus; },
/* harmony export */   "getAtomicSoftwareError": function() { return /* binding */ getAtomicSoftwareError; },
/* harmony export */   "getAtomicSoftwareInstallError": function() { return /* binding */ getAtomicSoftwareInstallError; },
/* harmony export */   "siteHasFeature": function() { return /* binding */ siteHasFeature; },
/* harmony export */   "requiresUpgrade": function() { return /* binding */ requiresUpgrade; },
/* harmony export */   "isJetpackSite": function() { return /* binding */ isJetpackSite; },
/* harmony export */   "isEligibleForProPlan": function() { return /* binding */ isEligibleForProPlan; }
/* harmony export */ });
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(52005);
/* harmony import */ var _types__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(52699);



const getState = state => state;
const getNewSite = state => state.newSite.data;
const getNewSiteError = state => state.newSite.error;
const isFetchingSite = state => state.newSite.isFetching;
const getFetchingSiteError = state => state.fetchingSiteError;
const isFetchingSiteDetails = state => state.isFetchingSiteDetails;
const isNewSite = state => !!state.newSite.data;
/**
 * Get a site matched by id. This selector has a matching
 * resolver that uses the `siteId` parameter to fetch an existing site. If the
 * site cannot be found, invalidate the resolution cache.
 *
 * @param state {State}		state object
 * @param siteId {number}	id of the site to look up
 */

const getSite = (state, siteId) => {
  return state.sites[siteId] || Object.values(state.sites).find(site => site && new URL(site.URL).host === siteId);
};
const getSiteIdBySlug = (_, slug) => {
  var _select$getSite;

  return (_select$getSite = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.select)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L).getSite(slug)) === null || _select$getSite === void 0 ? void 0 : _select$getSite.ID;
};
const getSiteTitle = (_, siteId) => {
  var _select$getSite2;

  return (_select$getSite2 = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.select)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L).getSite(siteId)) === null || _select$getSite2 === void 0 ? void 0 : _select$getSite2.name;
};
const getSiteVerticalId = (_, siteId) => {
  var _select$getSite3, _select$getSite3$opti;

  return (_select$getSite3 = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.select)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L).getSite(siteId)) === null || _select$getSite3 === void 0 ? void 0 : (_select$getSite3$opti = _select$getSite3.options) === null || _select$getSite3$opti === void 0 ? void 0 : _select$getSite3$opti.site_vertical_id;
}; // @TODO: Return LaunchStatus instead of a boolean

const isSiteLaunched = (state, siteId) => {
  var _state$launchStatus$s;

  return ((_state$launchStatus$s = state.launchStatus[siteId]) === null || _state$launchStatus$s === void 0 ? void 0 : _state$launchStatus$s.status) === _types__WEBPACK_IMPORTED_MODULE_2__/* .SiteLaunchStatus.SUCCESS */ .uS.SUCCESS;
}; // @TODO: Return LaunchStatus instead of a boolean

const isSiteLaunching = (state, siteId) => {
  var _state$launchStatus$s2;

  return ((_state$launchStatus$s2 = state.launchStatus[siteId]) === null || _state$launchStatus$s2 === void 0 ? void 0 : _state$launchStatus$s2.status) === _types__WEBPACK_IMPORTED_MODULE_2__/* .SiteLaunchStatus.IN_PROGRESS */ .uS.IN_PROGRESS;
};
const isSiteAtomic = (state, siteId) => {
  var _select$getSite4, _select$getSite4$opti;

  return ((_select$getSite4 = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.select)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L).getSite(siteId)) === null || _select$getSite4 === void 0 ? void 0 : (_select$getSite4$opti = _select$getSite4.options) === null || _select$getSite4$opti === void 0 ? void 0 : _select$getSite4$opti.is_wpcom_atomic) === true;
};
const isSiteWPForTeams = (state, siteId) => {
  var _select$getSite5, _select$getSite5$opti;

  return ((_select$getSite5 = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.select)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L).getSite(siteId)) === null || _select$getSite5 === void 0 ? void 0 : (_select$getSite5$opti = _select$getSite5.options) === null || _select$getSite5$opti === void 0 ? void 0 : _select$getSite5$opti.is_wpforteams_site) === true;
};
const getSiteDomains = (state, siteId) => {
  return state.sitesDomains[siteId];
};
const getSiteSettings = (state, siteId) => {
  return state.sitesSettings[siteId];
};
const getSiteGlobalStyles = (state, siteId) => {
  return state.sitesGlobalStyles[siteId];
};
const getSiteSetupError = state => {
  return state.siteSetupErrors;
};
const getSiteOptions = (state, siteId) => {
  var _state$sites$siteId;

  return (_state$sites$siteId = state.sites[siteId]) === null || _state$sites$siteId === void 0 ? void 0 : _state$sites$siteId.options;
};
const getSiteOption = (state, siteId, optionName) => {
  var _state$sites$siteId2, _state$sites$siteId2$;

  return (_state$sites$siteId2 = state.sites[siteId]) === null || _state$sites$siteId2 === void 0 ? void 0 : (_state$sites$siteId2$ = _state$sites$siteId2.options) === null || _state$sites$siteId2$ === void 0 ? void 0 : _state$sites$siteId2$[optionName];
};
const getPrimarySiteDomain = (_, siteId) => {
  var _select$getSiteDomain;

  return (_select$getSiteDomain = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.select)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L).getSiteDomains(siteId)) === null || _select$getSiteDomain === void 0 ? void 0 : _select$getSiteDomain.find(domain => domain.primary_domain);
};
const getSiteSubdomain = (_, siteId) => {
  var _select$getSiteDomain2;

  return (_select$getSiteDomain2 = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.select)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L).getSiteDomains(siteId)) === null || _select$getSiteDomain2 === void 0 ? void 0 : _select$getSiteDomain2.find(domain => domain.is_subdomain);
};
const getSiteLatestAtomicTransfer = (state, siteId) => {
  var _state$latestAtomicTr;

  return (_state$latestAtomicTr = state.latestAtomicTransferStatus[siteId]) === null || _state$latestAtomicTr === void 0 ? void 0 : _state$latestAtomicTr.transfer;
};
const getSiteLatestAtomicTransferError = (state, siteId) => {
  var _state$latestAtomicTr2;

  return (_state$latestAtomicTr2 = state.latestAtomicTransferStatus[siteId]) === null || _state$latestAtomicTr2 === void 0 ? void 0 : _state$latestAtomicTr2.errorCode;
};
const getAtomicSoftwareStatus = (state, siteId, softwareSet) => {
  var _state$atomicSoftware, _state$atomicSoftware2;

  return (_state$atomicSoftware = state.atomicSoftwareStatus[siteId]) === null || _state$atomicSoftware === void 0 ? void 0 : (_state$atomicSoftware2 = _state$atomicSoftware[softwareSet]) === null || _state$atomicSoftware2 === void 0 ? void 0 : _state$atomicSoftware2.status;
};
const getAtomicSoftwareError = (state, siteId, softwareSet) => {
  var _state$atomicSoftware3, _state$atomicSoftware4;

  return (_state$atomicSoftware3 = state.atomicSoftwareStatus[siteId]) === null || _state$atomicSoftware3 === void 0 ? void 0 : (_state$atomicSoftware4 = _state$atomicSoftware3[softwareSet]) === null || _state$atomicSoftware4 === void 0 ? void 0 : _state$atomicSoftware4.error;
};
const getAtomicSoftwareInstallError = (state, siteId, softwareSet) => {
  var _state$atomicSoftware5, _state$atomicSoftware6;

  return (_state$atomicSoftware5 = state.atomicSoftwareInstallStatus[siteId]) === null || _state$atomicSoftware5 === void 0 ? void 0 : (_state$atomicSoftware6 = _state$atomicSoftware5[softwareSet]) === null || _state$atomicSoftware6 === void 0 ? void 0 : _state$atomicSoftware6.error;
};
const siteHasFeature = (_, siteId, featureKey) => {
  var _select$getSite6, _select$getSite6$plan;

  return Boolean(siteId && ((_select$getSite6 = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.select)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L).getSite(siteId)) === null || _select$getSite6 === void 0 ? void 0 : (_select$getSite6$plan = _select$getSite6.plan) === null || _select$getSite6$plan === void 0 ? void 0 : _select$getSite6$plan.features.active.includes(featureKey)));
};
const requiresUpgrade = (state, siteId) => {
  return siteId && !(0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.select)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L).siteHasFeature(siteId, 'woop');
};
function isJetpackSite(state, siteId) {
  var _select$getSite7;

  return Boolean(siteId && ((_select$getSite7 = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.select)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L).getSite(siteId)) === null || _select$getSite7 === void 0 ? void 0 : _select$getSite7.jetpack));
}
function isEligibleForProPlan(state, siteId) {
  if (!siteId) {
    return false;
  }

  if (isJetpackSite(state, siteId) && !isSiteAtomic(state, siteId) || isSiteWPForTeams(state, siteId)) {
    return false;
  }

  return true;
}

/***/ }),

/***/ 52699:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Hc": function() { return /* binding */ SiteLaunchError; },
/* harmony export */   "uS": function() { return /* binding */ SiteLaunchStatus; },
/* harmony export */   "bc": function() { return /* binding */ AtomicTransferStatus; },
/* harmony export */   "Hf": function() { return /* binding */ AtomicTransferError; },
/* harmony export */   "O": function() { return /* binding */ LatestAtomicTransferStatus; },
/* harmony export */   "sw": function() { return /* binding */ AtomicSoftwareInstallStatus; }
/* harmony export */ });
/* unused harmony export Visibility */
let Visibility;

(function (Visibility) {
  Visibility[Visibility["PublicIndexed"] = 1] = "PublicIndexed";
  Visibility[Visibility["PublicNotIndexed"] = 0] = "PublicNotIndexed";
  Visibility[Visibility["Private"] = -1] = "Private";
})(Visibility || (Visibility = {}));

let SiteLaunchError;

(function (SiteLaunchError) {
  SiteLaunchError["INTERNAL"] = "internal";
})(SiteLaunchError || (SiteLaunchError = {}));

let SiteLaunchStatus;

(function (SiteLaunchStatus) {
  SiteLaunchStatus["UNINITIALIZED"] = "unintialized";
  SiteLaunchStatus["IN_PROGRESS"] = "in_progress";
  SiteLaunchStatus["SUCCESS"] = "success";
  SiteLaunchStatus["FAILURE"] = "failure";
})(SiteLaunchStatus || (SiteLaunchStatus = {}));

let AtomicTransferStatus;

(function (AtomicTransferStatus) {
  AtomicTransferStatus["UNINITIALIZED"] = "unintialized";
  AtomicTransferStatus["IN_PROGRESS"] = "in_progress";
  AtomicTransferStatus["SUCCESS"] = "success";
  AtomicTransferStatus["FAILURE"] = "failure";
})(AtomicTransferStatus || (AtomicTransferStatus = {}));

let AtomicTransferError;

(function (AtomicTransferError) {
  AtomicTransferError["INTERNAL"] = "internal";
})(AtomicTransferError || (AtomicTransferError = {}));

let LatestAtomicTransferStatus;

(function (LatestAtomicTransferStatus) {
  LatestAtomicTransferStatus["UNINITIALIZED"] = "unintialized";
  LatestAtomicTransferStatus["IN_PROGRESS"] = "in_progress";
  LatestAtomicTransferStatus["SUCCESS"] = "success";
  LatestAtomicTransferStatus["FAILURE"] = "failure";
})(LatestAtomicTransferStatus || (LatestAtomicTransferStatus = {}));

let AtomicSoftwareInstallStatus;

(function (AtomicSoftwareInstallStatus) {
  AtomicSoftwareInstallStatus["UNINITIALIZED"] = "unintialized";
  AtomicSoftwareInstallStatus["IN_PROGRESS"] = "in_progress";
  AtomicSoftwareInstallStatus["SUCCESS"] = "success";
  AtomicSoftwareInstallStatus["FAILURE"] = "failure";
})(AtomicSoftwareInstallStatus || (AtomicSoftwareInstallStatus = {}));

/***/ }),

/***/ 14803:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "v": function() { return /* binding */ useSibylQuery; }
/* harmony export */ });
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(82066);
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(18552);



const wpcomSupportBlog = (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('wpcom_support_blog');
const jetpackSupportBlog = (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('jetpack_support_blog');
function useSibylQuery(query, isJetpackSite, isAtomic) {
  const site = !isJetpackSite || isAtomic ? wpcomSupportBlog : jetpackSupportBlog;
  return (0,react_query__WEBPACK_IMPORTED_MODULE_1__.useQuery)(query, async () => await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)({
    path: '/help/qanda',
    apiVersion: '1.1',
    query: `query=${encodeURIComponent(query)}&site=${encodeURIComponent(site)}`
  }), {
    refetchOnWindowFocus: false,
    keepPreviousData: true
  });
}

/***/ }),

/***/ 41515:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "M": function() { return /* binding */ useSubmitForumsMutation; }
/* harmony export */ });
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(82066);
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(18552);


function useSubmitForumsMutation() {
  return (0,react_query__WEBPACK_IMPORTED_MODULE_0__.useMutation)(_ref => {
    let {
      site,
      message,
      subject,
      locale,
      hideInfo,
      userDeclaredSiteUrl
    } = _ref;
    const blogHelpMessages = [];

    if (site) {
      if (site.jetpack) {
        blogHelpMessages.push('WP.com: Unknown');
        blogHelpMessages.push('Jetpack: Yes');
      } else {
        blogHelpMessages.push('WP.com: Yes');
      }

      blogHelpMessages.push('Correct account: yes');
    } else if (userDeclaredSiteUrl) {
      blogHelpMessages.push(`Self-declared URL: ${userDeclaredSiteUrl}`);
    }

    const forumMessage = message + '\n\n' + blogHelpMessages.join('\n');
    const requestData = {
      subject,
      message: forumMessage,
      locale,
      client: 'help-center',
      hide_blog_info: hideInfo,
      blog_id: site === null || site === void 0 ? void 0 : site.ID,
      blog_url: site === null || site === void 0 ? void 0 : site.URL
    };
    return (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP)({
      path: '/help/forums/support/topics/new',
      apiVersion: '1.1',
      method: 'POST',
      body: requestData
    });
  });
}

/***/ }),

/***/ 32457:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "g": function() { return /* binding */ useSubmitTicketMutation; }
/* harmony export */ });
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(82066);
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(18552);


function useSubmitTicketMutation() {
  return (0,react_query__WEBPACK_IMPORTED_MODULE_0__.useMutation)(newTicket => (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP)({
    path: '/help/tickets/kayako/new',
    apiVersion: '1.1',
    method: 'POST',
    body: newTicket
  }));
}

/***/ }),

/***/ 99706:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "p": function() { return /* binding */ useSupportAvailability; }
/* harmony export */ });
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(82066);
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(18552);


function useSupportAvailability(supportType) {
  let enabled = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
  return (0,react_query__WEBPACK_IMPORTED_MODULE_0__.useQuery)(supportType === 'OTHER' ? 'otherSupportAvailability' : 'chatSupportAvailability', async () => await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .ZP)({
    path: `help/eligibility/${supportType === 'OTHER' ? 'all' : 'chat'}/mine`,
    apiNamespace: 'wpcom/v2/',
    apiVersion: '2'
  }), {
    enabled,
    refetchOnWindowFocus: false,
    keepPreviousData: true
  });
}

/***/ }),

/***/ 71382:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "d": function() { return /* binding */ createActions; }
/* harmony export */ });
/* harmony import */ var qs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(19126);
/* harmony import */ var qs__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(qs__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wpcom_request_controls__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(93661);


function createActions(clientCreds) {
  const receiveCurrentUser = currentUser => ({
    type: 'RECEIVE_CURRENT_USER',
    currentUser
  });

  const receiveCurrentUserFailed = () => ({
    type: 'RECEIVE_CURRENT_USER_FAILED'
  });

  const fetchNewUser = () => ({
    type: 'FETCH_NEW_USER'
  });

  const receiveNewUser = response => ({
    type: 'RECEIVE_NEW_USER',
    response
  });

  const receiveNewUserFailed = error => ({
    type: 'RECEIVE_NEW_USER_FAILED',
    error
  });

  const clearErrors = () => ({
    type: 'CLEAR_ERRORS'
  });

  function* createAccount(params) {
    yield fetchNewUser();

    try {
      const newUser = yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_1__/* .wpcomRequest */ ._9)({
        body: {
          // defaults
          is_passwordless: true,
          signup_flow_name: 'gutenboarding',
          locale: 'en',
          ...clientCreds,
          ...params,
          // Set to false because account validation should be a separate action
          validate: false
        },
        path: '/users/new',
        apiVersion: '1.1',
        method: 'post',
        query: (0,qs__WEBPACK_IMPORTED_MODULE_0__.stringify)({
          locale: params.locale
        })
      });
      yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_1__/* .reloadProxy */ .sS)(); // Need to rerequest access after the proxy is reloaded

      yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_1__/* .requestAllBlogsAccess */ .Vw)();
      yield receiveNewUser(newUser);
      return {
        ok: true
      };
    } catch (error) {
      const newUserError = error;
      yield receiveNewUserFailed(newUserError);
      return {
        ok: false,
        newUserError
      };
    }
  }

  return {
    receiveCurrentUser,
    receiveCurrentUserFailed,
    fetchNewUser,
    receiveNewUser,
    receiveNewUserFailed,
    clearErrors,
    createAccount
  };
}

/***/ }),

/***/ 37037:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "L": function() { return /* binding */ STORE_KEY; }
/* harmony export */ });
const STORE_KEY = 'automattic/user';

/***/ }),

/***/ 88330:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "z": function() { return /* binding */ register; }
/* harmony export */ });
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wpcom_request_controls__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(93661);
/* harmony import */ var _actions__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(71382);
/* harmony import */ var _constants__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(37037);
/* harmony import */ var _reducer__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(85938);
/* harmony import */ var _resolvers__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(45177);
/* harmony import */ var _selectors__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(47092);








let isRegistered = false;
function register(clientCreds) {
  if (!isRegistered) {
    isRegistered = true;
    (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.registerStore)(_constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L, {
      actions: (0,_actions__WEBPACK_IMPORTED_MODULE_2__/* .createActions */ .d)(clientCreds),
      controls: _wpcom_request_controls__WEBPACK_IMPORTED_MODULE_3__/* .controls */ .ai,
      reducer: _reducer__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .ZP,
      resolvers: (0,_resolvers__WEBPACK_IMPORTED_MODULE_5__/* .createResolvers */ .i)(clientCreds),
      selectors: _selectors__WEBPACK_IMPORTED_MODULE_6__
    });
  }

  return _constants__WEBPACK_IMPORTED_MODULE_1__/* .STORE_KEY */ .L;
}

/***/ }),

/***/ 85938:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony exports currentUser, newUserData, newUserError, isFetchingNewUser */
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_0__);

const currentUser = (state, action) => {
  switch (action.type) {
    case 'RECEIVE_CURRENT_USER':
      return action.currentUser;

    case 'RECEIVE_CURRENT_USER_FAILED':
      return null;
  }

  return state;
};
const newUserData = (state, action) => {
  if (action.type === 'RECEIVE_NEW_USER') {
    const {
      response
    } = action;
    return {
      username: response.signup_sandbox_username || response.username,
      userId: response.signup_sandbox_user_id || response.user_id,
      bearerToken: response.bearer_token
    };
  } else if (action.type === 'RECEIVE_NEW_USER_FAILED') {
    return undefined;
  }

  return state;
};
const newUserError = (state, action) => {
  switch (action.type) {
    case 'FETCH_NEW_USER':
      return undefined;

    case 'RECEIVE_NEW_USER':
      return undefined;

    case 'CLEAR_ERRORS':
      return undefined;

    case 'RECEIVE_NEW_USER_FAILED':
      return {
        error: action.error.error,
        status: action.error.status,
        statusCode: action.error.statusCode,
        name: action.error.name,
        message: action.error.message
      };
  }

  return state;
};
const isFetchingNewUser = function () {
  let state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
  let action = arguments.length > 1 ? arguments[1] : undefined;

  switch (action.type) {
    case 'FETCH_NEW_USER':
      return true;

    case 'RECEIVE_NEW_USER':
      return false;

    case 'RECEIVE_NEW_USER_FAILED':
      return false;
  }

  return state;
};
const newUser = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.combineReducers)({
  data: newUserData,
  error: newUserError,
  isFetching: isFetchingNewUser
});
const reducer = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.combineReducers)({
  currentUser,
  newUser
});
/* harmony default export */ __webpack_exports__["ZP"] = (reducer);

/***/ }),

/***/ 45177:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "i": function() { return /* binding */ createResolvers; }
/* harmony export */ });
/* harmony import */ var _wpcom_request_controls__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(93661);
/* harmony import */ var _actions__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(71382);


function createResolvers(clientCreds) {
  const {
    receiveCurrentUser,
    receiveCurrentUserFailed
  } = (0,_actions__WEBPACK_IMPORTED_MODULE_0__/* .createActions */ .d)(clientCreds);

  function* getCurrentUser() {
    // In environments where `wpcom-user-bootstrap` is set to true, the currentUser
    // object will be server-side rendered to window.currentUser. In these cases,
    // return that object instead of performing another API request to `/me`.
    if (window.currentUser) {
      return receiveCurrentUser(window.currentUser);
    }

    try {
      const currentUser = yield (0,_wpcom_request_controls__WEBPACK_IMPORTED_MODULE_1__/* .wpcomRequest */ ._9)({
        path: '/me',
        apiVersion: '1.1'
      });
      return receiveCurrentUser(currentUser);
    } catch (err) {
      return receiveCurrentUserFailed();
    }
  }

  return {
    getCurrentUser
  };
}

/***/ }),

/***/ 47092:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "getState": function() { return /* binding */ getState; },
/* harmony export */   "getCurrentUser": function() { return /* binding */ getCurrentUser; },
/* harmony export */   "isCurrentUserLoggedIn": function() { return /* binding */ isCurrentUserLoggedIn; },
/* harmony export */   "getNewUser": function() { return /* binding */ getNewUser; },
/* harmony export */   "getNewUserError": function() { return /* binding */ getNewUserError; },
/* harmony export */   "isFetchingNewUser": function() { return /* binding */ isFetchingNewUser; },
/* harmony export */   "isNewUser": function() { return /* binding */ isNewUser; }
/* harmony export */ });
const getState = state => state;
const getCurrentUser = state => state.currentUser;
const isCurrentUserLoggedIn = state => {
  var _state$currentUser;

  return !!((_state$currentUser = state.currentUser) !== null && _state$currentUser !== void 0 && _state$currentUser.ID);
};
const getNewUser = state => state.newUser.data;
const getNewUserError = state => state.newUser.error;
const isFetchingNewUser = state => state.newUser.isFetching;
const isNewUser = state => !!state.newUser.data;

/***/ }),

/***/ 93661:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_9": function() { return /* binding */ wpcomRequest; },
/* harmony export */   "sS": function() { return /* binding */ reloadProxy; },
/* harmony export */   "Vw": function() { return /* binding */ requestAllBlogsAccess; },
/* harmony export */   "ai": function() { return /* binding */ controls; }
/* harmony export */ });
/* unused harmony exports fetchAndParse, wait */
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(18552);

const wpcomRequest = request => ({
  type: 'WPCOM_REQUEST',
  request
});
/**
 * Action for performing a fetching using `window.fetch()` and parsing the response body.
 * It's different from `apiFetch()` from
 * `@wordpress/data-controls` in that it doesn't use any middleware to add extra parameters.
 *
 * @param resource the resource you wish to fetch
 * @param options request options
 */

const fetchAndParse = (resource, options) => ({
  type: 'FETCH_AND_PARSE',
  resource,
  options
});
const reloadProxy = () => ({
  type: 'RELOAD_PROXY'
});
const requestAllBlogsAccess = () => ({
  type: 'REQUEST_ALL_BLOGS_ACCESS'
});
const wait = ms => ({
  type: 'WAIT',
  ms
});
const controls = {
  WPCOM_REQUEST: _ref => {
    let {
      request
    } = _ref;
    return (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)(request);
  },
  FETCH_AND_PARSE: async _ref2 => {
    let {
      resource,
      options
    } = _ref2;
    const response = await window.fetch(resource, options);
    return {
      ok: response.ok,
      body: await response.json()
    };
  },
  RELOAD_PROXY: () => {
    (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_0__/* .reloadProxy */ .sS)();
  },
  REQUEST_ALL_BLOGS_ACCESS: () => (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_0__/* .requestAllBlogsAccess */ .Vw)(),
  WAIT: _ref3 => {
    let {
      ms
    } = _ref3;
    return new Promise(resolve => setTimeout(resolve, ms));
  }
};

/***/ }),

/***/ 10819:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ buildConnection; }
/* harmony export */ });
/*
 * This function creates a stub `Connection` object that dynamically loads the chunk
 * with the `happychat/connection` library only after the first method call.
 */
function buildConnection(props) {
  // Promise with a lazy initialized `Connection`
  let connection = null; // Async load the connection library and return a promise with its default export.
  // That's a factory function that creates and returns the `Connection` class instance.

  function importConnectionLib() {
    return Promise.resolve(/* import() */).then(__webpack_require__.bind(__webpack_require__, 56989));
  }

  function getConnection() {
    if (!connection) {
      connection = importConnectionLib().then(_ref => {
        let {
          default: createConnection
        } = _ref;
        return createConnection(props);
      });
    }

    return connection;
  }

  return {
    async init(dispatch, auth) {
      const conn = await getConnection();
      return conn.init(dispatch, auth);
    },

    async request(action, timeout) {
      const conn = await getConnection();
      return conn.request(action, timeout);
    },

    async send(action) {
      const conn = await getConnection();
      return conn.send(action);
    }

  };
}

/***/ }),

/***/ 56989:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Connection": function() { return /* binding */ Connection; },
/* harmony export */   "buildConnectionForCheckingAvailability": function() { return /* binding */ buildConnectionForCheckingAvailability; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(56666);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(34386);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var socket_io_client__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(17768);
/* harmony import */ var socket_io_client__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(socket_io_client__WEBPACK_IMPORTED_MODULE_1__);



const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('calypso:happychat:connection');

const buildConnection = socket => typeof socket === 'string' ? new (socket_io_client__WEBPACK_IMPORTED_MODULE_1___default())(socket, {
  // force websocket connection since we no longer have sticky connections server side.
  transports: ['websocket']
}) // If socket is an URL, connect to server.
: socket; // If socket is not an url, use it directly. Useful for testing.
//The second one is an identity function, used in 'use-happychat-available' hook


class Connection {
  constructor() {
    let props = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    let closeAfterAccept = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveAccept", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveConnect", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveDisconnect", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveError", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveInit", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveLocalizedSupport", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveMessage", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveMessageOptimistic", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveMessageUpdate", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveReconnecting", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveStatus", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveToken", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "receiveUnauthorized", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "requestTranscript", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "closeAfterAccept", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "dispatch", void 0);

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "openSocket", void 0);

    Object.assign(this, props);
    this.closeAfterAccept = closeAfterAccept;
  }
  /**
   * Init the SockeIO connection: check user authorization and bind socket events
   *
   * @param dispatch Redux dispatch function
   * @param auth Authentication promise, will return the user info upon fulfillment
   * @returns Fulfilled (returns the opened socket)
   *                   	 or rejected (returns an error message)
   */


  init(dispatch, auth) {
    if (this.openSocket) {
      debug('socket is already connected');
      return this.openSocket;
    }

    this.dispatch = dispatch;
    this.openSocket = new Promise((resolve, reject) => {
      auth.then(_ref => {
        let {
          url,
          user: {
            signer_user_id,
            jwt,
            locale,
            groups,
            skills,
            geoLocation
          }
        } = _ref;
        const socket = buildConnection(url);
        socket.once('connect', () => {
          var _this$receiveConnect;

          return dispatch((_this$receiveConnect = this.receiveConnect) === null || _this$receiveConnect === void 0 ? void 0 : _this$receiveConnect.call(this));
        }).on('token', handler => {
          var _this$receiveToken;

          dispatch((_this$receiveToken = this.receiveToken) === null || _this$receiveToken === void 0 ? void 0 : _this$receiveToken.call(this));
          handler({
            signer_user_id,
            jwt,
            locale,
            groups,
            skills
          });
        }).on('init', () => {
          var _this$receiveInit, _this$requestTranscri;

          dispatch((_this$receiveInit = this.receiveInit) === null || _this$receiveInit === void 0 ? void 0 : _this$receiveInit.call(this, {
            signer_user_id,
            locale,
            groups,
            skills,
            geoLocation
          }));
          dispatch((_this$requestTranscri = this.requestTranscript) === null || _this$requestTranscri === void 0 ? void 0 : _this$requestTranscri.call(this));
          resolve(socket);
        }).on('unauthorized', () => {
          var _this$receiveUnauthor;

          socket.close();
          dispatch((_this$receiveUnauthor = this.receiveUnauthorized) === null || _this$receiveUnauthor === void 0 ? void 0 : _this$receiveUnauthor.call(this, 'User is not authorized'));
          reject('user is not authorized');
        }).on('disconnect', reason => {
          var _this$receiveDisconne;

          return dispatch((_this$receiveDisconne = this.receiveDisconnect) === null || _this$receiveDisconne === void 0 ? void 0 : _this$receiveDisconne.call(this, reason));
        }).on('reconnecting', () => {
          var _this$receiveReconnec;

          return dispatch((_this$receiveReconnec = this.receiveReconnecting) === null || _this$receiveReconnec === void 0 ? void 0 : _this$receiveReconnec.call(this));
        }).on('status', status => {
          var _this$receiveStatus;

          return dispatch((_this$receiveStatus = this.receiveStatus) === null || _this$receiveStatus === void 0 ? void 0 : _this$receiveStatus.call(this, status));
        }).on('accept', accept => {
          var _this$receiveAccept;

          dispatch((_this$receiveAccept = this.receiveAccept) === null || _this$receiveAccept === void 0 ? void 0 : _this$receiveAccept.call(this, accept));

          if (this.closeAfterAccept) {
            socket.close();
          }
        }).on('localized-support', accept => {
          var _this$receiveLocalize;

          return dispatch((_this$receiveLocalize = this.receiveLocalizedSupport) === null || _this$receiveLocalize === void 0 ? void 0 : _this$receiveLocalize.call(this, accept));
        }).on('message', message => {
          var _this$receiveMessage;

          return dispatch((_this$receiveMessage = this.receiveMessage) === null || _this$receiveMessage === void 0 ? void 0 : _this$receiveMessage.call(this, message));
        }).on('message.optimistic', message => {
          var _this$receiveMessageO;

          return dispatch((_this$receiveMessageO = this.receiveMessageOptimistic) === null || _this$receiveMessageO === void 0 ? void 0 : _this$receiveMessageO.call(this, message));
        }).on('message.update', message => {
          var _this$receiveMessageU;

          return dispatch((_this$receiveMessageU = this.receiveMessageUpdate) === null || _this$receiveMessageU === void 0 ? void 0 : _this$receiveMessageU.call(this, message));
        }).on('reconnect_attempt', () => {
          socket.io.opts.transports = ['polling', 'websocket'];
        });
      }).catch(e => reject(e));
    });
    return this.openSocket;
  }
  /**
   * Given a Redux action, emits a SocketIO event.
   *
   * @param  {object} action A Redux action with props
   *                    {
   *                  		event: SocketIO event name,
   *                  	  payload: contents to be sent,
   *                  	  error: message to be shown should the event fails to be sent,
   *                  	}
   * @returns { Promise } Fulfilled (returns nothing)
   *                     or rejected (returns an error message)
   */


  send(action) {
    if (!this.openSocket) {
      return;
    }

    return this.openSocket.then(socket => socket.emit(action.event, action.payload), e => {
      var _this$dispatch, _this$receiveError;

      (_this$dispatch = this.dispatch) === null || _this$dispatch === void 0 ? void 0 : _this$dispatch.call(this, (_this$receiveError = this.receiveError) === null || _this$receiveError === void 0 ? void 0 : _this$receiveError.call(this, 'failed to send ' + action.event + ': ' + e)); // so we can relay the error message, for testing purposes

      return Promise.reject(e);
    });
  }
  /**
   *
   * Given a Redux action and a timeout, emits a SocketIO event that request
   * some info to the Happychat server.
   *
   * The request can have three states, and will dispatch an action accordingly:
   *
   * - request was succesful: would dispatch action.callback
   * - request was unsucessful: would dispatch receiveError
   *
   * @param  {object} action A Redux action with props
   *                  	{
   *                  		event: SocketIO event name,
   *                  		payload: contents to be sent,
   *                  		callback: a Redux action creator
   *                  	}
   * @param  {number} timeout How long (in milliseconds) has the server to respond
   * @returns { Promise } Fulfilled (returns the transcript response)
   *                     or rejected (returns an error message)
   */


  request(action, timeout) {
    if (!this.openSocket) {
      return;
    }

    return this.openSocket.then(socket => {
      const promiseRace = Promise.race([new Promise((resolve, reject) => {
        socket.emit(action.event, action.payload, (e, result) => {
          if (e) {
            return reject(new Error(e)); // request failed
          }

          return resolve(result); // request succesful
        });
      }), new Promise((resolve, reject) => setTimeout(() => {
        return reject(new Error('timeout')); // request timeout
      }, timeout))]); // dispatch the request state upon promise race resolution

      promiseRace.then(result => {
        var _this$dispatch2, _action$callback;

        return (_this$dispatch2 = this.dispatch) === null || _this$dispatch2 === void 0 ? void 0 : _this$dispatch2.call(this, (_action$callback = action.callback) === null || _action$callback === void 0 ? void 0 : _action$callback.call(action, result));
      }, e => {
        if (e.message !== 'timeout') {
          var _this$dispatch3, _this$receiveError2;

          (_this$dispatch3 = this.dispatch) === null || _this$dispatch3 === void 0 ? void 0 : _this$dispatch3.call(this, (_this$receiveError2 = this.receiveError) === null || _this$receiveError2 === void 0 ? void 0 : _this$receiveError2.call(this, action.event + ' request failed: ' + e.message));
        }
      });
      return promiseRace;
    }, e => {
      var _this$dispatch4, _this$receiveError3;

      (_this$dispatch4 = this.dispatch) === null || _this$dispatch4 === void 0 ? void 0 : _this$dispatch4.call(this, (_this$receiveError3 = this.receiveError) === null || _this$receiveError3 === void 0 ? void 0 : _this$receiveError3.call(this, 'failed to send ' + action.event + ': ' + e)); // so we can relay the error message, for testing purposes

      return Promise.reject(e);
    });
  }

} // Used by the Help Center, it closes the socket after receiving 'accept' or 'unauthorized'

const buildConnectionForCheckingAvailability = connectionProps => new Connection(connectionProps, true);
/* harmony default export */ __webpack_exports__["default"] = (connectionProps => new Connection(connectionProps));

/***/ }),

/***/ 61082:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ useHappychatAuth; }
/* harmony export */ });
/* unused harmony export requestHappyChatAuth */
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(11481);
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(82066);
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(18552);




async function requestHappyChatAuth() {
  const user = await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)({
    path: '/me',
    apiVersion: '1.1'
  });
  const url = (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('happychat_url');
  const locale = (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_3__/* .getLocaleSlug */ .Yj)();
  const happychatUser = {
    signer_user_id: user.ID,
    locale,
    groups: ['WP.com'],
    skills: {
      product: ['WP.com']
    }
  };
  const session = await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)({
    path: '/happychat/session',
    apiVersion: '1.1',
    method: 'POST'
  });
  const {
    session_id,
    geo_location
  } = session;
  happychatUser.geoLocation = geo_location;
  const sign = await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .ZP)({
    path: '/jwt/sign',
    apiVersion: '1.1',
    method: 'POST',
    body: {
      payload: JSON.stringify({
        user,
        session_id
      })
    }
  });
  const {
    jwt
  } = sign;
  return {
    url,
    user: {
      jwt,
      ...happychatUser
    },
    fullUser: user
  };
}
function useHappychatAuth() {
  let enabled = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
  return (0,react_query__WEBPACK_IMPORTED_MODULE_1__.useQuery)('getHappychatAuth', requestHappyChatAuth, {
    staleTime: Infinity,
    enabled
  });
}

/***/ }),

/***/ 89645:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export useHappychatAvailable */
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _connection__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(56989);
/* harmony import */ var _use_happychat_auth__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(61082);



function useHappychatAvailable() {
  const [available, setIsAvailable] = (0,react__WEBPACK_IMPORTED_MODULE_0__.useState)(undefined);
  const {
    data: dataAuth,
    isLoading: isLoadingAuth
  } = (0,_use_happychat_auth__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)();
  (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    if (!isLoadingAuth && dataAuth) {
      const connection = (0,_connection__WEBPACK_IMPORTED_MODULE_2__.buildConnectionForCheckingAvailability)({
        receiveAccept: receivedAvailability => {
          setIsAvailable(receivedAvailability);
        },
        receiveUnauthorized: () => {
          setIsAvailable(false);
        }
      });
      connection.init(value => value, Promise.resolve(dataAuth));
    }
  }, [dataAuth, isLoadingAuth]);
  return {
    available: Boolean(available),
    isLoading: available === undefined
  };
}
/* harmony default export */ __webpack_exports__["Z"] = (useHappychatAvailable);

/***/ }),

/***/ 40495:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "x": function() { return /* binding */ BackButton; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(43239);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(5869);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(21100);
/* harmony import */ var _wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(95885);
/* harmony import */ var react_router_dom__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(29175);
/* harmony import */ var _styles_scss__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(62829);






const BackButton = _ref => {
  let {
    onClick,
    backToRoot = false
  } = _ref;
  const {
    __
  } = (0,_wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_2__/* .useI18n */ .QT)();
  const history = (0,react_router_dom__WEBPACK_IMPORTED_MODULE_3__/* .useHistory */ .k6)();

  function defaultOnClick() {
    if (backToRoot) {
      history.push('/');
    } else {
      history.goBack();
    }
  }

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, {
    className: "back-button__help-center",
    borderless: true,
    onClick: onClick || defaultOnClick
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z,
    size: 18
  }), __('Back', "full-site-editing"));
};

/***/ }),

/***/ 7577:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "z": function() { return /* binding */ BackToTopButton; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(43239);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(5869);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(94140);
/* harmony import */ var _wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(95885);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _back_to_top_button_scss__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(50436);







const BackToTopButton = () => {
  const elementRef = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useRef)(null);
  const scrollParentRef = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useRef)(null);
  const {
    __
  } = (0,_wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_3__/* .useI18n */ .QT)();
  const SCROLL_THRESHOLD = 400;
  const [visible, setVisible] = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useState)(false);
  const scrollCallback = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useCallback)(() => {
    const containerNode = scrollParentRef.current;

    if (containerNode) {
      if (containerNode.scrollTop > SCROLL_THRESHOLD) {
        setVisible(true);
      } else {
        setVisible(false);
      }
    }
  }, [scrollParentRef]);
  (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    if (elementRef.current) {
      scrollParentRef.current = elementRef.current.parentElement;
    }
  }, [elementRef]);
  (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    const containerNode = scrollParentRef.current;

    if (containerNode) {
      containerNode.addEventListener('scroll', scrollCallback);
      return () => {
        containerNode.removeEventListener('scroll', scrollCallback);
      };
    }
  }, [scrollParentRef, scrollCallback]);

  const scrollToTop = () => {
    if (scrollParentRef.current) {
      scrollParentRef.current.scrollTop = 0;
    }
  };

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, {
    ref: elementRef,
    className: classnames__WEBPACK_IMPORTED_MODULE_1___default()('back-to-top-button__help-center', {
      'is-visible': visible
    }),
    onClick: scrollToTop
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z,
    size: 16
  }), __('Back to top', "full-site-editing"));
};

/***/ }),

/***/ 19762:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var calypso_blocks_support_article_dialog_header__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(85774);
/* harmony import */ var calypso_components_embed_container__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(22169);
/* harmony import */ var _placeholder_lines__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(15166);
/* harmony import */ var _help_center_article_content_scss__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(21586);


/* eslint-disable no-restricted-imports */



 // import './style.scss';



const ContentWithExternalLinks = _ref => {
  let {
    content,
    className
  } = _ref;
  const contentRef = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useRef)(null);
  (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    if (contentRef.current && content.length) {
      contentRef.current.innerHTML = content;
      const externalLinks = contentRef.current.querySelectorAll('a[href*="http"]');
      externalLinks.forEach(l => l.setAttribute('target', '_blank'));
    }
  }, [contentRef, content]);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    ref: contentRef,
    className: className
  });
};

const ArticleContent = _ref2 => {
  let {
    content,
    title,
    link,
    isLoading = false
  } = _ref2;
  const post = {
    title: title,
    url: link
  };
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("article", {
    className: "help-center-article-content__story"
  }, isLoading ? (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_placeholder_lines__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, {
    lines: 8
  }) : (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(calypso_blocks_support_article_dialog_header__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, {
    post: post,
    isLoading: false
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(calypso_components_embed_container__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(ContentWithExternalLinks, {
    className: "help-center-article-content__story-content",
    content: content
  }))));
};

/* harmony default export */ __webpack_exports__["Z"] = (ArticleContent);

/***/ }),

/***/ 19892:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(4792);
/* harmony import */ var calypso_blocks_inline_help_constants__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(91040);
/* harmony import */ var calypso_components_data_query_reader_post__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(56077);
/* harmony import */ var calypso_components_data_query_reader_site__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(9232);
/* harmony import */ var calypso_data_support_article_alternates_use_support_article_alternates_query__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(1230);
/* harmony import */ var calypso_state_reader_posts_selectors__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(6712);
/* harmony import */ var _help_center_article_content__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(19762);
/* harmony import */ var _help_center_article_content_scss__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(21586);


/* eslint-disable no-restricted-imports */







 // import './style.scss';



const getPostKey = (blogId, postId) => ({
  blogId,
  postId
});

const useSupportArticleAlternatePostKey = (blogId, postId) => {
  const supportArticleAlternates = (0,calypso_data_support_article_alternates_use_support_article_alternates_query__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(blogId, postId);

  if (supportArticleAlternates.isLoading) {
    return null;
  }

  if (!supportArticleAlternates.data) {
    return getPostKey(blogId, postId);
  }

  return getPostKey(supportArticleAlternates.data.blog_id, supportArticleAlternates.data.page_id);
};

const ArticleFetchingContent = _ref => {
  let {
    postId,
    blogId,
    articleUrl
  } = _ref;
  const postKey = useSupportArticleAlternatePostKey(+(blogId ?? calypso_blocks_inline_help_constants__WEBPACK_IMPORTED_MODULE_7__/* .SUPPORT_BLOG_ID */ .Di), postId);
  const post = (0,react_redux__WEBPACK_IMPORTED_MODULE_2__/* .useSelector */ .v9)(state => (0,calypso_state_reader_posts_selectors__WEBPACK_IMPORTED_MODULE_8__/* .getPostByKey */ .UK)(state, postKey));
  const isLoading = !(post !== null && post !== void 0 && post.content) || !postKey;
  const siteId = post === null || post === void 0 ? void 0 : post.site_ID;
  const shouldQueryReaderPost = !post && postKey;
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    //If a url includes an anchor, let's scroll this into view!
    if (typeof window !== 'undefined' && articleUrl && articleUrl.indexOf('#') !== -1 && post !== null && post !== void 0 && post.content) {
      setTimeout(() => {
        const anchorId = articleUrl.split('#').pop();

        if (anchorId) {
          const element = document.getElementById(anchorId);

          if (element) {
            element.scrollIntoView();
          }
        }
      }, 0);
    }
  }, [articleUrl, post]);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, siteId && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(calypso_components_data_query_reader_site__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z, {
    siteId: +siteId
  }), shouldQueryReaderPost && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(calypso_components_data_query_reader_post__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z, {
    postKey: postKey,
    isHelpCenter: true
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_article_content__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z, {
    content: post === null || post === void 0 ? void 0 : post.content,
    title: post === null || post === void 0 ? void 0 : post.title,
    link: post === null || post === void 0 ? void 0 : post.link,
    isLoading: isLoading
  }));
};

/* harmony default export */ __webpack_exports__["Z"] = (ArticleFetchingContent);

/***/ }),

/***/ 23025:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "j": function() { return /* binding */ SITE_STORE; },
/* harmony export */   "_": function() { return /* binding */ HelpCenterContactForm; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36115);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(43239);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(37499);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(27136);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(32457);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(41515);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(34381);
/* harmony import */ var _automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(30849);
/* harmony import */ var _automattic_site_picker__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(1283);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(55609);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(65736);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(_wordpress_i18n__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(5869);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(5614);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(4792);
/* harmony import */ var react_router_dom__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(29175);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(73041);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(20834);
/* harmony import */ var _directly__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(39226);
/* harmony import */ var _stores__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(98865);
/* harmony import */ var _support_variations__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(44241);
/* harmony import */ var _back_button__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(40495);
/* harmony import */ var _help_center_notice__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(10083);
/* harmony import */ var _help_center_sibyl_articles__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(61108);
/* harmony import */ var _help_center_contact_form_scss__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(27427);


/* eslint-disable no-restricted-imports */

/**
 * External Dependencies
 */








const __ = _wordpress_i18n__WEBPACK_IMPORTED_MODULE_4__.__;





/**
 * Internal Dependencies
 */








const SITE_STORE = 'automattic/site';
const fakeFaces = Array.from({
  length: 10
}, (_, index) => `https://s0.wp.com/i/fake-faces/face-${index}.jpg`);
const randomTwoFaces = fakeFaces.sort(() => Math.random() - 0.5).slice(0, 2);

const HelpCenterSitePicker = _ref => {
  let {
    onSelect,
    currentSite,
    siteId,
    enabled
  } = _ref;
  const otherSite = {
    name: __('Other site', "full-site-editing"),
    ID: 0,
    logo: {
      id: '',
      sizes: [],
      url: ''
    },
    URL: ''
  };

  function pickSite(ID) {
    onSelect(ID);
  }

  const options = [currentSite, otherSite];
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_site_picker__WEBPACK_IMPORTED_MODULE_9__/* .SitePickerDropDown */ .a, {
    enabled: enabled,
    onPickSite: pickSite,
    options: options,
    siteId: siteId
  });
};

const titles = {
  CHAT: {
    formTitle: __('Start live chat', "full-site-editing"),
    trayText: __('Our WordPress experts will be with you right away', "full-site-editing"),
    buttonLabel: __('Chat with us', "full-site-editing"),
    buttonLoadingLabel: __('Connecting to chat', "full-site-editing")
  },
  EMAIL: {
    formTitle: __('Send us an email', "full-site-editing"),
    trayText: __('Our WordPress experts will get back to you soon', "full-site-editing"),
    buttonLabel: __('Email us', "full-site-editing"),
    buttonLoadingLabel: __('Sending email', "full-site-editing")
  },
  DIRECTLY: {
    formTitle: __('Start live chat with an expert', "full-site-editing"),
    formSubtitle: __('These are others, like yourself, who have been selected because of their WordPress.com knowledge to help answer questions.', "full-site-editing"),
    trayText: __('An expert user will be with you right away', "full-site-editing"),
    formDisclaimer: __('Please do not provide financial or contact information when submitting this form.', "full-site-editing"),
    buttonLabel: __('Ask an expert', "full-site-editing"),
    buttonLoadingLabel: __('Connecting you to an expert', "full-site-editing")
  },
  FORUM: {
    formTitle: __('Ask in our community forums', "full-site-editing"),
    formDisclaimer: __('Please do not provide financial or contact information when submitting this form.', "full-site-editing"),
    buttonLabel: __('Ask in the forums', "full-site-editing"),
    buttonLoadingLabel: __('Posting in the forums', "full-site-editing")
  }
};
const HelpCenterContactForm = () => {
  const {
    search
  } = (0,react_router_dom__WEBPACK_IMPORTED_MODULE_10__/* .useLocation */ .TH)();
  const sectionName = (0,react_redux__WEBPACK_IMPORTED_MODULE_6__/* .useSelector */ .v9)(calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z);
  const params = new URLSearchParams(search);
  const mode = params.get('mode');
  const history = (0,react_router_dom__WEBPACK_IMPORTED_MODULE_10__/* .useHistory */ .k6)();
  const [hideSiteInfo, setHideSiteInfo] = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(false);
  const [hasSubmittingError, setHasSubmittingError] = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(false);
  const locale = (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_12__/* .useLocale */ .bU)();
  const {
    isLoading: submittingTicket,
    mutateAsync: submitTicket
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_13__/* .useSubmitTicketMutation */ .g)();
  const {
    isLoading: submittingTopic,
    mutateAsync: submitTopic
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_14__/* .useSubmitForumsMutation */ .M)();
  const [sitePickerChoice, setSitePickerChoice] = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)('CURRENT_SITE');
  const {
    selectedSite,
    subject,
    message,
    userDeclaredSiteUrl,
    directlyData
  } = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_3__.useSelect)(select => {
    return {
      selectedSite: select(_stores__WEBPACK_IMPORTED_MODULE_15__/* .HELP_CENTER_STORE */ .aM).getSite(),
      subject: select(_stores__WEBPACK_IMPORTED_MODULE_15__/* .HELP_CENTER_STORE */ .aM).getSubject(),
      message: select(_stores__WEBPACK_IMPORTED_MODULE_15__/* .HELP_CENTER_STORE */ .aM).getMessage(),
      userDeclaredSiteUrl: select(_stores__WEBPACK_IMPORTED_MODULE_15__/* .HELP_CENTER_STORE */ .aM).getUserDeclaredSiteUrl(),
      directlyData: select(_stores__WEBPACK_IMPORTED_MODULE_15__/* .HELP_CENTER_STORE */ .aM).getDirectly()
    };
  });
  const userData = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_3__.useSelect)(select => select(_stores__WEBPACK_IMPORTED_MODULE_15__/* .USER_STORE */ .Em).getCurrentUser());
  const {
    setSite,
    resetStore,
    setShowHelpCenter,
    setUserDeclaredSiteUrl,
    setUserDeclaredSite,
    setSubject,
    setMessage
  } = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_3__.useDispatch)(_stores__WEBPACK_IMPORTED_MODULE_15__/* .HELP_CENTER_STORE */ .aM);
  const {
    result: ownershipResult,
    isLoading: isAnalysisLoading,
    site: userDeclaredSite
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_16__/* .useSiteAnalysis */ .g)(userDeclaredSiteUrl);
  (0,react__WEBPACK_IMPORTED_MODULE_5__.useEffect)(() => {
    const supportVariation = (0,_support_variations__WEBPACK_IMPORTED_MODULE_17__/* .getSupportVariationFromMode */ .yQ)(mode);
    (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_inlinehelp_contact_view', {
      support_variation: supportVariation,
      location: 'help-center',
      section: sectionName
    });
  }, [mode, sectionName]); // record the resolved site

  (0,react__WEBPACK_IMPORTED_MODULE_5__.useEffect)(() => {
    if (userDeclaredSite) {
      setUserDeclaredSite(userDeclaredSite);
    }
  }, [userDeclaredSite, setUserDeclaredSite]);
  (0,react__WEBPACK_IMPORTED_MODULE_5__.useEffect)(() => {
    if (directlyData !== null && directlyData !== void 0 && directlyData.hasSession) {
      (0,_directly__WEBPACK_IMPORTED_MODULE_7__/* .execute */ .ht)(['maximize', {}]);
      setShowHelpCenter(false);
    }
  }, [directlyData, setShowHelpCenter]);
  const isSubmitting = submittingTicket || submittingTopic;
  const formTitles = titles[mode];
  const siteId = (0,react_redux__WEBPACK_IMPORTED_MODULE_6__/* .useSelector */ .v9)(calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_18__/* ["default"] */ .Z);
  const currentSite = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_3__.useSelect)(select => select(SITE_STORE).getSite(siteId));
  let supportSite; // if the user picked "other site", force them to declare a site

  if (sitePickerChoice === 'OTHER_SITE') {
    supportSite = userDeclaredSite;
  } else {
    supportSite = selectedSite || currentSite;
  }

  function handleCTA() {
    switch (mode) {
      case 'CHAT':
        {
          if (supportSite) {
            var _supportSite$plan;

            (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_inlinehelp_contact_submit', {
              support_variation: 'happychat',
              location: 'help-center',
              section: sectionName
            });
            (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_help_live_chat_begin', {
              site_plan_product_id: supportSite ? (_supportSite$plan = supportSite.plan) === null || _supportSite$plan === void 0 ? void 0 : _supportSite$plan.product_id : null,
              is_automated_transfer: supportSite ? supportSite.options.is_automated_transfer : null,
              location: 'help-center',
              section: sectionName
            });
            history.push('/inline-chat');
            break;
          }

          break;
        }

      case 'EMAIL':
        {
          if (supportSite) {
            var _supportSite$plan2;

            const ticketMeta = ['Site I need help with: ' + supportSite.URL, 'Plan: ' + ((_supportSite$plan2 = supportSite.plan) === null || _supportSite$plan2 === void 0 ? void 0 : _supportSite$plan2.product_slug)];
            const kayakoMessage = [...ticketMeta, '\n', message].join('\n');
            submitTicket({
              subject: subject ?? '',
              message: kayakoMessage,
              locale,
              client: 'browser:help-center',
              is_chat_overflow: false,
              blog_url: supportSite.URL
            }).then(() => {
              (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_inlinehelp_contact_submit', {
                support_variation: 'kayako',
                location: 'help-center',
                section: sectionName
              });
              history.push('/success');
              resetStore();
            }).catch(() => {
              setHasSubmittingError(true);
            });
          }

          break;
        }

      case 'FORUM':
        {
          submitTopic({
            site: supportSite,
            message: message ?? '',
            subject: subject ?? '',
            locale,
            hideInfo: hideSiteInfo,
            userDeclaredSiteUrl
          }).then(response => {
            (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_inlinehelp_contact_submit', {
              support_variation: 'forums',
              location: 'help-center',
              section: sectionName
            });
            history.push(`/success?forumTopic=${encodeURIComponent(response.topic_URL)}`);
            resetStore();
          }).catch(() => {
            setHasSubmittingError(true);
          });
          break;
        }

      case 'DIRECTLY':
        {
          (0,_directly__WEBPACK_IMPORTED_MODULE_7__/* .askDirectlyQuestion */ .SW)(message ?? '', (userData === null || userData === void 0 ? void 0 : userData.display_name) ?? '', (userData === null || userData === void 0 ? void 0 : userData.email) ?? '');
          (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_inlinehelp_contact_submit', {
            support_variation: 'directly',
            location: 'help-center',
            section: sectionName
          });
          setShowHelpCenter(false);
          break;
        }
    }
  }

  const InfoTip = () => {
    const [ref, setRef] = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)();
    const [isOpen, setOpen] = (0,react__WEBPACK_IMPORTED_MODULE_5__.useState)(false);
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_19__/* ["default"] */ .Z, {
      borderless: true,
      ref: reference => ref !== reference && setRef(reference),
      "aria-haspopup": true,
      "aria-label": __('More information'),
      onClick: () => setOpen(!isOpen)
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_20__/* ["default"] */ .Z, {
      icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_21__/* ["default"] */ .Z,
      size: 18
    })), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_22__/* ["default"] */ .Z, {
      isVisible: isOpen,
      context: ref,
      position: "top left"
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", null, "This may result in a longer response time,", (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("br", null), "but WordPress.com staff in the forums will", (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("br", null), "still be able to view your site's URL.")));
  };

  const isCTADisabled = () => {
    if (isSubmitting || !message) {
      return true;
    }

    switch (mode) {
      case 'CHAT':
        return !supportSite;

      case 'EMAIL':
        return !supportSite || !subject;

      case 'FORUM':
        return !subject;
    }
  };

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("main", {
    className: "help-center-contact-form"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_back_button__WEBPACK_IMPORTED_MODULE_23__/* .BackButton */ .x, null), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("h1", {
    className: "help-center-contact-form__site-picker-title"
  }, formTitles.formTitle), formTitles.formSubtitle && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", {
    className: "help-center-contact-form__site-picker-form-subtitle"
  }, formTitles.formSubtitle), formTitles.formDisclaimer && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", {
    className: "help-center-contact-form__site-picker-form-warning"
  }, formTitles.formDisclaimer), mode !== 'DIRECTLY' && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("section", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(HelpCenterSitePicker, {
    enabled: mode === 'FORUM',
    currentSite: currentSite,
    onSelect: id => {
      if (id !== 0) {
        setSite(currentSite);
      }

      setSitePickerChoice(id === 0 ? 'OTHER_SITE' : 'CURRENT_SITE');
    },
    siteId: sitePickerChoice === 'CURRENT_SITE' ? currentSite === null || currentSite === void 0 ? void 0 : currentSite.ID : 0
  })), sitePickerChoice === 'OTHER_SITE' && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("section", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__.TextControl, {
    label: __('Site address', "full-site-editing"),
    value: userDeclaredSiteUrl ?? '',
    onChange: setUserDeclaredSiteUrl
  })), ownershipResult && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_notice__WEBPACK_IMPORTED_MODULE_24__/* .HelpCenterOwnershipNotice */ .J, {
    ownershipResult: ownershipResult,
    isAnalysisLoading: isAnalysisLoading,
    userDeclaredSite: userDeclaredSite
  })), ['FORUM', 'EMAIL'].includes(mode) && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("section", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__.TextControl, {
    className: "help-center-contact-form__subject",
    label: __('Subject', "full-site-editing"),
    value: subject ?? '',
    onChange: setSubject
  })), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("section", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("label", {
    className: "help-center-contact-form__label",
    htmlFor: "help-center-contact-form__message"
  }, __('How can we help you today?', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("textarea", {
    id: "help-center-contact-form__message",
    rows: 10,
    value: message ?? '',
    onInput: event => setMessage(event.currentTarget.value),
    className: "help-center-contact-form__message"
  })), mode === 'FORUM' && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("section", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "help-center-contact-form__domain-sharing"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__.CheckboxControl, {
    checked: hideSiteInfo,
    label: __('Don’t display my site’s URL publicly', "full-site-editing"),
    help: (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(InfoTip, null),
    onChange: value => setHideSiteInfo(value)
  }))), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("section", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_19__/* ["default"] */ .Z, {
    disabled: isCTADisabled(),
    onClick: handleCTA,
    primary: true,
    className: "help-center-contact-form__site-picker-cta"
  }, isSubmitting ? formTitles.buttonLoadingLabel : formTitles.buttonLabel), hasSubmittingError && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_25__/* ["default"] */ .Z, {
    isError: true,
    text: __('Something went wrong, please try again later.', "full-site-editing")
  })), ['CHAT', 'EMAIL'].includes(mode) && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("section", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "help-center-contact-form__site-picker-hes-tray"
  }, randomTwoFaces.map(f => (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("img", {
    src: f,
    "aria-hidden": "true",
    alt: ""
  })), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", {
    className: "help-center-contact-form__site-picker-hes-tray-text"
  }, formTitles.trayText))), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_sibyl_articles__WEBPACK_IMPORTED_MODULE_26__/* .SibylArticles */ .e, {
    supportSite: supportSite,
    message: message
  }));
};

/***/ }),

/***/ 98490:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_": function() { return /* binding */ HelpCenterContactPage; },
/* harmony export */   "K": function() { return /* binding */ HelpCenterContactButton; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36115);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(6010);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(5869);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(77343);
/* harmony import */ var _wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(95885);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(4792);
/* harmony import */ var react_router_dom__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(47933);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(73041);
/* harmony import */ var ___WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(40495);
/* harmony import */ var _hooks_use_should_render_chat_option__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(97878);
/* harmony import */ var _hooks_use_should_render_email_option__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(82513);
/* harmony import */ var _hooks_use_still_need_help_url__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(83822);
/* harmony import */ var _icons_mail__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(67605);
/* harmony import */ var _help_center_sibyl_articles__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(61108);


/* eslint-disable no-restricted-imports */

/**
 * External Dependencies
 */









/**
 * Internal Dependencies
 */








const ConditionalLink = _ref => {
  let {
    active,
    ...props
  } = _ref;

  if (active) {
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .Link */ .rU, props);
  }

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", props);
};

const HelpCenterContactPage = () => {
  const {
    __
  } = (0,_wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_6__/* .useI18n */ .QT)();
  const renderEmail = (0,_hooks_use_should_render_email_option__WEBPACK_IMPORTED_MODULE_7__/* .useShouldRenderEmailOption */ .X)();
  const renderChat = (0,_hooks_use_should_render_chat_option__WEBPACK_IMPORTED_MODULE_8__/* .useShouldRenderChatOption */ .v)();

  if (renderChat.isLoading) {
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      className: "help-center-contact-page__loading"
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_9__/* .Spinner */ .$, {
      baseClassName: ""
    }));
  }

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "help-center-contact-page"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(___WEBPACK_IMPORTED_MODULE_10__/* .BackButton */ .x, null), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "help-center-contact-page__content"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("h3", null, __('Contact our WordPress.com experts', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: classnames__WEBPACK_IMPORTED_MODULE_2___default()('help-center-contact-page__boxes', {
      'is-reversed': !renderChat.render || renderChat.state !== 'AVAILABLE'
    })
  }, renderChat.render && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(ConditionalLink, {
    active: renderChat.state === 'AVAILABLE',
    to: "/contact-form?mode=CHAT"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: classnames__WEBPACK_IMPORTED_MODULE_2___default()('help-center-contact-page__box', 'chat', {
      'is-disabled': renderChat.state !== 'AVAILABLE'
    }),
    role: "button",
    tabIndex: 0
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "help-center-contact-page__box-icon"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z
  })), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("h2", null, __('Live chat', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", null, renderChat.state !== 'AVAILABLE' ? __('Chat is unavailable right now', "full-site-editing") : __('Get an immediate reply', "full-site-editing"))))), renderEmail && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .Link */ .rU, {
    to: "/contact-form?mode=EMAIL"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: classnames__WEBPACK_IMPORTED_MODULE_2___default()('help-center-contact-page__box', 'email'),
    role: "button",
    tabIndex: 0
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "help-center-contact-page__box-icon"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z, {
    icon: (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_icons_mail__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .Z, null)
  })), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("h2", null, __('Email', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", null, __('An expert will get back to you soon', "full-site-editing"))))))), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_sibyl_articles__WEBPACK_IMPORTED_MODULE_14__/* .SibylArticles */ .e, null));
};
const HelpCenterContactButton = () => {
  const {
    __
  } = (0,_wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_6__/* .useI18n */ .QT)();
  const url = (0,_hooks_use_still_need_help_url__WEBPACK_IMPORTED_MODULE_15__/* .useStillNeedHelpURL */ .A)();
  const sectionName = (0,react_redux__WEBPACK_IMPORTED_MODULE_4__/* .useSelector */ .v9)(calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_16__/* ["default"] */ .Z);
  const redirectToWpcom = url === 'https://wordpress.com/help/contact';

  const trackContactButtonClicked = () => {
    (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_inlinehelp_morehelp_click', {
      location: 'help-center',
      section: sectionName
    });
  };

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .Link */ .rU, {
    to: redirectToWpcom ? {
      pathname: url
    } : url,
    target: redirectToWpcom ? '_blank' : '_self',
    onClick: trackContactButtonClicked,
    className: "button help-center-contact-page__button"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", null, __('Still need help?', "full-site-editing")));
};

/***/ }),

/***/ 30250:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(7896);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(6010);
/* harmony import */ var _automattic_viewport_react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(76951);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(55609);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react_draggable__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(41327);
/* harmony import */ var react_draggable__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(react_draggable__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var react_router_dom__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(29175);
/* harmony import */ var _contexts_FeatureFlagContext__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(24478);
/* harmony import */ var _help_center_content__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(407);
/* harmony import */ var _help_center_footer__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(14059);
/* harmony import */ var _help_center_header__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(24934);



/**
 * External Dependencies
 */







/**
 * Internal Dependencies
 */






const OptionalDraggable = _ref => {
  let {
    draggable,
    ...props
  } = _ref;

  if (!draggable) {
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, props.children);
  }

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)((react_draggable__WEBPACK_IMPORTED_MODULE_4___default()), props);
};

const HelpCenterContainer = _ref2 => {
  let {
    handleClose,
    isLoading
  } = _ref2;
  const [isMinimized, setIsMinimized] = (0,react__WEBPACK_IMPORTED_MODULE_3__.useState)(false);
  const [isVisible, setIsVisible] = (0,react__WEBPACK_IMPORTED_MODULE_3__.useState)(true);
  const isMobile = (0,_automattic_viewport_react__WEBPACK_IMPORTED_MODULE_5__/* .useMobileBreakpoint */ ._z)();
  const classNames = classnames__WEBPACK_IMPORTED_MODULE_2___default()('help-center__container', isMobile ? 'is-mobile' : 'is-desktop', {
    'is-minimized': isMinimized
  });

  const onDismiss = () => {
    setIsVisible(false);
  };

  const toggleVisible = () => {
    if (!isVisible) {
      handleClose();
    }
  };

  const animationProps = {
    style: {
      animation: `${isVisible ? 'fadeIn' : 'fadeOut'} .5s`
    },
    onAnimationEnd: toggleVisible
  }; // This is a workaround for an issue with Draggable in StrictMode
  // https://github.com/react-grid-layout/react-draggable/blob/781ef77c86be9486400da9837f43b96186166e38/README.md

  const nodeRef = (0,react__WEBPACK_IMPORTED_MODULE_3__.useRef)(null);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_6__/* .MemoryRouter */ .VA, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_contexts_FeatureFlagContext__WEBPACK_IMPORTED_MODULE_7__/* .FeatureFlagProvider */ .O, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(OptionalDraggable, {
    draggable: !isMobile,
    nodeRef: nodeRef,
    handle: ".help-center__container-header",
    bounds: "body"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.Card, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)({
    className: classNames
  }, animationProps, {
    ref: nodeRef
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_header__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z, {
    isMinimized: isMinimized,
    onMinimize: () => setIsMinimized(true),
    onMaximize: () => setIsMinimized(false),
    onDismiss: onDismiss
  }), isLoading ? (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "help-center-container__loading"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_10__/* .Spinner */ .$, {
    baseClassName: "",
    className: "help-center-container__spinner"
  })) : (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_content__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z, null), !isMinimized && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_footer__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, null))))));
};

/* harmony default export */ __webpack_exports__["Z"] = (HelpCenterContainer);

/***/ }),

/***/ 407:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36115);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(55609);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(4792);
/* harmony import */ var react_router_dom__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(29175);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(73041);
/* harmony import */ var _help_center_contact_form__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(23025);
/* harmony import */ var _help_center_contact_page__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(98490);
/* harmony import */ var _help_center_embed_result__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(26212);
/* harmony import */ var _help_center_inline_chat__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(27420);
/* harmony import */ var _help_center_search__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(817);
/* harmony import */ var _ticket_success_screen__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(94509);


/* eslint-disable no-restricted-imports */

/**
 * External Dependencies
 */







/**
 * Internal Dependencies
 */








const HelpCenterContent = () => {
  const location = (0,react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .useLocation */ .TH)();
  const className = classnames__WEBPACK_IMPORTED_MODULE_3___default()('help-center__container-content');
  const section = (0,react_redux__WEBPACK_IMPORTED_MODULE_4__/* .useSelector */ .v9)(calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z);
  (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_helpcenter_page_open', {
      pathname: location.pathname,
      search: location.search,
      section,
      location: 'help-center'
    });
  }, [location, section]);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__.CardBody, {
    className: className
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .Route */ .AW, {
    exact: true,
    path: "/"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_search__WEBPACK_IMPORTED_MODULE_7__/* .HelpCenterSearch */ .Z, null)), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .Route */ .AW, {
    path: "/post"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_embed_result__WEBPACK_IMPORTED_MODULE_8__/* .HelpCenterEmbedResult */ .X, null)), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .Route */ .AW, {
    path: "/contact-options"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_contact_page__WEBPACK_IMPORTED_MODULE_9__/* .HelpCenterContactPage */ ._, null)), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .Route */ .AW, {
    path: "/contact-form"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_contact_form__WEBPACK_IMPORTED_MODULE_10__/* .HelpCenterContactForm */ ._, null)), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .Route */ .AW, {
    path: "/success"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_ticket_success_screen__WEBPACK_IMPORTED_MODULE_11__/* .SuccessScreen */ .k, null)), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .Route */ .AW, {
    path: "/inline-chat"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_inline_chat__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, null)));
};

/* harmony default export */ __webpack_exports__["Z"] = (HelpCenterContent);

/***/ }),

/***/ 26212:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "X": function() { return /* binding */ HelpCenterEmbedResult; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36115);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(43239);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(55609);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(5869);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(22042);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(4792);
/* harmony import */ var react_router_dom__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(29175);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(73041);
/* harmony import */ var _back_button__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(40495);
/* harmony import */ var _back_to_top_button__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(7577);
/* harmony import */ var _help_center_article_content__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(19762);
/* harmony import */ var _help_center_article_fetching_content__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(19892);


/* eslint-disable no-restricted-imports */













const HelpCenterEmbedResult = () => {
  const {
    state,
    search
  } = (0,react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .useLocation */ .TH)();
  const history = (0,react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .useHistory */ .k6)();
  const sectionName = (0,react_redux__WEBPACK_IMPORTED_MODULE_4__/* .useSelector */ .v9)(calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z);
  const params = new URLSearchParams(search);
  const postId = (state === null || state === void 0 ? void 0 : state.post_id) ?? params.get('postId');
  const blogId = (state === null || state === void 0 ? void 0 : state.blog_id) ?? params.get('blogId');
  const link = (state === null || state === void 0 ? void 0 : state.link) ?? params.get('link');
  const query = (state === null || state === void 0 ? void 0 : state.query) ?? params.get('query');
  (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    const tracksData = {
      search_query: query,
      location: 'help-center',
      section: sectionName,
      result_url: link
    };
    (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)(`calypso_inlinehelp_article_open`, tracksData);
  }, [query, link, sectionName]);

  const redirectToSearchOrHome = () => {
    if (state !== null && state !== void 0 && state.query) {
      history.push(`/?query=${state.query}`);
    } else {
      history.push('/');
    }
  };

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "help-center-embed-result"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__.Flex, {
    justify: "space-between"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__.FlexItem, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_back_button__WEBPACK_IMPORTED_MODULE_7__/* .BackButton */ .x, {
    onClick: redirectToSearchOrHome
  })), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__.FlexItem, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z, {
    borderless: true,
    href: link ?? '',
    target: "_blank",
    className: "help-center-embed-result__external-button"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_10__/* ["default"] */ .Z,
    size: 20
  })))), state !== null && state !== void 0 && state.content ? (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_article_content__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z, {
    content: state.content,
    title: state.title,
    link: state.link
  }) : postId && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_article_fetching_content__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    postId: +postId,
    blogId: blogId
  })), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_back_to_top_button__WEBPACK_IMPORTED_MODULE_13__/* .BackToTopButton */ .z, null));
};

/***/ }),

/***/ 14059:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(55609);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react_router_dom__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(29175);
/* harmony import */ var _help_center_contact_page__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(98490);






const HelpCenterFooter = () => {
  const className = classnames__WEBPACK_IMPORTED_MODULE_2___default()('help-center__container-footer');
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.CardFooter, {
    className: className
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_3__/* .Route */ .AW, {
    path: "/",
    exact: true
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_contact_page__WEBPACK_IMPORTED_MODULE_4__/* .HelpCenterContactButton */ .K, null)));
};

/* harmony default export */ __webpack_exports__["Z"] = (HelpCenterFooter);

/***/ }),

/***/ 24934:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* unused harmony export ArticleTitle */
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(55609);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(5869);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(39739);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(48632);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(26715);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(63103);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(60199);
/* harmony import */ var _wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(95885);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var react_router_dom__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(29175);
/* harmony import */ var _happychat_window_communicator__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(71645);








function ArticleTitle() {
  const location = (0,react_router_dom__WEBPACK_IMPORTED_MODULE_4__/* .useLocation */ .TH)();
  const {
    title
  } = location.state;
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", {
    className: "help-center-header__article-title"
  }, title));
}

const SupportModeTitle = () => {
  const {
    __
  } = (0,_wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_7__/* .useI18n */ .QT)();
  const {
    search
  } = (0,react_router_dom__WEBPACK_IMPORTED_MODULE_4__/* .useLocation */ .TH)();
  const params = new URLSearchParams(search);
  const mode = params.get('mode');

  switch (mode) {
    case 'CHAT':
      return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z, {
        icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z
      }), __('Start live chat', "full-site-editing"));

    case 'EMAIL':
      {
        return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, __('Send us an email', "full-site-editing"));
      }

    case 'FORUM':
      {
        return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, __('Ask in our community forums', "full-site-editing"));
      }

    default:
      {
        return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, __('Help Center', "full-site-editing"));
      }
  }
};

const HelpCenterHeader = _ref => {
  let {
    isMinimized,
    onMinimize,
    onMaximize,
    onDismiss
  } = _ref;
  const classNames = classnames__WEBPACK_IMPORTED_MODULE_2___default()('help-center__container-header');
  const {
    __
  } = (0,_wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_7__/* .useI18n */ .QT)();
  const [chatWindowStatus, setChatWindowStatus] = (0,react__WEBPACK_IMPORTED_MODULE_3__.useState)('closed');
  const [unreadCount, setUnreadCount] = (0,react__WEBPACK_IMPORTED_MODULE_3__.useState)(0);
  const formattedUnreadCount = unreadCount > 9 ? '9+' : unreadCount;

  function requestMaximize() {
    onMaximize === null || onMaximize === void 0 ? void 0 : onMaximize();
  } // kill the help center when the user closes the popup chat window


  (0,react__WEBPACK_IMPORTED_MODULE_3__.useEffect)(() => {
    if (chatWindowStatus === 'ended') {
      onDismiss === null || onDismiss === void 0 ? void 0 : onDismiss();
    }
  }, [chatWindowStatus, onDismiss]);
  (0,_happychat_window_communicator__WEBPACK_IMPORTED_MODULE_9__/* .useHCWindowCommunicator */ .g)(setChatWindowStatus, setUnreadCount);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.CardHeader, {
    className: classNames
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.Flex, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", {
    id: "header-text",
    className: "help-center-header__text"
  }, isMinimized ? (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_4__/* .Switch */ .rs, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_4__/* .Route */ .AW, {
    path: "/",
    exact: true
  }, __('Help Center', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_4__/* .Route */ .AW, {
    path: "/contact-options"
  }, __('Contact Options', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_4__/* .Route */ .AW, {
    path: "/contact-form",
    component: SupportModeTitle
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_4__/* .Route */ .AW, {
    path: "/post",
    component: ArticleTitle
  })) : __('Help Center', "full-site-editing"), isMinimized && unreadCount ? (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", {
    className: "help-center-header__unread-count"
  }, formattedUnreadCount) : null), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", null, isMinimized ? (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.Button, {
    className: 'help-center-header__maximize',
    label: __('Maximize Help Center', "full-site-editing"),
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_10__/* ["default"] */ .Z,
    tooltipPosition: "top left",
    onClick: requestMaximize
  }) : (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.Button, {
    className: 'help-center-header__minimize',
    label: __('Minimize Help Center', "full-site-editing"),
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z,
    tooltipPosition: "top left",
    onClick: onMinimize
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.Button, {
    className: 'help-center-header__close',
    label: __('Close Help Center', "full-site-editing"),
    tooltipPosition: "top left",
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z,
    onClick: onDismiss
  }))));
};

/* harmony default export */ __webpack_exports__["Z"] = (HelpCenterHeader);

/***/ }),

/***/ 27420:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _help_center_inline_chat_scss__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(96459);


/**
 * External Dependencies
 */

const env =  true ? 'prod' : 0;

const InlineChat = () => {
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("iframe", {
    className: "help-center-inline-chat__iframe",
    title: "Happychat",
    src: `https://widgets.wp.com/calypso-happychat/?env=${env}`
  });
};

/* harmony default export */ __webpack_exports__["Z"] = (InlineChat);

/***/ }),

/***/ 62795:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "r": function() { return /* binding */ HelpCenterMoreResources; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36115);
/* harmony import */ var _automattic_calypso_products__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(4112);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(53762);
/* harmony import */ var _automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(47498);
/* harmony import */ var _automattic_whats_new__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(94819);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(55609);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(5869);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(81835);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(22042);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(26176);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(10812);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(86642);
/* harmony import */ var _wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(95885);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(4792);
/* harmony import */ var calypso_state_purchases_selectors__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(76678);
/* harmony import */ var calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(83377);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(73041);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(20834);
/* harmony import */ var _icons_new_releases__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(51519);


/* eslint-disable no-restricted-imports */

/* eslint-disable wpcalypso/jsx-classname-namespace */














const circle = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__.SVG, {
  viewBox: "0 0 24 24"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__.Circle, {
  cx: "12",
  cy: "12",
  r: "5"
}));
const HelpCenterMoreResources = () => {
  const {
    __
  } = (0,_wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_4__/* .useI18n */ .QT)();
  const [showWhatsNewDot, setShowWhatsNewDot] = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useState)(false);
  const sectionName = (0,react_redux__WEBPACK_IMPORTED_MODULE_3__/* .useSelector */ .v9)(calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z);
  const {
    isBusinessOrEcomPlanUser,
    siteId,
    isSimpleSite
  } = (0,react_redux__WEBPACK_IMPORTED_MODULE_3__/* .useSelector */ .v9)(state => {
    const purchases = (0,calypso_state_purchases_selectors__WEBPACK_IMPORTED_MODULE_6__/* .getUserPurchases */ .I)(state);
    const purchaseSlugs = purchases && purchases.map(purchase => purchase.productSlug);
    const siteId = (0,calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(state);
    return {
      isBusinessOrEcomPlanUser: !!(purchaseSlugs && (purchaseSlugs.some(_automattic_calypso_products__WEBPACK_IMPORTED_MODULE_8__/* .isWpComBusinessPlan */ .pl) || purchaseSlugs.some(_automattic_calypso_products__WEBPACK_IMPORTED_MODULE_8__/* .isWpComEcommercePlan */ .$J))),
      siteId: siteId,
      isSimpleSite: (0,calypso_state_sites_selectors__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z)(state) || false
    };
  });
  const {
    data,
    isLoading,
    setHasSeenWhatsNewModal
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_10__/* .useHasSeenWhatsNewModalQuery */ .R)(siteId, isSimpleSite);
  (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    if (!isLoading && data) {
      setShowWhatsNewDot(!data.has_seen_whats_new_modal);
    }
  }, [data, isLoading]);
  const [showGuide, setShowGuide] = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useState)(false);

  const trackMoreResourcesButtonClick = resource => {
    (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_help_moreresources_click', {
      is_business_or_ecommerce_plan_user: isBusinessOrEcomPlanUser,
      resource: resource,
      location: 'help-center',
      section: sectionName
    });
  };

  const trackWebinairsButtonClick = () => {
    (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_help_courses_click', {
      is_business_or_ecommerce_plan_user: isBusinessOrEcomPlanUser,
      location: 'help-center',
      section: sectionName
    });
    trackMoreResourcesButtonClick('webinairs');
  };

  const handleWhatsNewClick = () => {
    if (!(data !== null && data !== void 0 && data.has_seen_whats_new_modal)) {
      setHasSeenWhatsNewModal(true);
    }

    setShowGuide(true);
    trackMoreResourcesButtonClick('whats-new');
  };

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("h3", {
    className: "help-center__section-title"
  }, __('More Resources', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("ul", {
    className: "inline-help__more-resources",
    "aria-labelledby": "inline-help__more-resources"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("li", {
    className: "inline-help__resource-item"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "inline-help__resource-cell"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("a", {
    href: (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_11__/* .localizeUrl */ .aq)('https://wordpress.com/support/video-tutorials/'),
    rel: "noreferrer",
    target: "_blank",
    className: "inline-help__video",
    onClick: () => trackMoreResourcesButtonClick('video')
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .Z,
    size: 24
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", null, __('Video tutorials', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .Z,
    size: 20
  })))), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("li", {
    className: "inline-help__resource-item"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "inline-help__resource-cell"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("a", {
    href: (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_11__/* .localizeUrl */ .aq)('https://wordpress.com/webinars'),
    rel: "noreferrer",
    target: "_blank",
    onClick: trackWebinairsButtonClick,
    className: "inline-help__capture-video"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_15__/* ["default"] */ .Z,
    size: 24
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", null, __('Webinars', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .Z,
    size: 20
  })))), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("li", {
    className: "inline-help__resource-item"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "inline-help__resource-cell"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("a", {
    href: (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_11__/* .localizeUrl */ .aq)('https://wpcourses.com/?ref=wpcom-help-more-resources'),
    rel: "noreferrer",
    target: "_blank",
    className: "inline-help__desktop",
    onClick: () => trackMoreResourcesButtonClick('courses')
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_16__/* ["default"] */ .Z,
    size: 24
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", null, __('Courses', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .Z,
    size: 20
  })))), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("li", {
    className: "inline-help__resource-item"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "inline-help__resource-cell"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("a", {
    href: (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_11__/* .localizeUrl */ .aq)('https://learn.wordpress.com'),
    rel: "noreferrer",
    target: "_blank",
    className: "inline-help__format-list-numbered",
    onClick: () => trackMoreResourcesButtonClick('guides')
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_17__/* ["default"] */ .Z,
    size: 24
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", null, __('Step-by-step guides', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .Z,
    size: 20
  })))), isSimpleSite && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("li", {
    className: "inline-help__resource-item"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "inline-help__resource-cell"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__.Button, {
    isLink: true,
    onClick: () => handleWhatsNewClick(),
    className: "inline-help__new-releases"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    icon: (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_icons_new_releases__WEBPACK_IMPORTED_MODULE_18__/* ["default"] */ .Z, null),
    size: 24
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", null, __("What's new", "full-site-editing")), showWhatsNewDot && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    className: "inline-help__new-releases_dot",
    icon: circle,
    size: 16
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .Z,
    size: 20
  }))))), showGuide && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_whats_new__WEBPACK_IMPORTED_MODULE_19__/* ["default"] */ .Z, {
    onClose: () => setShowGuide(false)
  }));
};

/***/ }),

/***/ 10083:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "J": function() { return /* binding */ HelpCenterOwnershipNotice; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(47498);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(55609);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(65736);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__);





const __ = _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__.__;
const responses = {
  NOT_OWNED_BY_USER: (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", null, __('Your site is linked to another WordPress.com account. If you’re trying to access it, please follow our Account Recovery procedure.', "full-site-editing"), "\xA0", ' ', (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.ExternalLink, {
    href: (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_3__/* .localizeUrl */ .aq)('https://wordpress.com/wp-login.php?action=recovery')
  }, __('Learn More', "full-site-editing"))),
  WPCOM: '',
  WPORG: (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createInterpolateElement)(__('Your site is not <hosted_on_our_services>hosted with our services</hosted_on_our_services>. Support for the self-hosted version of WordPress is provided by the <wordpress_org_community_forums>WordPress.org community forums</wordpress_org_community_forums>, or if the problem relates to a specific plugin or theme, contact support for that product instead. If you’re not sure, share your question with a link, and we’ll point you in the right direction!', "full-site-editing"), {
    hosted_on_our_services: (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.ExternalLink, {
      href: (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_3__/* .localizeUrl */ .aq)('https://wordpress.com/support/com-vs-org/')
    }),
    wordpress_org_community_forums: (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.ExternalLink, {
      href: (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_3__/* .localizeUrl */ .aq)('https://wordpress.org/support/forums/')
    })
  })),
  UNKNOWN: (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", null, __("We couldn't fetch enough information about this site to determine our ability to support you with it.", "full-site-editing"))
};
function HelpCenterOwnershipNotice(_ref) {
  let {
    ownershipResult,
    isAnalysisLoading,
    userDeclaredSite
  } = _ref;

  if (isAnalysisLoading || ownershipResult === 'WPCOM') {
    if (ownershipResult === 'WPCOM') {
      return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", {
        className: "help-center-notice__positive-feedback"
      }, userDeclaredSite === null || userDeclaredSite === void 0 ? void 0 : userDeclaredSite.name);
    }

    return null;
  }

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "help-center-notice__container"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.Icon, {
    icon: "info-outline"
  })), responses[ownershipResult]);
}

/***/ }),

/***/ 90887:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_22__ = __webpack_require__(7896);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_20__ = __webpack_require__(56399);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(34923);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(94514);
/* harmony import */ var _automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(30849);
/* harmony import */ var _automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_23__ = __webpack_require__(47498);
/* harmony import */ var _wordpress_a11y__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(25158);
/* harmony import */ var _wordpress_a11y__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_a11y__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(65736);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_18__ = __webpack_require__(5869);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_19__ = __webpack_require__(58706);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_21__ = __webpack_require__(39739);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var page__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(78319);
/* harmony import */ var page__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(page__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_27__ = __webpack_require__(13980);
/* harmony import */ var prop_types__WEBPACK_IMPORTED_MODULE_27___default = /*#__PURE__*/__webpack_require__.n(prop_types__WEBPACK_IMPORTED_MODULE_27__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_5__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(4792);
/* harmony import */ var calypso_components_data_query_user_purchases__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(66525);
/* harmony import */ var calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_24__ = __webpack_require__(93345);
/* harmony import */ var calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_25__ = __webpack_require__(50118);
/* harmony import */ var calypso_state_analytics_actions__WEBPACK_IMPORTED_MODULE_17__ = __webpack_require__(19298);
/* harmony import */ var calypso_state_inline_help_selectors_get_admin_help_results__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(89621);
/* harmony import */ var calypso_state_selectors_has_cancelable_user_purchases__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(16193);
/* harmony import */ var calypso_state_sites_hooks__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(56733);
/* harmony import */ var calypso_state_sites_selectors_is_simple_site__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(83377);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(73041);
/* harmony import */ var _hooks_use_help_search_query__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(77331);
/* harmony import */ var _placeholder_lines__WEBPACK_IMPORTED_MODULE_26__ = __webpack_require__(15166);



/* eslint-disable no-restricted-imports */





const __ = _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__.__;

















const noop = () => {
  return;
};

function debounceSpeak(_ref) {
  let {
    message = '',
    priority = 'polite',
    timeout = 800
  } = _ref;
  return (0,lodash__WEBPACK_IMPORTED_MODULE_3__.debounce)(() => {
    (0,_wordpress_a11y__WEBPACK_IMPORTED_MODULE_1__.speak)(message, priority);
  }, timeout);
}

const loadingSpeak = debounceSpeak({
  message: 'Loading search results.',
  timeout: 1500
});
const resultsSpeak = debounceSpeak({
  message: 'Search results loaded.'
});
const errorSpeak = debounceSpeak({
  message: 'No search results found.'
});

const filterManagePurchaseLink = (hasPurchases, isPurchasesSection) => {
  if (hasPurchases || isPurchasesSection) {
    return () => true;
  }

  return article => article.post_id !== 111349;
};

function HelpSearchResults(_ref2) {
  let {
    externalLinks = false,
    onSelect,
    onAdminSectionSelect = noop,
    searchQuery = '',
    placeholderLines,
    openAdminInNewTab = false,
    location = 'inline-help-popover'
  } = _ref2;
  const dispatch = (0,react_redux__WEBPACK_IMPORTED_MODULE_6__/* .useDispatch */ .I0)();
  const {
    hasPurchases,
    sectionName,
    adminResults,
    isSimpleSite
  } = (0,react_redux__WEBPACK_IMPORTED_MODULE_6__/* .useSelector */ .v9)(state => {
    return {
      hasPurchases: (0,calypso_state_selectors_has_cancelable_user_purchases__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)(state),
      sectionName: (0,calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_10__/* ["default"] */ .Z)(state),
      adminResults: (0,calypso_state_inline_help_selectors_get_admin_help_results__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z)(state, searchQuery, 3),
      isSimpleSite: (0,calypso_state_sites_selectors_is_simple_site__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z)(state)
    };
  });
  const isPurchasesSection = ['purchases', 'site-purchases'].includes(sectionName);
  const siteIntent = (0,calypso_state_sites_hooks__WEBPACK_IMPORTED_MODULE_9__/* .useSiteOption */ .P)('site_intent');
  const rawContextualResults = (0,react__WEBPACK_IMPORTED_MODULE_5__.useMemo)(() => (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_13__/* .getContextResults */ .r_)(sectionName, siteIntent), [sectionName, siteIntent]);
  const locale = (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_14__/* .useLocale */ .bU)();
  const contextualResults = rawContextualResults.filter( // Unless searching with Inline Help or on the Purchases section, hide the
  // "Managing Purchases" documentation link for users who have not made a purchase.
  filterManagePurchaseLink(hasPurchases, isPurchasesSection));
  const {
    data: searchData,
    isLoading: isSearching
  } = (0,_hooks_use_help_search_query__WEBPACK_IMPORTED_MODULE_15__/* .useHelpSearchQuery */ .e)(searchQuery, locale, isSimpleSite);
  const searchResults = searchData ?? [];
  const hasAPIResults = searchResults.length > 0;
  (0,react__WEBPACK_IMPORTED_MODULE_5__.useEffect)(() => {
    // Cancel all queued speak messages.
    loadingSpeak.cancel();
    resultsSpeak.cancel();
    errorSpeak.cancel(); // If there's no query, then we don't need to announce anything.

    if (!searchQuery) {
      return;
    }

    if (isSearching) {
      loadingSpeak();
    } else if (!hasAPIResults) {
      errorSpeak();
    } else if (hasAPIResults) {
      resultsSpeak();
    }
  }, [isSearching, hasAPIResults, searchQuery]);

  const onLinkClickHandler = (event, result, type) => {
    const {
      link
    } = result; // check and catch admin section links.

    if (type === _automattic_data_stores__WEBPACK_IMPORTED_MODULE_16__/* .SUPPORT_TYPE_ADMIN_SECTION */ .QZ && link) {
      // record track-event.
      dispatch((0,calypso_state_analytics_actions__WEBPACK_IMPORTED_MODULE_17__/* .recordTracksEvent */ .jN)('calypso_inlinehelp_admin_section_visit', {
        link: link,
        search_term: searchQuery,
        location,
        section: sectionName
      })); // push state only if it's internal link.

      if (!/^http/.test(link)) {
        event.preventDefault();
        openAdminInNewTab ? window.open('https://wordpress.com' + link, '_blank') : page__WEBPACK_IMPORTED_MODULE_4___default()(link);
        onAdminSectionSelect(event);
      }

      return;
    }

    onSelect(event, result);
  };

  const renderHelpLink = (result, type) => {
    const {
      link,
      title,
      icon
    } = result;
    const external = externalLinks && type !== _automattic_data_stores__WEBPACK_IMPORTED_MODULE_16__/* .SUPPORT_TYPE_ADMIN_SECTION */ .QZ;

    const LinkIcon = () => {
      if (type === 'admin_section') {
        return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_18__/* ["default"] */ .Z, {
          icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_19__/* ["default"] */ .Z
        });
      }

      if (icon) {
        return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_20__/* ["default"] */ .Z, {
          icon: icon
        });
      }

      return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_18__/* ["default"] */ .Z, {
        icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_21__/* ["default"] */ .Z
      });
    };

    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react__WEBPACK_IMPORTED_MODULE_5__.Fragment, {
      key: link ?? title
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("li", {
      className: "help-center-search-results__item"
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      className: "help-center-search-results__cell"
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("a", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_22__/* ["default"] */ .Z)({
      href: (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_23__/* .localizeUrl */ .aq)(link),
      onClick: event => {
        if (!external) {
          event.preventDefault();
        }

        onLinkClickHandler(event, result, type);
      }
    }, external && {
      target: '_blank',
      rel: 'noreferrer'
    }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(LinkIcon, null), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("span", null, (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_24__/* .preventWidows */ .R)((0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_25__/* .decodeEntities */ .S)(title)))))));
  };

  const renderSearchResultsSection = _ref3 => {
    let {
      type,
      title,
      results,
      condition
    } = _ref3;
    const id = `inline-search--${type}`;
    return condition ? (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react__WEBPACK_IMPORTED_MODULE_5__.Fragment, {
      key: id
    }, title ? (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("h3", {
      id: id,
      className: "help-center-search-results__title"
    }, title) : null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("ul", {
      className: "help-center-search-results__list",
      "aria-labelledby": title ? id : undefined
    }, results.map(result => renderHelpLink(result, type)))) : null;
  };

  const renderSearchSections = () => {
    const sections = [{
      type: _automattic_data_stores__WEBPACK_IMPORTED_MODULE_16__/* .SUPPORT_TYPE_API_HELP */ .EE,
      title: __('Recommended resources', "full-site-editing"),
      results: searchResults.slice(0, 5),
      condition: !isSearching && searchResults.length > 0
    }, {
      type: _automattic_data_stores__WEBPACK_IMPORTED_MODULE_16__/* .SUPPORT_TYPE_CONTEXTUAL_HELP */ .D_,
      title: !searchQuery.length ? __('Recommended resources', "full-site-editing") : '',
      results: contextualResults.slice(0, 6),
      condition: !isSearching && !searchResults.length && contextualResults.length > 0
    }, {
      type: _automattic_data_stores__WEBPACK_IMPORTED_MODULE_16__/* .SUPPORT_TYPE_ADMIN_SECTION */ .QZ,
      title: __('Show me where to', "full-site-editing"),
      results: adminResults,
      condition: !!searchQuery && adminResults.length > 0
    }];
    return sections.map(renderSearchResultsSection);
  };

  const resultsLabel = hasAPIResults ? __('Search Results', "full-site-editing") : __('Helpful resources for this section', "full-site-editing");

  const renderSearchResults = () => {
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react__WEBPACK_IMPORTED_MODULE_5__.Fragment, null, isSearching && !searchResults.length && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_placeholder_lines__WEBPACK_IMPORTED_MODULE_26__/* ["default"] */ .Z, {
      lines: placeholderLines
    }), searchQuery && !(hasAPIResults || isSearching) ? (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", {
      className: "help-center-search-results__empty-results"
    }, __('Sorry, there were no matches. Here are some of the most searched for help pages for this section:', "full-site-editing")) : null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
      className: "help-center-search-results__results",
      "aria-label": resultsLabel
    }, renderSearchSections()));
  };

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react__WEBPACK_IMPORTED_MODULE_5__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(calypso_components_data_query_user_purchases__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z, null), renderSearchResults());
}

HelpSearchResults.propTypes = {
  searchQuery: (prop_types__WEBPACK_IMPORTED_MODULE_27___default().string),
  onSelect: (prop_types__WEBPACK_IMPORTED_MODULE_27___default().func.isRequired),
  onAdminSectionSelect: (prop_types__WEBPACK_IMPORTED_MODULE_27___default().func)
};
/* harmony default export */ __webpack_exports__["Z"] = (HelpSearchResults);

/***/ }),

/***/ 817:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ HelpCenterSearch; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(65736);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react_router_dom__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(29175);
/* harmony import */ var calypso_blocks_inline_help_inline_help_search_card__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(71688);
/* harmony import */ var calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(93345);
/* harmony import */ var calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(50118);
/* harmony import */ var _help_center_more_resources__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(62795);
/* harmony import */ var _help_center_search_results__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(90887);
/* harmony import */ var _help_center_search_scss__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(6128);
/* harmony import */ var _help_center_sibyl_articles__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(61108);


/* eslint-disable wpcalypso/jsx-classname-namespace */

/* eslint-disable no-restricted-imports */


const __ = _wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__.__;







const HelpCenterSearch = () => {
  const history = (0,react_router_dom__WEBPACK_IMPORTED_MODULE_4__/* .useHistory */ .k6)();
  const {
    search
  } = (0,react_router_dom__WEBPACK_IMPORTED_MODULE_4__/* .useLocation */ .TH)();
  const params = new URLSearchParams(search);
  const query = params.get('query');
  const [searchQuery, setSearchQuery] = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useState)(query || '');
  const redirectToArticle = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useCallback)((event, result) => {
    event.preventDefault();
    const searchResult = { ...result,
      title: (0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_5__/* .preventWidows */ .R)((0,calypso_lib_formatting__WEBPACK_IMPORTED_MODULE_6__/* .decodeEntities */ .S)(result.title)),
      query: searchQuery
    };
    history.push(`/post/?${result.slug}`, searchResult);
  }, [history, searchQuery]);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "inline-help__search"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(calypso_blocks_inline_help_inline_help_search_card__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z, {
    searchQuery: searchQuery,
    onSearch: setSearchQuery,
    location: "help-center",
    isVisible: true,
    placeholder: __('Search for help', "full-site-editing")
  }), searchQuery && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_search_results__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z, {
    onSelect: redirectToArticle,
    searchQuery: searchQuery,
    openAdminInNewTab: true,
    placeholderLines: 4,
    location: "help-center"
  }), !searchQuery && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_sibyl_articles__WEBPACK_IMPORTED_MODULE_8__/* .SibylArticles */ .e, {
    message: "",
    supportSite: undefined
  }), !searchQuery && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_more_resources__WEBPACK_IMPORTED_MODULE_9__/* .HelpCenterMoreResources */ .r, null));
};

/***/ }),

/***/ 61108:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "e": function() { return /* binding */ SibylArticles; }
/* harmony export */ });
/* unused harmony export SITE_STORE */
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(7896);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(14803);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(45655);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(34923);
/* harmony import */ var _automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(30849);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(5869);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(39739);
/* harmony import */ var _wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(95885);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(4792);
/* harmony import */ var react_router_dom__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(47933);
/* harmony import */ var use_debounce__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(17127);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(73041);



/* eslint-disable no-restricted-imports */

/* eslint-disable wpcalypso/jsx-classname-namespace */










const SITE_STORE = 'automattic/site';

const ConfigurableLink = _ref => {
  let {
    external,
    fullUrl,
    ...props
  } = _ref;

  if (external) {
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("a", (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)({
      href: fullUrl,
      target: "_blank",
      rel: "noreferrer noopener"
    }, props));
  }

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .Link */ .rU, props);
};

function getPostUrl(article, query) {
  // if it's a wpcom support article, it has an ID
  if (article.post_id) {
    const params = new URLSearchParams({
      postId: article.post_id,
      query,
      link: article.link ?? '',
      title: article.title
    });

    if (article.blog_id) {
      params.set('blogId', article.blog_id);
    }

    const search = params.toString();
    return {
      pathname: '/post',
      search
    };
  }

  return article.link;
}

function SibylArticles(_ref2) {
  let {
    message = '',
    supportSite
  } = _ref2;
  const {
    __
  } = (0,_wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_6__/* .useI18n */ .QT)();
  const locale = (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_7__/* .useLocale */ .bU)();
  const isAtomic = Boolean((0,_wordpress_data__WEBPACK_IMPORTED_MODULE_1__.useSelect)(select => supportSite && select(SITE_STORE).isSiteAtomic(supportSite === null || supportSite === void 0 ? void 0 : supportSite.ID)));
  const isJetpack = Boolean((0,_wordpress_data__WEBPACK_IMPORTED_MODULE_1__.useSelect)(select => select(SITE_STORE).isJetpackSite(supportSite === null || supportSite === void 0 ? void 0 : supportSite.ID)));
  const [debouncedMessage] = (0,use_debounce__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z)(message || '', 500);
  const {
    data: sibylArticles
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_9__/* .useSibylQuery */ .v)(debouncedMessage, isJetpack, isAtomic);
  const {
    data: intent
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_10__/* .useSiteIntent */ .B)(supportSite === null || supportSite === void 0 ? void 0 : supportSite.ID);
  const sectionName = (0,react_redux__WEBPACK_IMPORTED_MODULE_3__/* .useSelector */ .v9)(calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z);
  const articles = (0,react__WEBPACK_IMPORTED_MODULE_2__.useMemo)(() => {
    return sibylArticles !== null && sibylArticles !== void 0 && sibylArticles.length ? sibylArticles : (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_12__/* .getContextResults */ .r_)(sectionName, (intent === null || intent === void 0 ? void 0 : intent.site_intent) ?? '');
  }, [sibylArticles, sectionName, intent === null || intent === void 0 ? void 0 : intent.site_intent]);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "help-center-sibyl-articles__container"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("h3", {
    id: "help-center--contextual_help",
    className: "help-center__section-title"
  }, __('Recommended resources', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("ul", {
    className: "help-center-sibyl-articles__list",
    "aria-labelledby": "help-center--contextual_help"
  }, articles.map(article => {
    if ('type' in article && ['video', 'tour'].includes(article.type)) {
      return;
    }

    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("li", {
      key: article.link
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(ConfigurableLink, {
      to: getPostUrl(article, message),
      external: 'en' !== locale,
      fullUrl: article.link
    }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .Z, {
      icon: _wordpress_icons__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .Z
    }), article.title));
  })));
}

/***/ }),

/***/ 55213:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36115);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(99706);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(4792);
/* harmony import */ var calypso_state_sites_selectors_is_simple_site__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(83377);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(20834);
/* harmony import */ var _directly__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(39226);
/* harmony import */ var _hooks_use_still_need_help_url__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(83822);
/* harmony import */ var _stores__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(98865);
/* harmony import */ var _help_center_contact_form__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(23025);
/* harmony import */ var _help_center_container__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(30250);
/* harmony import */ var _styles_scss__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(62829);


/* eslint-disable no-restricted-imports */

/* eslint-disable no-console */

/**
 * External Dependencies
 */







/**
 * Internal Dependencies
 */








const HelpCenter = _ref => {
  let {
    handleClose
  } = _ref;
  const portalParent = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useRef)(document.createElement('div')).current;
  const {
    siteId,
    isSimpleSite
  } = (0,react_redux__WEBPACK_IMPORTED_MODULE_3__/* .useSelector */ .v9)(state => {
    return {
      siteId: (0,calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(state),
      isSimpleSite: (0,calypso_state_sites_selectors_is_simple_site__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)(state)
    };
  }); // prefetch the current site and user

  const site = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_2__.useSelect)(select => select(_help_center_contact_form__WEBPACK_IMPORTED_MODULE_8__/* .SITE_STORE */ .j).getSite(siteId));
  const user = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_2__.useSelect)(select => select(_stores__WEBPACK_IMPORTED_MODULE_9__/* .USER_STORE */ .Em).getCurrentUser());
  const {
    setDirectlyData
  } = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_2__.useDispatch)(_stores__WEBPACK_IMPORTED_MODULE_9__/* .HELP_CENTER_STORE */ .aM);
  const {
    isLoading: isLoadingChat
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_10__/* .useSupportAvailability */ .p)('CHAT', isSimpleSite);
  const {
    data: supportData,
    isLoading: isSupportDataLoading
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_10__/* .useSupportAvailability */ .p)('OTHER', isSimpleSite);
  (0,_hooks_use_still_need_help_url__WEBPACK_IMPORTED_MODULE_11__/* .useStillNeedHelpURL */ .A)();
  (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    if (supportData !== null && supportData !== void 0 && supportData.is_user_eligible_for_directly) {
      (0,_directly__WEBPACK_IMPORTED_MODULE_4__/* .execute */ .ht)(['onReady', _ref2 => {
        let {
          session
        } = _ref2;
        setDirectlyData({
          isLoaded: true,
          hasSession: session
        });
      }]);
    }
  }, [supportData, setDirectlyData]);
  const isLoading = isSimpleSite ? [!site, !user, isSupportDataLoading, isLoadingChat].some(Boolean) : false;
  (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    const classes = ['help-center'];
    portalParent.classList.add(...classes);
    portalParent.setAttribute('aria-modal', 'true');
    portalParent.setAttribute('aria-labelledby', 'header-text');
    document.body.appendChild(portalParent);
    const start = Date.now();
    return () => {
      (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_helpcenter_activity_time', {
        elapsed: (Date.now() - start) / 1000
      });
      document.body.removeChild(portalParent);
      handleClose();
    };
  }, [portalParent]);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createPortal)((0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_help_center_container__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z, {
    handleClose: handleClose,
    isLoading: isLoading
  }), portalParent);
};

/* harmony default export */ __webpack_exports__["Z"] = (HelpCenter);

/***/ }),

/***/ 92421:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);


const HelpIcon = _ref => {
  let {
    newItems
  } = _ref;
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("svg", {
    width: "24",
    height: "24",
    viewBox: "0 0 24 24",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, newItems ? (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("path", {
    d: "M 12.75 15.5 L 12.75 17 L 11.25 17 L 11.25 15.5 Z M 9 10.75 C 9.033 9.975 9.377 9.13 9.879 8.629 C 10.38 8.127 11.225 7.75 12 7.75 C 12.775 7.75 13.62 8.127 14.121 8.629 C 14.623 9.13 15 9.975 15 10.75 C 15 11.473 14.672 12.266 14.229 12.758 C 13.873 13.154 13.317 13.474 12.75 13.639 L 12.75 14.5 L 11.25 14.5 L 11.25 13.25 C 11.283 13.026 11.401 12.688 11.534 12.551 C 11.666 12.415 11.971 12.286 12.167 12.241 C 12.593 12.221 12.84 12.059 13.115 11.754 C 13.39 11.448 13.5 11.186 13.5 10.75 C 13.5 10.282 13.373 10.002 13.061 9.689 C 12.748 9.377 12.468 9.25 12 9.25 C 11.532 9.25 11.252 9.377 10.939 9.689 C 10.627 10.002 10.467 10.282 10.5 10.75 Z M 18.187 18.687 C 16.645 20.229 14.362 21.25 12 21.25 C 9.638 21.25 7.355 20.229 5.813 18.687 C 4.271 17.145 3.25 14.862 3.25 12.5 C 3.25 10.138 4.271 7.855 5.813 6.313 C 7.355 4.771 9.638 3.75 12 3.75 C 13.466 3.75 14.902 4.143 16.149 4.811 C 15.836 5.188 15.578 5.612 15.386 6.071 C 14.388 5.538 13.257 5.25 12 5.25 C 9.944 5.25 8.227 6.02 6.873 7.373 C 5.52 8.727 4.75 10.444 4.75 12.5 C 4.75 14.556 5.52 16.273 6.873 17.627 C 8.227 18.98 9.944 19.75 12 19.75 C 14.056 19.75 15.773 18.98 17.127 17.627 C 18.382 16.371 19.135 14.803 19.238 12.942 C 19.486 12.98 19.741 13 20 13 C 20.251 13 20.497 12.982 20.738 12.946 C 20.619 15.147 19.632 17.242 18.187 18.687 Z"
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("circle", {
    cx: "20",
    cy: "8",
    r: "4",
    fill: "var( --color-masterbar-unread-dot-background )"
  })) : (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("path", {
    d: "M 12.75 15.5 L 12.75 17 L 11.25 17 L 11.25 15.5 Z M 9 10.75 C 9.033 9.975 9.377 9.13 9.879 8.629 C 10.38 8.127 11.225 7.75 12 7.75 C 12.775 7.75 13.62 8.127 14.121 8.629 C 14.623 9.13 15 9.975 15 10.75 C 15 11.473 14.672 12.266 14.229 12.758 C 13.873 13.154 13.317 13.474 12.75 13.639 L 12.75 14.5 L 11.25 14.5 L 11.25 13.25 C 11.283 13.026 11.401 12.688 11.534 12.551 C 11.666 12.415 11.971 12.286 12.167 12.241 C 12.593 12.221 12.84 12.059 13.115 11.754 C 13.39 11.448 13.5 11.186 13.5 10.75 C 13.5 10.282 13.373 10.002 13.061 9.689 C 12.748 9.377 12.468 9.25 12 9.25 C 11.532 9.25 11.252 9.377 10.939 9.689 C 10.627 10.002 10.467 10.282 10.5 10.75 Z M 20.75 12.5 C 20.75 14.862 19.729 17.145 18.187 18.687 C 16.645 20.229 14.362 21.25 12 21.25 C 9.638 21.25 7.355 20.229 5.813 18.687 C 4.271 17.145 3.25 14.862 3.25 12.5 C 3.25 10.138 4.271 7.855 5.813 6.313 C 7.355 4.771 9.638 3.75 12 3.75 C 14.362 3.75 16.645 4.771 18.187 6.313 C 19.729 7.855 20.75 10.138 20.75 12.5 Z M 17.127 7.373 C 15.773 6.02 14.056 5.25 12 5.25 C 9.944 5.25 8.227 6.02 6.873 7.373 C 5.52 8.727 4.75 10.444 4.75 12.5 C 4.75 14.556 5.52 16.273 6.873 17.627 C 8.227 18.98 9.944 19.75 12 19.75 C 14.056 19.75 15.773 18.98 17.127 17.627 C 18.48 16.273 19.25 14.556 19.25 12.5 C 19.25 10.444 18.48 8.727 17.127 7.373 Z"
  }));
};

/* harmony default export */ __webpack_exports__["Z"] = (HelpIcon);

/***/ }),

/***/ 15166:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ PlaceholderLines; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _placeholder_lines_scss__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(25827);


function PlaceholderLines(_ref) {
  let {
    lines = 4
  } = _ref;
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "placeholder-lines__help-center"
  }, Array.from({
    length: lines
  }, (_, n) => (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    key: n,
    className: "placeholder-lines__help-center-item"
  })));
}

/***/ }),

/***/ 69309:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "t": function() { return /* binding */ SuccessIcon; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);

const SuccessIcon = () => (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("svg", {
  width: "70",
  height: "70",
  viewBox: "0 0 70 70",
  fill: "none",
  xmlns: "http://www.w3.org/2000/svg"
}, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("path", {
  d: "M68.6749 34.9921C68.6749 43.7173 65.2099 52.0854 59.0417 58.2565C52.8736 64.4276 44.5072 67.8966 35.782 67.9008C29.2051 58.6978 25.5391 47.734 25.2577 36.426C24.9764 25.118 28.0925 13.9855 34.2036 4.46683L35.782 2.0835C44.5072 2.08768 52.8736 5.55667 59.0417 11.7278C65.2099 17.8989 68.6749 26.2669 68.6749 34.9921Z",
  fill: "#EFEFEF"
}), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("path", {
  d: "M68.6745 34.9922C68.6745 43.9211 65.1275 52.4843 58.8139 58.798C52.5002 65.1116 43.9371 68.6586 35.0082 68.6586C26.0793 68.6586 17.5162 65.1116 11.2025 58.798C4.88884 52.4843 1.34188 43.9211 1.34188 34.9922C1.33725 32.9271 1.52752 30.866 1.91011 28.8366C3.44563 20.5851 8.00795 13.2047 14.7026 8.14248C21.3972 3.08021 29.7414 0.701285 38.0991 1.47185C46.4568 2.24242 54.2252 6.10701 59.8814 12.308C65.5376 18.509 68.6736 26.5991 68.6745 34.9922V34.9922Z",
  stroke: "#003A5F",
  strokeWidth: "1.68",
  strokeLinecap: "round",
  strokeLinejoin: "round"
}), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("path", {
  d: "M23.334 37.9118L31.5091 45.0617L47.1664 23.675",
  stroke: "#003A5F",
  strokeWidth: "3",
  strokeLinecap: "round",
  strokeLinejoin: "round"
}));

/***/ }),

/***/ 94509:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "k": function() { return /* binding */ SuccessScreen; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36115);
/* harmony import */ var _wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(95885);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(4792);
/* harmony import */ var react_router_dom__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(29175);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(73041);
/* harmony import */ var _back_button__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(40495);
/* harmony import */ var _success_icon__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(69309);


/* eslint-disable no-restricted-imports */








const SuccessScreen = () => {
  const {
    __
  } = (0,_wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_4__/* .useI18n */ .QT)();
  const {
    search
  } = (0,react_router_dom__WEBPACK_IMPORTED_MODULE_5__/* .useLocation */ .TH)();
  const sectionName = (0,react_redux__WEBPACK_IMPORTED_MODULE_3__/* .useSelector */ .v9)(calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z);
  const params = new URLSearchParams(search);
  const forumTopicUrl = params.get('forumTopic');

  const trackForumOpen = () => (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('calypso_inlinehelp_forums_open', {
    location: 'help-center',
    section: sectionName
  });

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_back_button__WEBPACK_IMPORTED_MODULE_7__/* .BackButton */ .x, {
    backToRoot: true
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "ticket-success-screen__help-center"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_success_icon__WEBPACK_IMPORTED_MODULE_8__/* .SuccessIcon */ .t, null), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("h1", {
    className: "ticket-success-screen__help-center-heading"
  }, __("We're on it!", "full-site-editing")), forumTopicUrl ? (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", {
    className: "ticket-success-screen__help-center-message"
  }, __('Your message has been submitted to our community forums.', "full-site-editing"), "\xA0", (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("a", {
    target: "_blank",
    rel: "noopener noreferrer",
    onClick: trackForumOpen,
    href: forumTopicUrl
  }, __('View the forums topic here.', "full-site-editing"))) : (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", {
    className: "ticket-success-screen__help-center-message"
  }, __("We've received your message, and you'll hear back from one of our Happiness Engineers shortly.", "full-site-editing"))));
};

/***/ }),

/***/ 24478:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "O": function() { return /* binding */ FeatureFlagProvider; }
/* harmony export */ });
/* unused harmony export useFeatureFlags */
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);



const FeatureFlagContext = /*#__PURE__*/react__WEBPACK_IMPORTED_MODULE_1__.createContext(undefined);
const FeatureFlagProvider = function (_ref) {
  let {
    children
  } = _ref;
  let featureFlags; // If the Editing Toolkit Plugin is not loaded

  if (typeof helpCenterFeatureFlags === 'undefined') {
    featureFlags = undefined;
  } else {
    featureFlags = helpCenterFeatureFlags;
  }

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(FeatureFlagContext.Provider, {
    value: featureFlags
  }, children);
};
function useFeatureFlags() {
  const featureFlags = useContext(FeatureFlagContext); // Trying to call hook outside of component that renders FeatureFlagProvider

  if (featureFlags === undefined) {
    throw new Error('useFeatureFlags must be used within a FeatureFlagProvider');
  }

  return featureFlags;
}

/***/ }),

/***/ 39226:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ht": function() { return /* binding */ execute; },
/* harmony export */   "SW": function() { return /* binding */ askDirectlyQuestion; }
/* harmony export */ });
/* unused harmony exports checkAPIThenInitializeDirectly, initializeDirectly */
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var _automattic_load_script__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(84898);
/* harmony import */ var _style_scss__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(23980);
/**
 *
 *
 *
 * @file Interface to the third-party Real Time Messaging (RTM) widget from Directly.
 * @see https:
 */




const DIRECTLY_RTM_SCRIPT_URL = 'https://widgets.wp.com/directly/embed.js';
const DIRECTLY_ASSETS_BASE_URL = 'https://www.directly.com';
/**
 * Gets the default set of options to configure the Directly RTM widget.
 * It's important to keep this config in a getter function, rather than a constant
 * on the module scope, to prevent import-time errors errors that could crash Calypso.
 *
 * @see https://cloudup.com/cySVQ9R_O6S for all configuration options
 * @returns The default configuration options
 */

function getDefaultOptions() {
  const ids = (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('directly_rtm_widget_ids');
  const env = (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('directly_rtm_widget_environment');
  return {
    id: ids[env],
    displayAskQuestion: true
  };
}

/**
 * Set up global variables and configuration for the RTM widget
 *
 * @see https://cloudup.com/cySVQ9R_O6S for the standard setup instructions
 */
function configureGlobals() {
  // Set up the global DirectlyRTM function, required for the RTM widget.
  // This snippet is pasted from Directly's setup code.
  if (!window.DirectlyRTM) {
    window.DirectlyRTM = function () {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      if (window.DirectlyRTM.cq) {
        window.DirectlyRTM.cq.push(...args);
      } else {
        window.DirectlyRTM.cq = args;
      }
    };
  } // Since we can only configure once per pageload, this library only provides a
  // single global configuration.


  window.DirectlyRTM(['config', getDefaultOptions()]);
}
/**
 * Inserts a dummy DOM element that the widget uses to calculate the base URL for its assets.
 *
 * Under standard setup, the RTM widget gathers its base URL by inspecting the src attribute of
 * the <script> used to load the library. Since we've got a custom setup that doesn't include
 * a <script> tag, we need to fake this by placing a DOM element with id="directlyRTMScript"
 * and a src with the appropriate base URL.
 *
 * @see https://cloudup.com/cySVQ9R_O6S for the standard setup instructions we've modified
 */


function insertDOM() {
  if (null !== document.getElementById('directlyRTMScript')) {
    return;
  }

  const d = document.createElement('img');
  d.id = 'directlyRTMScript';
  d.src = DIRECTLY_ASSETS_BASE_URL;
  document.body.appendChild(d);
}
/**
 * Initializes the RTM widget if it hasn't already been initialized, and then executes the
 * command by passing the arguments to window.DirectlyRTM
 *
 * @returns Promise that resolves after initialization and command execution
 */


async function execute(args) {
  await initializeDirectly();
  return window.DirectlyRTM(...args);
}
/**
 * Make the request for Directly's remote JavaScript.
 *
 * @returns Promise that resolves after the script loads or fails
 */

function loadDirectlyScript() {
  return (0,_automattic_load_script__WEBPACK_IMPORTED_MODULE_1__/* .loadScript */ .ve)(DIRECTLY_RTM_SCRIPT_URL);
}

let directlyPromise;
/**
 * Initializes the RTM widget if it hasn't already been initialized. This sets up global
 * objects and DOM elements and requests the vendor script.
 *
 * @returns Promise that resolves after initialization completes or fails
 */

function checkAPIThenInitializeDirectly() {
  if (directlyPromise instanceof Promise) {
    return directlyPromise;
  }

  directlyPromise = wpcomRequest({
    path: '/help/directly/mine',
    apiVersion: '1.1'
  }).then(_ref => {
    let {
      isAvailable
    } = _ref;

    if (!isAvailable) {
      return Promise.reject(new Error('Directly Real-Time Messaging is not available at this time.'));
    }

    return initializeDirectly();
  });
  return directlyPromise;
}
let initialized = false;
/**
 * Initializes the RTM widget if it hasn't already been initialized. This sets up global
 * objects and DOM elements and requests the vendor script.
 *
 * @returns Promise that resolves after initialization completes or fails
 */

function initializeDirectly() {
  if (initialized) {
    return directlyPromise;
  }

  initialized = true;
  configureGlobals();
  insertDOM();
  directlyPromise = loadDirectlyScript();
  return directlyPromise;
}
/**
 * Ask a question to the Directly RTM widget.
 *
 * @param questionText - The question to submit
 * @param name - The question asker's name
 * @param email - The question asker's email address
 * @returns Promise that resolves after initialization completes
 */

async function askDirectlyQuestion(questionText, name, email) {
  // There's a bug that happens when you "askQuestion" and the widget is showing the minimized
  // bubble with an expert avatar in it (indicating an active chat session). In this case,
  // the widget throws errors and becomes unusable.
  //
  // As of the time of this comment Directly is still investigating this issue, which
  // appears to be on their end. Their suggested stopgap is to "nagivate" out of the
  // active chat before the "askQuestion" fires, hence the solution here. Note that
  // "navigate" is an undocumented API, so you won't see it in the config guide.
  await execute(['navigate', '/ask']);
  return execute(['askQuestion', {
    questionText,
    name,
    email
  }]);
}

/***/ }),

/***/ 71645:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "g": function() { return /* binding */ useHCWindowCommunicator; }
/* harmony export */ });
/* harmony import */ var _automattic_happychat_connection__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(61082);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(9818);
/* harmony import */ var _wordpress_data__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_data__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(82066);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(4792);
/* harmony import */ var calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(20834);
/* harmony import */ var _stores__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(98865);
/* eslint-disable no-restricted-imports */

/**
 * External Dependencies
 */






/**
 * Internal Dependencies
 */



/**
 * This hook attaches an event listener to the window to listen to Happychat messages that com from https://widgets.wp.com/calypso-happychat/
 * It collects information from the help-center store and forwards it to Happychat. It also forwards the unread count and the state changes (ended, blurred, closed, opened) to whoever uses the hook
 *
 * @param onStateChange a callback that will be called whenever state changes
 * @param onUnreadChange a callback that will be called with the number of new unread messages
 */
function useHCWindowCommunicator(onStateChange, onUnreadChange) {
  const {
    selectedSite,
    subject,
    message,
    userDeclaredSite
  } = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.useSelect)(select => {
    return {
      selectedSite: select(_stores__WEBPACK_IMPORTED_MODULE_4__/* .HELP_CENTER_STORE */ .aM).getSite(),
      userDeclaredSite: select(_stores__WEBPACK_IMPORTED_MODULE_4__/* .HELP_CENTER_STORE */ .aM).getUserDeclaredSite(),
      subject: select(_stores__WEBPACK_IMPORTED_MODULE_4__/* .HELP_CENTER_STORE */ .aM).getSubject(),
      message: select(_stores__WEBPACK_IMPORTED_MODULE_4__/* .HELP_CENTER_STORE */ .aM).getMessage()
    };
  });
  const siteId = (0,react_redux__WEBPACK_IMPORTED_MODULE_3__/* .useSelector */ .v9)(calypso_state_ui_selectors__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z);
  const currentSite = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.useSelect)(select => select(_stores__WEBPACK_IMPORTED_MODULE_4__/* .SITE_STORE */ .j4).getSite(siteId), [siteId]);
  const queryClient = (0,react_query__WEBPACK_IMPORTED_MODULE_2__.useQueryClient)();
  const supportSite = selectedSite || userDeclaredSite || currentSite;
  const {
    resetStore
  } = (0,_wordpress_data__WEBPACK_IMPORTED_MODULE_0__.useDispatch)(_stores__WEBPACK_IMPORTED_MODULE_4__/* .HELP_CENTER_STORE */ .aM);
  (0,_automattic_happychat_connection__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)();
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    const messageHandler = event => {
      // please be careful about changing this check
      // sometimes we send sensitive information to this event's origin,
      // and changing this to something untrusted is a serious security risk.
      if (event.origin === 'https://widgets.wp.com') {
        const {
          data
        } = event;

        switch (data.type) {
          case 'calypso-happy-chat-unread-messages':
            onUnreadChange(data.state);
            break;

          case 'window-state-change':
            onStateChange(data.state);

            if (data.state === 'ended') {
              // cleanup
              window.removeEventListener('message', messageHandler); // now clear the store, since we sent everything

              resetStore();
            }

            break;

          case 'happy-chat-introduction-data':
            {
              var _event$source, _supportSite$plan;

              (_event$source = event.source) === null || _event$source === void 0 ? void 0 : _event$source.postMessage({
                type: 'happy-chat-introduction-data',
                siteId: supportSite === null || supportSite === void 0 ? void 0 : supportSite.ID.toString(),
                subject,
                message,
                planSlug: supportSite === null || supportSite === void 0 ? void 0 : (_supportSite$plan = supportSite.plan) === null || _supportSite$plan === void 0 ? void 0 : _supportSite$plan.product_slug,
                siteUrl: supportSite === null || supportSite === void 0 ? void 0 : supportSite.URL
              }, {
                targetOrigin: event.origin
              });
              break;
            }

          case 'happy-chat-authentication-data':
            {
              // this hooks up to the query initiated above (useHappychatAuth)
              // and returns a promise. We wait for this promise to prevent a race-condition.
              queryClient.fetchQuery('getHappychatAuth').then(auth => {
                var _event$source2;

                (_event$source2 = event.source) === null || _event$source2 === void 0 ? void 0 : _event$source2.postMessage({
                  type: 'happy-chat-authentication-data',
                  authData: auth
                }, {
                  targetOrigin: event.origin
                });
              });
              break;
            }
        }
      }
    };

    window.addEventListener('message', messageHandler);
    return () => {
      window.removeEventListener('message', messageHandler);
    };
  }, [onStateChange, onUnreadChange, queryClient, supportSite, subject, message, resetStore]);
}

/***/ }),

/***/ 77331:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "e": function() { return /* binding */ useHelpSearchQuery; }
/* harmony export */ });
/* harmony import */ var _wordpress_api_fetch__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(86989);
/* harmony import */ var _wordpress_api_fetch__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_api_fetch__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(82066);
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(18552);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(97006);




const useHelpSearchQuery = function (search) {
  let locale = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'en';
  let isSimpleSite = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
  let queryOptions = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};
  const queryClient = (0,react_query__WEBPACK_IMPORTED_MODULE_1__.useQueryClient)();
  return (0,react_query__WEBPACK_IMPORTED_MODULE_1__.useQuery)(['help', search], () => (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .shouldTargetWpcom */ .DS)(isSimpleSite) ? (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP)({
    path: `help/search/wpcom?query=${search}&locale=${locale}`,
    apiNamespace: 'wpcom/v2/',
    apiVersion: '2'
  }) : _wordpress_api_fetch__WEBPACK_IMPORTED_MODULE_0___default()({
    global: true,
    path: `/wpcom/v2/help-center/search?query=${search}&locale=${locale}`
  }), {
    onSuccess: async data => {
      if (!data[0].content) {
        const newData = await Promise.all(data.map(async result => {
          const article = (0,_utils__WEBPACK_IMPORTED_MODULE_2__/* .shouldTargetWpcom */ .DS)(isSimpleSite) ? await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .ZP)({
            path: `help/article/${result.blog_id}/${result.post_id}`,
            apiNamespace: 'wpcom/v2/',
            apiVersion: '2'
          }) : await _wordpress_api_fetch__WEBPACK_IMPORTED_MODULE_0___default()({
            global: true,
            path: `/wpcom/v2/help-center/fetch-post?blog_id=${result.blog_id}&post_id=${result.post_id}`
          });
          return { ...result,
            content: article.content
          };
        }));
        queryClient.setQueryData(['help', search], newData);
      }
    },
    refetchOnWindowFocus: false,
    refetchOnMount: false,
    enabled: !!search,
    ...queryOptions
  });
};

/***/ }),

/***/ 97878:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "v": function() { return /* binding */ useShouldRenderChatOption; }
/* harmony export */ });
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99706);
/* harmony import */ var _automattic_happychat_connection__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(89645);


function useShouldRenderChatOption() {
  const {
    data: chatStatus
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_0__/* .useSupportAvailability */ .p)('CHAT');
  const {
    available,
    isLoading
  } = (0,_automattic_happychat_connection__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)();

  if (!(chatStatus !== null && chatStatus !== void 0 && chatStatus.is_user_eligible)) {
    return {
      render: false,
      isLoading
    };
  } else if (chatStatus !== null && chatStatus !== void 0 && chatStatus.is_chat_closed) {
    return {
      render: true,
      state: 'CLOSED',
      isLoading
    };
  } else if (available) {
    return {
      render: true,
      state: 'AVAILABLE',
      isLoading
    };
  }

  return {
    render: true,
    state: 'UNAVAILABLE',
    isLoading
  };
}

/***/ }),

/***/ 82513:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "X": function() { return /* binding */ useShouldRenderEmailOption; }
/* harmony export */ });
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99706);

function useShouldRenderEmailOption() {
  const {
    data: supportAvailability
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_0__/* .useSupportAvailability */ .p)('OTHER');

  if (supportAvailability !== null && supportAvailability !== void 0 && supportAvailability.is_user_eligible_for_tickets || supportAvailability !== null && supportAvailability !== void 0 && supportAvailability.is_user_eligible_for_upwork) {
    return true;
  }

  return false;
}

/***/ }),

/***/ 83822:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "A": function() { return /* binding */ useStillNeedHelpURL; }
/* harmony export */ });
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(63830);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(99706);
/* harmony import */ var react_redux__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4792);
/* harmony import */ var calypso_state_sites_selectors_is_simple_site__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(83377);
/* harmony import */ var _utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(97006);
/* eslint-disable no-restricted-imports */




function useStillNeedHelpURL() {
  const {
    hasCookies
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_1__/* .useHas3PC */ .O)();
  const isSimpleSite = (0,react_redux__WEBPACK_IMPORTED_MODULE_0__/* .useSelector */ .v9)(state => (0,calypso_state_sites_selectors_is_simple_site__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(state));
  const canUseWpcomApis = Boolean((0,_utils__WEBPACK_IMPORTED_MODULE_3__/* .shouldTargetWpcom */ .DS)(isSimpleSite));
  const {
    data: supportAvailability
  } = (0,_automattic_data_stores__WEBPACK_IMPORTED_MODULE_4__/* .useSupportAvailability */ .p)('OTHER', canUseWpcomApis); // email support is available for all non-free users, let's use it as a proxy for free users
  // TODO: check purchases instead

  const isFreeUser = !(supportAvailability !== null && supportAvailability !== void 0 && supportAvailability.is_user_eligible_for_tickets);

  if (!canUseWpcomApis) {
    return 'https://wordpress.com/help/contact';
  }

  if (!isFreeUser) {
    return '/contact-options';
  }

  if (supportAvailability !== null && supportAvailability !== void 0 && supportAvailability.is_user_eligible_for_directly && hasCookies) {
    return '/contact-form?mode=DIRECTLY';
  }

  return '/contact-form?mode=FORUM';
}

/***/ }),

/***/ 67605:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);


const Mail = () => {
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    width: "24",
    height: "24",
    viewBox: "0 0 24 24"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("path", {
    d: "M18 6.75H6C5.30964 6.75 4.75 7.30964 4.75 8V16C4.75 16.6904 5.30964 17.25 6 17.25H18C18.6904 17.25 19.25 16.6904 19.25 16V8C19.25 7.30964 18.6904 6.75 18 6.75Z",
    stroke: "#fff",
    strokeWidth: "1.5",
    fill: "transparent"
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("path", {
    d: "M5 7L12 13L19 7",
    stroke: "#fff",
    fill: "transparent",
    strokeWidth: "1.5"
  }));
};

/* harmony default export */ __webpack_exports__["Z"] = (Mail);

/***/ }),

/***/ 51519:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);


const NewReleases = () => {
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("svg", {
    xmlns: "http://www.w3.org/2000/svg",
    viewBox: "0 0 24 24",
    height: "24",
    width: "24"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("path", {
    d: "M0 0h24v24H0V0z",
    fill: "none"
  }), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("path", {
    d: "M23 12l-2.44-2.78.34-3.68-3.61-.82-1.89-3.18L12 3 8.6 1.54 6.71 4.72l-3.61.81.34 3.68L1 12l2.44 2.78-.34 3.69 3.61.82 1.89 3.18L12 21l3.4 1.46 1.89-3.18 3.61-.82-.34-3.68L23 12zm-4.51 2.11l.26 2.79-2.74.62-1.43 2.41L12 18.82l-2.58 1.11-1.43-2.41-2.74-.62.26-2.8L3.66 12l1.85-2.12-.26-2.78 2.74-.61 1.43-2.41L12 5.18l2.58-1.11 1.43 2.41 2.74.62-.26 2.79L20.34 12l-1.85 2.11zM11 15h2v2h-2zm0-8h2v6h-2z"
  }));
};

/* harmony default export */ __webpack_exports__["Z"] = (NewReleases);

/***/ }),

/***/ 98865:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "aM": function() { return /* binding */ HELP_CENTER_STORE; },
/* harmony export */   "Em": function() { return /* binding */ USER_STORE; },
/* harmony export */   "j4": function() { return /* binding */ SITE_STORE; }
/* harmony export */ });
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(17624);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(88330);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(52369);

const HELP_CENTER_STORE = _automattic_data_stores__WEBPACK_IMPORTED_MODULE_0__/* .register */ .z(); // these creds are only needed when signing up users

const USER_STORE = _automattic_data_stores__WEBPACK_IMPORTED_MODULE_1__/* .register */ .z({
  client_id: '',
  client_secret: ''
});
const SITE_STORE = _automattic_data_stores__WEBPACK_IMPORTED_MODULE_2__/* .register */ .z2({
  client_id: '',
  client_secret: ''
});

/***/ }),

/***/ 44241:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "yQ": function() { return /* binding */ getSupportVariationFromMode; }
/* harmony export */ });
/* unused harmony exports SUPPORT_CHAT_OVERFLOW, SUPPORT_DIRECTLY, SUPPORT_FORUM, SUPPORT_HAPPYCHAT, SUPPORT_TICKET, SUPPORT_UPWORK_TICKET */
const SUPPORT_CHAT_OVERFLOW = 'SUPPORT_CHAT_OVERFLOW';
const SUPPORT_DIRECTLY = 'SUPPORT_DIRECTLY';
const SUPPORT_FORUM = 'SUPPORT_FORUM';
const SUPPORT_HAPPYCHAT = 'SUPPORT_HAPPYCHAT';
const SUPPORT_TICKET = 'SUPPORT_TICKET';
const SUPPORT_UPWORK_TICKET = 'SUPPORT_UPWORK_TICKET';
/**
 * @param {string} mode Help Center contact form mode
 * @returns {string} One of the exported support variation constants listed above
 */

const getSupportVariationFromMode = mode => {
  switch (mode) {
    case 'CHAT':
      return SUPPORT_HAPPYCHAT;

    case 'EMAIL':
      return SUPPORT_TICKET;

    case 'FORUM':
      return SUPPORT_FORUM;

    case 'DIRECTLY':
      return SUPPORT_DIRECTLY;

    case 'UPWORK':
      return SUPPORT_UPWORK_TICKET;
  }
};

/***/ }),

/***/ 97006:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "DS": function() { return /* binding */ shouldTargetWpcom; }
/* harmony export */ });
/* unused harmony exports shouldShowHelpCenterToUser, isAllowedOrigin, shouldLoadInlineHelp */
/* eslint-disable no-restricted-imports */
 // list of valid origins for wpcom requests.
// taken from wpcom-proxy-request (rest-proxy/provider-v2.0.js)

const wpcomAllowedOrigins = ['https://wordpress.com', 'https://cloud.jetpack.com', 'http://wpcalypso.wordpress.com', // for running docker on dev instances
'http://widgets.wp.com', 'https://widgets.wp.com', 'https://dev-mc.a8c.com', 'https://mc.a8c.com', 'https://dserve.a8c.com', 'http://calypso.localhost:3000', 'https://calypso.localhost:3000', 'http://jetpack.cloud.localhost:3000', 'https://jetpack.cloud.localhost:3000', 'http://calypso.localhost:3001', 'https://calypso.localhost:3001', 'https://calypso.live', 'http://127.0.0.1:41050', 'http://send.linguine.localhost:3000']; // function that tells us if we want to show the Help Center to the user, given that we're showing it to
// only a certain percentage of users.

function shouldShowHelpCenterToUser(userId) {
  const currentSegment = 30; //percentage of users that will see the Help Center, not the FAB

  const userSegment = userId % 100;
  return userSegment < currentSegment;
}
/**
 * Shelved from rest-proxy/provider-v2.0.js.
 * This returns true for all WPCOM origins except Atomic sites.
 *
 * @param origin
 * @returns
 */

function isAllowedOrigin(origin) {
  // sites in the allow-list and some subdomains of "calypso.live" and "wordpress.com"
  // are allowed without further check
  return wpcomAllowedOrigins.includes(origin) || origin.match(/^https:\/\/[a-z0-9-]+\.calypso\.live$/) || origin.match(/^https:\/\/([a-z0-9-]+\.)+wordpress\.com$/);
}
function shouldTargetWpcom(isSimpleSite) {
  return isSimpleSite || isAllowedOrigin(window.location.origin);
}
function shouldLoadInlineHelp(sectionName, currentRoute) {
  if (isWpMobileApp()) {
    return false;
  }

  const exemptedSections = ['jetpack-connect', 'happychat', 'devdocs', 'help', 'home'];
  const exemptedRoutes = ['/log-in/jetpack'];
  const exemptedRoutesStartingWith = ['/start/p2', '/start/setup-site', '/plugins/domain', '/plugins/marketplace/setup'];
  return !exemptedSections.includes(sectionName) && !exemptedRoutes.includes(currentRoute) && !exemptedRoutesStartingWith.some(startsWithString => currentRoute.startsWith(startsWithString));
}

/***/ }),

/***/ 8057:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _default_i18n__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(94724);


/* harmony default export */ __webpack_exports__["Z"] = (/*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.createContext)(_default_i18n__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z));

/***/ }),

/***/ 94724:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _i18n__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(50914);

/* harmony default export */ __webpack_exports__["Z"] = (new _i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z());

/***/ }),

/***/ 50914:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var events__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(22699);
/* harmony import */ var events__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(events__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_interpolate_components__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(32594);
/* harmony import */ var _tannin_sprintf__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(96668);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var hash_js_lib_hash_sha_1__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(35079);
/* harmony import */ var hash_js_lib_hash_sha_1__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(hash_js_lib_hash_sha_1__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var lru__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(7839);
/* harmony import */ var lru__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(lru__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var tannin__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(49830);
/* harmony import */ var _number_format__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(10003);








/**
 * Module variables
 */

const debug = debug__WEBPACK_IMPORTED_MODULE_1___default()('i18n-calypso');
/**
 * Constants
 */

const decimal_point_translation_key = 'number_format_decimals';
const thousands_sep_translation_key = 'number_format_thousands_sep';
const domain_key = 'messages';
const translationLookup = [// By default don't modify the options when looking up translations.
function (options) {
  return options;
}];
const hashCache = {}; // raise a console warning

function warn() {
  if (!I18N.throwErrors) {
    return;
  }

  if ('undefined' !== typeof window && window.console && window.console.warn) {
    window.console.warn.apply(window.console, arguments);
  }
} // turns Function.arguments into an array


function simpleArguments(args) {
  return Array.prototype.slice.call(args);
}
/**
 * Coerce the possible arguments and normalize to a single object.
 *
 * @param   {any} args - arguments passed in from `translate()`
 * @returns {object}         - a single object describing translation needs
 */


function normalizeTranslateArguments(args) {
  const original = args[0]; // warn about older deprecated syntax

  if (typeof original !== 'string' || args.length > 3 || args.length > 2 && typeof args[1] === 'object' && typeof args[2] === 'object') {
    warn('Deprecated Invocation: `translate()` accepts ( string, [string], [object] ). These arguments passed:', simpleArguments(args), '. See https://github.com/Automattic/i18n-calypso#translate-method');
  }

  if (args.length === 2 && typeof original === 'string' && typeof args[1] === 'string') {
    warn('Invalid Invocation: `translate()` requires an options object for plural translations, but passed:', simpleArguments(args));
  } // options could be in position 0, 1, or 2
  // sending options as the first object is deprecated and will raise a warning


  let options = {};

  for (let i = 0; i < args.length; i++) {
    if (typeof args[i] === 'object') {
      options = args[i];
    }
  } // `original` can be passed as first parameter or as part of the options object
  // though passing original as part of the options is a deprecated approach and will be removed


  if (typeof original === 'string') {
    options.original = original;
  } else if (typeof options.original === 'object') {
    options.plural = options.original.plural;
    options.count = options.original.count;
    options.original = options.original.single;
  }

  if (typeof args[1] === 'string') {
    options.plural = args[1];
  }

  if (typeof options.original === 'undefined') {
    throw new Error('Translate called without a `string` value as first argument.');
  }

  return options;
}
/**
 * Takes translate options object and coerces to a Tannin request to retrieve translation.
 *
 * @param   {object} tannin  - tannin data object
 * @param   {object} options - object describing translation
 * @returns {string}         - the returned translation from Tannin
 */


function getTranslationFromTannin(tannin, options) {
  return tannin.dcnpgettext(domain_key, options.context, options.original, options.plural, options.count);
}

function getTranslation(i18n, options) {
  for (let i = translationLookup.length - 1; i >= 0; i--) {
    const lookup = translationLookup[i](Object.assign({}, options));
    const key = lookup.context ? lookup.context + '\u0004' + lookup.original : lookup.original; // Only get the translation from tannin if it exists.

    if (i18n.state.locale[key]) {
      return getTranslationFromTannin(i18n.state.tannin, lookup);
    }
  }

  return null;
}

function I18N() {
  if (!(this instanceof I18N)) {
    return new I18N();
  }

  this.defaultLocaleSlug = 'en'; // Tannin always needs a plural form definition, or it fails when dealing with plurals.

  this.defaultPluralForms = n => n === 1 ? 0 : 1;

  this.state = {
    numberFormatSettings: {},
    tannin: undefined,
    locale: undefined,
    localeSlug: undefined,
    localeVariant: undefined,
    textDirection: undefined,
    translations: lru__WEBPACK_IMPORTED_MODULE_3___default()({
      max: 100
    })
  };
  this.componentUpdateHooks = [];
  this.translateHooks = [];
  this.stateObserver = new events__WEBPACK_IMPORTED_MODULE_0__.EventEmitter(); // Because the higher-order component can wrap a ton of React components,
  // we need to bump the number of listeners to infinity and beyond
  // FIXME: still valid?

  this.stateObserver.setMaxListeners(0); // default configuration

  this.configure();
}

I18N.throwErrors = false;

I18N.prototype.on = function () {
  this.stateObserver.on(...arguments);
};

I18N.prototype.off = function () {
  this.stateObserver.off(...arguments);
};

I18N.prototype.emit = function () {
  this.stateObserver.emit(...arguments);
};
/**
 * Formats numbers using locale settings and/or passed options.
 *
 * @param   {string|number}  number to format (required)
 * @param   {number|object}  options  Number of decimal places or options object (optional)
 * @returns {string}         Formatted number as string
 */


I18N.prototype.numberFormat = function (number) {
  let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  const decimals = typeof options === 'number' ? options : options.decimals || 0;
  const decPoint = options.decPoint || this.state.numberFormatSettings.decimal_point || '.';
  const thousandsSep = options.thousandsSep || this.state.numberFormatSettings.thousands_sep || ',';
  return (0,_number_format__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)(number, decimals, decPoint, thousandsSep);
};

I18N.prototype.configure = function (options) {
  Object.assign(this, options || {});
  this.setLocale();
};

I18N.prototype.setLocale = function (localeData) {
  var _this$state$locale$te, _this$state$locale$, _this$state$locale$$m;

  if (localeData && localeData[''] && localeData['']['key-hash']) {
    const keyHash = localeData['']['key-hash'];

    const transform = function (string, hashLength) {
      const lookupPrefix = hashLength === false ? '' : String(hashLength);

      if (typeof hashCache[lookupPrefix + string] !== 'undefined') {
        return hashCache[lookupPrefix + string];
      }

      const hash = hash_js_lib_hash_sha_1__WEBPACK_IMPORTED_MODULE_2___default()().update(string).digest('hex');

      if (hashLength) {
        return hashCache[lookupPrefix + string] = hash.substr(0, hashLength);
      }

      return hashCache[lookupPrefix + string] = hash;
    };

    const generateLookup = function (hashLength) {
      return function (options) {
        if (options.context) {
          options.original = transform(options.context + String.fromCharCode(4) + options.original, hashLength);
          delete options.context;
        } else {
          options.original = transform(options.original, hashLength);
        }

        return options;
      };
    };

    if (keyHash.substr(0, 4) === 'sha1') {
      if (keyHash.length === 4) {
        translationLookup.push(generateLookup(false));
      } else {
        const variableHashLengthPos = keyHash.substr(5).indexOf('-');

        if (variableHashLengthPos < 0) {
          const hashLength = Number(keyHash.substr(5));
          translationLookup.push(generateLookup(hashLength));
        } else {
          const minHashLength = Number(keyHash.substr(5, variableHashLengthPos));
          const maxHashLength = Number(keyHash.substr(6 + variableHashLengthPos));

          for (let hashLength = minHashLength; hashLength <= maxHashLength; hashLength++) {
            translationLookup.push(generateLookup(hashLength));
          }
        }
      }
    }
  } // if localeData is not given, assumes default locale and reset


  if (!localeData || !localeData[''].localeSlug) {
    this.state.locale = {
      '': {
        localeSlug: this.defaultLocaleSlug,
        plural_forms: this.defaultPluralForms
      }
    };
  } else if (localeData[''].localeSlug === this.state.localeSlug) {
    // Exit if same data as current (comparing references only)
    if (localeData === this.state.locale) {
      return;
    } // merge new data into existing one


    Object.assign(this.state.locale, localeData);
  } else {
    this.state.locale = Object.assign({}, localeData);
  }

  this.state.localeSlug = this.state.locale[''].localeSlug;
  this.state.localeVariant = this.state.locale[''].localeVariant; // extract the `textDirection` info (LTR or RTL) from either:
  // - the translation for the special string "ltr" (standard in Core, not present in Calypso)
  // - or the `momentjs_locale.textDirection` property present in Calypso translation files

  this.state.textDirection = ((_this$state$locale$te = this.state.locale['text direction\u0004ltr']) === null || _this$state$locale$te === void 0 ? void 0 : _this$state$locale$te[0]) || ((_this$state$locale$ = this.state.locale['']) === null || _this$state$locale$ === void 0 ? void 0 : (_this$state$locale$$m = _this$state$locale$.momentjs_locale) === null || _this$state$locale$$m === void 0 ? void 0 : _this$state$locale$$m.textDirection);
  this.state.tannin = new tannin__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z({
    [domain_key]: this.state.locale
  }); // Updates numberFormat preferences with settings from translations

  this.state.numberFormatSettings.decimal_point = getTranslationFromTannin(this.state.tannin, normalizeTranslateArguments([decimal_point_translation_key]));
  this.state.numberFormatSettings.thousands_sep = getTranslationFromTannin(this.state.tannin, normalizeTranslateArguments([thousands_sep_translation_key])); // If translation isn't set, define defaults.

  if (this.state.numberFormatSettings.decimal_point === decimal_point_translation_key) {
    this.state.numberFormatSettings.decimal_point = '.';
  }

  if (this.state.numberFormatSettings.thousands_sep === thousands_sep_translation_key) {
    this.state.numberFormatSettings.thousands_sep = ',';
  }

  this.stateObserver.emit('change');
};

I18N.prototype.getLocale = function () {
  return this.state.locale;
};
/**
 * Get the current locale slug.
 *
 * @returns {string} The string representing the currently loaded locale
 */


I18N.prototype.getLocaleSlug = function () {
  return this.state.localeSlug;
};
/**
 * Get the current locale variant. That's set for some special locales that don't have a
 * standard ISO code, like `de_formal` or `sr_latin`.
 *
 * @returns {string|undefined} The string representing the currently loaded locale's variant
 */


I18N.prototype.getLocaleVariant = function () {
  return this.state.localeVariant;
};
/**
 * Get the current text direction, left-to-right (LTR) or right-to-left (RTL).
 *
 * @returns {boolean} `true` in case the current locale has RTL text direction
 */


I18N.prototype.isRtl = function () {
  return this.state.textDirection === 'rtl';
};
/**
 * Adds new translations to the locale data, overwriting any existing translations with a matching key.
 *
 * @param {object} localeData Locale data
 */


I18N.prototype.addTranslations = function (localeData) {
  for (const prop in localeData) {
    if (prop !== '') {
      this.state.tannin.data.messages[prop] = localeData[prop];
    }
  }

  this.stateObserver.emit('change');
};
/**
 * Checks whether the given original has a translation.
 *
 * @returns {boolean} whether a translation exists
 */


I18N.prototype.hasTranslation = function () {
  return !!getTranslation(this, normalizeTranslateArguments(arguments));
};
/**
 * Exposes single translation method.
 * See sibling README
 *
 * @returns {string|object} translated text or an object containing React children that can be inserted into a parent component
 */


I18N.prototype.translate = function () {
  const options = normalizeTranslateArguments(arguments);
  let translation = getTranslation(this, options);

  if (!translation) {
    // This purposefully calls tannin for a case where there is no translation,
    // so that tannin gives us the expected object with English text.
    translation = getTranslationFromTannin(this.state.tannin, options);
  } // handle any string substitution


  if (options.args) {
    const sprintfArgs = Array.isArray(options.args) ? options.args.slice(0) : [options.args];
    sprintfArgs.unshift(translation);

    try {
      translation = (0,_tannin_sprintf__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(...sprintfArgs);
    } catch (error) {
      if (!window || !window.console) {
        return;
      }

      const errorMethod = this.throwErrors ? 'error' : 'warn';

      if (typeof error !== 'string') {
        window.console[errorMethod](error);
      } else {
        window.console[errorMethod]('i18n sprintf error:', sprintfArgs);
      }
    }
  } // interpolate any components


  if (options.components) {
    translation = (0,_automattic_interpolate_components__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z)({
      mixedString: translation,
      components: options.components,
      throwErrors: this.throwErrors
    });
  } // run any necessary hooks


  this.translateHooks.forEach(function (hook) {
    translation = hook(translation, options);
  });
  return translation;
};
/**
 * Causes i18n to re-render all translations.
 *
 * This can be necessary if an extension makes changes that i18n is unaware of
 * and needs those changes manifested immediately (e.g. adding an important
 * translation hook, or modifying the behaviour of an existing hook).
 *
 * If at all possible, react components should try to use the more local
 * updateTranslation() function inherited from the mixin.
 */


I18N.prototype.reRenderTranslations = function () {
  debug('Re-rendering all translations due to external request');
  this.stateObserver.emit('change');
};

I18N.prototype.registerComponentUpdateHook = function (callback) {
  this.componentUpdateHooks.push(callback);
};

I18N.prototype.registerTranslateHook = function (callback) {
  this.translateHooks.push(callback);
};

/* harmony default export */ __webpack_exports__["Z"] = (I18N);

/***/ }),

/***/ 11481:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Iu": function() { return /* binding */ translate; },
/* harmony export */   "Yj": function() { return /* binding */ getLocaleSlug; }
/* harmony export */ });
/* unused harmony exports numberFormat, configure, setLocale, getLocale, getLocaleVariant, isRtl, addTranslations, reRenderTranslations, registerComponentUpdateHook, registerTranslateHook, state, stateObserver, on, off, emit */
/* harmony import */ var _default_i18n__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(94724);







/* harmony default export */ __webpack_exports__["ZP"] = (_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z); // Export the default instance's properties and bound methods for convenience
// These should be deprecated eventually, exposing only the default `i18n` instance

const numberFormat = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].numberFormat.bind */ .Z.numberFormat.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const translate = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].translate.bind */ .Z.translate.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const configure = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].configure.bind */ .Z.configure.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const setLocale = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].setLocale.bind */ .Z.setLocale.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const getLocale = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].getLocale.bind */ .Z.getLocale.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const getLocaleSlug = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].getLocaleSlug.bind */ .Z.getLocaleSlug.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const getLocaleVariant = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].getLocaleVariant.bind */ .Z.getLocaleVariant.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const isRtl = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].isRtl.bind */ .Z.isRtl.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const addTranslations = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].addTranslations.bind */ .Z.addTranslations.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const reRenderTranslations = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].reRenderTranslations.bind */ .Z.reRenderTranslations.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const registerComponentUpdateHook = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].registerComponentUpdateHook.bind */ .Z.registerComponentUpdateHook.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const registerTranslateHook = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].registerTranslateHook.bind */ .Z.registerTranslateHook.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const state = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].state */ .Z.state;
const stateObserver = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].stateObserver */ .Z.stateObserver;
const on = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].on.bind */ .Z.on.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const off = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].off.bind */ .Z.off.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);
const emit = _default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"].emit.bind */ .Z.emit.bind(_default_i18n__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);

/***/ }),

/***/ 10003:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ number_format; }
/* harmony export */ });
/*
 * Exposes number format capability
 *
 * @copyright Copyright (c) 2013 Kevin van Zonneveld (http://kvz.io) and Contributors (http://phpjs.org/authors).
 * @license See CREDITS.md
 * @see https://github.com/kvz/phpjs/blob/ffe1356af23a6f2512c84c954dd4e828e92579fa/functions/strings/number_format.js
 */
function toFixedFix(n, prec) {
  const k = Math.pow(10, prec);
  return '' + (Math.round(n * k) / k).toFixed(prec);
}

function number_format(number, decimals, dec_point, thousands_sep) {
  number = (number + '').replace(/[^0-9+\-Ee.]/g, '');
  const n = !isFinite(+number) ? 0 : +number;
  const prec = !isFinite(+decimals) ? 0 : Math.abs(decimals);
  const sep = typeof thousands_sep === 'undefined' ? ',' : thousands_sep;
  const dec = typeof dec_point === 'undefined' ? '.' : dec_point;
  let s = ''; // Fix for IE parseFloat(0.55).toFixed(0) = 0;

  s = (prec ? toFixedFix(n, prec) : '' + Math.round(n)).split('.');

  if (s[0].length > 3) {
    s[0] = s[0].replace(/\B(?=(?:\d{3})+(?!\d))/g, sep);
  }

  if ((s[1] || '').length < prec) {
    s[1] = s[1] || '';
    s[1] += new Array(prec - s[1].length + 1).join('0');
  }

  return s.join(dec);
}

/***/ }),

/***/ 18373:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "V": function() { return /* binding */ useRtl; }
/* harmony export */ });
/* unused harmony export withRtl */
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(7896);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_compose__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(94333);
/* harmony import */ var _wordpress_compose__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_compose__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var use_subscription__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(36718);
/* harmony import */ var _context__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(8057);






function useRtl() {
  const i18n = (0,react__WEBPACK_IMPORTED_MODULE_2__.useContext)(_context__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z); // Subscription object (adapter) for the `useSubscription` hook

  const RtlSubscription = (0,react__WEBPACK_IMPORTED_MODULE_2__.useMemo)(() => ({
    getCurrentValue() {
      return i18n.isRtl();
    },

    subscribe(callback) {
      i18n.on('change', callback);
      return () => i18n.off('change', callback);
    }

  }), [i18n]);
  return (0,use_subscription__WEBPACK_IMPORTED_MODULE_3__.useSubscription)(RtlSubscription);
}
const withRtl = (0,_wordpress_compose__WEBPACK_IMPORTED_MODULE_1__.createHigherOrderComponent)(WrappedComponent => /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_2__.forwardRef)((props, ref) => {
  const isRtl = useRtl();
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(WrappedComponent, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z)({}, props, {
    isRtl: isRtl,
    ref: ref
  }));
}), 'WithRTL');

/***/ }),

/***/ 10975:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ useTranslate; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _context__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(8057);



function bindTranslate(i18n) {
  const translate = i18n.translate.bind(i18n);
  Object.defineProperty(translate, 'localeSlug', {
    get: i18n.getLocaleSlug.bind(i18n)
  });
  return translate;
}

function useTranslate() {
  const i18n = (0,react__WEBPACK_IMPORTED_MODULE_0__.useContext)(_context__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z);
  const [counter, setCounter] = (0,react__WEBPACK_IMPORTED_MODULE_0__.useState)(0);
  (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    const onChange = () => setCounter(c => c + 1);

    i18n.on('change', onChange);
    return () => i18n.off('change', onChange);
  }, [i18n]);
  return (0,react__WEBPACK_IMPORTED_MODULE_0__.useMemo)(() => bindTranslate(i18n, counter), [i18n, counter]);
}

/***/ }),

/***/ 30849:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Iw": function() { return /* binding */ LocaleProvider; },
/* harmony export */   "bU": function() { return /* binding */ useLocale; }
/* harmony export */ });
/* unused harmony exports localeContext, withLocale, useIsEnglishLocale */
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_compose__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(94333);
/* harmony import */ var _wordpress_compose__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_compose__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(65736);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);






const localeContext = /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_3__.createContext)(null);
const LocaleProvider = _ref => {
  let {
    children,
    localeSlug
  } = _ref;
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(localeContext.Provider, {
    value: localeSlug
  }, children);
};
/**
 * Returns locale slug
 *
 * @param {string} locale locale to be converted e.g. "en_US".
 * @returns locale string e.g. "en"
 */

function mapWpI18nLangToLocaleSlug() {
  let locale = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

  if (!locale) {
    return '';
  }

  const TARGET_LOCALES = ['pt_br', 'pt-br', 'zh_tw', 'zh-tw', 'zh_cn', 'zh-cn', 'zh_sg', 'zh-sg'];
  const lowerCaseLocale = locale.toLowerCase();
  const formattedLocale = TARGET_LOCALES.includes(lowerCaseLocale) ? lowerCaseLocale.replace('_', '-') : lowerCaseLocale.replace(/([-_].*)$/i, '');
  return formattedLocale || 'en';
}
/**
 * Get the current locale slug from the @wordpress/i18n locale data
 */


function getWpI18nLocaleSlug() {
  var _i18n$getLocaleData, _i18n$getLocaleData$;

  const language = _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__.getLocaleData ? (_i18n$getLocaleData = _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__.getLocaleData()) === null || _i18n$getLocaleData === void 0 ? void 0 : (_i18n$getLocaleData$ = _i18n$getLocaleData['']) === null || _i18n$getLocaleData$ === void 0 ? void 0 : _i18n$getLocaleData$.language : '';
  return mapWpI18nLangToLocaleSlug(language);
}
/**
 * React hook providing the current locale slug. If `<LocaleProvider>` hasn't
 * been defined in the component tree then it will fall back to using the
 * data from `@wordpress/i18n` to determine the current locale slug.
 *
 * @example
 *
 * import { useLocale } from '@automattic/i18n-utils';
 * function MyComponent() {
 *   const locale = useLocale();
 *   return <div>The current locale is: { locale }</div>;
 * }
 */


function useLocale() {
  var _window;

  const fromProvider = (0,react__WEBPACK_IMPORTED_MODULE_3__.useContext)(localeContext);
  const providerHasLocale = !!fromProvider;
  const [fromWpI18n, setWpLocale] = (0,react__WEBPACK_IMPORTED_MODULE_3__.useState)(getWpI18nLocaleSlug());
  (0,react__WEBPACK_IMPORTED_MODULE_3__.useEffect)(() => {
    // If the <LocaleProvider> has been used further up the component tree
    // then we don't want to subscribe to any defaultI18n changes.
    if (providerHasLocale) {
      return;
    }

    setWpLocale(getWpI18nLocaleSlug());
    return _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__.subscribe(() => {
      setWpLocale(getWpI18nLocaleSlug());
    });
  }, [providerHasLocale]);
  return fromProvider || fromWpI18n || ((_window = window) === null || _window === void 0 ? void 0 : _window._currentUserLocale) || 'en';
}
/**
 * HoC providing the current locale slug supplied to `<LocaleProvider>`.
 *
 * @param InnerComponent Component that will receive `locale` as a prop
 * @returns Component enhanced with locale
 * @example
 *
 * import { withLocale } from '@automattic/i18n-utils';
 * function MyComponent( { locale } ) {
 *   return <div>The current locale is: { locale }</div>;
 * }
 * export default withLocale( MyComponent );
 */

const withLocale = (0,_wordpress_compose__WEBPACK_IMPORTED_MODULE_1__.createHigherOrderComponent)(InnerComponent => {
  return props => {
    const locale = useLocale();
    const innerProps = { ...props,
      locale
    };
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(InnerComponent, innerProps);
  };
}, 'withLocale');
/**
 * React hook providing whether the current locale slug belongs to English or not
 *
 * @example
 *
 * import { useIsEnglishLocale } from '@automattic/i18n-utils';
 * function MyComponent() {
 *   const isEnglishLocale = useIsEnglishLocale();
 *   return <div>The current locale is English: { isEnglishLocale }</div>;
 * }
 */

function useIsEnglishLocale() {
  const locale = useLocale();
  return englishLocales.includes(locale);
}

/***/ }),

/***/ 94655:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "GG": function() { return /* binding */ localesWithBlog; },
/* harmony export */   "iT": function() { return /* binding */ localesWithPrivacyPolicy; },
/* harmony export */   "xn": function() { return /* binding */ localesWithCookiePolicy; },
/* harmony export */   "Xb": function() { return /* binding */ localesToSubdomains; },
/* harmony export */   "hI": function() { return /* binding */ supportSiteLocales; },
/* harmony export */   "mL": function() { return /* binding */ forumLocales; },
/* harmony export */   "vS": function() { return /* binding */ magnificentNonEnLocales; },
/* harmony export */   "_r": function() { return /* binding */ jetpackComLocales; }
/* harmony export */ });
/* unused harmony exports i18nDefaultLocaleSlug, englishLocales, livechatSupportLocales */
/**
 * The locale sets here map roughly to those found in locales.php
 *
 * todo: move these into @automattic/languages as another downloaded resource
 * todo: cleanup _shared.json - replace references to the below config options with imports from here
 */
const i18nDefaultLocaleSlug = 'en';
const localesWithBlog = ['en', 'ja', 'es', 'pt', 'fr', 'pt-br'];
const localesWithPrivacyPolicy = ['en', 'fr', 'de', 'es'];
const localesWithCookiePolicy = ['en', 'fr', 'de', 'es'];
const localesToSubdomains = {
  'pt-br': 'br',
  br: 'bre',
  zh: 'zh-cn',
  'zh-hk': 'zh-tw',
  'zh-sg': 'zh-cn',
  kr: 'ko'
}; // replaces config( 'english_locales' )

const englishLocales = (/* unused pure expression or super */ null && (['en', 'en-gb'])); // replaces config( 'livechat_support_locales' )

const livechatSupportLocales = (/* unused pure expression or super */ null && (['en'])); // replaces config( 'support_site_locales' )

const supportSiteLocales = ['ar', 'de', 'en', 'es', 'fr', 'he', 'id', 'it', 'ja', 'ko', 'nl', 'pt-br', 'ru', 'sv', 'tr', 'zh-cn', 'zh-tw']; // replaces config( 'forum_locales')

const forumLocales = ['ar', 'de', 'el', 'en', 'es', 'fa', 'fi', 'fr', 'id', 'it', 'ja', 'nl', 'pt', 'pt-br', 'ru', 'sv', 'th', 'tl', 'tr']; // replaces config( 'magnificent_non_en_locales')

const magnificentNonEnLocales = ['es', 'pt-br', 'de', 'fr', 'he', 'ja', 'it', 'nl', 'ru', 'tr', 'id', 'zh-cn', 'zh-tw', 'ko', 'ar', 'sv']; // replaces config( 'jetpack_com_locales')

const jetpackComLocales = ['en', 'ar', 'de', 'es', 'fr', 'he', 'id', 'it', 'ja', 'ko', 'nl', 'pt-br', 'ro', 'ru', 'sv', 'tr', 'zh-cn', 'zh-tw'];

/***/ }),

/***/ 47498:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "aq": function() { return /* binding */ localizeUrl; }
/* harmony export */ });
/* unused harmony exports useLocalizeUrl, withLocalizeUrl */
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_compose__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(94333);
/* harmony import */ var _wordpress_compose__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_compose__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var i18n_calypso__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(11481);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _locale_context__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(30849);
/* harmony import */ var _locales__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(94655);






const INVALID_URL = `http://__domain__.invalid`;

function getDefaultLocale() {
  return (i18n_calypso__WEBPACK_IMPORTED_MODULE_3__/* .getLocaleSlug */ .Yj === null || i18n_calypso__WEBPACK_IMPORTED_MODULE_3__/* .getLocaleSlug */ .Yj === void 0 ? void 0 : (0,i18n_calypso__WEBPACK_IMPORTED_MODULE_3__/* .getLocaleSlug */ .Yj)()) ?? 'en';
}

const setLocalizedUrlHost = function (hostname) {
  let validLocales = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  return (url, locale) => {
    if (validLocales.includes(locale) && locale !== 'en') {
      // Avoid changing the hostname when the locale is set via the path.
      if (url.pathname.substr(0, locale.length + 2) !== '/' + locale + '/') {
        url.host = `${_locales__WEBPACK_IMPORTED_MODULE_4__/* .localesToSubdomains */ .Xb[locale] || locale}.${hostname}`;
      }
    }

    return url;
  };
};

const setLocalizedWpComPath = function (prefix) {
  let validLocales = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : [];
  let limitPathMatch = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
  return (url, localeSlug) => {
    url.host = 'wordpress.com';

    if (typeof limitPathMatch === 'object' && limitPathMatch instanceof RegExp && !limitPathMatch.test(url.pathname)) {
      validLocales = []; // only rewrite to English.
    }

    url.pathname = prefix + url.pathname;

    if (validLocales.includes(localeSlug) && localeSlug !== 'en') {
      url.pathname = localeSlug + url.pathname;
    }

    return url;
  };
};

const prefixOrSuffixLocalizedUrlPath = function () {
  let validLocales = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  let limitPathMatch = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  let prefixOrSuffix = arguments.length > 2 ? arguments[2] : undefined;
  return (url, localeSlug) => {
    if (typeof limitPathMatch === 'object' && limitPathMatch instanceof RegExp) {
      if (!limitPathMatch.test(url.pathname)) {
        return url; // No rewriting if not matches the path.
      }
    }

    if (!validLocales.includes(localeSlug) || localeSlug === 'en') {
      return url;
    }

    if (prefixOrSuffix === 'prefix') {
      url.pathname = localeSlug + url.pathname;
    } else if (prefixOrSuffix === 'suffix') {
      // Make sure there's a slash between the path and the locale. Plus, if
      // the path has a trailing slash, add one after the suffix too.
      if (url.pathname.endsWith('/')) {
        url.pathname += localeSlug + '/';
      } else {
        url.pathname += '/' + localeSlug;
      }
    }

    return url;
  };
};

const prefixLocalizedUrlPath = function () {
  let validLocales = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  let limitPathMatch = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  return (url, localeSlug) => {
    return prefixOrSuffixLocalizedUrlPath(validLocales, limitPathMatch, 'prefix')(url, localeSlug);
  };
};

const suffixLocalizedUrlPath = function () {
  let validLocales = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  let limitPathMatch = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  return (url, localeSlug) => {
    return prefixOrSuffixLocalizedUrlPath(validLocales, limitPathMatch, 'suffix')(url, localeSlug);
  };
};

const urlLocalizationMapping = {
  'wordpress.com/support/': prefixLocalizedUrlPath(_locales__WEBPACK_IMPORTED_MODULE_4__/* .supportSiteLocales */ .hI),
  'wordpress.com/forums/': prefixLocalizedUrlPath(_locales__WEBPACK_IMPORTED_MODULE_4__/* .forumLocales */ .mL),
  'wordpress.com/blog/': prefixLocalizedUrlPath(_locales__WEBPACK_IMPORTED_MODULE_4__/* .localesWithBlog */ .GG, /^\/blog\/?$/),
  'wordpress.com/tos/': prefixLocalizedUrlPath(_locales__WEBPACK_IMPORTED_MODULE_4__/* .magnificentNonEnLocales */ .vS),
  'wordpress.com/wp-admin/': setLocalizedUrlHost('wordpress.com', _locales__WEBPACK_IMPORTED_MODULE_4__/* .magnificentNonEnLocales */ .vS),
  'wordpress.com/wp-login.php': setLocalizedUrlHost('wordpress.com', _locales__WEBPACK_IMPORTED_MODULE_4__/* .magnificentNonEnLocales */ .vS),
  'jetpack.com': setLocalizedUrlHost('jetpack.com', _locales__WEBPACK_IMPORTED_MODULE_4__/* .jetpackComLocales */ ._r),
  'en.support.wordpress.com': setLocalizedWpComPath('/support', _locales__WEBPACK_IMPORTED_MODULE_4__/* .supportSiteLocales */ .hI),
  'en.blog.wordpress.com': setLocalizedWpComPath('/blog', _locales__WEBPACK_IMPORTED_MODULE_4__/* .localesWithBlog */ .GG, /^\/$/),
  'apps.wordpress.com': prefixLocalizedUrlPath(_locales__WEBPACK_IMPORTED_MODULE_4__/* .magnificentNonEnLocales */ .vS),
  'en.forums.wordpress.com': setLocalizedWpComPath('/forums', _locales__WEBPACK_IMPORTED_MODULE_4__/* .forumLocales */ .mL),
  'automattic.com/privacy/': prefixLocalizedUrlPath(_locales__WEBPACK_IMPORTED_MODULE_4__/* .localesWithPrivacyPolicy */ .iT),
  'automattic.com/cookies/': prefixLocalizedUrlPath(_locales__WEBPACK_IMPORTED_MODULE_4__/* .localesWithCookiePolicy */ .xn),
  'wordpress.com/help/contact/': (url, localeSlug, isLoggedIn) => {
    if (isLoggedIn) {
      return url;
    }

    url.pathname = url.pathname.replace(/\/help\//, '/support/');
    return prefixLocalizedUrlPath(_locales__WEBPACK_IMPORTED_MODULE_4__/* .supportSiteLocales */ .hI)(url, localeSlug);
  },
  'wordpress.com': (url, localeSlug) => {
    // Don't rewrite checkout and me URLs.
    if (/^\/(checkout|me)(\/|$)/.test(url.pathname)) {
      return url;
    } // Don't rewrite Calypso URLs that have the URL at the end.


    if (/\/([a-z0-9-]+\.)+[a-z]{2,}\/?$/.test(url.pathname)) {
      return url;
    }

    return prefixLocalizedUrlPath(_locales__WEBPACK_IMPORTED_MODULE_4__/* .magnificentNonEnLocales */ .vS)(url, localeSlug);
  },
  'wordpress.com/theme/': (url, localeSlug, isLoggedIn) => {
    return isLoggedIn ? url : prefixLocalizedUrlPath(_locales__WEBPACK_IMPORTED_MODULE_4__/* .magnificentNonEnLocales */ .vS)(url, localeSlug);
  },
  'wordpress.com/themes/': (url, localeSlug, isLoggedIn) => {
    return isLoggedIn ? url : prefixLocalizedUrlPath(_locales__WEBPACK_IMPORTED_MODULE_4__/* .magnificentNonEnLocales */ .vS)(url, localeSlug);
  },
  'wordpress.com/log-in/': (url, localeSlug, isLoggedIn) => {
    return isLoggedIn ? url : suffixLocalizedUrlPath(_locales__WEBPACK_IMPORTED_MODULE_4__/* .magnificentNonEnLocales */ .vS)(url, localeSlug);
  }
};
function localizeUrl(fullUrl) {
  let locale = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : getDefaultLocale();
  let isLoggedIn = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : true;
  let url;

  try {
    url = new URL(String(fullUrl), INVALID_URL);
  } catch (e) {
    return fullUrl;
  } // Ignore and passthrough /relative/urls that have no host specified


  if (url.origin === INVALID_URL) {
    return fullUrl;
  } // Let's unify the URL.


  url.protocol = 'https:'; // Let's use `host` for everything.

  url.hostname = '';

  if (!url.pathname.endsWith('.php')) {
    // Essentially a trailingslashit.
    url.pathname = (url.pathname + '/').replace(/\/+$/, '/');
  }

  const firstPathSegment = url.pathname.substr(0, 1 + url.pathname.indexOf('/', 1));

  if ('en.wordpress.com' === url.host) {
    url.host = 'wordpress.com';
  }

  if ('/' + locale + '/' === firstPathSegment) {
    return fullUrl;
  } // Lookup is checked back to front.


  const lookup = [url.host, url.host + firstPathSegment, url.host + url.pathname];

  for (let i = lookup.length - 1; i >= 0; i--) {
    if (lookup[i] in urlLocalizationMapping) {
      return urlLocalizationMapping[lookup[i]](url, locale, isLoggedIn).href;
    }
  } // Nothing needed to be changed, just return it unmodified.


  return fullUrl;
}
function useLocalizeUrl() {
  const providerLocale = (0,_locale_context__WEBPACK_IMPORTED_MODULE_5__/* .useLocale */ .bU)();
  return (0,react__WEBPACK_IMPORTED_MODULE_2__.useCallback)((fullUrl, locale, isLoggedIn) => {
    if (locale) {
      return localizeUrl(fullUrl, locale, isLoggedIn);
    }

    return localizeUrl(fullUrl, providerLocale, isLoggedIn);
  }, [providerLocale]);
}
const withLocalizeUrl = (0,_wordpress_compose__WEBPACK_IMPORTED_MODULE_1__.createHigherOrderComponent)(InnerComponent => {
  return props => {
    const localizeUrl = useLocalizeUrl();
    const innerProps = { ...props,
      localizeUrl
    };
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(InnerComponent, innerProps);
  };
}, 'withLocalizeUrl');

/***/ }),

/***/ 6339:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "TF": function() { return /* binding */ isDefaultLocale; }
/* harmony export */ });
/* unused harmony exports getPathParts, isLocaleVariant, isLocaleRtl, canBeTranslated, translationExists, getLanguageSlugs, getMappedLanguageSlug, getLanguageRouteParam, getLanguage, getLocaleFromPath, addLocaleToPath, removeLocaleFromPath, filterLanguageRevisions, isMagnificentLocale, isTranslatedIncompletely */
/* harmony import */ var _automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(20899);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_1__);





/**
 * a locale can consist of three component
 * aa: language code
 * -bb: regional code
 * _cc: variant suffix
 * while the language code is mandatory, the other two are optional.
 */

const localeRegex = /^[A-Z]{2,3}(-[A-Z]{2,3})?(_[A-Z]{2,6})?$/i;
function getPathParts(path) {
  // Remove trailing slash then split. If there is a trailing slash,
  // then the end of the array could contain an empty string.
  return path.replace(/\/$/, '').split('/');
}
/**
 * Checks if provided locale is a default one.
 *
 * @param {string} locale - locale slug (eg: 'fr')
 * @returns {boolean} true when the default locale is provided
 */

function isDefaultLocale(locale) {
  return locale === (0,_automattic_calypso_config__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .ZP)('i18n_default_locale_slug');
}
/**
 * Checks if provided locale has a parentLangSlug and is therefore a locale variant
 *
 * @param {string} locale - locale slug (eg: 'fr')
 * @returns {boolean} true when the locale has a parentLangSlug
 */

function isLocaleVariant(locale) {
  if (typeof locale !== 'string') {
    return false;
  }

  const language = getLanguage(locale);
  return !!language && typeof language.parentLangSlug === 'string';
}
function isLocaleRtl(locale) {
  if (typeof locale !== 'string') {
    return null;
  }

  const language = getLanguage(locale);

  if (!language) {
    return null;
  }

  return Boolean(language.rtl);
}
/**
 * Checks against a list of locales that don't have any GP translation sets
 * A 'translation set' refers to a collection of strings to be translated see:
 * https://glotpress.blog/the-manual/translation-sets/
 *
 * @param {string} locale - locale slug (eg: 'fr')
 * @returns {boolean} true when the locale is NOT a member of the exception list
 */

function canBeTranslated(locale) {
  return ['en', 'sr_latin'].indexOf(locale) === -1;
}
/**
 * To be used with the same parameters as i18n-calpyso's translate():
 * Check whether the user would be exposed to text not in their language.
 *
 * Since the text is in English, this is always true in that case. Otherwise
 * We check whether a translation was provided for this text.
 *
 * @returns {boolean} true when a user would see text they can read.
 */

function translationExists(phrase) {
  const localeSlug = typeof getLocaleSlug === 'function' ? getLocaleSlug() : 'en';
  return isDefaultLocale(localeSlug) || i18n.hasTranslation(phrase);
}
/**
 * Return a list of all supported language slugs
 *
 * @returns {Array} A list of all supported language slugs
 */

function getLanguageSlugs() {
  return map(languages, 'langSlug');
}
/**
 * Map provided language slug to supported slug if applicable.
 *
 * @param {string} langSlug Locale slug for the language
 * @returns {string} Mapped language slug
 */

function getMappedLanguageSlug(langSlug) {
  // See pxLjZ-6UQ-p2 for details.
  if (langSlug === 'no') {
    return 'nb';
  }

  return langSlug;
}
/**
 * Return a specifier for page.js/Express route param that enumerates all supported languages.
 *
 * @param {string} name of the parameter. By default it's `lang`, some routes use `locale`.
 * @param {boolean} optional whether to put the `?` character at the end, making the param optional
 * @returns {string} Router param specifier that looks like `:lang(cs|de|fr|pl)`
 */

function getLanguageRouteParam() {
  let name = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'lang';
  let optional = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;
  return `:${name}(${getLanguageSlugs().join('|')})${optional ? '?' : ''}`;
}
/**
 * Matches and returns language from config.languages based on the given localeSlug
 *
 * @param   {string} langSlug locale slug of the language to match
 * @returns {object|undefined} An object containing the locale data or undefined.
 */

function getLanguage(langSlug) {
  langSlug = getMappedLanguageSlug(langSlug);

  if (langSlug && localeRegex.test(langSlug)) {
    // Find for the langSlug first. If we can't find it, split it and find its parent slug.
    // Please see the comment above `localeRegex` to see why we can split by - or _ and find the parent slug.
    return find(languages, {
      langSlug
    }) || find(languages, {
      langSlug: langSlug.split(/[-_]/)[0]
    });
  }

  return undefined;
}
/**
 * Assuming that locale is adding at the end of path, retrieves the locale if present.
 *
 * @param {string} path - original path
 * @returns {string|undefined} The locale slug if present or undefined
 */

function getLocaleFromPath(path) {
  const urlParts = getUrlParts(path);
  const locale = getPathParts(urlParts.pathname).pop();
  return 'undefined' === typeof getLanguage(locale) ? undefined : locale;
}
/**
 * Adds a locale slug to the current path.
 *
 * Will replace existing locale slug, if present.
 *
 * @param path - original path
 * @param locale - locale slug (eg: 'fr')
 * @returns original path with new locale slug
 */

function addLocaleToPath(path, locale) {
  const urlParts = getUrlParts(path);
  const queryString = urlParts.search || '';
  return removeLocaleFromPath(urlParts.pathname) + `/${locale}` + queryString;
}
/**
 * Removes the trailing locale slug from the path, if it is present.
 * '/start/en' => '/start', '/start' => '/start', '/start/flow/fr' => '/start/flow', '/start/flow' => '/start/flow'
 *
 * @param  path - original path
 * @returns original path minus locale slug
 */

function removeLocaleFromPath(path) {
  const urlParts = getUrlParts(path);
  const queryString = urlParts.search || '';
  const parts = getPathParts(urlParts.pathname);
  const locale = parts.pop();

  if ('undefined' === typeof getLanguage(locale)) {
    parts.push(locale);
  }

  return parts.join('/') + queryString;
}
/**
 * Filter out unexpected values from the given language revisions object.
 *
 * @param {object} languageRevisions A candidate language revisions object for filtering.
 * @returns {object} A valid language revisions object derived from the given one.
 */

function filterLanguageRevisions(languageRevisions) {
  const langSlugs = getLanguageSlugs(); // Since there is no strong guarantee that the passed-in revisions map will have the identical set of languages as we define in calypso,
  // simply filtering against what we have here should be sufficient.

  return pickBy(languageRevisions, (revision, slug) => {
    if (typeof revision !== 'number') {
      return false;
    }

    if (!includes(langSlugs, slug)) {
      return false;
    }

    return true;
  });
}
/**
 * Checks if provided locale is one of the magnificenet non-english locales.
 *
 * @param locale Locale slug
 * @returns true when provided magnificent non-english locale.
 */

function isMagnificentLocale(locale) {
  return config('magnificent_non_en_locales').includes(locale);
}
/**
 * Checks if provided locale is translated incompletely (is missing essential translations).
 *
 * @param   {string}  locale Locale slug
 * @returns {boolean} Whether provided locale is flagged as translated incompletely.
 */

function isTranslatedIncompletely(locale) {
  var _getLanguage;

  return ((_getLanguage = getLanguage(locale)) === null || _getLanguage === void 0 ? void 0 : _getLanguage.isTranslatedIncompletely) === true;
}

/***/ }),

/***/ 32594:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ interpolate; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _tokenize__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(1310);



function getCloseIndex(openIndex, tokens) {
  const openToken = tokens[openIndex];
  let nestLevel = 0;

  for (let i = openIndex + 1; i < tokens.length; i++) {
    const token = tokens[i];

    if (token.value === openToken.value) {
      if (token.type === 'componentOpen') {
        nestLevel++;
        continue;
      }

      if (token.type === 'componentClose') {
        if (nestLevel === 0) {
          return i;
        }

        nestLevel--;
      }
    }
  } // if we get this far, there was no matching close token


  throw new Error('Missing closing component token `' + openToken.value + '`');
}

function buildChildren(tokens, components) {
  let children = [];
  let openComponent;
  let openIndex;

  for (let i = 0; i < tokens.length; i++) {
    const token = tokens[i];

    if (token.type === 'string') {
      children.push(token.value);
      continue;
    } // component node should at least be set


    if (components[token.value] === undefined) {
      throw new Error(`Invalid interpolation, missing component node: \`${token.value}\``);
    } // should be either ReactElement or null (both type "object"), all other types deprecated


    if (typeof components[token.value] !== 'object') {
      throw new Error(`Invalid interpolation, component node must be a ReactElement or null: \`${token.value}\``);
    } // we should never see a componentClose token in this loop


    if (token.type === 'componentClose') {
      throw new Error(`Missing opening component token: \`${token.value}\``);
    }

    if (token.type === 'componentOpen') {
      openComponent = components[token.value];
      openIndex = i;
      break;
    } // componentSelfClosing token


    children.push(components[token.value]);
    continue;
  }

  if (openComponent) {
    const closeIndex = getCloseIndex(openIndex, tokens);
    const grandChildTokens = tokens.slice(openIndex + 1, closeIndex);
    const grandChildren = buildChildren(grandChildTokens, components);
    const clonedOpenComponent = /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.cloneElement)(openComponent, {}, grandChildren);
    children.push(clonedOpenComponent);

    if (closeIndex < tokens.length - 1) {
      const siblingTokens = tokens.slice(closeIndex + 1);
      const siblings = buildChildren(siblingTokens, components);
      children = children.concat(siblings);
    }
  }

  children = children.filter(Boolean);

  if (children.length === 0) {
    return null;
  }

  if (children.length === 1) {
    return children[0];
  }

  return /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_0__.createElement)(react__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, ...children);
}

function interpolate(options) {
  const {
    mixedString,
    components,
    throwErrors
  } = options;

  if (!components) {
    return mixedString;
  }

  if (typeof components !== 'object') {
    if (throwErrors) {
      throw new Error(`Interpolation Error: unable to process \`${mixedString}\` because components is not an object`);
    }

    return mixedString;
  }

  const tokens = (0,_tokenize__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(mixedString);

  try {
    return buildChildren(tokens, components);
  } catch (error) {
    if (throwErrors) {
      throw new Error(`Interpolation Error: unable to process \`${mixedString}\` because of error \`${error.message}\``);
    }

    return mixedString;
  }
}

/***/ }),

/***/ 1310:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ tokenize; }
/* harmony export */ });
function identifyToken(item) {
  // {{/example}}
  if (item.startsWith('{{/')) {
    return {
      type: 'componentClose',
      value: item.replace(/\W/g, '')
    };
  } // {{example /}}


  if (item.endsWith('/}}')) {
    return {
      type: 'componentSelfClosing',
      value: item.replace(/\W/g, '')
    };
  } // {{example}}


  if (item.startsWith('{{')) {
    return {
      type: 'componentOpen',
      value: item.replace(/\W/g, '')
    };
  }

  return {
    type: 'string',
    value: item
  };
}

function tokenize(mixedString) {
  const tokenStrings = mixedString.split(/(\{\{\/?\s*\w+\s*\/?\}\})/g); // split to components and strings

  return tokenStrings.map(identifyToken);
}

/***/ }),

/***/ 83340:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "hg": function() { return /* binding */ isLoading; },
/* harmony export */   "lZ": function() { return /* binding */ addScriptCallback; },
/* harmony export */   "_W": function() { return /* binding */ handleRequestSuccess; },
/* harmony export */   "Yt": function() { return /* binding */ handleRequestError; }
/* harmony export */ });
/* unused harmony exports getCallbacksMap, removeScriptCallback, removeScriptCallbacks, removeAllScriptCallbacks, executeCallbacks */
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);

const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('lib/load-script/callback-handler');
/**
 * Module variables
 */

const callbacksForURLsInProgress = new Map();
function getCallbacksMap() {
  return callbacksForURLsInProgress;
}
function isLoading(url) {
  return getCallbacksMap().has(url);
}
function addScriptCallback(url, callback) {
  const callbacksMap = getCallbacksMap();

  if (isLoading(url)) {
    debug(`Adding a callback for an existing script from "${url}"`);
    callbacksMap.get(url).add(callback);
  } else {
    debug(`Adding a callback for a new script from "${url}"`);
    callbacksMap.set(url, new Set([callback]));
  }
}
function removeScriptCallback(url, callback) {
  debug(`Removing a known callback for a script from "${url}"`);

  if (!isLoading(url)) {
    return;
  }

  const callbacksMap = getCallbacksMap();
  const callbacksAtUrl = callbacksMap.get(url);
  callbacksAtUrl.delete(callback);

  if (callbacksAtUrl.size === 0) {
    callbacksMap.delete(url);
  }
}
function removeScriptCallbacks(url) {
  debug(`Removing all callbacks for a script from "${url}"`);
  getCallbacksMap().delete(url);
}
function removeAllScriptCallbacks() {
  debug('Removing all callbacks for scripts from all URLs');
  getCallbacksMap().clear();
}
function executeCallbacks(url) {
  let error = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
  const callbacksMap = getCallbacksMap();
  const callbacksForUrl = callbacksMap.get(url);

  if (callbacksForUrl) {
    const debugMessage = `Executing callbacks for "${url}"` + (error === null ? ' with success' : ` with error "${error}"`);
    debug(debugMessage);
    callbacksForUrl.forEach(cb => {
      if (typeof cb === 'function') {
        cb(error);
      }
    });
    callbacksMap.delete(url);
  }
}
function handleRequestSuccess() {
  const url = this.getAttribute('src');
  debug(`Handling successful request for "${url}"`);
  executeCallbacks(url);
  this.onload = null;
}
function handleRequestError() {
  const url = this.getAttribute('src');
  debug(`Handling failed request for "${url}"`);
  executeCallbacks(url, new Error(`Failed to load script "${url}"`));
  this.onerror = null;
}

/***/ }),

/***/ 55606:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "C": function() { return /* binding */ createScriptElement; },
/* harmony export */   "k": function() { return /* binding */ attachToHead; }
/* harmony export */ });
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _callback_handler__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(83340);


const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('lib/load-script/dom-operations');
function createScriptElement(url) {
  debug(`Creating script element for "${url}"`);
  const script = document.createElement('script');
  script.src = url;
  script.type = 'text/javascript';
  script.async = true;
  script.onload = _callback_handler__WEBPACK_IMPORTED_MODULE_1__/* .handleRequestSuccess */ ._W;
  script.onerror = _callback_handler__WEBPACK_IMPORTED_MODULE_1__/* .handleRequestError */ .Yt;
  return script;
}
function attachToHead(element) {
  debug('Attaching element to head');
  document.head.appendChild(element);
}

/***/ }),

/***/ 84898:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "ve": function() { return /* binding */ loadScript; },
/* harmony export */   "D1": function() { return /* binding */ loadjQueryDependentScript; }
/* harmony export */ });
/* unused harmony export JQUERY_URL */
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _callback_handler__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(83340);
/* harmony import */ var _dom_operations__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(55606);
/**
 * A little module for loading a external script
 *
 */



const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('package/load-script'); // NOTE: This exists for compatibility.


/**
 * Module variables
 */

const JQUERY_URL = 'https://s0.wp.com/wp-includes/js/jquery/jquery.js'; //
// loadScript and loadjQueryDependentScript
//

function loadScript(url, callback) {
  // If this script is not currently being loaded, create a script element and attach to document head.
  const shouldLoadScript = !(0,_callback_handler__WEBPACK_IMPORTED_MODULE_1__/* .isLoading */ .hg)(url);

  if (shouldLoadScript) {
    // the onload/onerror callbacks are guaranteed to be called asynchronously, so it's ok to first
    // add the element and only then attach callbacks, as long as it happens in one event loop tick.
    (0,_dom_operations__WEBPACK_IMPORTED_MODULE_2__/* .attachToHead */ .k)((0,_dom_operations__WEBPACK_IMPORTED_MODULE_2__/* .createScriptElement */ .C)(url));
  } // if callback is provided, behave traditionally


  if (typeof callback === 'function') {
    (0,_callback_handler__WEBPACK_IMPORTED_MODULE_1__/* .addScriptCallback */ .lZ)(url, callback);
    return;
  } // but if not, return a Promise


  return new Promise((resolve, reject) => {
    (0,_callback_handler__WEBPACK_IMPORTED_MODULE_1__/* .addScriptCallback */ .lZ)(url, error => {
      if (error === null) {
        resolve();
      } else {
        reject(error);
      }
    });
  });
}
function loadjQueryDependentScript(url, callback) {
  debug(`Loading a jQuery dependent script from "${url}"`);

  if (window.jQuery) {
    debug(`jQuery found on window, skipping jQuery script loading for "${url}"`);
    return loadScript(url, callback);
  }

  const loadPromise = loadScript(JQUERY_URL).then(() => loadScript(url)); // if callback is provided, call it on resolution

  if (typeof callback === 'function') {
    loadPromise.then(() => callback(null), error => callback(error));
    return;
  } // if not, return the Promise


  return loadPromise;
}

/***/ }),

/***/ 28636:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ photon; }
/* harmony export */ });
/* harmony import */ var crc32__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(74334);
/* harmony import */ var crc32__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(crc32__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var seed_random__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(10547);
/* harmony import */ var seed_random__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(seed_random__WEBPACK_IMPORTED_MODULE_2__);



const debug = debug__WEBPACK_IMPORTED_MODULE_1___default()('photon');
/**
 * Options argument to query string parameter mappings.
 */

const mappings = {
  width: 'w',
  height: 'h',
  letterboxing: 'lb',
  removeLetterboxing: 'ulb'
};
const PARSE_BASE_HOST = '__domain__.invalid';
const PARSE_BASE_URL = `https://${PARSE_BASE_HOST}`;
const PHOTON_BASE_URL = 'https://i0.wp.com';

/**
 * Returns a "photon" URL from the given image URL.
 *
 * Defaults to returning an `https:` secure URL from Photon.
 * Pass `secure: false` to get `http:`.
 *
 * Photon documentation: http://developer.wordpress.com/docs/photon/
 *
 * @param imageUrl - the URL of the image to run through Photon
 * @param [opts]   - optional options object with Photon options
 * @returns The generated Photon URL string
 */
function photon(imageUrl, opts) {
  let parsedUrl;

  try {
    parsedUrl = new URL(imageUrl, PARSE_BASE_URL);
  } catch {
    // Return null for invalid URLs.
    return null;
  }

  const wasSecure = parsedUrl.protocol === 'https:';
  const photonUrl = new URL(PHOTON_BASE_URL);

  if (isAlreadyPhotoned(parsedUrl.host)) {
    // We already have a server to use.
    // Use it, even if it doesn't match our hash.
    photonUrl.pathname = parsedUrl.pathname;
    photonUrl.hostname = wasSecure ? 'i0.wp.com' : parsedUrl.hostname;
  } else {
    // Photon does not support URLs with a querystring component
    if (parsedUrl.search) {
      return null;
    }

    let formattedUrl = parsedUrl.href.replace(`${parsedUrl.protocol}/`, ''); // Handle blob: protocol URLs.

    if (parsedUrl.protocol === 'blob:') {
      formattedUrl = parsedUrl.pathname.replace('://', '//');
    } // Handle path-absolute and path-relative URLs.


    if (parsedUrl.hostname === PARSE_BASE_HOST) {
      formattedUrl = parsedUrl.pathname;
    }

    photonUrl.pathname = formattedUrl;
    photonUrl.hostname = serverFromUrlParts(formattedUrl, photonUrl.protocol === 'https:');

    if (wasSecure) {
      photonUrl.searchParams.set('ssl', '1');
    }
  }

  if (opts) {
    for (const [opt, value] of Object.entries(opts)) {
      if (opt === 'host' || opt === 'hostname') {
        photonUrl.hostname = value;
        continue;
      }

      if (opt === 'secure' && !value) {
        photonUrl.protocol = 'http:';
        continue;
      }

      photonUrl.searchParams.set(mappings[opt] ?? opt, value.toString());
    }
  } // do this after so a passed opt can't override it


  debug('generated Photon URL: %s', photonUrl.href);
  return photonUrl.href;
}

function isAlreadyPhotoned(host) {
  return /^i[0-2]\.wp\.com$/.test(host);
}
/**
 * Determine which Photon server to connect to: `i0`, `i1`, or `i2`.
 *
 * Statically hash the subdomain based on the URL, to optimize browser caches.
 * Only use i0 when using photon over https, based on the assumption that https
 * maps to http/2 (or later)
 *
 * @param  {string} pathname The pathname to use
 * @param  {boolean} isSecure Whether we're constructing a HTTPS URL or a HTTP one
 * @returns {string}          The hostname for the pathname
 */


function serverFromUrlParts(pathname, isSecure) {
  if (isSecure) {
    return 'i0.wp.com';
  }

  const hash = crc32__WEBPACK_IMPORTED_MODULE_0___default()(pathname);
  const rng = seed_random__WEBPACK_IMPORTED_MODULE_2___default()(hash);
  const server = 'i' + Math.floor(rng() * 3);
  debug('determined server "%s" to use with "%s"', server, pathname);
  return server + '.wp.com';
}

/***/ }),

/***/ 67009:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "r": function() { return /* binding */ useArrowNavigation; }
/* harmony export */ });
/* harmony import */ var _wordpress_dom__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(45904);
/* harmony import */ var _wordpress_dom__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_dom__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_1__);


const useArrowNavigation = (enabled, element, open, onOpen) => {
  const handleTrapFocus = (0,react__WEBPACK_IMPORTED_MODULE_1__.useCallback)(event => {
    const focusableElements = element ? _wordpress_dom__WEBPACK_IMPORTED_MODULE_0__.focus.focusable.find(element) : [];
    let focusedIndex = focusableElements.findIndex(el => document.activeElement === el);
    focusedIndex = focusedIndex === -1 ? 0 : focusedIndex;

    if (event.key === 'ArrowUp') {
      var _focusableElements$in;

      let index = focusedIndex - 1;

      if (index < 0) {
        index = focusableElements.length - 1;
      }

      (_focusableElements$in = focusableElements[index]) === null || _focusableElements$in === void 0 ? void 0 : _focusableElements$in.focus();
    } else if (event.key === 'ArrowDown') {
      var _focusableElements$in2;

      const index = (focusedIndex + 1) % focusableElements.length;
      (_focusableElements$in2 = focusableElements[index]) === null || _focusableElements$in2 === void 0 ? void 0 : _focusableElements$in2.focus();

      if (!open) {
        onOpen();
      }
    }

    if (['ArrowUp', 'ArrowDown'].includes(event.key)) {
      event.preventDefault();
      event.stopPropagation();
    }
  }, [element, open, onOpen]);
  (0,react__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    if (enabled) {
      document.addEventListener('keydown', handleTrapFocus);
    }

    return () => {
      document.removeEventListener('keydown', handleTrapFocus);
    };
  }, [handleTrapFocus, enabled]);
};

/***/ }),

/***/ 1283:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "a": function() { return /* binding */ SitePickerDropDown; }
/* harmony export */ });
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_tour_kit__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(95386);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(65736);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(93519);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(5869);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(26715);
/* harmony import */ var _wordpress_icons__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(43383);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var _hooks__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(67009);
/* harmony import */ var _style_scss__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(19201);


/* eslint-disable wpcalypso/jsx-classname-namespace */


const __ = _wordpress_i18n__WEBPACK_IMPORTED_MODULE_1__.__;






const SiteLogo = _ref => {
  let {
    logo
  } = _ref;

  if (logo !== null && logo !== void 0 && logo.url) {
    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("img", {
      width: "34",
      alt: "",
      "aria-hidden": "true",
      src: logo === null || logo === void 0 ? void 0 : logo.url
    });
  }

  return _wordpress_icons__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z;
};

const SitePickerItem = _ref2 => {
  let {
    host,
    name,
    onClick,
    open,
    mainItem,
    selected,
    logo,
    id,
    enabled = true
  } = _ref2;
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("button", {
    className: classnames__WEBPACK_IMPORTED_MODULE_2___default()('site-picker__site-item', {
      'main-item': mainItem,
      selected,
      enabled
    }),
    onClick: onClick // eslint-disable-next-line jsx-a11y/no-autofocus
    ,
    autoFocus: selected,
    tabIndex: 0,
    id: id
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "site-picker__site-item-site-logo"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(SiteLogo, {
    logo: logo
  })), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "site-picker__site-info"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("h1", {
    className: "site-picker__site-title"
  }, name), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", {
    className: "site-picker__site-domain"
  }, host)), mainItem && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_icons__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, {
    icon: open ? _wordpress_icons__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z : _wordpress_icons__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z,
    width: "34"
  })));
};

const SitePickerDropDown = _ref3 => {
  var _selectedSite$URL, _selectedSite$URL2;

  let {
    siteId,
    options,
    onPickSite,
    enabled
  } = _ref3;
  const [ref, setRef] = (0,react__WEBPACK_IMPORTED_MODULE_3__.useState)(null);
  const [open, setOpen] = (0,react__WEBPACK_IMPORTED_MODULE_3__.useState)(false);
  (0,_automattic_tour_kit__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z)({
    current: ref
  });
  (0,_hooks__WEBPACK_IMPORTED_MODULE_10__/* .useArrowNavigation */ .r)(enabled, ref, open, () => setOpen(true));
  const selectedSite = options.find(s => (s === null || s === void 0 ? void 0 : s.ID) === siteId) || options[0]; // close on clicking outside

  (0,react__WEBPACK_IMPORTED_MODULE_3__.useEffect)(() => {
    function onClickOutside(event) {
      if (ref && !ref.contains(event.target)) {
        setOpen(false);
      }
    }

    if (open && enabled) {
      window.addEventListener('click', onClickOutside);
      return () => {
        window.removeEventListener('click', onClickOutside);
      };
    }
  }, [siteId, options, open, ref, enabled]);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Fragment, null, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("label", {
    className: "site-picker__label",
    htmlFor: "site-picker-button"
  }, enabled ? __('Select a site', "full-site-editing") : __('Site', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: classnames__WEBPACK_IMPORTED_MODULE_2___default()('site-picker__site-dropdown', {
      open
    })
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(SitePickerItem, {
    host: (selectedSite === null || selectedSite === void 0 ? void 0 : (_selectedSite$URL = selectedSite.URL) === null || _selectedSite$URL === void 0 ? void 0 : _selectedSite$URL.replace('https://', '')) ?? '',
    enabled: enabled,
    name: (selectedSite === null || selectedSite === void 0 ? void 0 : selectedSite.name) ?? ( // if site has no name, show URL
    selectedSite === null || selectedSite === void 0 ? void 0 : (_selectedSite$URL2 = selectedSite.URL) === null || _selectedSite$URL2 === void 0 ? void 0 : _selectedSite$URL2.replace('https://', '')) ?? __('Unknown site', "full-site-editing"),
    logo: selectedSite === null || selectedSite === void 0 ? void 0 : selectedSite.logo // mainItem implies showing the dropdown arrow, hide it when the picking feature is disabled
    ,
    mainItem: enabled,
    open: open,
    onClick: () => {
      if (enabled) {
        setOpen(o => !o);
      }
    },
    onKeyDown: event => {
      if (event.key === 'ArrowDown' && enabled) {
        setOpen(true);
      }
    },
    id: "site-picker-button"
  }), open && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    ref: r => r !== ref && setRef(r),
    className: "site-picker__site-drawer"
  }, options.map((option, index) => {
    var _option$URL;

    return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(SitePickerItem, {
      host: (option === null || option === void 0 ? void 0 : (_option$URL = option.URL) === null || _option$URL === void 0 ? void 0 : _option$URL.replace('https://', '')) ?? '',
      name: (option === null || option === void 0 ? void 0 : option.name) ?? '',
      open: open,
      logo: option === null || option === void 0 ? void 0 : option.logo,
      onClick: () => {
        if (option) {
          onPickSite(option === null || option === void 0 ? void 0 : option.ID);
          setOpen(false);
        }
      },
      selected: (option === null || option === void 0 ? void 0 : option.ID) === siteId,
      id: `site-picker-button-item-${index}`
    });
  }))));
};

/***/ }),

/***/ 19444:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ createSelector; }
/* harmony export */ });
/* harmony import */ var _wordpress_is_shallow_equal__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(49127);
/* harmony import */ var _wordpress_is_shallow_equal__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_is_shallow_equal__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_warning__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(12560);
/* harmony import */ var _wordpress_warning__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_warning__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_2__);



/**
 * Constants
 */

/**
 * Defines acceptable argument types for a memoized selector when using the
 * default cache key generating function.
 */

const VALID_ARG_TYPES = ['number', 'boolean', 'string'];

/**
 * Default behavior for determining whether current state differs from previous
 * state, which is the basis upon which memoize cache is cleared. Should return
 * a value or array of values to be shallowly compared for strict equality.
 *
 * @param state Current state object
 * @returns Value(s) to be shallow compared
 */
const DEFAULT_GET_DEPENDANTS = state => state;
/**
 * At runtime, assigns a function which returns a cache key for the memoized
 * selector function, given a state object and a variable set of arguments. In
 * development mode, this warns when the memoized selector is passed a complex
 * object argument, as these cannot be depended upon as reliable cache keys.
 */


const DEFAULT_GET_CACHE_KEY = (() => {
  if (true) {
    return function (_) {
      for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      return args.join();
    };
  }

  return function (_) {
    for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
      args[_key2 - 1] = arguments[_key2];
    }

    const hasInvalidArg = args.some(arg => {
      return arg && !VALID_ARG_TYPES.includes(typeof arg);
    });

    if (hasInvalidArg) {
      _wordpress_warning__WEBPACK_IMPORTED_MODULE_1___default()('Do not pass complex objects as arguments for a memoized selector');
    }

    return args.join();
  };
})();
/**
 * Given an array of getDependants functions, returns a single function which,
 * when called, returns an array of mapped results from those functions.
 *
 * @param dependants Array of getDependants
 * @returns Function mapping getDependants results
 */


const makeSelectorFromArray = dependants => function (state) {
  for (var _len3 = arguments.length, args = new Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {
    args[_key3 - 1] = arguments[_key3];
  }

  return dependants.map(dependant => dependant(state, ...args));
};
/**
 * Returns a memoized state selector for use with the global application state.
 *
 * @param selector      Function calculating cached result
 * @param getDependants Function(s) describing dependent
 *                                             state, or an array of dependent
 *                                             state selectors
 * @param getCacheKey   Function generating cache key
 * @returns Memoized selector
 */


function createSelector(selector) {
  let getDependants = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : DEFAULT_GET_DEPENDANTS;
  let getCacheKey = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : DEFAULT_GET_CACHE_KEY;
  const memoizedSelector = (0,lodash__WEBPACK_IMPORTED_MODULE_2__.memoize)(selector, getCacheKey);
  let lastDependants;
  const getDependantsFn = typeof getDependants === 'function' ? getDependants : makeSelectorFromArray(getDependants);
  return Object.assign(function (state) {
    for (var _len4 = arguments.length, args = new Array(_len4 > 1 ? _len4 - 1 : 0), _key4 = 1; _key4 < _len4; _key4++) {
      args[_key4 - 1] = arguments[_key4];
    }

    let currentDependants = getDependantsFn(state, ...args);

    if (!Array.isArray(currentDependants)) {
      currentDependants = [currentDependants];
    }

    if (lastDependants && !_wordpress_is_shallow_equal__WEBPACK_IMPORTED_MODULE_0___default()(currentDependants, lastDependants)) {
      var _memoizedSelector$cac, _memoizedSelector$cac2;

      (_memoizedSelector$cac = (_memoizedSelector$cac2 = memoizedSelector.cache).clear) === null || _memoizedSelector$cac === void 0 ? void 0 : _memoizedSelector$cac.call(_memoizedSelector$cac2);
    }

    lastDependants = currentDependants;
    return memoizedSelector(state, ...args);
  }, {
    memoizedSelector
  });
}

/***/ }),

/***/ 49931:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(92819);
/* harmony import */ var lodash__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(lodash__WEBPACK_IMPORTED_MODULE_0__);


function isThunk(action) {
  return 'function' === typeof action;
}
/**
 * Given an action object or thunk, returns an updated object or thunk which
 * will include additional data in the action (as provided) when dispatched.
 *
 * @see 'client/state/utils/with-enhancers' for a more advanced alternative
 *
 * @param action Action object or thunk
 * @param data   Additional data to include in action
 * @returns Augmented action object or thunk
 */


function extendAction(action) {
  let data = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  if (!isThunk(action)) {
    return (0,lodash__WEBPACK_IMPORTED_MODULE_0__.merge)({}, action, data);
  }

  return function (dispatch, getState) {
    const newDispatch = a => dispatch(extendAction(a, data));

    for (var _len = arguments.length, extraArgs = new Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
      extraArgs[_key - 2] = arguments[_key];
    }

    return action(newDispatch, getState, ...extraArgs);
  };
}

/* harmony default export */ __webpack_exports__["Z"] = (extendAction);

/***/ }),

/***/ 39542:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ getInitialState; }
/* harmony export */ });
function getInitialState(reducer) {
  return reducer(undefined, {
    type: '@@calypso/INIT'
  });
}

/***/ }),

/***/ 83685:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "P1": function() { return /* reexport safe */ _create_selector__WEBPACK_IMPORTED_MODULE_0__.Z; },
/* harmony export */   "zc": function() { return /* reexport safe */ _extend_action__WEBPACK_IMPORTED_MODULE_1__.Z; },
/* harmony export */   "aY": function() { return /* reexport safe */ _get_initial_state__WEBPACK_IMPORTED_MODULE_2__.Z; },
/* harmony export */   "xi": function() { return /* reexport safe */ _with_storage_key__WEBPACK_IMPORTED_MODULE_3__.Z; }
/* harmony export */ });
/* harmony import */ var _create_selector__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(19444);
/* harmony import */ var _extend_action__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(49931);
/* harmony import */ var _get_initial_state__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(39542);
/* harmony import */ var _with_storage_key__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(61261);





/***/ }),

/***/ 61261:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
const withStorageKey = (storageKey, reducer) => {
  reducer.storageKey = storageKey;
  return reducer;
};

/* harmony default export */ __webpack_exports__["Z"] = (withStorageKey);

/***/ }),

/***/ 95386:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_dom__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(45904);
/* harmony import */ var _wordpress_dom__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_dom__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_1__);
/**
 * External Dependencies
 */


/**
 * A hook that constraints tabbing/focus on focuable elements in the given element ref.
 *
 * @param ref React.MutableRefObject< null | HTMLElement >
 */

const useFocusTrap = ref => {
  const [firstFocusableElement, setFirstFocusableElement] = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_1__.useState)();
  const [lastFocusableElement, setLastFocusableElement] = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_1__.useState)();
  const handleTrapFocus = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_1__.useCallback)(event => {
    let handled = false;

    if (event.key === 'Tab') {
      if (event.shiftKey) {
        // Shift + Tab
        if (document.activeElement === firstFocusableElement) {
          lastFocusableElement === null || lastFocusableElement === void 0 ? void 0 : lastFocusableElement.focus();
          handled = true;
        }
      } else if (document.activeElement === lastFocusableElement) {
        // Tab
        firstFocusableElement === null || firstFocusableElement === void 0 ? void 0 : firstFocusableElement.focus();
        handled = true;
      }
    }

    if (handled) {
      event.preventDefault();
      event.stopPropagation();
    }
  }, [firstFocusableElement, lastFocusableElement]);
  (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_1__.useEffect)(() => {
    const focusableElements = ref.current ? _wordpress_dom__WEBPACK_IMPORTED_MODULE_0__.focus.focusable.find(ref.current) : [];

    if (focusableElements && focusableElements.length) {
      setFirstFocusableElement(focusableElements[0]);
      setLastFocusableElement(focusableElements[focusableElements.length - 1]);
    }

    document.addEventListener('keydown', handleTrapFocus);
    return () => {
      document.removeEventListener('keydown', handleTrapFocus);
    };
  }, [ref, handleTrapFocus]);
};

/* harmony default export */ __webpack_exports__["Z"] = (useFocusTrap);

/***/ }),

/***/ 56868:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ treeSelect; }
/* harmony export */ });
const defaultGetCacheKey = function () {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  return args.join();
};

const isFunction = fn => {
  return !!fn && typeof fn === 'function';
};

const isObject = o => {
  return !!o && typeof o === 'object';
};

/**
 * Returns a selector that caches values.
 *
 * @param getDependents A Function describing the dependent(s) of the selector.
 *                      Must return an array which gets passed as the first arg to the selector.
 * @param selector      A standard selector for calculating cached result.
 * @param options       Options bag with additional arguments.
 *
 * @returns Cached selector
 */
function treeSelect(getDependents, selector) {
  let options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};

  if (false) {}

  let cache = new WeakMap();
  const {
    getCacheKey = defaultGetCacheKey
  } = options;

  const cachedSelector = function (state) {
    for (var _len2 = arguments.length, args = new Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
      args[_key2 - 1] = arguments[_key2];
    }

    const dependents = getDependents(state, ...args);

    if (false) {} // create a dependency tree for caching selector results.
    // this is beneficial over standard memoization techniques so that we can
    // garbage collect any values that are based on outdated dependents


    const leafCache = dependents.reduce(insertDependentKey, cache);
    const key = getCacheKey(...args);

    if (leafCache.has(key)) {
      return leafCache.get(key);
    }

    const value = selector(dependents, ...args);
    leafCache.set(key, value);
    return value;
  };

  cachedSelector.clearCache = () => {
    // WeakMap doesn't have `clear` method, so we need to recreate it
    cache = new WeakMap();
  };

  return cachedSelector;
}
/*
 * This object will be used as a WeakMap key if a dependency is a falsy value (null, undefined, ...)
 */

const NULLISH_KEY = {};
/*
 * First tries to get the value for the key.
 * If the key is not present, then inserts a new map and returns it
 *
 * Note: Inserts WeakMaps except for the last map which will be a regular Map.
 * The last map is a regular one because the the key for the last map is the string results of args.join().
 */

function insertDependentKey(map, key, currentIndex, arr) {
  // eslint-disable-line @typescript-eslint/no-explicit-any
  if (key != null && Object(key) !== key) {
    throw new TypeError('key must be an object, `null`, or `undefined`');
  }

  const weakMapKey = key || NULLISH_KEY;
  const existingMap = map.get(weakMapKey);

  if (existingMap) {
    return existingMap;
  }

  const newMap = currentIndex === arr.length - 1 ? new Map() : new WeakMap();
  map.set(weakMapKey, newMap);
  return newMap;
}

/***/ }),

/***/ 76951:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "_z": function() { return /* binding */ useMobileBreakpoint; }
/* harmony export */ });
/* unused harmony exports useBreakpoint, useDesktopBreakpoint, withBreakpoint, withMobileBreakpoint, withDesktopBreakpoint */
/* harmony import */ var _babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(7896);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_viewport__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(79321);
/* harmony import */ var _wordpress_compose__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(94333);
/* harmony import */ var _wordpress_compose__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_compose__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_2__);





/**
 * React hook for getting the status for a breakpoint and keeping it updated.
 *
 * @param {string} breakpoint The breakpoint to consider.
 * @returns {boolean} The current status for the breakpoint.
 */

function useBreakpoint(breakpoint) {
  const [state, setState] = (0,react__WEBPACK_IMPORTED_MODULE_2__.useState)(() => ({
    isActive: (0,_automattic_viewport__WEBPACK_IMPORTED_MODULE_3__/* .isWithinBreakpoint */ .kV)(breakpoint),
    breakpoint
  }));
  (0,react__WEBPACK_IMPORTED_MODULE_2__.useEffect)(() => {
    function handleBreakpointChange(isActive) {
      setState(prevState => {
        // Ensure we bail out without rendering if nothing changes, by preserving state.
        if (prevState.isActive === isActive && prevState.breakpoint === breakpoint) {
          return prevState;
        }

        return {
          isActive,
          breakpoint
        };
      });
    }

    const unsubscribe = (0,_automattic_viewport__WEBPACK_IMPORTED_MODULE_3__/* .subscribeIsWithinBreakpoint */ .Sp)(breakpoint, handleBreakpointChange); // The unsubscribe function is the entire cleanup for the effect.

    return unsubscribe;
  }, [breakpoint]);
  return breakpoint === state.breakpoint ? state.isActive : (0,_automattic_viewport__WEBPACK_IMPORTED_MODULE_3__/* .isWithinBreakpoint */ .kV)(breakpoint);
}
/**
 * React hook for getting the status for the mobile breakpoint and keeping it
 * updated.
 *
 * @returns {boolean} The current status for the breakpoint.
 */

function useMobileBreakpoint() {
  return useBreakpoint(_automattic_viewport__WEBPACK_IMPORTED_MODULE_3__/* .MOBILE_BREAKPOINT */ .Gh);
}
/**
 * React hook for getting the status for the desktop breakpoint and keeping it
 * updated.
 *
 * @returns {boolean} The current status for the breakpoint.
 */

function useDesktopBreakpoint() {
  return useBreakpoint(DESKTOP_BREAKPOINT);
}
/**
 * React higher order component for getting the status for a breakpoint and
 * keeping it updated.
 *
 * @param {string} breakpoint The breakpoint to consider.
 * @returns {Function} A function that given a component returns the
 * wrapped component.
 */

const withBreakpoint = breakpoint => createHigherOrderComponent(WrappedComponent => /*#__PURE__*/forwardRef((props, ref) => {
  const isActive = useBreakpoint(breakpoint);
  return createElement(WrappedComponent, _extends({}, props, {
    isBreakpointActive: isActive,
    ref: ref
  }));
}), 'WithBreakpoint');
/**
 * React higher order component for getting the status for the mobile
 * breakpoint and keeping it updated.
 *
 * @param {import('react').Component|Function} Wrapped The component to wrap.
 * @returns {Function} The wrapped component.
 */

const withMobileBreakpoint = (0,_wordpress_compose__WEBPACK_IMPORTED_MODULE_1__.createHigherOrderComponent)(WrappedComponent => /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_2__.forwardRef)((props, ref) => {
  const isActive = useBreakpoint(_automattic_viewport__WEBPACK_IMPORTED_MODULE_3__/* .MOBILE_BREAKPOINT */ .Gh);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(WrappedComponent, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)({}, props, {
    isBreakpointActive: isActive,
    ref: ref
  }));
}), 'WithMobileBreakpoint');
/**
 * React higher order component for getting the status for the desktop
 * breakpoint and keeping it updated.
 *
 * @param {import('react').Component|Function} Wrapped The component to wrap.
 * @returns {Function} The wrapped component.
 */

const withDesktopBreakpoint = (0,_wordpress_compose__WEBPACK_IMPORTED_MODULE_1__.createHigherOrderComponent)(WrappedComponent => /*#__PURE__*/(0,react__WEBPACK_IMPORTED_MODULE_2__.forwardRef)((props, ref) => {
  const isActive = useBreakpoint(_automattic_viewport__WEBPACK_IMPORTED_MODULE_3__/* .DESKTOP_BREAKPOINT */ .oh);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(WrappedComponent, (0,_babel_runtime_helpers_extends__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)({}, props, {
    isBreakpointActive: isActive,
    ref: ref
  }));
}), 'WithDesktopBreakpoint');

/***/ }),

/***/ 79321:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Gh": function() { return /* binding */ MOBILE_BREAKPOINT; },
/* harmony export */   "oh": function() { return /* binding */ DESKTOP_BREAKPOINT; },
/* harmony export */   "kV": function() { return /* binding */ isWithinBreakpoint; },
/* harmony export */   "Sp": function() { return /* binding */ subscribeIsWithinBreakpoint; },
/* harmony export */   "tq": function() { return /* binding */ isMobile; },
/* harmony export */   "jv": function() { return /* binding */ resolveDeviceTypeByViewPort; }
/* harmony export */ });
/* unused harmony exports getMediaQueryList, subscribeIsMobile, isDesktop, subscribeIsDesktop, getWindowInnerWidth, isTabletResolution, DEVICE_MOBILE, DEVICE_TABLET, DEVICE_DESKTOP */
// Determine whether a user is viewing calypso from a device within a
// particular mobile-first responsive breakpoint, matching our existing media
// queries. [1]
//
// This function takes a string matching one of our mobile-first breakpoints
// and returns a boolean based on whether the current `window.innerWidth`
// matches. This is used to segment behavior based on device or browser size,
// but should not be used in place of css for design.
//
// Valid breakpoints include:
// - '<480px'
// - '<660px'
// - '<800px'
// - '<960px'
// - '<1040px'
// - '<1280px'
// - '<1400px'
// - '>480px'
// - '>660px'
// - '>800px'
// - '>960px'
// - '>1040px'
// - '>1280px'
// - '>1400px'
// - '480px-660px'
// - '480px-960px'
// - '660px-960px'
//
// As implemented in our sass media query mixins, minimums are exclusive, while
// maximums are inclusive. i.e.,
//
// - '>480px' is equivalent to `@media (min-width: 481px)`
// - '<960px' is equivalent to `@media (max-width: 960px)`
// - '480px-960px' is equivalent to `@media (max-width: 960px) and (min-width: 481px)`
//
// [1] https://github.com/Automattic/wp-calypso/blob/HEAD/docs/coding-guidelines/css.md#media-queries
//
// FIXME: We can't detect window size on the server, so until we have more intelligent detection,
// use 769, which is just above the general maximum mobile screen width.
const SERVER_WIDTH = 769;
const MOBILE_BREAKPOINT = '<480px';
const DESKTOP_BREAKPOINT = '>960px';
const isServer = typeof window === 'undefined' || !window.matchMedia;

const noop = () => null;

function addListenerFunctions(obj) {
  return {
    addListener: () => undefined,
    removeListener: () => undefined,
    ...obj
  };
}

function createMediaQueryList(args) {
  const {
    min,
    max
  } = args ?? {};

  if (min !== undefined && max !== undefined) {
    return isServer ? addListenerFunctions({
      matches: SERVER_WIDTH > min && SERVER_WIDTH <= max
    }) : window.matchMedia(`(min-width: ${min + 1}px) and (max-width: ${max}px)`);
  }

  if (min !== undefined) {
    return isServer ? addListenerFunctions({
      matches: SERVER_WIDTH > min
    }) : window.matchMedia(`(min-width: ${min + 1}px)`);
  }

  if (max !== undefined) {
    return isServer ? addListenerFunctions({
      matches: SERVER_WIDTH <= max
    }) : window.matchMedia(`(max-width: ${max}px)`);
  }

  return false;
}

const mediaQueryLists = {
  '<480px': createMediaQueryList({
    max: 480
  }),
  '<660px': createMediaQueryList({
    max: 660
  }),
  '<782px': createMediaQueryList({
    max: 782
  }),
  '<800px': createMediaQueryList({
    max: 800
  }),
  '<960px': createMediaQueryList({
    max: 960
  }),
  '<1040px': createMediaQueryList({
    max: 1040
  }),
  '<1280px': createMediaQueryList({
    max: 1280
  }),
  '<1400px': createMediaQueryList({
    max: 1400
  }),
  '>480px': createMediaQueryList({
    min: 480
  }),
  '>660px': createMediaQueryList({
    min: 660
  }),
  '>782px': createMediaQueryList({
    min: 782
  }),
  '>800px': createMediaQueryList({
    min: 800
  }),
  '>960px': createMediaQueryList({
    min: 960
  }),
  '>1040px': createMediaQueryList({
    min: 1040
  }),
  '>1280px': createMediaQueryList({
    min: 1280
  }),
  '>1400px': createMediaQueryList({
    min: 1400
  }),
  '480px-660px': createMediaQueryList({
    min: 480,
    max: 660
  }),
  '660px-960px': createMediaQueryList({
    min: 660,
    max: 960
  }),
  '480px-960px': createMediaQueryList({
    min: 480,
    max: 960
  })
};
function getMediaQueryList(breakpoint) {
  if (!mediaQueryLists.hasOwnProperty(breakpoint)) {
    try {
      // eslint-disable-next-line no-console
      console.warn('Undefined breakpoint used in `mobile-first-breakpoint`', breakpoint);
    } catch (e) {}

    return undefined;
  }

  return mediaQueryLists[breakpoint];
}
/**
 * Returns whether the current window width matches a breakpoint.
 *
 * @param {string} breakpoint The breakpoint to consider.
 * @returns {boolean|undefined} Whether the provided breakpoint is matched.
 */

function isWithinBreakpoint(breakpoint) {
  const mediaQueryList = getMediaQueryList(breakpoint);
  return mediaQueryList ? mediaQueryList.matches : undefined;
}
/**
 * Registers a listener to be notified of changes to breakpoint matching status.
 *
 * @param {string} breakpoint The breakpoint to consider.
 * @param {Function} listener The listener to be called on change.
 * @returns {Function} The function to be called when unsubscribing.
 */

function subscribeIsWithinBreakpoint(breakpoint, listener) {
  if (!listener) {
    return noop;
  }

  const mediaQueryList = getMediaQueryList(breakpoint);

  if (mediaQueryList && !isServer) {
    const wrappedListener = evt => listener(evt.matches);

    mediaQueryList.addListener(wrappedListener); // Return unsubscribe function.

    return () => mediaQueryList.removeListener(wrappedListener);
  }

  return noop;
}
/**
 * Returns whether the current window width matches the mobile breakpoint.
 *
 * @returns {boolean|undefined} Whether the mobile breakpoint is matched.
 */

function isMobile() {
  return isWithinBreakpoint(MOBILE_BREAKPOINT);
}
/**
 * Registers a listener to be notified of changes to mobile breakpoint matching status.
 *
 * @param {Function} listener The listener to be called on change.
 * @returns {Function} The registered subscription; undefined if none.
 */

function subscribeIsMobile(listener) {
  return subscribeIsWithinBreakpoint(MOBILE_BREAKPOINT, listener);
}
/**
 * Returns whether the current window width matches the desktop breakpoint.
 *
 * @returns {boolean|undefined} Whether the desktop breakpoint is matched.
 */

function isDesktop() {
  return isWithinBreakpoint(DESKTOP_BREAKPOINT);
}
/**
 * Registers a listener to be notified of changes to desktop breakpoint matching status.
 *
 * @param {Function} listener The listener to be called on change.
 * @returns {Function} The registered subscription; undefined if none.
 */

function subscribeIsDesktop(listener) {
  return subscribeIsWithinBreakpoint(DESKTOP_BREAKPOINT, listener);
}
/**
 * Returns the current window width.
 * Avoid using this method, as it triggers a layout recalc.
 *
 * @returns {number} The current window width, in pixels.
 */

function getWindowInnerWidth() {
  return isServer ? SERVER_WIDTH : window.innerWidth;
}
/******************************************/

/*       Vertical Scroll Experiment       */

/*  	       pcbrnV-XN-p2               */

/******************************************/
//TODO: To be refactored using above using the DESKTOP_BREAKPOINT constant

function isTabletResolution() {
  if (!isServer) {
    return window.innerWidth < 1040;
  }

  return false;
}
const DEVICE_MOBILE = 'mobile';
const DEVICE_TABLET = 'tablet';
const DEVICE_DESKTOP = 'desktop';
function resolveDeviceTypeByViewPort() {
  if (isMobile()) {
    return DEVICE_MOBILE;
  } else if (isTabletResolution()) {
    return DEVICE_TABLET;
  }

  return DEVICE_DESKTOP;
}
/******************************************/

/***/ }),

/***/ 24568:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_components__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(13668);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(55609);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(65736);
/* harmony import */ var _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _wordpress_keycodes__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(39630);
/* harmony import */ var _wordpress_keycodes__WEBPACK_IMPORTED_MODULE_3___default = /*#__PURE__*/__webpack_require__.n(_wordpress_keycodes__WEBPACK_IMPORTED_MODULE_3__);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(72779);
/* harmony import */ var classnames__WEBPACK_IMPORTED_MODULE_4___default = /*#__PURE__*/__webpack_require__.n(classnames__WEBPACK_IMPORTED_MODULE_4__);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_5___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_5__);


/**
 * WordPress dependencies
 */




const __ = _wordpress_i18n__WEBPACK_IMPORTED_MODULE_2__.__;

/**
 * External dependencies
 */




const Guide = _ref => {
  let {
    children,
    className,
    onFinish
  } = _ref;
  const [currentPage, setCurrentPage] = (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useState)(0);
  const pages = _wordpress_element__WEBPACK_IMPORTED_MODULE_0__.Children.map(children, child => ({
    content: child
  })) || [];
  const canGoBack = currentPage > 0;
  const canGoForward = currentPage < (pages === null || pages === void 0 ? void 0 : pages.length) - 1;

  const goBack = () => {
    if (canGoBack) {
      setCurrentPage(currentPage - 1);
    }
  };

  const goForward = () => {
    if (canGoForward) {
      setCurrentPage(currentPage + 1);
    } else {
      onFinish();
    }
  };

  if (pages.length === 0) {
    return null;
  }

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.Modal, {
    className: classnames__WEBPACK_IMPORTED_MODULE_4___default()('components-guide', className),
    overlayClassName: classnames__WEBPACK_IMPORTED_MODULE_4___default()('components-guide-overlay', className),
    onRequestClose: onFinish,
    onKeyDown: event => {
      if (event.keyCode === _wordpress_keycodes__WEBPACK_IMPORTED_MODULE_3__.LEFT) {
        goBack();
      } else if (event.keyCode === _wordpress_keycodes__WEBPACK_IMPORTED_MODULE_3__.RIGHT) {
        goForward();
      }
    },
    title: ''
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "guide__container"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "guide__page"
  }, pages[currentPage].content), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "guide__footer"
  }, pages.length > 1 && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_automattic_components__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, {
    activePageIndex: currentPage,
    numberOfPages: pages.length,
    onChange: setCurrentPage
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "guide__buttons"
  }, currentPage > 0 && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.Button, {
    className: "guide__back-button",
    isTertiary: true,
    onClick: goBack
  }, __('Back', "full-site-editing")), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_1__.Button, {
    className: "guide__forward-button",
    autoFocus: currentPage === 0 // eslint-disable-line jsx-a11y/no-autofocus
    ,
    isPrimary: true,
    onClick: goForward
  }, canGoForward ? __('Next') : __('Done')))))));
};

/* harmony default export */ __webpack_exports__["Z"] = (Guide);

/***/ }),

/***/ 94819:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(30849);
/* harmony import */ var react_query__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(82066);
/* harmony import */ var wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(18552);
/* harmony import */ var _components_guide__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(24568);
/* harmony import */ var _whats_new_page__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(43727);
/* harmony import */ var _style_scss__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(46590);








const WhatsNewGuide = _ref => {
  let {
    onClose
  } = _ref;
  const locale = (0,_automattic_i18n_utils__WEBPACK_IMPORTED_MODULE_3__/* .useLocale */ .bU)();
  const {
    data,
    isLoading
  } = (0,react_query__WEBPACK_IMPORTED_MODULE_1__.useQuery)('WhatsNewAnnouncements', async () => await (0,wpcom_proxy_request__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .ZP)({
    path: `/whats-new/list?_locale=${locale}`,
    apiNamespace: 'wpcom/v2'
  }), {
    refetchOnWindowFocus: false
  });

  if (!data || isLoading) {
    return null;
  }

  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_components_guide__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z // eslint-disable-next-line wpcalypso/jsx-classname-namespace
  , {
    className: "whats-new-guide__main",
    onFinish: onClose
  }, data.map((page, index) => (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_whats_new_page__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z, {
    key: page.announcementId,
    pageNumber: index + 1,
    isLastPage: index === data.length - 1,
    description: page.description,
    heading: page.heading,
    imageSrc: page.imageSrc,
    link: page.link
  })));
};

/* harmony default export */ __webpack_exports__["Z"] = (WhatsNewGuide);

/***/ }),

/***/ 43727:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(69307);
/* harmony import */ var _wordpress_element__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_wordpress_element__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(36115);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(55609);
/* harmony import */ var _wordpress_components__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__);
/* harmony import */ var _wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(95885);






const WhatsNewPage = _ref => {
  let {
    heading,
    description,
    imageSrc,
    isLastPage,
    link,
    pageNumber
  } = _ref;

  const __ = (0,_wordpress_react_i18n__WEBPACK_IMPORTED_MODULE_3__/* .useI18n */ .QT)().__;

  (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.useEffect)(() => {
    (0,_automattic_calypso_analytics__WEBPACK_IMPORTED_MODULE_1__/* .recordTracksEvent */ .jN)('wpcom_whats_new_slide_view', {
      slide_number: pageNumber,
      is_last_slide: isLastPage
    });
  }, [isLastPage, pageNumber]);
  return (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "whats-new-page__container"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "whats-new-page__text"
  }, heading && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("h1", {
    className: "whats-new-page__heading"
  }, heading), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "whats-new-page__description"
  }, description && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("p", null, description), link && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)(_wordpress_components__WEBPACK_IMPORTED_MODULE_2__.Button, {
    className: "whats-new-page__link",
    href: link,
    isTertiary: true,
    isLink: true,
    target: "_blank"
  }, __('Learn more', "full-site-editing")))), (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "whats-new-page__visual"
  }, imageSrc && (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("div", {
    className: "whats-new-page__image-container"
  }, (0,_wordpress_element__WEBPACK_IMPORTED_MODULE_0__.createElement)("img", {
    src: imageSrc,
    alt: description,
    "aria-hidden": "true",
    className: 'whats-new-page__image'
  }))));
};

/* harmony default export */ __webpack_exports__["Z"] = (WhatsNewPage);

/***/ }),

/***/ 18552:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Vw": function() { return /* binding */ requestAllBlogsAccess; },
/* harmony export */   "sS": function() { return /* binding */ reloadProxy; }
/* harmony export */ });
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var progress_event__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(48650);
/* harmony import */ var progress_event__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(progress_event__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var uuid__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(88767);
/* harmony import */ var wp_error__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(82884);
/* harmony import */ var wp_error__WEBPACK_IMPORTED_MODULE_2___default = /*#__PURE__*/__webpack_require__.n(wp_error__WEBPACK_IMPORTED_MODULE_2__);




/**
 * debug instance
 */

const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('wpcom-proxy-request');
/**
 * WordPress.com REST API base endpoint.
 */

const proxyOrigin = 'https://public-api.wordpress.com';
/**
 * "Origin" of the current HTML page.
 */

const origin = window.location.protocol + '//' + window.location.host;
let onStreamRecord = null;
/**
 * Detecting support for the structured clone algorithm. IE8 and 9, and Firefox
 * 6.0 and below only support strings as postMessage's message. This browsers
 * will try to use the toString method.
 *
 * https://developer.mozilla.org/en-US/docs/Web/API/Window/postMessage
 * https://developer.mozilla.org/en-US/docs/Web/Guide/API/DOM/The_structured_clone_algorithm
 * https://github.com/Modernizr/Modernizr/issues/388#issuecomment-31127462
 */

const postStrings = (() => {
  let r = false;

  try {
    window.postMessage({
      toString: function () {
        r = true;
      }
    }, '*');
  } catch (e) {
    /* empty */
  }

  return r;
})();
/**
 * Test if the browser supports constructing a new `File` object. Not present on Edge and IE.
 */


const supportsFileConstructor = (() => {
  try {
    // eslint-disable-next-line no-new
    new window.File(['a'], 'test.jpg', {
      type: 'image/jpeg'
    });
    return true;
  } catch (e) {
    return false;
  }
})();
/**
 * Reference to the <iframe> DOM element.
 * Gets set in the install() function.
 */


let iframe = null;
/**
 * Set to `true` upon the iframe's "load" event.
 */

let loaded = false;
/**
 * Array of buffered API requests. Added to when API requests are done before the
 * proxy <iframe> is "loaded", and fulfilled once the "load" DOM event on the
 * iframe occurs.
 */

let buffered;
/**
 * In-flight API request XMLHttpRequest dummy "proxy" instances.
 */

const requests = {};
/**
 * Are HTML5 XMLHttpRequest2 "progress" events supported?
 * See: http://goo.gl/xxYf6D
 */

const supportsProgress = !!window.ProgressEvent && !!window.FormData;
debug('using "origin": %o', origin);
/**
 * Performs a "proxied REST API request". This happens by calling
 * `iframe.postMessage()` on the proxy iframe instance, which from there
 * takes care of WordPress.com user authentication (via the currently
 * logged-in user's cookies).
 *
 * @param {object} originalParams - request parameters
 * @param {Function} [fn] - callback response
 * @returns {window.XMLHttpRequest} XMLHttpRequest instance
 */

const makeRequest = (originalParams, fn) => {
  const params = Object.assign({}, originalParams);
  debug('request(%o)', params); // inject the <iframe> upon the first proxied API request

  if (!iframe) {
    install();
  } // generate a uuid for this API request


  const id = (0,uuid__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)();
  params.callback = id;
  params.supports_args = true; // supports receiving variable amount of arguments

  params.supports_error_obj = true; // better Error object info

  params.supports_progress = supportsProgress; // supports receiving XHR "progress" events
  // force uppercase "method" since that's what the <iframe> is expecting

  params.method = String(params.method || 'GET').toUpperCase();
  debug('params object: %o', params);
  const xhr = new window.XMLHttpRequest();
  xhr.params = params; // store the `XMLHttpRequest` instance so that "onmessage" can access it again

  requests[id] = xhr;

  if ('function' === typeof fn) {
    // a callback function was provided
    let called = false;

    const xhrOnLoad = e => {
      if (called) {
        return;
      }

      called = true;
      const body = e.response || xhr.response;
      debug('body: ', body);
      debug('headers: ', e.headers);
      fn(null, body, e.headers);
    };

    const xhrOnError = e => {
      if (called) {
        return;
      }

      called = true;
      const error = e.error || e.err || e;
      debug('error: ', error);
      debug('headers: ', e.headers);
      fn(error, null, e.headers);
    };

    xhr.addEventListener('load', xhrOnLoad);
    xhr.addEventListener('abort', xhrOnError);
    xhr.addEventListener('error', xhrOnError);
  }

  if ('function' === typeof params.onStreamRecord) {
    // remove onStreamRecord param, which can’t be cloned
    onStreamRecord = params.onStreamRecord;
    delete params.onStreamRecord; // FIXME @azabani implement stream mode processing
    // Hint: port the algorithm from wpcom-xhr-request@1.2.0 to /public.api/rest-proxy/provider-
    // v2.0.js in rWP, then plumb stream records from onmessage below to onStreamRecord (or add
    // the XMLHttpRequest#response to ondownloadprogress there, then parse the chunks here).
  }

  if (loaded) {
    submitRequest(params);
  } else {
    debug('buffering API request since proxying <iframe> is not yet loaded');
    buffered.push(params);
  }

  return xhr;
};
/**
 * Performs a "proxied REST API request". This happens by calling
 * `iframe.postMessage()` on the proxy iframe instance, which from there
 * takes care of WordPress.com user authentication (via the currently
 * logged-in user's cookies).
 *
 * If no function is specified as second parameter, a promise is returned.
 *
 * @param {object} originalParams - request parameters
 * @param {Function} [fn] - callback response
 * @returns {window.XMLHttpRequest|Promise} XMLHttpRequest instance or Promise
 */


const request = (originalParams, fn) => {
  // if callback is provided, behave traditionally
  if ('function' === typeof fn) {
    // request method
    return makeRequest(originalParams, fn);
  } // but if not, return a Promise


  return new Promise((res, rej) => {
    makeRequest(originalParams, (err, response) => {
      err ? rej(err) : res(response);
    });
  });
};
/**
 * Set proxy to "access all users' blogs" mode.
 */


function requestAllBlogsAccess() {
  return request({
    metaAPI: {
      accessAllUsersBlogs: true
    }
  });
}
/**
 * Calls the `postMessage()` function on the <iframe>.
 *
 * @param {object} params
 */

function submitRequest(params) {
  debug('sending API request to proxy <iframe> %o', params); // `formData` needs to be patched if it contains `File` objects to work around
  // a Chrome bug. See `patchFileObjects` description for more details.

  if (params.formData) {
    patchFileObjects(params.formData);
  }

  iframe.contentWindow.postMessage(postStrings ? JSON.stringify(params) : params, proxyOrigin);
}
/**
 * Returns `true` if `v` is a DOM File instance, `false` otherwise.
 *
 * @param {any} v - instance to analyze
 * @returns {boolean} `true` if `v` is a DOM File instance
 */


function isFile(v) {
  return v && Object.prototype.toString.call(v) === '[object File]';
}
/*
 * Find a `File` object in a form data value. It can be either the value itself, or
 * in a `fileContents` property of the value.
 */


function getFileValue(v) {
  if (isFile(v)) {
    return v;
  }

  if (typeof v === 'object' && isFile(v.fileContents)) {
    return v.fileContents;
  }

  return null;
}
/**
 * Finds all `File` instances in `formData` and creates a new `File` instance whose storage is
 * forced to be a `Blob` instead of being backed by a file on disk. That works around a bug in
 * Chrome where `File` instances with `has_backing_file` flag cannot be sent over a process
 * boundary when site isolation is on.
 *
 * @see https://bugs.chromium.org/p/chromium/issues/detail?id=866805
 * @see https://bugs.chromium.org/p/chromium/issues/detail?id=631877
 * @param {Array} formData Form data to patch
 */


function patchFileObjects(formData) {
  // There are several landmines to avoid when making file uploads work on all browsers:
  // - the `new File()` constructor trick breaks file uploads on Safari 10 in a way that's
  //   impossible to detect: it will send empty files in the multipart/form-data body.
  //   Therefore we need to detect Chrome.
  // - IE11 and Edge don't support the `new File()` constructor at all. It will throw exception,
  //   so it's detectable by the `supportsFileConstructor` code.
  // - `window.chrome` exists also on Edge (!), `window.chrome.webstore` is only in Chrome and
  //   not in other Chromium based browsers (which have the site isolation bug, too).
  if (!window.chrome || !supportsFileConstructor) {
    return;
  }

  for (let i = 0; i < formData.length; i++) {
    const val = getFileValue(formData[i][1]);

    if (val) {
      formData[i][1] = new window.File([val], val.name, {
        type: val.type
      });
    }
  }
}
/**
 * Injects the proxy <iframe> instance in the <body> of the current
 * HTML page.
 */


function install() {
  debug('install()');

  if (iframe) {
    uninstall();
  }

  buffered = []; // listen to messages sent to `window`

  window.addEventListener('message', onmessage); // create the <iframe>

  iframe = document.createElement('iframe'); // set `src` and hide the iframe

  iframe.src = proxyOrigin + '/wp-admin/rest-proxy/?v=2.0#' + origin;
  iframe.style.display = 'none'; // inject the <iframe> into the <body>

  document.body.appendChild(iframe);
}
/**
 * Reloads the proxy iframe.
 */


const reloadProxy = () => {
  install();
};
/**
 * Removes the <iframe> proxy instance from the <body> of the page.
 */


function uninstall() {
  debug('uninstall()');
  window.removeEventListener('message', onmessage);
  document.body.removeChild(iframe);
  loaded = false;
  iframe = null;
}
/**
 * The proxy <iframe> instance's "load" event callback function.
 */


function onload() {
  debug('proxy <iframe> "load" event');
  loaded = true; // flush any buffered API calls

  if (buffered) {
    for (let i = 0; i < buffered.length; i++) {
      submitRequest(buffered[i]);
    }

    buffered = null;
  }
}
/**
 * The main `window` object's "message" event callback function.
 *
 * @param {window.Event} e
 */


function onmessage(e) {
  debug('onmessage'); // Filter out messages from different origins

  if (e.origin !== proxyOrigin) {
    debug('ignoring message... %o !== %o', e.origin, proxyOrigin);
    return;
  } // Filter out messages from different iframes


  if (e.source !== iframe.contentWindow) {
    debug('ignoring message... iframe elements do not match');
    return;
  }

  let {
    data
  } = e;

  if (!data) {
    return debug('no `data`, bailing');
  } // Once the iframe is loaded, we can start using it.


  if (data === 'ready') {
    onload();
    return;
  }

  if (postStrings && 'string' === typeof data) {
    data = JSON.parse(data);
  } // check if we're receiving a "progress" event


  if (data.upload || data.download) {
    return onprogress(data);
  }

  if (!data.length) {
    return debug("`e.data` doesn't appear to be an Array, bailing...");
  } // first get the `xhr` instance that we're interested in


  const id = data[data.length - 1];

  if (!(id in requests)) {
    return debug('bailing, no matching request with callback: %o', id);
  }

  const xhr = requests[id]; // Build `error` and `body` object from the `data` object

  const {
    params
  } = xhr;
  const body = data[0];
  let statusCode = data[1];
  const headers = data[2]; // We don't want to delete requests while we're processing stream messages

  if (statusCode === 207) {// 207 is a signal from rest-proxy. It means, "this isn't the final
    // response to the query." The proxy supports WebSocket connections
    // by invoking the original success callback for each message received.
  } else {
    // this is the final response to this query
    delete requests[id];
  }

  if (!params.metaAPI) {
    debug('got %o status code for URL: %o', statusCode, params.path);
  } else {
    statusCode = body === 'metaAPIupdated' ? 200 : 500;
  }

  if (typeof headers === 'object') {
    // add statusCode into headers object
    headers.status = statusCode;

    if (shouldProcessInStreamMode(headers['Content-Type'])) {
      if (statusCode === 207) {
        onStreamRecord(body);
        return;
      }
    }
  }

  if (statusCode && 2 === Math.floor(statusCode / 100)) {
    // 2xx status code, success
    resolve(xhr, body, headers);
  } else {
    // any other status code is a failure
    const wpe = wp_error__WEBPACK_IMPORTED_MODULE_2___default()(params, statusCode, body);
    reject(xhr, wpe, headers);
  }
}
/**
 * Returns true iff stream mode processing is required (see wpcom-xhr-request@1.2.0).
 *
 * @param {string} contentType response Content-Type header value
 */


function shouldProcessInStreamMode(contentType) {
  return /^application[/]x-ndjson($|;)/.test(contentType);
}
/**
 * Handles a "progress" event being proxied back from the iframe page.
 *
 * @param {object} data
 */


function onprogress(data) {
  debug('got "progress" event: %o', data);
  const xhr = requests[data.callbackId];

  if (xhr) {
    const prog = new (progress_event__WEBPACK_IMPORTED_MODULE_1___default())('progress', data);
    const target = data.upload ? xhr.upload : xhr;
    target.dispatchEvent(prog);
  }
}
/**
 * Emits the "load" event on the `xhr`.
 *
 * @param {window.XMLHttpRequest} xhr
 * @param {object} body
 */


function resolve(xhr, body, headers) {
  const e = new (progress_event__WEBPACK_IMPORTED_MODULE_1___default())('load');
  e.data = e.body = e.response = body;
  e.headers = headers;
  xhr.dispatchEvent(e);
}
/**
 * Emits the "error" event on the `xhr`.
 *
 * @param {window.XMLHttpRequest} xhr
 * @param {Error} err
 */


function reject(xhr, err, headers) {
  const e = new (progress_event__WEBPACK_IMPORTED_MODULE_1___default())('error');
  e.error = e.err = err;
  e.headers = headers;
  xhr.dispatchEvent(e);
}
/**
 * Export `request` function.
 */


/* harmony default export */ __webpack_exports__["ZP"] = (request);


/***/ }),

/***/ 91202:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ WPCOM; }
/* harmony export */ });
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _lib_batch__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(89728);
/* harmony import */ var _lib_domain__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(47114);
/* harmony import */ var _lib_domains__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(20035);
/* harmony import */ var _lib_me__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(22836);
/* harmony import */ var _lib_plans__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(6870);
/* harmony import */ var _lib_site__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(32579);
/* harmony import */ var _lib_users__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(54308);
/* harmony import */ var _lib_util_pinghub__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(33818);
/* harmony import */ var _lib_util_request__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(60781);
/* harmony import */ var _lib_util_send_request__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(73918);











/**
 * Local module constants
 */

const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('wpcom');
const DEFAULT_ASYNC_TIMEOUT = 30000;
/**
 * XMLHttpRequest (and CORS) API access method.
 *
 * API authentication is done via an (optional) access `token`,
 * which needs to be retrieved via OAuth.
 *
 * Request Handler is optional and XHR is defined as default.
 *
 * @param {string} [token] - OAuth API access token
 * @param {Function} [reqHandler] - function Request Handler
 * @returns {WPCOM} wpcom instance
 */

function WPCOM(token, reqHandler) {
  if (!(this instanceof WPCOM)) {
    return new WPCOM(token, reqHandler);
  } // `token` is optional


  if ('function' === typeof token) {
    reqHandler = token;
    token = null;
  }

  if (token) {
    debug('Token defined: %s…', token.substring(0, 6));
    this.token = token;
  }

  const noHandler = (params, fn) => {
    debug('No request handler. Failing.');
    fn(new Error('No request handler provided'));
  };

  this.request = reqHandler || noHandler; // Add Req instance

  this.req = new _lib_util_request__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z(this); // Add Pinghub instance

  this.pinghub = new _lib_util_pinghub__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z(this); // Default api version;

  this.apiVersion = '1.1';
}
/**
 * Return `Me` object instance
 *
 * @returns {Me} Me instance
 */

WPCOM.prototype.me = function () {
  return new _lib_me__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z(this);
};
/**
 * Return `Domains` object instance
 *
 * @returns {Domains} Domains instance
 */


WPCOM.prototype.domains = function () {
  return new _lib_domains__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z(this);
};
/**
 * Return `Domain` object instance
 *
 * @param {string} domainId - domain identifier
 * @returns {Domain} Domain instance
 */


WPCOM.prototype.domain = function (domainId) {
  return new _lib_domain__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z(domainId, this);
};
/**
 * Return `Site` object instance
 *
 * @param {string} id - site identifier
 * @returns {Site} Site instance
 */


WPCOM.prototype.site = function (id) {
  return new _lib_site__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z(id, this);
};
/**
 * Return `Users` object instance
 *
 * @returns {Users} Users instance
 */


WPCOM.prototype.users = function () {
  return new _lib_users__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z(this);
};
/**
 * Return `Plans` object instance
 *
 * @returns {Plans} Plans instance
 */


WPCOM.prototype.plans = function () {
  return new _lib_plans__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z(this);
};
/**
 * Return `Batch` object instance
 *
 * @returns {Batch} Batch instance
 */


WPCOM.prototype.batch = function () {
  return new _lib_batch__WEBPACK_IMPORTED_MODULE_10__/* ["default"] */ .Z(this);
};
/**
 * List Freshly Pressed Posts
 *
 * @param {object} [query] - query object
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


WPCOM.prototype.freshlyPressed = function (query, fn) {
  return this.req.get('/freshly-pressed', query, fn);
}; // Expose send-request
// TODO: use `this.req` instead of this method


WPCOM.prototype.sendRequest = function (params, query, body, fn) {
  const msg = 'WARN! Don use `sendRequest() anymore. Use `this.req` method.';
  /* eslint-disable no-console */

  if (console && console.warn) {
    console.warn(msg);
  } else {
    console.log(msg);
  }
  /* eslint-enable no-console */


  return _lib_util_send_request__WEBPACK_IMPORTED_MODULE_6__/* ["default"].call */ .Z.call(this, params, query, body, fn);
};
/**
 * Re-export all the class types.
 */


WPCOM.Batch = _lib_batch__WEBPACK_IMPORTED_MODULE_10__/* ["default"] */ .Z;
WPCOM.Domain = _lib_domain__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z;
WPCOM.Domains = _lib_domains__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z;
WPCOM.Me = _lib_me__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z;
WPCOM.Pinghub = _lib_util_pinghub__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z;
WPCOM.Plans = _lib_plans__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z;
WPCOM.Request = _lib_util_request__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z;
WPCOM.Site = _lib_site__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z;
WPCOM.Users = _lib_users__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z;

if (!Promise.prototype.timeout) {
  /**
   * Returns a new promise with a deadline
   *
   * After the timeout interval, the promise will
   * reject. If the actual promise settles before
   * the deadline, the timer is cancelled.
   *
   * @param {number} delay how many ms to wait
   * @returns {Promise} promise
   */
  Promise.prototype.timeout = function () {
    let delay = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : DEFAULT_ASYNC_TIMEOUT;
    let timer;
    const timeout = new Promise((resolve, reject) => {
      timer = setTimeout(() => {
        reject(new Error('Action timed out while waiting for response.'));
      }, delay);
    });

    const cancelTimeout = () => {
      clearTimeout(timer);
      return this;
    };

    return Promise.race([this.then(cancelTimeout).catch(cancelTimeout), timeout]);
  };
}

/***/ }),

/***/ 89728:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
class Batch {
  /**
   * Create a `Batch` instance
   *
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(wpcom) {
    if (!(this instanceof Batch)) {
      return new Batch(wpcom);
    }

    this.wpcom = wpcom;
    this.urls = [];
  }
  /**
   * Add url to batch requests
   *
   * @param {string} url - endpoint url
   * @returns {Batch} batch instance
   */


  add(url) {
    this.urls.push(url);
    return this;
  }
  /**
   * Run the batch request
   *
   * @param {object} [query] - optional query parameter
   * @param {Function} fn - callback
   * @returns {Promise} Promise
   */


  run() {
    let query = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    let fn = arguments.length > 1 ? arguments[1] : undefined;

    if ('function' === typeof query) {
      fn = query;
      query = {};
    } // add urls to query object


    query.urls = this.urls;
    return this.wpcom.req.get('/batch', query, fn);
  }

}
/**
 * Expose `Batch` module
 */


/* harmony default export */ __webpack_exports__["Z"] = (Batch);

/***/ }),

/***/ 46398:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
const root = '/domains/';

class DomainDns {
  /**
   * `DomainDns` constructor.
   *
   * @param {string} domainId - domain identifier
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {undefined} undefined
   */
  constructor(domainId, wpcom) {
    if (!(this instanceof DomainDns)) {
      return new DomainDns(domainId, wpcom);
    }

    this._domain = domainId;
    this._subpath = root + this._domain + '/dns';
    this.wpcom = wpcom;
  }
  /**
   * Adds a DNS record
   *
   * @param {object} record - record
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  add(record, query, fn) {
    if ('function' === typeof query) {
      fn = query;
      query = {};
    }

    return this.wpcom.req.post(this._subpath + '/add', query, record, fn);
  }
  /**
   * Delete a DNS record
   *
   * @param {string} record - record
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  delete(record, query, fn) {
    return this.wpcom.req.post(this._subpath + '/delete', query, record, fn);
  }
  /**
   * Sets the default A records also deleting any A and AAAA custom records.
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Function} request handler
   */


  setDefaultARecords(query, fn) {
    return this.wpcom.req.post(this._subpath + '/set-default-a-records', query, null, fn);
  }

}
/**
 * Expose `DomainDns` module
 */


/* harmony default export */ __webpack_exports__["Z"] = (DomainDns);

/***/ }),

/***/ 4449:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
const root = '/domains/';

class DomainEmail {
  /**
   * `DomainEmail` constructor.
   *
   * @param {string} [email] - email
   * @param {string} domainId - domain identifier
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {undefined} undefined
   */
  constructor(email, domainId, wpcom) {
    if (!(this instanceof DomainEmail)) {
      return new DomainEmail(email, domainId, wpcom);
    }

    if (email) {
      this._email = email;
    }

    this._domain = domainId;
    this._subpath = root + this._domain + '/email/';
    this.wpcom = wpcom;
  }
  /**
   * Update the email forwards/configuration for a domain.
   *
   * @param {string} destination - the email address to forward email to.
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  forward(destination, query, fn) {
    const body = {
      destination: destination
    };
    return this.wpcom.req.post(this._subpath + this._email, query, body, fn);
  }
  /**
   * Create an email forward for the domain
   * if it has enough licenses.
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  add(mailbox, destination, query, fn) {
    if ('function' === typeof query) {
      fn = query;
      query = {};
    }

    const body = {
      mailbox: mailbox,
      destination: destination
    };
    return this.wpcom.req.post(this._subpath + 'new', query, body, fn);
  }
  /**
   * Delete an email forward for the domain
   *
   * @param {string} mailbox - mailbox to alter
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  delete(mailbox, query, fn) {
    return this.wpcom.req.del(this._subpath + mailbox + '/delete', query, fn);
  }

}
/**
 * Expose `DomainEmail` module
 */


/* harmony default export */ __webpack_exports__["Z"] = (DomainEmail);

/***/ }),

/***/ 47114:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _domain_dns__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(46398);
/* harmony import */ var _domain_email__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(4449);


const root = '/domains/';

class Domain {
  /**
   * `Domain` constructor.
   *
   * @param {string} id - domain identifier
   * @param wpcom - wpcom instance
   * @returns {undefined} undefined
   */
  constructor(id, wpcom) {
    if (!(this instanceof Domain)) {
      return new Domain(id, wpcom);
    }

    this._id = id;
    this.wpcom = wpcom;
  }
  /**
   * Get the status of the domain
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  status(query, fn) {
    return this.wpcom.req.get(root + this._id + '/status', query, fn);
  }
  /**
   * Check if the given domain is available
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  isAvailable(query, fn) {
    return this.wpcom.req.get(root + this._id + '/is-available', query, fn);
  }
  /**
   * Check if the given domain name can be mapped to
   * a WordPress blog.
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  isMappable(query, fn) {
    return this.wpcom.req.get(root + this._id + '/is-mappable', query, fn);
  }
  /**
   * Check if the given domain name can be used for site redirect.
   *
   * @param {string} siteId - site id of the site to check
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  canRedirect(siteId, query, fn) {
    const path = root + siteId + '/' + this._id + '/can-redirect';
    return this.wpcom.req.get(path, query, fn);
  }
  /**
   * Get the email forwards/configuration for a domain.
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  emailForwards(query, fn) {
    return this.wpcom.req.get(root + this._id + '/email', query, fn);
  }
  /**
   * Get a list of the nameservers for the domain
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  nameserversList(query, fn) {
    return this.wpcom.req.get(root + this._id + '/nameservers', query, fn);
  }
  /**
   * Update the nameservers for the domain
   *
   * @param {Array} nameservers - nameservers list
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  updateNameservers(nameservers, query, fn) {
    const body = {
      nameservers: nameservers
    };
    return this.wpcom.req.post(root + this._id + '/nameservers', query, body, fn);
  }
  /**
   * Get a list of the DNS records for the domain
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  dnsList(query, fn) {
    return this.wpcom.req.get(root + this._id + '/dns', query, fn);
  }
  /**
   * Get a list of all Google Apps accounts for the domain
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  googleAppsList(query, fn) {
    return this.wpcom.req.get(root + this._id + '/google-apps', query, fn);
  }
  /**
   * Resend the ICANN verification email for the domain
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  resendICANN(query, fn) {
    return this.wpcom.req.post(root + this._id + '/resend-icann', query, fn);
  }
  /**
   * Return `DomainEmail` instance
   *
   * @param {string} [email] - email identifier
   * @returns {DomainEmail} DomainEmail instance
   */


  email(email) {
    return new _domain_email__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z(email, this._id, this.wpcom);
  }
  /**
   * Return `DomainDns` instance
   *
   * @returns {DomainDns} DomainDns instance
   */


  dns() {
    return new _domain_dns__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z(this._id, this.wpcom);
  }
  /**
   * Gets info needed to provide mapping setup instructions for a domain.
   *
   * @param {string} siteId - site id the domain will be mapped to
   * @param {object} query - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  mappingSetupInfo(siteId, query, fn) {
    return this.wpcom.req.get(root + this._id + '/mapping-setup-info/' + siteId, query, fn);
  }
  /**
   * Gets the mapping status for a domain.
   *
   * @param {object} query - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  mappingStatus(query, fn) {
    return this.wpcom.req.get(root + this._id + '/mapping-status', query, fn);
  }
  /**
   * Update the connection mode used to connect this domain and retrieve its mapping status.
   *
   * @param {string} mode - connection mode used to connect this domain (can be "suggested" or "advanced")
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  updateConnectionModeAndGetMappingStatus(mode, query, fn) {
    const body = {
      mode
    };
    return this.wpcom.req.post(root + this._id + '/mapping-status', query, body, fn);
  }

}
/**
 * Expose `Domain` module
 */


/* harmony default export */ __webpack_exports__["Z"] = (Domain);

/***/ }),

/***/ 20035:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
const root = '/domains/';

class Domains {
  /**
   * `Domains` constructor.
   *
   * @param wpcom - wpcom instance
   * @returns {undefined} undefined
   */
  constructor(wpcom) {
    if (!(this instanceof Domains)) {
      return new Domains(wpcom);
    }

    this.wpcom = wpcom;
  }
  /**
   * Get a list of suggested domain names that are available for
   * registration based on a given term or domain name.
   *
   * @param {string|object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  suggestions(query, fn) {
    if ('string' === typeof query) {
      query = {
        query: query
      };
    }

    return this.wpcom.req.get(root + 'suggestions', query, fn);
  }
  /**
   * GET example domain suggestions
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  suggestionsExamples(query, fn) {
    return this.wpcom.req.get(root + 'suggestions/examples', query, fn);
  }
  /**
   * Get a localized list of supported countries for domain registrations.
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  supportedCountries(query, fn) {
    return this.wpcom.req.get(root + 'supported-countries', query, fn);
  }
  /**
   * Get a localized list of supported states for domain registrations.
   *
   * @param {string} countryCode - country code ISO 3166-1 alpha-2 identifier
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  supportedStates(countryCode, query, fn) {
    const path = root + 'supported-states/' + countryCode;
    return this.wpcom.req.get(path, query, fn);
  }

}
/**
 * Expose `Domains` module
 */


/* harmony default export */ __webpack_exports__["Z"] = (Domains);

/***/ }),

/***/ 82921:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ MeConnectedApp; }
/* harmony export */ });
const root = '/me/connected-applications/';
class MeConnectedApp {
  /**
   * `MeConnectedApp` constructor.
   *
   * @param {string} appId - application identifier
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(appId, wpcom) {
    if (!(this instanceof MeConnectedApp)) {
      return new MeConnectedApp(appId, wpcom);
    }

    this._id = appId;
    this.wpcom = wpcom;
  }
  /**
   * Get one of current user's connected applications.
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  get(query, fn) {
    return this.wpcom.req.get(root + this._id, query, fn);
  }
  /**
   * Delete the app of the  current user
   * through of the given appId
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  delete(query, fn) {
    return this.wpcom.req.del(root + this._id + '/delete', query, fn);
  }

}

/***/ }),

/***/ 22836:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Me; }
/* harmony export */ });
/* harmony import */ var _me_connected_application__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(82921);
/* harmony import */ var _me_keyring_connection__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(12769);
/* harmony import */ var _me_publicize_connection__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(82695);
/* harmony import */ var _me_settings__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(17699);
/* harmony import */ var _me_two_step__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(29814);





/**
 * Create `Me` instance
 *
 * @param {object} wpcom - wpcom instance
 * @returns {null} null
 */

function Me(wpcom) {
  if (!(this instanceof Me)) {
    return new Me(wpcom);
  }

  this.wpcom = wpcom;
}
/**
 * Meta data about auth token's User
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

Me.prototype.get = function (query, fn) {
  return this.wpcom.req.get('/me', query, fn);
};
/**
 * Get user billing history.
 *
 * @param {object} [query] - query object parameter
 * @param {Function} [fn] - callback function
 * @returns {Function} request handler
 */


Me.prototype.billingHistory = function (query, fn) {
  return this.wpcom.req.get('/me/billing-history', query, fn);
};
/**
 * Get a list of posts of from the user's blogs
 *
 * Example:
 *    // Get posts list
 *    wpcom
 *    .me()
 *    .postsList( function( err, data ) {
 *      // posts list data object
 *    } );
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Me.prototype.postsList = function (query, fn) {
  return this.wpcom.req.get('/me/posts', query, fn);
};
/**
 * A list of the current user's sites
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Me.prototype.sites = function (query, fn) {
  return this.wpcom.req.get('/me/sites', query, fn);
};
/**
 * List the currently authorized user's likes
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Me.prototype.likes = function (query, fn) {
  return this.wpcom.req.get('/me/likes', query, fn);
};
/**
 * Get current user's connected applications.
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Me.prototype.connectedApps = function (query, fn) {
  return this.wpcom.req.get('/me/connected-applications', query, fn);
};
/**
 * Get a list of all the keyring connections
 * associated with the current user
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Me.prototype.keyringConnections = function (query, fn) {
  return this.wpcom.req.get('/me/connections', query, fn);
};
/**
 * Get a list of publicize connections
 * that the current user has set up.
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Me.prototype.publicizeConnections = function (query, fn) {
  return this.wpcom.req.get('/me/publicize-connections', query, fn);
};
/**
 * Return a `MeSettings` instance.
 *
 * @returns {MeSettings} MeSettings instance
 */


Me.prototype.settings = function () {
  return new _me_settings__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z(this.wpcom);
};
/**
 * Return a `MeConnectedApp` instance.
 *
 * @param {string} id - app id
 * @returns {MeConnectedApp} Me ConnectedApp instance
 */


Me.prototype.connectedApp = function (id) {
  return new _me_connected_application__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z(id, this.wpcom);
};
/**
 * Return a `MePublicizeConnection` instance.
 *
 * @param {string} id - connection id
 * @returns {MePublicizeConnection} MeSettings instance
 */


Me.prototype.publicizeConnection = function (id) {
  return new _me_publicize_connection__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z(id, this.wpcom);
};
/**
 * Return a `MeTwoStep` instance.
 *
 * @returns {MeTwoStep} MeTwoStep instance
 */


Me.prototype.twoStep = function () {
  return new _me_two_step__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z(this.wpcom);
};
/**
 * Return a `MeKeyringConnection` instance.
 *
 * @param {string} id - connection id
 * @returns {MeKeyringConnection} MeKeyringConnection instance
 */


Me.prototype.keyringConnection = function (id) {
  return new _me_keyring_connection__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z(id, this.wpcom);
};

/***/ }),

/***/ 12769:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ KeyringConnection; }
/* harmony export */ });
const root = '/me/connections/';
class KeyringConnection {
  /**
   * `KeyringConnection` constructor.
   *
   * @param {string} keyId - the connection ID to take action on.
   * @param {object} wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(keyId, wpcom) {
    if (!(this instanceof KeyringConnection)) {
      return new KeyringConnection(keyId, wpcom);
    }

    this._id = keyId;
    this.wpcom = wpcom;
  }
  /**
   * Get a single Keyring connection that the current user has setup.
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  get(query, fn) {
    return this.wpcom.req.get({
      path: root + this._id,
      apiNamespace: 'wpcom/v2'
    }, query, fn);
  }
  /**
   * Delete the Keyring connection (and associated token) with the
   * provided ID. Also deletes all associated publicize connections.
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  delete(query, fn) {
    return this.wpcom.req.get({
      path: root + this._id,
      apiNamespace: 'wpcom/v2',
      method: 'DELETE'
    }, query, fn);
  }

}

/***/ }),

/***/ 82695:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ PublicizeConnection; }
/* harmony export */ });
const root = '/me/publicize-connections/';
class PublicizeConnection {
  /**
   * `PublicizeConnection` constructor.
   *
   * @param {string} connectionId - application identifier
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(connectionId, wpcom) {
    if (!(this instanceof PublicizeConnection)) {
      return new PublicizeConnection(connectionId, wpcom);
    }

    this._id = connectionId;
    this.wpcom = wpcom;
  }
  /**
   * Get a single publicize connection that the current user has set up.
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  get(query, fn) {
    return this.wpcom.req.get(root + this._id, query, fn);
  }
  /**
   * Add a publicize connection belonging to the current user.
   *
   * @param {object} [query] - query object parameter
   * @param {object} body - body object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  add(query, body, fn) {
    return this.wpcom.req.post(root + 'new', query, body, fn);
  }
  /**
   * Update a publicize connection belonging to the current user.
   *
   * @param {object} [query] - query object parameter
   * @param {object} body - body object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  update(query, body, fn) {
    return this.wpcom.req.put(root + this._id, query, body, fn);
  }
  /**
   * Delete the app of the  current user
   * through of the given connectionId
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  delete(query, fn) {
    return this.wpcom.req.del(root + this._id + '/delete', query, fn);
  }

}

/***/ }),

/***/ 17699:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ MeSettings; }
/* harmony export */ });
/* harmony import */ var _me_settings_password__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(30142);
/* harmony import */ var _me_settings_profile_links__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(39283);


/**
 * `MeSettings` constructor.
 *
 * Use a `WPCOM#Me` instance to create a new `MeSettings` instance.
 *
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */

function MeSettings(wpcom) {
  if (!(this instanceof MeSettings)) {
    return new MeSettings(wpcom);
  }

  this.wpcom = wpcom;
}
/**
 * Get settings for the current user.
 *
 * Example:
 *    // Get settings for the current user
 *    wpcom
 *    .me()
 *    .settings()
 *    .get( function( err, data ) {
 *      // user settings data object
 *    } );
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

MeSettings.prototype.get = function (query, fn) {
  return this.wpcom.req.get('/me/settings', query, fn);
};
/**
 * Update settings of the current user
 *
 * @param {object} [query] - query object parameter
 * @param {object} body - body object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


MeSettings.prototype.update = function (query, body, fn) {
  return this.wpcom.req.put('/me/settings/', query, body, fn);
};
/**
 * Return `MeProfileLinks` instance
 *
 * Example:
 *    // Create a MeProfileLinks instance
 *    var profile_links = wpcom.me().settings().profileLinks();
 *
 * @returns {MeProfileLinks} MeProfileLinks instance
 */


MeSettings.prototype.profileLinks = function () {
  return new _me_settings_profile_links__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z(this.wpcom);
};
/**
 * Return `MeSettingsPassword` instance
 *
 * @returns {MeSettingsPassword} MeSettingsPassword instance
 */


MeSettings.prototype.password = function () {
  return new _me_settings_password__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z(this.wpcom);
};

/***/ }),

/***/ 30142:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ MeSettingsPassword; }
/* harmony export */ });
const root = '/me/settings/password/';
class MeSettingsPassword {
  /**
   * `MeSettingsPassword` constructor.
   *
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(wpcom) {
    if (!(this instanceof MeSettingsPassword)) {
      return new MeSettingsPassword(wpcom);
    }

    this.wpcom = wpcom;
  }
  /**
   * Verify strength of a user's new password.
   *
   * @param {string} password - the users's potential new password
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  validate(password, query, fn) {
    return this.wpcom.req.post(root + 'validate', query, {
      password: password
    }, fn);
  }

}

/***/ }),

/***/ 39283:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ ProfileLinks; }
/* harmony export */ });
/**
 * Endpoint root
 */
const root = '/me/settings/profile-links';
/**
 * `ProfileLinks` constructor.
 *
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */

function ProfileLinks(wpcom) {
  if (!(this instanceof ProfileLinks)) {
    return new ProfileLinks(wpcom);
  }

  this.wpcom = wpcom;
}
/**
 * Get profile links of the current user.
 *
 * Example:
 *   // Get profile links of the current user
 *    wpcom
 *    .me()
 *    .settings()
 *    .profileLinks()
 *    .get( function( err, data ) {
 *      // profile links data
 *    } );
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

ProfileLinks.prototype.get = function (query, fn) {
  return this.wpcom.req.get(root, query, fn);
}; // Create `mine` alias


ProfileLinks.prototype.mine = ProfileLinks.prototype.get;
/**
 * Add a profile link to current user.
 *
 * Example:
 *    // Add profile link to current user
 *    wpcom
 *    .me()
 *    .settings()
 *    .profileLinks()
 *    .add( {
 *      title: "WordPress Blog",
 *      value: "en.blog.wordpress.com"
 *    }, function( err, data ) {
 *      // profile has been added
 *    } );
 *
 * @param {Array|object} links - profile links
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

ProfileLinks.prototype.add = function (links, query, fn) {
  // query object is optional
  if ('function' === typeof query) {
    fn = query;
    query = {};
  } // links can be Array or an Object


  if (!(links instanceof Array)) {
    links = [links];
  } // Set api version 1.2 for this endpoint


  query.apiVersion = '1.2';
  const path = root + '/new';
  return this.wpcom.req.post(path, query, {
    links: links
  }, fn);
};
/**
 * Remove your ProfileLinks from a Post.
 *
 * Example:
 *    // Remove profile link from current user
 *    wpcom
 *    .me()
 *    .settings()
 *    .profileLinks()
 *    .del( 'example.wordpress.com', function( err, data ) {
 *      // profile has been deleted
 *    } );
 *
 * @param {string} slug - the URL of the profile link
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


ProfileLinks.prototype.del = function (slug, query, fn) {
  const path = root + '/' + slug + '/delete';
  return this.wpcom.req.del(path, query, fn);
}; // Create `delete` alias


ProfileLinks.prototype.delete = ProfileLinks.prototype.del;

/***/ }),

/***/ 29814:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ MeTwoStep; }
/* harmony export */ });
/* harmony import */ var _me_two_step_sms__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(14086);

const root = '/me/two-step/';
class MeTwoStep {
  /**
   * `MeTwoStep` constructor.
   *
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(wpcom) {
    if (!(this instanceof MeTwoStep)) {
      return new MeTwoStep(wpcom);
    }

    this.wpcom = wpcom;
  }
  /**
   * Get information about current user's two factor configuration.
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  get(query, fn) {
    return this.wpcom.req.get(root, query, fn);
  }
  /**
   * Return a `MeTwoStepSMS` instance.
   *
   * @returns {MeTwoStepSMS} MeTwoStepSMS instance
   */


  sms() {
    return new _me_two_step_sms__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z(this.wpcom);
  }

}

/***/ }),

/***/ 14086:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ MeTwoStepSMS; }
/* harmony export */ });
const root = '/me/two-step/sms/';
class MeTwoStepSMS {
  /**
   * `MeTwoStepSMS` constructor.
   *
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(wpcom) {
    if (!(this instanceof MeTwoStepSMS)) {
      return new MeTwoStepSMS(wpcom);
    }

    this.wpcom = wpcom;
  }
  /**
   * Sends a two-step code via SMS to the current user.
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  send(query, fn) {
    return this.wpcom.req.post(root + 'new', query, fn);
  }

}

/***/ }),

/***/ 6870:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Plans; }
/* harmony export */ });
const root = '/plans';
class Plans {
  /**
   * `Plans` constructor.
   *
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {undefined} undefined
   */
  constructor(wpcom) {
    if (!(this instanceof Plans)) {
      return new Plans(wpcom);
    }

    this.wpcom = wpcom;
  }
  /**
   * Get a list of active WordPress.com plans
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  list(query, fn) {
    return this.wpcom.req.get(root, query, fn);
  }
  /**
   * Get a list of features for active WordPress.com plans
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  features(query, fn) {
    return this.wpcom.req.get(`${root}/features`, query, fn);
  }

}

/***/ }),

/***/ 70209:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/* harmony default export */ __webpack_exports__["Z"] = ([{
  name: 'categoriesList',
  subpath: 'categories'
}, {
  name: 'commentsList',
  subpath: 'comments'
}, {
  name: 'domainsList',
  subpath: 'domains'
}, {
  name: 'embedsList',
  subpath: 'embeds'
}, {
  name: 'followsList',
  subpath: 'follows'
}, {
  name: 'mediaList',
  subpath: 'media'
}, {
  name: 'pageTemplates',
  subpath: 'page-templates'
}, {
  name: 'pluginsList',
  subpath: 'plugins'
}, {
  name: 'postsList',
  subpath: 'posts'
}, {
  name: 'postTypesList',
  subpath: 'post-types'
}, {
  name: 'shortcodesList',
  subpath: 'shortcodes'
}, {
  name: 'stats',
  subpath: 'stats'
}, {
  name: 'statsClicks',
  subpath: 'stats/clicks'
}, {
  name: 'statsCommentFollowers',
  subpath: 'stats/comment-followers'
}, {
  name: 'statsComments',
  subpath: 'stats/comments'
}, {
  name: 'statsCountryViews',
  subpath: 'stats/country-views'
}, {
  name: 'statsFollowers',
  subpath: 'stats/followers'
}, {
  name: 'statsInsights',
  subpath: 'stats/insights'
}, {
  name: 'statsPublicize',
  subpath: 'stats/publicize'
}, {
  name: 'statsReferrers',
  subpath: 'stats/referrers'
}, {
  name: 'statsSearchTerms',
  subpath: 'stats/search-terms'
}, {
  name: 'statsStreak',
  subpath: 'stats/streak'
}, {
  name: 'statsSummary',
  subpath: 'stats/summary'
}, {
  name: 'statsTags',
  subpath: 'stats/tags'
}, {
  name: 'statsTopAuthors',
  subpath: 'stats/top-authors'
}, {
  name: 'statsTopPosts',
  subpath: 'stats/top-posts'
}, {
  name: 'statsVideoPlays',
  subpath: 'stats/video-plays'
}, {
  name: 'statsVisits',
  subpath: 'stats/visits'
}, {
  name: 'tagsList',
  subpath: 'tags'
}, {
  name: 'usersList',
  subpath: 'users'
}, {
  name: 'wpcomPluginsList',
  subpath: 'wpcom-plugins'
}]);

/***/ }),

/***/ 8729:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/* harmony default export */ __webpack_exports__["Z"] = ([{
  name: 'likesList',
  subpath: 'likes'
}, {
  name: 'subscribersList',
  subpath: 'subscribers'
}]);

/***/ }),

/***/ 53388:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Category; }
/* harmony export */ });
/**
 * Category methods
 *
 * @param {string} [slug] - category slug
 * @param {string} sid - site id
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */
function Category(slug, sid, wpcom) {
  if (!sid) {
    throw new Error('`site id` is not correctly defined');
  }

  if (!(this instanceof Category)) {
    return new Category(slug, sid, wpcom);
  }

  this.wpcom = wpcom;
  this._sid = sid;
  this._slug = slug;
}
/**
 * Set category `slug`
 *
 * @param {string} slug - category slug
 */

Category.prototype.slug = function (slug) {
  this._slug = slug;
};
/**
 * Get category
 *
 * @param {object} [query] - query object parameter - query object parameter
 * @param {Function} fn - callback function - callback
 * @returns {Function} request handler
 */


Category.prototype.get = function (query, fn) {
  const path = '/sites/' + this._sid + '/categories/slug:' + this._slug;
  return this.wpcom.req.get(path, query, fn);
};
/**
 * Add category
 *
 * @param {object} [query] - query object parameter
 * @param {object} body - body object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Category.prototype.add = function (query, body, fn) {
  const path = '/sites/' + this._sid + '/categories/new';
  return this.wpcom.req.post(path, query, body, fn);
};
/**
 * Edit category
 *
 * @param {object} [query] - query object parameter
 * @param {object} body - body object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Category.prototype.update = function (query, body, fn) {
  const path = '/sites/' + this._sid + '/categories/slug:' + this._slug;
  return this.wpcom.req.put(path, query, body, fn);
};
/**
 * Delete category
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Category.prototype.delete = Category.prototype.del = function (query, fn) {
  const path = '/sites/' + this._sid + '/categories/slug:' + this._slug + '/delete';
  return this.wpcom.req.del(path, query, fn);
};

/***/ }),

/***/ 21832:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Comment; }
/* harmony export */ });
/* harmony import */ var _site_comment_like__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(77369);

/**
 * Comment methods
 *
 * @param {string} [cid] comment id
 * @param {string} [pid] post id
 * @param {string} sid site id
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */

function Comment(cid, pid, sid, wpcom) {
  if (!sid) {
    throw new Error('`site id` is not correctly defined');
  }

  if (!(this instanceof Comment)) {
    return new Comment(cid, pid, sid, wpcom);
  }

  this.wpcom = wpcom;
  this._cid = cid;
  this._pid = pid;
  this._sid = sid;
}
/**
 * Return a single Comment
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

Comment.prototype.get = function (query, fn) {
  const path = '/sites/' + this._sid + '/comments/' + this._cid;
  return this.wpcom.req.get(path, query, fn);
};
/**
 * Return recent comments for a post
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Comment.prototype.replies = function (query, fn) {
  const path = '/sites/' + this._sid + '/posts/' + this._pid + '/replies/';
  return this.wpcom.req.get(path, query, fn);
};
/**
 * Create a comment on a post
 *
 * @param {object} [query] - query object parameter
 * @param {string|object} body - body parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Comment.prototype.add = function (query, body, fn) {
  if (undefined === fn) {
    if (undefined === body) {
      body = query;
      query = {};
    } else if ('function' === typeof body) {
      fn = body;
      body = query;
      query = {};
    }
  }

  body = 'string' === typeof body ? {
    content: body
  } : body;
  const path = '/sites/' + this._sid + '/posts/' + this._pid + '/replies/new';
  return this.wpcom.req.post(path, query, body, fn);
};
/**
 * Edit a comment
 *
 * @param {object} [query] - query object parameter
 * @param {string|object} body - body parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Comment.prototype.update = function (query, body, fn) {
  if ('function' === typeof body) {
    fn = body;
    body = query;
    query = {};
  }

  body = 'string' === typeof body ? {
    content: body
  } : body;
  const path = '/sites/' + this._sid + '/comments/' + this._cid;
  return this.wpcom.req.put(path, query, body, fn);
};
/**
 * Create a Comment as a reply to another Comment
 *
 * @param {object} [query] - query object parameter
 * @param {string|object} body - body parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Comment.prototype.reply = function (query, body, fn) {
  if ('function' === typeof body) {
    fn = body;
    body = query;
    query = {};
  }

  body = 'string' === typeof body ? {
    content: body
  } : body;
  const path = '/sites/' + this._sid + '/comments/' + this._cid + '/replies/new';
  return this.wpcom.req.post(path, query, body, fn);
};
/**
 * Delete a comment
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Comment.prototype.del = Comment.prototype.delete = function (query, fn) {
  const path = '/sites/' + this._sid + '/comments/' + this._cid + '/delete';
  return this.wpcom.req.del(path, query, fn);
};
/**
 * Create a `commentLike` instance
 *
 * @returns {object} CommentLike instance
 */


Comment.prototype.like = function () {
  return (0,_site_comment_like__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(this._cid, this._sid, this.wpcom);
};
/**
 * Get comment likes list
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Comment.prototype.likesList = function (query, fn) {
  const path = '/sites/' + this._sid + '/comments/' + this._cid + '/likes';
  return this.wpcom.req.get(path, query, fn);
};

/***/ }),

/***/ 77369:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ CommentLike; }
/* harmony export */ });
/**
 * CommentLike methods
 *
 * @param {string} cid comment id
 * @param {string} sid site id
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */
function CommentLike(cid, sid, wpcom) {
  if (!sid) {
    throw new Error('`site id` is not correctly defined');
  }

  if (!cid) {
    throw new Error('`comment id` is not correctly defined');
  }

  if (!(this instanceof CommentLike)) {
    return new CommentLike(cid, sid, wpcom);
  }

  this.wpcom = wpcom;
  this._cid = cid;
  this._sid = sid;
}
/**
 * Get your Like status for a Comment
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

CommentLike.prototype.mine = CommentLike.prototype.state = function (query, fn) {
  const path = '/sites/' + this._sid + '/comments/' + this._cid + '/likes/mine';
  return this.wpcom.req.get(path, query, fn);
};
/**
 * Like a comment
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


CommentLike.prototype.add = function (query, fn) {
  const path = '/sites/' + this._sid + '/comments/' + this._cid + '/likes/new';
  return this.wpcom.req.post(path, query, fn);
};
/**
 * Remove your Like from a Comment
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


CommentLike.prototype.del = CommentLike.prototype.delete = function (query, fn) {
  const path = '/sites/' + this._sid + '/comments/' + this._cid + '/likes/mine/delete';
  return this.wpcom.req.del(path, query, fn);
};

/***/ }),

/***/ 52096:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/**
 * SiteCreditVouchers methods
 *
 * @param {string} sid - site id
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */
class SiteCreditVouchers {
  constructor(sid, wpcom) {
    if (!sid) {
      throw new Error('`site id` is not correctly defined');
    }

    if (!(this instanceof SiteCreditVouchers)) {
      return new SiteCreditVouchers(sid, wpcom);
    }

    this.wpcom = wpcom;
    this._sid = sid;
    this.path = `/sites/${this._sid}/vouchers`;
  }
  /**
   * Get site vouchers list
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  list() {
    let query = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    let fn = arguments.length > 1 ? arguments[1] : undefined;
    query.apiNamespace = 'wpcom/v2';
    return this.wpcom.req.get(this.path, query, fn);
  }
  /**
   * Get site voucher
   *
   * @param {string} serviceType - service type
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  get(serviceType) {
    let query = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    let fn = arguments.length > 2 ? arguments[2] : undefined;
    query.apiNamespace = 'wpcom/v2';
    return this.wpcom.req.get(`${this.path}/${serviceType}`, query, fn);
  }
  /**
   * Assign a new voucher to the site
   *
   * @param {string} serviceType - service type
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  assign(serviceType) {
    let query = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
    let fn = arguments.length > 2 ? arguments[2] : undefined;
    query.apiNamespace = 'wpcom/v2';
    return this.wpcom.req.post(`${this.path}/${serviceType}/assign`, query, {}, fn);
  }

}

/* harmony default export */ __webpack_exports__["Z"] = (SiteCreditVouchers);

/***/ }),

/***/ 67569:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/**
 * Module vars
 */
const root = '/sites';

class SiteDomain {
  /**
   * `SiteDomain` constructor.
   *
   * @param {number|string} id - site identifier
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {undefined} undefined
   */
  constructor(id, wpcom) {
    if (!(this instanceof SiteDomain)) {
      return new SiteDomain(id, wpcom);
    }

    this._sid = id;
    this.path = `${root}/${this._sid}/domains`;
    this.wpcom = wpcom;
  }
  /**
   * Get the primary domain for a site
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Function} request handler
   */


  getPrimary(query, fn) {
    return this.wpcom.req.get(`${this.path}/primary`, query, fn);
  }
  /**
   * Set the primary domain for a site
   *
   * @param {string} domain - domain to set
   * @param {Function} [fn] - callback function
   * @returns {Function} request handler
   */


  setPrimary(domain, fn) {
    return this.wpcom.req.put(`${this.path}/primary`, {}, {
      domain
    }, fn);
  }
  /**
   * Get the redirect status for a site
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Function} request handler
   */


  getRedirect(query, fn) {
    return this.wpcom.req.get(`${this.path}/redirect`, query, fn);
  }
  /**
   * Set the redirect location for a site
   *
   * @param {string|object} location - location to set
   * @param {Function} [fn] - callback function
   * @returns {Function} request handler
   */


  setRedirect(location, fn) {
    if (typeof location === 'string') {
      location = {
        location
      };
    }

    return this.wpcom.req.put(`${this.path}/redirect`, {}, location, fn);
  }

}
/**
 * Expose `SiteDomain` module
 */


/* harmony default export */ __webpack_exports__["Z"] = (SiteDomain);

/***/ }),

/***/ 78447:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Follow; }
/* harmony export */ });
/**
 * Follow
 *
 * @param {string} site_id - site id
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */
function Follow(site_id, wpcom) {
  if (!site_id) {
    throw new Error('`site id` is not correctly defined');
  }

  if (!(this instanceof Follow)) {
    return new Follow(site_id, wpcom);
  }

  this.wpcom = wpcom;
  this._sid = site_id;
}
/**
 * Get the follow status for current
 * user on current blog sites
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

Follow.prototype.mine = Follow.prototype.state = function (query, fn) {
  const path = '/sites/' + this._sid + '/follows/mine';
  return this.wpcom.req.get(path, query, fn);
};
/**
 * Follow the site
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Follow.prototype.follow = Follow.prototype.add = function (query, fn) {
  const path = '/sites/' + this._sid + '/follows/new';
  return this.wpcom.req.put(path, query, null, fn);
};
/**
 * Unfollow the site
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Follow.prototype.unfollow = Follow.prototype.del = function (query, fn) {
  const path = '/sites/' + this._sid + '/follows/mine/delete';
  return this.wpcom.req.del(path, query, null, fn);
};

/***/ }),

/***/ 32579:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _runtime_site_get__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(70209);
/* harmony import */ var _site_category__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(53388);
/* harmony import */ var _site_comment__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(21832);
/* harmony import */ var _site_credit_vouchers__WEBPACK_IMPORTED_MODULE_13__ = __webpack_require__(52096);
/* harmony import */ var _site_domain__WEBPACK_IMPORTED_MODULE_16__ = __webpack_require__(67569);
/* harmony import */ var _site_follow__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(78447);
/* harmony import */ var _site_media__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(8837);
/* harmony import */ var _site_plugin__WEBPACK_IMPORTED_MODULE_10__ = __webpack_require__(20361);
/* harmony import */ var _site_post__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(83164);
/* harmony import */ var _site_post_type__WEBPACK_IMPORTED_MODULE_14__ = __webpack_require__(77187);
/* harmony import */ var _site_settings__WEBPACK_IMPORTED_MODULE_15__ = __webpack_require__(60150);
/* harmony import */ var _site_tag__WEBPACK_IMPORTED_MODULE_7__ = __webpack_require__(5489);
/* harmony import */ var _site_taxonomy__WEBPACK_IMPORTED_MODULE_12__ = __webpack_require__(51986);
/* harmony import */ var _site_wordads__WEBPACK_IMPORTED_MODULE_8__ = __webpack_require__(11753);
/* harmony import */ var _site_wpcom_plugin__WEBPACK_IMPORTED_MODULE_11__ = __webpack_require__(54866);
/* harmony import */ var _util_runtime_builder__WEBPACK_IMPORTED_MODULE_9__ = __webpack_require__(99426);

















/**
 * Module vars
 */

const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('wpcom:site');
const root = '/sites';
/**
 * Site class
 */

class Site {
  /**
   * Create a Site instance
   *
   * @param {string} id - site id
   * @param wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(id, wpcom) {
    if (!(this instanceof Site)) {
      return new Site(id, wpcom);
    }

    this.wpcom = wpcom;
    debug('set %o site id', id);
    this._id = encodeURIComponent(id);
    this.path = `${root}/${this._id}`;
  }
  /**
   * Require site information
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  get(query, fn) {
    return this.wpcom.req.get(this.path, query, fn);
  }
  /**
   * Create a `Post` instance
   *
   * @param {string} id - post id
   * @returns {Post} Post instance
   */


  post(id) {
    return new _site_post__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z(id, this._id, this.wpcom);
  }
  /**
   * Add a new blog post
   *
   * @param {object} body - body object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  addPost(body, fn) {
    const post = new _site_post__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z(null, this._id, this.wpcom);
    return post.add(body, fn);
  }
  /**
   * Delete a blog post
   *
   * @param {string} id - post id
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  deletePost(id, fn) {
    const post = new _site_post__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z(id, this._id, this.wpcom);
    return post.delete(fn);
  }
  /**
   * Create a `Media` instance
   *
   * @param {string} id - post id
   * @returns {Media} Media instance
   */


  media(id) {
    return new _site_media__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z(id, this._id, this.wpcom);
  }
  /**
   * Add a media from a file
   *
   * @param {object} [query] - query object parameter
   * @param {Array|string} files - media files to add
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  addMediaFiles(query, files, fn) {
    const media = new _site_media__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z(null, this._id, this.wpcom);
    return media.addFiles(query, files, fn);
  }
  /**
   * Add a new media from url
   *
   * @param {object} [query] - query object parameter
   * @param {Array|string} files - media files to add
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  addMediaUrls(query, files, fn) {
    const media = new _site_media__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z(null, this._id, this.wpcom);
    return media.addUrls(query, files, fn);
  }
  /**
   * Delete a blog media
   *
   * @param {string} id - media id
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  deleteMedia(id, fn) {
    const media = new _site_media__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z(id, this._id, this.wpcom);
    return media.del(fn);
  }
  /**
   * Create a `Comment` instance
   *
   * @param {string} id - comment id
   * @returns {Comment} Comment instance
   */


  comment(id) {
    return new _site_comment__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z(id, null, this._id, this.wpcom);
  }
  /**
   * Create a `Follow` instance
   *
   * @returns {Follow} Follow instance
   */


  follow() {
    return new _site_follow__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z(this._id, this.wpcom);
  }
  /**
   * Create a `SitePlugin` instance
   *
   * @param {string} slug - plugin identifier
   * @returns {SitePlugin} SitePlugin instance
   */


  plugin(slug) {
    return new _site_plugin__WEBPACK_IMPORTED_MODULE_10__/* ["default"] */ .Z(slug, this._id, this.wpcom);
  }
  /**
   * Create a `SiteWPComPlugin` instance
   *
   * @param {string} slug - plugin identifier
   * @returns {SiteWPComPlugin} SiteWPComPlugin instance
   */


  wpcomPlugin(slug) {
    return new _site_wpcom_plugin__WEBPACK_IMPORTED_MODULE_11__/* ["default"] */ .Z(slug, this._id, this.wpcom);
  }
  /**
   * Create a `Category` instance
   * Set `cat` alias
   *
   * @param {string} [slug] - category slug
   * @returns {Category} Category instance
   */


  category(slug) {
    return new _site_category__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z(slug, this._id, this.wpcom);
  }
  /**
   * Create a `Tag` instance
   *
   * @param {string} [slug] - tag slug
   * @returns {Tag} Tag instance
   */


  tag(slug) {
    return new _site_tag__WEBPACK_IMPORTED_MODULE_7__/* ["default"] */ .Z(slug, this._id, this.wpcom);
  }
  /**
   * Create a `Taxonomy` instance
   *
   * @param {string} [slug] - taxonomy slug
   * @returns {SiteTaxonomy} SiteTaxonomy instance
   */


  taxonomy(slug) {
    return new _site_taxonomy__WEBPACK_IMPORTED_MODULE_12__/* ["default"] */ .Z(slug, this._id, this.wpcom);
  }
  /**
   * Create a `SiteCreditVouchers` instance
   *
   * @returns {SiteCreditVouchers} SiteCreditVouchers instance
   */


  creditVouchers() {
    return new _site_credit_vouchers__WEBPACK_IMPORTED_MODULE_13__/* ["default"] */ .Z(this._id, this.wpcom);
  }
  /**
   * Create a `SitePostType` instance
   *
   * @param {string} [slug] - post type slug
   * @returns {SitePostType} SitePostType instance
   */


  postType(slug) {
    return new _site_post_type__WEBPACK_IMPORTED_MODULE_14__/* ["default"] */ .Z(slug, this._id, this.wpcom);
  }
  /**
   * Create a `SiteSettings` instance
   *
   * @returns {SiteSettings} SiteSettings instance
   */


  settings() {
    return new _site_settings__WEBPACK_IMPORTED_MODULE_15__/* ["default"] */ .Z(this._id, this.wpcom);
  }
  /**
   * Create a `SiteDomain` instance
   *
   * @returns {SiteDomain} SiteDomain instance
   */


  domain() {
    return new _site_domain__WEBPACK_IMPORTED_MODULE_16__/* ["default"] */ .Z(this._id, this.wpcom);
  }
  /**
   * Get number of posts in the post type groups by post status
   *
   * Example:*
   *   // Get number post of pages
   *    wpcom
   *    .site( 'my-blog.wordpress.com' )
   *    .postCounts( 'page', function( err, data ) {
   *      // `counts` data object
   *    } );
   *
   * @param {string} type - post type
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  postCounts() {
    let type = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'post';
    let query = arguments.length > 1 ? arguments[1] : undefined;
    let fn = arguments.length > 2 ? arguments[2] : undefined;

    if ('function' === typeof query) {
      fn = query;
      query = {};
    }

    return this.wpcom.req.get(`${this.path}/post-counts/${type}`, query, fn);
  }
  /**
   * Get a rendered shortcode for a site.
   *
   * Note: The current user must have publishing access.
   *
   * @param {string} url - shortcode url
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  renderShortcode(url, query, fn) {
    if ('string' !== typeof url) {
      throw new TypeError('expected a url String');
    }

    if ('function' === typeof query) {
      fn = query;
      query = {};
    }

    query = query || {};
    query.shortcode = url;
    return this.wpcom.req.get(`${this.path}/shortcodes/render`, query, fn);
  }
  /**
   * Get a rendered embed for a site.
   *
   * Note: The current user must have publishing access.
   *
   * @param {string} url - embed url
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  renderEmbed(url, query, fn) {
    if ('string' !== typeof url) {
      throw new TypeError('expected an embed String');
    }

    if ('function' === typeof query) {
      fn = query;
      query = {};
    }

    query = query || {};
    query.embed_url = url;
    return this.wpcom.req.get(`${this.path}/embeds/render`, query, fn);
  }
  /**
   * Mark a referrering domain as spam
   *
   * @param {string} domain - domain
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  statsReferrersSpamNew(domain, fn) {
    const path = `${this.path}/stats/referrers/spam/new`;
    return this.wpcom.req.post(path, {
      domain
    }, null, fn);
  }
  /**
   * Remove referrering domain from spam
   *
   * @param {string} domain - domain
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  statsReferrersSpamDelete(domain, fn) {
    const path = `${this.path}/stats/referrers/spam/delete`;
    return this.wpcom.req.post(path, {
      domain
    }, null, fn);
  }
  /**
   * Get detailed stats about a VideoPress video
   *
   * @param {string} videoId - video id
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  statsVideo(videoId, query, fn) {
    const path = `${this.path}/stats/video/${videoId}`;

    if ('function' === typeof query) {
      fn = query;
      query = {};
    }

    return this.wpcom.req.get(path, query, fn);
  }
  /**
   * Get detailed stats about a particular post
   *
   * @param {string} postId - post id
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  statsPostViews(postId, query, fn) {
    const path = `${this.path}/stats/post/${postId}`;

    if ('function' === typeof query) {
      fn = query;
      query = {};
    }

    return this.wpcom.req.get(path, query, fn);
  }
  /**
   * Return a `SiteWordAds` instance.
   *
   * Example:*
   *    // Create a SiteWordAds instance
   *
   *    const wordAds = wpcom
   *      .site( 'my-blog.wordpress.com' )
   *      .wordAds();
   *
   * @returns {SiteWordAds} SiteWordAds instance
   */


  wordAds() {
    return new _site_wordads__WEBPACK_IMPORTED_MODULE_8__/* ["default"] */ .Z(this._id, this.wpcom);
  }

} // add methods in runtime


(0,_util_runtime_builder__WEBPACK_IMPORTED_MODULE_9__/* ["default"] */ .Z)(Site, _runtime_site_get__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, (methodParams, ctx) => {
  return `/sites/${ctx._id}/${methodParams.subpath}`;
});
/* harmony default export */ __webpack_exports__["Z"] = (Site);

/***/ }),

/***/ 8837:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Media; }
/* harmony export */ });
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _tus_uploader__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(78183);
/* harmony import */ var _util_fs__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(76426);



const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('wpcom:media');
/**
 * Build a formData object to be sent in a POST request
 *
 * @param  {Array|File} files - array of files
 * @returns {Array} formData array
 */

function buildFormData(files) {
  const formData = [];
  const isArray = Array.isArray(files);
  files = isArray ? files : [files];
  let i;
  let f;
  let k;
  let param;

  for (i = 0; i < files.length; i++) {
    f = files[i];

    if ('string' === typeof f) {
      f = (0,_util_fs__WEBPACK_IMPORTED_MODULE_2__/* .createReadStream */ .U)(f);
    }

    const isStream = !!f._readableState;
    const isFile = 'undefined' !== typeof File && f instanceof File;
    debug('isStream: %s', isStream);
    debug('isFile: %s', isFile);

    if (!isFile && !isStream) {
      // process file attributes like as `title`, `description`, ...
      for (k in f) {
        debug('add %o => %o', k, f[k]);

        if ('file' !== k) {
          param = 'attrs[' + i + '][' + k + ']';
          formData.push([param, f[k]]);
        }
      } // set file path


      f = f.file;

      if ('string' === typeof f) {
        f = (0,_util_fs__WEBPACK_IMPORTED_MODULE_2__/* .createReadStream */ .U)(f);
      }
    }

    formData.push(['media[]', f]);
  }

  return formData;
}
/**
 * Media methods
 *
 * @param {string} id - media id
 * @param {string} sid site id
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */


function Media(id, sid, wpcom) {
  if (!(this instanceof Media)) {
    return new Media(id, sid, wpcom);
  }

  this.wpcom = wpcom;
  this._sid = sid;
  this._id = id;

  if (!this._id) {
    debug('WARN: media `id` is not defined');
  }
}
/**
 * Get media
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

Media.prototype.get = function () {
  let query = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  let fn = arguments.length > 1 ? arguments[1] : undefined;
  query.apiVersion = query.apiVersion || '1.2';
  const path = '/sites/' + this._sid + '/media/' + this._id;
  return this.wpcom.req.get(path, query, fn);
};
/**
 * Update media
 *
 * @param {object} [query] - query object parameter
 * @param {object} body - body object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Media.prototype.update = function (query, body, fn) {
  const params = {
    path: '/sites/' + this._sid + '/media/' + this._id
  };
  return this.wpcom.req.put(params, query, body, fn);
};
/**
 * Edit media
 *
 * @param {object} [query] - query object parameter
 * @param {object} body - body object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Media.prototype.edit = function (query, body, fn) {
  if (typeof body === 'function' || !body) {
    fn = body;
    body = query;
    query = {};
  }

  const params = {
    path: '/sites/' + this._sid + '/media/' + this._id + '/edit'
  };

  if (body && body.media) {
    params.formData = [['media', body.media]];
    delete body.media;

    for (const k in body) {
      params.formData.push([`attrs[${k}]`, body[k]]);
    }

    body = null;
  }

  return this.wpcom.req.put(params, query, body, fn);
};
/**
 * Add media file
 *
 * @param {object} [query] - query object parameter
 * @param {string|object|Array} files - files to add
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Media.prototype.addFiles = function (query, files, fn) {
  if (undefined === fn) {
    if (undefined === files) {
      files = query;
      query = {};
    } else if ('function' === typeof files) {
      fn = files;
      files = query;
      query = {};
    }
  }

  if (!Array.isArray(files)) {
    files = [files];
  }

  const videoFiles = this.filterFilesUploadableOnVideoPress(files);

  if (videoFiles.length) {
    const uploader = new _tus_uploader__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z(this.wpcom, this._sid);
    return uploader.startUpload(videoFiles);
  }

  const params = {
    path: '/sites/' + this._sid + '/media/new',
    formData: buildFormData(files)
  };
  return this.wpcom.req.post(params, query, null, fn);
};
/**
 * Filters an array to only return files that can use VideoPress for upload.
 *
 * @param {Array} files An array of file objects
 * @returns {Array}
 */


Media.prototype.filterFilesUploadableOnVideoPress = function (files) {
  return files.filter(file => this.fileCanBeUploadedOnVideoPress(file));
};
/**
 * Checks whether a media file can use VideoPress for upload.
 *
 * @param {object} file A file object
 * @returns {boolean}
 */


Media.prototype.fileCanBeUploadedOnVideoPress = function (file) {
  return !!file.canUseVideoPress && !!file.type && file.type.startsWith('video/');
};
/**
 * Add media files from URL
 *
 * @param {object} [query] - query object parameter
 * @param {string|Array|object} media - files to add
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Media.prototype.addUrls = function (query, media, fn) {
  if (undefined === fn) {
    if (undefined === media) {
      media = query;
      query = {};
    } else if ('function' === typeof media) {
      fn = media;
      media = query;
      query = {};
    }
  }

  const path = '/sites/' + this._sid + '/media/new';
  const body = {
    media_urls: []
  }; // process formData

  let i;
  let m;
  let url;
  let k;
  media = Array.isArray(media) ? media : [media];

  for (i = 0; i < media.length; i++) {
    m = media[i];

    if ('string' === typeof m) {
      url = m;
    } else {
      if (!body.attrs) {
        body.attrs = [];
      } // add attributes


      body.attrs[i] = {};

      for (k in m) {
        if ('url' !== k) {
          body.attrs[i][k] = m[k];
        }
      }

      url = m.url;
    } // push url into [media_url]


    body.media_urls.push(url);
  }

  return this.wpcom.req.post(path, query, body, fn);
};
/**
 * Delete media
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Media.prototype.delete = Media.prototype.del = function (query, fn) {
  const path = '/sites/' + this._sid + '/media/' + this._id + '/delete';
  return this.wpcom.req.del(path, query, fn);
};

/***/ }),

/***/ 20361:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/**
 * Module vars
 */
const root = '/sites';

class SitePlugin {
  /**
   * `SitePlugin` constructor.
   *
   * @param {string} [slug] - the plugin slug
   * @param {number|string} sid - site identifier
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {undefined} undefined
   */
  constructor(slug, sid, wpcom) {
    if (!(this instanceof SitePlugin)) {
      return new SitePlugin(slug, sid, wpcom);
    }

    if (!slug) {
      throw new Error('`slug` is not correctly defined');
    }

    this._slug = encodeURIComponent(slug);
    this._sid = sid;
    this.wpcom = wpcom;
    const path = `${root}/${this._sid}/plugins`;
    this.pluginPath = `${path}/${this._slug}`;
  }
  /**
   * Get informtion about the plugin
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  get(query, fn) {
    return this.wpcom.req.get(this.pluginPath, query, fn);
  }
  /**
   * Update the plugin configuration
   *
   * @param {object} [query] - query object parameter
   * @param {object} body - plugin body object
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  update(query, body, fn) {
    return this.wpcom.req.put(this.pluginPath, query, body, fn);
  }
  /**
   * Update the plugin version
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  updateVersion(query, fn) {
    return this.wpcom.req.put(`${this.pluginPath}/update`, query, fn);
  }
  /**
   * Install the plugin
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  install(query, fn) {
    const body = {
      slug: this._slug
    };
    return this.wpcom.req.post(`${root}/${this._sid}/plugins/install`, query, body, fn);
  }
  /**
   * Delete the plugin
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  delete(query, fn) {
    return this.wpcom.req.put(`${this.pluginPath}/delete`, query, fn);
  }
  /**
   * Activate the plugin
   * This method is a shorthand of update()
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  activate(query, fn) {
    return this.update(query, {
      active: true
    }, fn);
  }
  /**
   * Deactivate the plugin
   * This method is a shorthand of update()
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  deactivate(query, fn) {
    return this.update(query, {
      active: false
    }, fn);
  }
  /**
   * Enable plugin autoupdate
   * This method is a shorthand of update()
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  enableAutoupdate(query, fn) {
    return this.update(query, {
      autoupdate: true
    }, fn);
  }
  /**
   * Disable plugin autoupdate
   * This method is a shorthand of update()
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  disableAutoupdate(query, fn) {
    return this.update(query, {
      autoupdate: false
    }, fn);
  }

}
/**
 * Expose `SitePlugin` module
 */


/* harmony default export */ __webpack_exports__["Z"] = (SitePlugin);

/***/ }),

/***/ 77187:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ SitePostType; }
/* harmony export */ });
/**
 * SitePostType class
 */
class SitePostType {
  /**
   * Create a SitePostType instance
   *
   * @param {string} postType - post type
   * @param {string} siteId - site id
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(postType, siteId, wpcom) {
    if (!siteId) {
      throw new TypeError('`siteId` is not correctly defined');
    }

    if (!postType) {
      throw new TypeError('`postType` is not correctly defined');
    }

    if (!(this instanceof SitePostType)) {
      return new SitePostType(postType, siteId, wpcom);
    }

    this.wpcom = wpcom;
    this._siteId = encodeURIComponent(siteId);
    this._postType = encodeURIComponent(postType);
    this._rootPath = `/sites/${this._siteId}/post-types/${this._postType}`;
  }
  /**
   * Get a list of taxonomies for the post type
   *
   * @param {object} query - query object
   * @param {Function} fn - callback function
   * @returns {Promise} Promise
   */


  taxonomiesList(query, fn) {
    const termsPath = `${this._rootPath}/taxonomies`;
    return this.wpcom.req.get(termsPath, query, fn);
  }

}

/***/ }),

/***/ 83164:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _runtime_site_post_get__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(8729);
/* harmony import */ var _site_comment__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(21832);
/* harmony import */ var _site_post_like__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(19932);
/* harmony import */ var _site_post_reblog__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(93185);
/* harmony import */ var _site_post_subscriber__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(52250);
/* harmony import */ var _util_runtime_builder__WEBPACK_IMPORTED_MODULE_6__ = __webpack_require__(99426);







/**
 * Module vars
 */

const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('wpcom:post');
const root = '/sites';
/**
 * SitePost class
 */

class SitePost {
  /**
   * SitePost methods
   *
   * @param {string} id - post id
   * @param {string} sid site id
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(id, sid, wpcom) {
    if (!(this instanceof SitePost)) {
      return new SitePost(id, sid, wpcom);
    }

    this.wpcom = wpcom;
    this._sid = sid;
    this.path = `${root}/${this._sid}/posts`; // set `id` and/or `slug` properties

    id = id || {};

    if ('object' !== typeof id) {
      this._id = id;
    } else {
      this._id = id.id;
      this._slug = id.slug;
    }
  }
  /**
   * Set post `id`
   *
   * @param {string} id - site id
   */


  id(id) {
    this._id = id;
  }
  /**
   * Set post `slug`
   *
   * @param {string} slug - site slug
   */


  slug(slug) {
    this._slug = slug;
  }
  /**
   * Get post url path
   *
   * @returns {string} post path
   */


  getPostPath() {
    return `${this.path}/${this._id}`;
  }
  /**
   * Get post
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  get(query, fn) {
    if (!this._id && this._slug) {
      return this.getBySlug(query, fn);
    }

    return this.wpcom.req.get(this.getPostPath(), query, fn);
  }
  /**
   * Get post by slug
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  getBySlug(query, fn) {
    return this.wpcom.req.get(`${this.path}/slug:${this._slug}`, query, fn);
  }
  /**
   * Add post
   *
   * @param {object} [query] - query object parameter
   * @param {object} body - body object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  add(query, body, fn) {
    if (undefined === fn) {
      if (undefined === body) {
        body = query;
        query = {};
      } else if ('function' === typeof body) {
        fn = body;
        body = query;
        query = {};
      }
    }

    return this.wpcom.req.post(`${this.path}/new`, query, body).then(data => {
      // update POST object
      this._id = data.ID;
      debug('Set post _id: %s', this._id);
      this._slug = data.slug;
      debug('Set post _slug: %s', this._slug);

      if ('function' === typeof fn) {
        fn(null, data);
      } else {
        return Promise.resolve(data);
      }
    }).catch(err => {
      if ('function' === typeof fn) {
        fn(err);
      } else {
        return Promise.reject(err);
      }
    });
  }
  /**
   * Edit post
   *
   * @param {object} [query] - query object parameter
   * @param {object} body - body object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  update(query, body, fn) {
    return this.wpcom.req.put(this.getPostPath(), query, body, fn);
  }
  /**
   * Delete post
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Promise} Promise
   */


  delete(query, fn) {
    const path = `${this.getPostPath()}/delete`;
    return this.wpcom.req.del(path, query, fn);
  }
  /**
   * Del post, alias of Delete
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Promise} Promise
   */


  del(query, fn) {
    return this.delete(query, fn);
  }
  /**
   * Restore post
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  restore(query, fn) {
    return this.wpcom.req.put(`${this.getPostPath()}/restore`, query, null, fn);
  }
  /**
   * Search within a site for related posts
   *
   * @param {object} body - body object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  related(body, fn) {
    return this.wpcom.req.put(`${this.getPostPath()}/related`, body, null, fn);
  }
  /**
   * Create a `Comment` instance
   *
   * @param {string} [cid] - comment id
   * @returns {Comment} Comment instance
   */


  comment(cid) {
    return new _site_comment__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z(cid, this._id, this._sid, this.wpcom);
  }
  /**
   * Return recent comments
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  comments(query, fn) {
    const comment = new _site_comment__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z(null, this._id, this._sid, this.wpcom);
    return comment.replies(query, fn);
  }
  /**
   * Create a `Like` instance
   *
   * @returns {Like} Like instance
   */


  like() {
    return new _site_post_like__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z(this._id, this._sid, this.wpcom);
  }
  /**
   * Create a `Reblog` instance
   *
   * @returns {Reblog} Reblog instance
   */


  reblog() {
    return new _site_post_reblog__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z(this._id, this._sid, this.wpcom);
  }
  /**
   * Return a `Subscriber` instance.
   *
   * Example:
   *    // Create a Subscriber instance of a post
   *    var post = wpcom.site( 'en.blog.wordpress.com' ).post( 1234 );
   *    var subs = post.subscriber();
   *
   * @returns {Subscriber} Subscriber instance
   */


  subscriber() {
    return new _site_post_subscriber__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z(this._id, this._sid, this.wpcom);
  }

} // add methods in runtime


(0,_util_runtime_builder__WEBPACK_IMPORTED_MODULE_6__/* ["default"] */ .Z)(SitePost, _runtime_site_post_get__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z, (item, ctx) => {
  return `/sites/${ctx._sid}/posts/${ctx._id}/${item.subpath}`;
});
/* harmony default export */ __webpack_exports__["Z"] = (SitePost);

/***/ }),

/***/ 19932:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Like; }
/* harmony export */ });
/**
 * Like methods
 *
 * @param {string} pid - post id
 * @param {string} sid - site id
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */
function Like(pid, sid, wpcom) {
  if (!sid) {
    throw new Error('`site id` is not correctly defined');
  }

  if (!pid) {
    throw new Error('`post id` is not correctly defined');
  }

  if (!(this instanceof Like)) {
    return new Like(pid, sid, wpcom);
  }

  this.wpcom = wpcom;
  this._pid = pid;
  this._sid = sid;
}
/**
 * Get your Like status for a Post
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 */

Like.prototype.mine = Like.prototype.state = function (query, fn) {
  const path = '/sites/' + this._sid + '/posts/' + this._pid + '/likes/mine';
  return this.wpcom.req.get(path, query, fn);
};
/**
 * Like a post
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Like.prototype.add = function (query, fn) {
  const path = '/sites/' + this._sid + '/posts/' + this._pid + '/likes/new';
  return this.wpcom.req.put(path, query, null, fn);
};
/**
 * Remove your Like from a Post
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 */


Like.prototype.del = Like.prototype.delete = function (query, fn) {
  const path = '/sites/' + this._sid + '/posts/' + this._pid + '/likes/mine/delete';
  return this.wpcom.req.del(path, query, fn);
};

/***/ }),

/***/ 93185:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Reblog; }
/* harmony export */ });
/**
 * Reblog methods
 *
 * @param {string} pid post id
 * @param {string} sid site id
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */
function Reblog(pid, sid, wpcom) {
  if (!sid) {
    throw new Error('`site id` is not correctly defined');
  }

  if (!pid) {
    throw new Error('`post id` is not correctly defined');
  }

  if (!(this instanceof Reblog)) {
    return new Reblog(pid, sid, wpcom);
  }

  this.wpcom = wpcom;
  this._pid = pid;
  this._sid = sid;
}
/**
 * Get your reblog status for a Post
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

Reblog.prototype.mine = Reblog.prototype.state = function (query, fn) {
  const path = '/sites/' + this._sid + '/posts/' + this._pid + '/reblogs/mine';
  return this.wpcom.req.get(path, query, fn);
};
/**
 * Reblog a post
 *
 * @param {object} [query] - query object parameter
 * @param {object} body - body object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Reblog.prototype.add = function (query, body, fn) {
  if ('function' === typeof body) {
    fn = body;
    body = query;
    query = {};
  }

  if (body && !body.destination_site_id) {
    return fn(new Error('destination_site_id is not defined'));
  }

  const path = '/sites/' + this._sid + '/posts/' + this._pid + '/reblogs/new';
  return this.wpcom.req.put(path, query, body, fn);
};
/**
 * Reblog a post to
 * It's almost an alias of Reblogs#add
 *
 * @param {number|string} dest site id destination
 * @param {string} [note] - post reblog note
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Reblog.prototype.to = function (dest, note, fn) {
  if (undefined === fn) {
    if (undefined === note) {
      note = null;
    } else if ('function' === typeof note) {
      fn = note;
      note = null;
    }
  }

  return this.add({
    note: note,
    destination_site_id: dest
  }, fn);
};

/***/ }),

/***/ 52250:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
class SitePostSubscriber {
  /**
   * `SitePostSubscriber` constructor.
   *
   * @param {string} id - post identifier
   * @param {string} sid - site identifier
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(id, sid, wpcom) {
    if (!sid) {
      throw new Error('`side id` is not correctly defined');
    }

    if (!id) {
      throw new Error('`post id` is not correctly defined');
    }

    if (!(this instanceof SitePostSubscriber)) {
      return new SitePostSubscriber(id, sid, wpcom);
    }

    this.wpcom = wpcom;
    this._id = id;
    this._sid = sid;
    this.path = `/sites/${this._sid}/posts/${this._id}/subscribers`;
  }
  /**
   * Get subscriber status for the current user for the Post.
   *
   *
   * Example:
   *    Get subscriber status for the current user for the Post
   *    wpcom
   *    .site( 'en.blog.wordpress.com' )
   *    .post( 1234 )
   *    .subscriber()
   *    .mine( function( err, data ) {
   *      // subscription data
   *    } );
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Promise} Promise
   */


  mine(query, fn) {
    return this.wpcom.req.get(`${this.path}/mine`, query, fn);
  }
  /**
   * Subscribe the current user to the post.
   *
   * Example:
   *    // Subscribe the current user to the post
   *    wpcom
   *    .site( 'en.blog.wordpress.com' )
   *    .post( 1234 )
   *    .subscriber()
   *    .add( function( err, data ) {
   *      // current user has been subscribed to post
   *    } );
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Promise} Promise
   */


  add(query, fn) {
    return this.wpcom.req.put(`${this.path}/new`, query, null, fn);
  }
  /**
   * Unsubscribe current user to the post
   *
   * Example:
   *    // Unsubscribe current user to the post
   *    wpcom
   *    .site( 'en.blog.wordpress.com' )
   *    .post( 1234 )
   *    .subscriber()
   *    .del( function( err, data ) {
   *      // current user has been unsubscribed to post
   *    } );
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Promise} Promise
   */


  del(query, fn) {
    return this.wpcom.req.del(`${this.path}/mine/delete`, query, fn);
  }

} // method alias


SitePostSubscriber.prototype.state = SitePostSubscriber.prototype.mine;
SitePostSubscriber.prototype.delete = SitePostSubscriber.prototype.del;
/* harmony default export */ __webpack_exports__["Z"] = (SitePostSubscriber);

/***/ }),

/***/ 60150:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/**
 * SiteSettings methods
 *
 * @param {string} sid - site id
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */
class SiteSettings {
  constructor(sid, wpcom) {
    if (!sid) {
      throw new Error('`site id` is not correctly defined');
    }

    if (!(this instanceof SiteSettings)) {
      return new SiteSettings(sid, wpcom);
    }

    this.wpcom = wpcom;
    this._sid = sid;
    this.path = `/sites/${this._sid}/settings`;
  }
  /**
   * Get site-settings
   *
   * @param {object} [query] - query object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  get(query, fn) {
    return this.wpcom.req.get(this.path, query, fn);
  }
  /**
   * Get site-settings single option
   *
   * @param {string} option - option to ask
   * @param {Function} [fn] - callback function
   * @returns {Function} request handler
   */


  getOption(option) {
    let fn = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : () => {};
    const query = {
      fields: 'settings'
    };
    return new Promise((resolve, reject) => {
      this.wpcom.req.get(this.path, query, (err, data) => {
        if (err) {
          fn(err);
          return reject(err);
        }

        if (!data) {
          fn();
          return resolve();
        }

        const settings = data.settings;

        if (settings && typeof settings[option] !== 'undefined') {
          fn(null, settings[option]);
          return resolve(settings[option]);
        }

        fn(null, data);
        return resolve(data);
      });
    });
  }
  /**
   * Update site-settings
   *
   * @param {object} [query] - query object parameter
   * @param {object} body - body object parameter
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  update(query, body, fn) {
    return this.wpcom.req.put(this.path, query, body, fn);
  }
  /**
   * Set site-settings single option
   *
   * @param {string} option - option to set
   * @param {*} value - value to assing to the given option
   * @param {Function} fn - callback function
   * @returns {Function} request handler
   */


  setOption(option, value, fn) {
    return this.wpcom.req.put(this.path, {}, {
      [option]: value
    }, fn);
  }

}

/* harmony default export */ __webpack_exports__["Z"] = (SiteSettings);

/***/ }),

/***/ 5489:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Tag; }
/* harmony export */ });
/**
 * Tag methods
 *
 * @param {string} [slug] - tag slug
 * @param {string} sid - site id
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */
function Tag(slug, sid, wpcom) {
  if (!sid) {
    throw new Error('`site id` is not correctly defined');
  }

  if (!(this instanceof Tag)) {
    return new Tag(slug, sid, wpcom);
  }

  this.wpcom = wpcom;
  this._sid = sid;
  this._slug = slug;
}
/**
 * Set tag `slug`
 *
 * @param {string} slug - tag slug
 */

Tag.prototype.slug = function (slug) {
  this._slug = slug;
};
/**
 * Get tag
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Tag.prototype.get = function (query, fn) {
  const path = '/sites/' + this._sid + '/tags/slug:' + this._slug;
  return this.wpcom.req.get(path, query, fn);
};
/**
 * Add tag
 *
 * @param {object} [query] - query object parameter
 * @param {object} body - body object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Tag.prototype.add = function (query, body, fn) {
  const path = '/sites/' + this._sid + '/tags/new';
  return this.wpcom.req.post(path, query, body, fn);
};
/**
 * Edit tag
 *
 * @param {object} [query] - query object parameter
 * @param {object} body - body object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Tag.prototype.update = function (query, body, fn) {
  const path = '/sites/' + this._sid + '/tags/slug:' + this._slug;
  return this.wpcom.req.put(path, query, body, fn);
};
/**
 * Delete tag
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Tag.prototype.delete = Tag.prototype.del = function (query, fn) {
  const path = '/sites/' + this._sid + '/tags/slug:' + this._slug + '/delete';
  return this.wpcom.req.del(path, query, fn);
};

/***/ }),

/***/ 51986:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _site_taxonomy_term__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(14046);

/**
 * SiteTaxonomy class
 */

class SiteTaxonomy {
  /**
   * Create a SiteTaxonomy instance
   *
   * @param {string} taxonomy - taxonomy type
   * @param {string} siteId - site id
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(taxonomy, siteId, wpcom) {
    if (!siteId) {
      throw new TypeError('`siteId` is not correctly defined');
    }

    if (!taxonomy) {
      throw new TypeError('`taxonomy` is not correctly defined');
    }

    if (!(this instanceof SiteTaxonomy)) {
      return new SiteTaxonomy(taxonomy, siteId, wpcom);
    }

    this.wpcom = wpcom;
    this._siteId = encodeURIComponent(siteId);
    this._taxonomy = encodeURIComponent(taxonomy);
    this._rootPath = `/sites/${this._siteId}/taxonomies/${this._taxonomy}`;
  }
  /**
   * Get a list of Terms for the Taxonomy
   *
   * @param {object} [query] - query object
   * @param {Function} fn - callback function
   * @returns {Promise} Promise
   */


  termsList(query, fn) {
    const termsPath = `${this._rootPath}/terms`;
    return this.wpcom.req.get(termsPath, query, fn);
  }
  /**
   * Return `Term` instance
   *
   * @param {string} [term] - term slug
   * @returns {SiteTaxonomyTerm} Term instance
   */


  term(term) {
    return new _site_taxonomy_term__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z(term, this._taxonomy, this._siteId, this.wpcom);
  }

}

/* harmony default export */ __webpack_exports__["Z"] = (SiteTaxonomy);

/***/ }),

/***/ 14046:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/**
 * SiteTaxonomyTerm class
 */
class SiteTaxonomyTerm {
  /**
   * Create a SiteTaxonomyTerm instance
   *
   * @param {string} term - term slug
   * @param {string} taxonomy - taxonomy type
   * @param {string} siteId - site id
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {null} null
   */
  constructor(term, taxonomy, siteId, wpcom) {
    if (!siteId) {
      throw new TypeError('`siteId` is not correctly defined');
    }

    if (!taxonomy) {
      throw new TypeError('`taxonomy` is not correctly defined');
    }

    if (!(this instanceof SiteTaxonomyTerm)) {
      return new SiteTaxonomyTerm(term, taxonomy, siteId, wpcom);
    }

    this.wpcom = wpcom;
    this._siteId = encodeURIComponent(siteId);
    this._taxonomy = encodeURIComponent(taxonomy);
    this._term = encodeURIComponent(term);
    this._taxonomyPath = `/sites/${this._siteId}/taxonomies/${this._taxonomy}/terms`;
  }
  /**
   * Get Term details
   *
   * @param {object} [query] - query parameters
   * @param {Function} fn - callback function
   * @returns {Promise} Promise
   */


  get(query, fn) {
    if (!this._term) {
      throw new Error('`term` is not correctly defined');
    }

    if ('function' === typeof query) {
      fn = query;
      query = {};
    }

    const path = `${this._taxonomyPath}/slug:${this._term}`;
    return this.wpcom.req.get(path, query, fn);
  }
  /**
   * Add new Term
   *
   * @param {object} [params] - term parameters
   * @param {Function} fn - callback function
   * @returns {Promise} Promise
   */


  add(params, fn) {
    if (!params || !params.name) {
      throw new Error('`params.name` is not correctly defined');
    }

    const path = `${this._taxonomyPath}/new`;
    return this.wpcom.req.post(path, params, fn);
  }
  /**
   * Delete Term
   *
   * @param {Function} fn - callback function
   * @returns {Promise} Promise
   */


  delete(fn) {
    if (!this._term) {
      throw new Error('`term` is not correctly defined');
    }

    const path = `${this._taxonomyPath}/slug:${this._term}/delete`;
    return this.wpcom.req.del(path, fn);
  }
  /**
   * Update Term
   *
   * @param {object} [params] - term parameters
   * @param {Function} fn - callback function
   * @returns {Promise} Promise
   */


  update(params, fn) {
    if (!this._term) {
      throw new Error('`term` is not correctly defined');
    }

    const path = `${this._taxonomyPath}/slug:${this._term}`;
    return this.wpcom.req.put(path, params, fn);
  }

}

/* harmony default export */ __webpack_exports__["Z"] = (SiteTaxonomyTerm);

/***/ }),

/***/ 93243:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ SiteWordAdsEarnings; }
/* harmony export */ });
/**
 * `SiteWordAdsEarnings` constructor.
 *
 * @param {string} sid - site identifier
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */
function SiteWordAdsEarnings(sid, wpcom) {
  if (!(this instanceof SiteWordAdsEarnings)) {
    return new SiteWordAdsEarnings(sid, wpcom);
  }

  this._sid = sid;
  this.wpcom = wpcom;
}
/**
 * Get detailed WordAds earnings information about the site.
 *
 * *Example:*
 *    // Get site earnings information
 *    wpcom
 *    .site( 'my-blog.wordpress.com' )
 *    .wordAds()
 *    .earnings()
 *    .get( function( err, data ) {
 *      // `earnings` information object
 *    } );
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

SiteWordAdsEarnings.prototype.get = function (query, fn) {
  return this.wpcom.req.get('/sites/' + this._sid + '/wordads/earnings', query, fn);
};

/***/ }),

/***/ 11753:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ SiteWordAds; }
/* harmony export */ });
/* harmony import */ var _site_wordads_earnings__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(93243);
/* harmony import */ var _site_wordads_settings__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(54549);
/* harmony import */ var _site_wordads_tos__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(71731);



/**
 * `SiteWordAds` constructor.
 *
 * Use a `WPCOM#Me` instance to create a new `SiteWordAds` instance.
 *
 * @param {string} sid - site identifier
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */

function SiteWordAds(sid, wpcom) {
  if (!(this instanceof SiteWordAds)) {
    return new SiteWordAds(sid, wpcom);
  }

  this._sid = sid;
  this.wpcom = wpcom;
}
/**
 * Return a `SiteWordAdsSettings` instance.
 *
 * *Example:*
 *    // Create a SiteWordAdsSettings instance
 *
 *    var wordAds = wpcom
 *      .site( 'my-blog.wordpress.com' )
 *      .wordAds()
 *      .settings();
 *
 * @returns {SiteWordAdsSettings} site WordAds settings instance
 */

SiteWordAds.prototype.settings = function () {
  return new _site_wordads_settings__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z(this._sid, this.wpcom);
};
/**
 * Return a `SiteWordAdsEarnings` instance.
 *
 * *Example:*
 *    // Create a SiteWordAdsEarnings instance
 *
 *    var wordAds = wpcom
 *      .site( 'my-blog.wordpress.com' )
 *      .wordAds()
 *      .earnings();
 *
 * @returns {SiteWordAdsEarnings} site WordAds earnings instance
 */


SiteWordAds.prototype.earnings = function () {
  return new _site_wordads_earnings__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z(this._sid, this.wpcom);
};
/**
 * Return a `SiteWordAdsTOS` instance.
 *
 * *Example:*
 *    // Create a SiteWordAdsTOS instance
 *
 *    var wordAds = wpcom
 *      .site( 'my-blog.wordpress.com' )
 *      .wordAds()
 *      .tos();
 *
 * Return  SiteWordAdsTOS object for the site.
 *
 * @returns {SiteWordAdsTOS} site wordAds TOS instance
 */


SiteWordAds.prototype.tos = function () {
  return new _site_wordads_tos__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z(this._sid, this.wpcom);
};

/***/ }),

/***/ 54549:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ SiteWordAdsSettings; }
/* harmony export */ });
/**
 * `SiteWordAdsSettings` constructor.
 *
 * @param {string} sid - site identifier
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */
function SiteWordAdsSettings(sid, wpcom) {
  if (!(this instanceof SiteWordAdsSettings)) {
    return new SiteWordAdsSettings(sid, wpcom);
  }

  this._sid = sid;
  this.wpcom = wpcom;
}
/**
 * Get detailed WordAds settings information about the site.
 *
 * *Example:*
 *    // Get site settings information
 *    wpcom
 *    .site( 'my-blog.wordpress.com' )
 *    .wordAds()
 *    .settings()
 *    .get( function( err, data ) {
 *      // `settings` information object
 *    } );
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

SiteWordAdsSettings.prototype.get = function (query, fn) {
  return this.wpcom.req.get('/sites/' + this._sid + '/wordads/settings', query, fn);
};
/**
 * Update WordAds settings for the site.
 *
 * *Example:*
 *    var settings = {}; // your settings here
 *
 *    // Get site settings information
 *    wpcom
 *    .site( 'my-blog.wordpress.com' )
 *    .wordAds()
 *    .settings()
 *    .update( settings, function( err, data ) {
 *      // data settings information object
 *    } );
 *
 * @param {object} [query] - query object parameter
 * @param {object} body - body object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


SiteWordAdsSettings.prototype.update = function (query, body, fn) {
  const path = '/sites/' + this._sid + '/wordads/settings';
  return this.wpcom.req.post(path, query, body, fn);
};

/***/ }),

/***/ 71731:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ SiteWordAdsTOS; }
/* harmony export */ });
/**
 * `SiteWordAdsTOS` constructor.
 *
 * @param {string} sid - site identifier
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */
function SiteWordAdsTOS(sid, wpcom) {
  if (!(this instanceof SiteWordAdsTOS)) {
    return new SiteWordAdsTOS(sid, wpcom);
  }

  this._sid = sid;
  this.wpcom = wpcom;
}
/**
 * GET site's WordAds TOS
 *
 * Example:
 *    // Get site TOS information
 *    wpcom
 *    .site( 'my-blog.wordpress.com' )
 *    .wordAds()
 *    .tos()
 *    .get( function( err, data ) {
 *      // `settings` information object
 *    } );
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

SiteWordAdsTOS.prototype.get = function (query, fn) {
  return this.wpcom.req.get('/sites/' + this._sid + '/wordads/tos', query, fn);
};
/**
 * UPDATE site's WordAds TOS
 *
 * Example:
 *    // Update TOS
 *    wpcom
 *    .site( 'my-blog.wordpress.com' )
 *    .wordAds()
 *    .tos()
 *    .update( { tos: 'signed' }, function( err, data ) {
 *      // data settings information object
 *    } );
 *
 * @param {object} [query] - query object parameter
 * @param {object} body - body object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


SiteWordAdsTOS.prototype.update = function (query, body, fn) {
  const path = '/sites/' + this._sid + '/wordads/tos';
  return this.wpcom.req.post(path, query, body, fn);
};
/**
 * SIGN site's WordAds TOS
 *
 * Example:
 *    // Sign TOS
 *    wpcom
 *    .site( 'my-blog.wordpress.com' )
 *    .wordAds()
 *    .tos()
 *    .sign( function( err, data ) {
 *      // data settings information object
 *    } );
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


SiteWordAdsTOS.prototype.sign = function (query, fn) {
  const path = '/sites/' + this._sid + '/wordads/tos';
  return this.wpcom.req.post(path, query, {
    tos: 'signed'
  }, fn);
};

/***/ }),

/***/ 54866:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/**
 * Module vars
 */
const root = '/sites';

class SiteWPComPlugin {
  /**
   * `SiteWPComPlugin` constructor.
   *
   * @param {string} [slug] - the plugin slug
   * @param {number|string} sid - site identifier
   * @param {WPCOM} wpcom - wpcom instance
   * @returns {undefined} undefined
   */
  constructor(slug, sid, wpcom) {
    if (!(this instanceof SiteWPComPlugin)) {
      return new SiteWPComPlugin(slug, sid, wpcom);
    }

    if (!slug) {
      throw new Error('`slug` is not correctly defined');
    }

    this._slug = encodeURIComponent(slug);
    this._sid = sid;
    this.wpcom = wpcom;
    const path = `${root}/${this._sid}/wpcom-plugins`;
    this.pluginPath = `${path}/${this._slug}`;
  }
  /**
   * Update the plugin configuration
   *
   * @param {object} [query] - query object parameter
   * @param {object} body - plugin body object
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  update(query, body, fn) {
    return this.wpcom.req.put(this.pluginPath, query, body, fn);
  }
  /**
   * Activate the plugin
   * This method is a shorthand of update()
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  activate(query, fn) {
    return this.update(query, {
      active: true
    }, fn);
  }
  /**
   * Deactivate the plugin
   * This method is a shorthand of update()
   *
   * @param {object} [query] - query object parameter
   * @param {Function} [fn] - callback function
   * @returns {Promise} Promise
   */


  deactivate(query, fn) {
    return this.update(query, {
      active: false
    }, fn);
  }

}
/**
 * Expose `SiteWPComPlugin` module
 */


/* harmony default export */ __webpack_exports__["Z"] = (SiteWPComPlugin);

/***/ }),

/***/ 78183:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ TusUploader; }
/* harmony export */ });
/* harmony import */ var _babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(56666);
/* harmony import */ var tus_js_client__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(90801);
/* harmony import */ var _site_media__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(8837);



/**
 * This class is an adapted version of wpcom's TUS uploader use-uploader.js.
 * It enables resumable uploads for videos.
 */

class TusUploader {
  constructor(wpcom, sid) {
    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "createGetJwtRequest", key => {
      const params = {
        path: '/sites/' + this._sid + '/media/videopress-upload-jwt',
        apiNamespace: 'wpcom/v2'
      };

      if (key) {
        params.key = key;
      }

      return this.wpcom.req.post(params, {}, null, null);
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "startUpload", files => {
      const file = files[0];
      return new Promise((resolve, reject) => {
        const uploader = this.resumableUploader({
          onError: error => reject(error),
          onSuccess: args => {
            const media = new _site_media__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z(args.mediaId, this._sid, this.wpcom);
            media.get().then(res => resolve({
              media: [res]
            })).catch(err => reject(err));
          },
          onProgress: () => {}
        });
        return this.createGetJwtRequest().then(jwtData => uploader(file, jwtData));
      });
    });

    (0,_babel_runtime_helpers_defineProperty__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)(this, "resumableUploader", _ref => {
      let {
        onError,
        onProgress,
        onSuccess
      } = _ref;
      const jwtsForKeys = {}; // Keep in sync with wpcom's use-uploader.js

      return (file, data) => {
        const upload = new tus_js_client__WEBPACK_IMPORTED_MODULE_0__/* .Upload */ .gq(file, {
          onError: onError,
          onProgress: onProgress,
          endpoint: 'https://public-api.wordpress.com/rest/v1.1/video-uploads/' + this._sid + '/',
          removeFingerprintOnSuccess: true,
          withCredentials: false,
          autoRetry: true,
          overridePatchMethod: false,
          chunkSize: 10000000,
          // 10Mb.
          allowedFileTypes: ['video/*'],
          metadata: {
            filename: file.name,
            filetype: file.type
          },
          retryDelays: [0, 1000, 3000, 5000, 10000],
          onAfterResponse: (req, res) => {
            // Why is this not showing the x-headers?
            if (res.getStatus() >= 400) {
              return;
            }

            const GUID_HEADER = 'x-videopress-upload-guid';
            const MEDIA_ID_HEADER = 'x-videopress-upload-media-id';
            const SRC_URL_HEADER = 'x-videopress-upload-src-url';
            const guid = res.getHeader(GUID_HEADER);
            const mediaId = res.getHeader(MEDIA_ID_HEADER);
            const src = res.getHeader(SRC_URL_HEADER);

            if (guid && mediaId && src) {
              onSuccess && onSuccess({
                mediaId: Number(mediaId),
                guid,
                src
              });
              return;
            }

            const headerMap = {
              'x-videopress-upload-key-token': 'token',
              'x-videopress-upload-key': 'key'
            };
            const tokenData = {};
            Object.keys(headerMap).forEach(function (header) {
              const value = res.getHeader(header);

              if (!value) {
                return;
              }

              tokenData[headerMap[header]] = value;
            });

            if (tokenData.key && tokenData.token) {
              jwtsForKeys[tokenData.key] = tokenData.token;
            }
          },
          onBeforeRequest: req => {
            // make ALL requests be either POST or GET to honor the public-api.wordpress.com "contract".
            const method = req._method;

            if (['HEAD', 'OPTIONS'].indexOf(method) >= 0) {
              req._method = 'GET';
              req.setHeader('X-HTTP-Method-Override', method);
            }

            if (['DELETE', 'PUT', 'PATCH'].indexOf(method) >= 0) {
              req._method = 'POST';
              req.setHeader('X-HTTP-Method-Override', method);
            }

            req._xhr.open(req._method, req._url, true); // Set the headers again, reopening the xhr resets them.


            Object.keys(req._headers).map(function (headerName) {
              req.setHeader(headerName, req._headers[headerName]);
            });

            if ('POST' === method) {
              const hasJWT = !!data.upload_token;

              if (hasJWT) {
                req.setHeader('x-videopress-upload-token', data.upload_token);
              } else {
                throw 'should never happen';
              }
            }

            if (['OPTIONS', 'GET', 'HEAD', 'DELETE', 'PUT', 'PATCH'].indexOf(method) >= 0) {
              const url = new URL(req._url);
              const path = url.pathname;
              const parts = path.split('/');
              const maybeUploadkey = parts[parts.length - 1];

              if (jwtsForKeys[maybeUploadkey]) {
                req.setHeader('x-videopress-upload-token', jwtsForKeys[maybeUploadkey]);
              } else if ('HEAD' === method) {
                return this.createGetJwtRequest(maybeUploadkey).then(responseData => {
                  jwtsForKeys[maybeUploadkey] = responseData.token;
                  req.setHeader('x-videopress-upload-token', responseData.token);
                  return req;
                });
              }
            }

            return Promise.resolve(req);
          }
        });
        upload.findPreviousUploads().then(function (previousUploads) {
          if (previousUploads.length) {
            upload.resumeFromPreviousUpload(previousUploads[0]);
          }

          upload.start();
        });
        return upload;
      };
    });

    this.wpcom = wpcom;
    this._sid = sid;
  }

}

/***/ }),

/***/ 54308:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Users; }
/* harmony export */ });
/**
 * Create a `Users` instance
 *
 * @param {WPCOM} wpcom - wpcom instance
 * @returns {null} null
 */
function Users(wpcom) {
  if (!(this instanceof Users)) {
    return new Users(wpcom);
  }

  this.wpcom = wpcom;
}
/**
 * A list of @mention suggestions for the current user
 *
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

Users.prototype.suggest = function (query, fn) {
  return this.wpcom.req.get('/users/suggest', query, fn);
};

/***/ }),

/***/ 76426:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "U": function() { return /* binding */ createReadStream; }
/* harmony export */ });
function createReadStream() {
  throw new Error('Cannot call fs functions within the browser');
}

/***/ }),

/***/ 33818:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Pinghub; }
/* harmony export */ });
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);

const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('wpcom:pinghub');
/**
 * Create a `Pinghub` instance
 *
 * @param {object} wpcom - wpcom instance
 * @returns {null} null
 */

function Pinghub(wpcom) {
  if (!(this instanceof Pinghub)) {
    return new Pinghub(wpcom);
  }

  this.wpcom = wpcom;
  this.conns = {};
}
/**
 * Open a websocket to Pinghub
 *
 * @param {string} path - request path
 * @param {Function} fn - callback function
 */

Pinghub.prototype.connect = function (path, fn) {
  debug('connect', path, fn);
  const pinghub = this;
  const params = {
    action: 'connect',
    path: '/pinghub' + path
  };

  const errorCallback = function () {}; // we want an xhr, not a promise


  const xhr = this.conns[path] = this.wpcom.req.get(params, errorCallback);

  xhr.onload = function (e) {
    debug('onload', path, e);
    fn(null, e);
  };

  xhr.onerror = xhr.onabort = xhr.onclose = function (e) {
    debug('onerror', path, e);
    pinghub.remove(path);
    fn(e, null);
  };
};
/**
 * Close a websocket connection (unsubscribe)
 *
 * @param {string} path - request path
 */


Pinghub.prototype.disconnect = function (path) {
  debug('disconnect', path);
  const params = {
    action: 'disconnect',
    path: '/pinghub' + path
  };

  const errorCallback = function () {}; // no promises


  this.wpcom.req.get(params, errorCallback);
};
/**
 * Remove a dead connection
 *
 * @param {string} path - pinghub channel
 */


Pinghub.prototype.remove = function (path) {
  debug('remove', path);
  delete this.conns[path];
};

/***/ }),

/***/ 60781:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ Req; }
/* harmony export */ });
/* harmony import */ var _send_request__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(73918);

/**
 * Expose `Request` module
 *
 * @param {WPCOM} wpcom - wpcom instance
 */

function Req(wpcom) {
  this.wpcom = wpcom;
}
/**
 * Request methods
 *
 * @param {object|string} params - params object
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

Req.prototype.get = function (params, query, fn) {
  // `query` is optional
  if ('function' === typeof query) {
    fn = query;
    query = {};
  }

  return _send_request__WEBPACK_IMPORTED_MODULE_0__/* ["default"].call */ .Z.call(this.wpcom, params, query, null, fn);
};
/**
 * Make `update` request
 *
 * @param {object|string} params
 * @param {object} [query] - query object parameter
 * @param {object} body - body object parameter
 * @param {Function} fn - callback function
 */


Req.prototype.post = Req.prototype.put = function (params, query, body, fn) {
  if (undefined === fn) {
    if (undefined === body) {
      body = query;
      query = {};
    } else if ('function' === typeof body) {
      fn = body;
      body = query;
      query = {};
    }
  } // params can be a string


  params = 'string' === typeof params ? {
    path: params
  } : params; // in v1 endpoints, DELETE and PUT operations use http POST, but for v2 endpoints we must allow this to be overridden

  params.method = params.method || 'post';
  return _send_request__WEBPACK_IMPORTED_MODULE_0__/* ["default"].call */ .Z.call(this.wpcom, params, query, body, fn);
};
/**
 * Make a `delete` request
 *
 * @param {object|string} params - params object
 * @param {object} [query] - query object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */


Req.prototype.del = function (params, query, fn) {
  if ('function' === typeof query) {
    fn = query;
    query = {};
  }

  return this.post(params, query, null, fn);
};

/***/ }),

/***/ 99426:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* export default binding */ __WEBPACK_DEFAULT_EXPORT__; }
/* harmony export */ });
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);

/**
 * Module vars
 */

const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('wpcom:runtime');
/**
 * Build a generic method
 *
 * @param {object} methodParams - method methodParams
 * @param {Function} buildPath - function called to build method path
 * @returns {string} method path
 */

const methodBuilder = (methodParams, buildPath) => {
  return function (query, fn) {
    const path = buildPath(methodParams, this);
    return this.wpcom.req.get(path, query, fn);
  };
};
/**
 * Add methods to the given Class in the
 * runtime process.
 *
 * @param {*} Class - class to extend
 * @param {Array} list - methods list
 * @param {Function} buildPath - function to build the method endpoint path
 */


/* harmony default export */ function __WEBPACK_DEFAULT_EXPORT__(Class, list, buildPath) {
  list.forEach(methodParams => {
    methodParams = 'object' === typeof methodParams ? methodParams : {
      name: methodParams
    };
    debug('Adding %o', methodParams.name);
    Class.prototype[methodParams.name] = methodBuilder(methodParams, buildPath);
  });
}

/***/ }),

/***/ 73918:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ sendRequest; }
/* harmony export */ });
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(38049);
/* harmony import */ var debug__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(debug__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var qs__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(19126);
/* harmony import */ var qs__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(qs__WEBPACK_IMPORTED_MODULE_1__);


const debug = debug__WEBPACK_IMPORTED_MODULE_0___default()('wpcom:send-request');
const debug_res = debug__WEBPACK_IMPORTED_MODULE_0___default()('wpcom:send-request:res');
/**
 * Request to WordPress REST API
 *
 * @param {string|object} params - params object
 * @param {object} [query] - query object parameter
 * @param {object} [body] - body object parameter
 * @param {Function} fn - callback function
 * @returns {Function} request handler
 */

function sendRequest(params, query, body, fn) {
  // `params` can be just the path ( String )
  params = 'string' === typeof params ? {
    path: params
  } : params;
  debug('sendRequest(%o )', params.path); // set `method` request param

  params.method = (params.method || 'get').toUpperCase(); // `query` is optional

  if ('function' === typeof query) {
    fn = query;
    query = {};
  } // `body` is optional


  if ('function' === typeof body) {
    fn = body;
    body = null;
  } // query could be `null`


  query = query || {}; // Handle special query parameters
  // - `apiVersion`

  if (query.apiVersion) {
    params.apiVersion = query.apiVersion;
    debug('apiVersion: %o', params.apiVersion);
    delete query.apiVersion;
  } else {
    params.apiVersion = this.apiVersion;
  } // - `apiNamespace`


  if (query.apiNamespace) {
    params.apiNamespace = query.apiNamespace;
    debug('apiNamespace: %o', params.apiNamespace);
    delete query.apiNamespace;
  } // - `proxyOrigin`


  if (query.proxyOrigin) {
    params.proxyOrigin = query.proxyOrigin;
    debug('proxyOrigin: %o', params.proxyOrigin);
    delete query.proxyOrigin;
  } // Stringify query object before to send


  query = qs__WEBPACK_IMPORTED_MODULE_1___default().stringify(query, {
    arrayFormat: 'brackets'
  }); // pass `query` and/or `body` to request params

  params.query = query;

  if (body) {
    params.body = body;
  }

  debug('params: %o', params); // if callback is provided, behave traditionally

  if ('function' === typeof fn) {
    // request method
    return this.request(params, function (err, res, headers) {
      debug_res(res);
      fn(err, res, headers);
    });
  } // but if not, return a Promise


  return new Promise((resolve, reject) => {
    this.request(params, (err, res) => {
      debug_res(res);
      err ? reject(err) : resolve(res);
    });
  });
}

/***/ }),

/***/ 38049:
/***/ (function(module, exports, __webpack_require__) {

/* eslint-env browser */

/**
 * This is the web browser implementation of `debug()`.
 */
exports.formatArgs = formatArgs;
exports.save = save;
exports.load = load;
exports.useColors = useColors;
exports.storage = localstorage();

exports.destroy = (() => {
  let warned = false;
  return () => {
    if (!warned) {
      warned = true;
      console.warn('Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`.');
    }
  };
})();
/**
 * Colors.
 */


exports.colors = ['#0000CC', '#0000FF', '#0033CC', '#0033FF', '#0066CC', '#0066FF', '#0099CC', '#0099FF', '#00CC00', '#00CC33', '#00CC66', '#00CC99', '#00CCCC', '#00CCFF', '#3300CC', '#3300FF', '#3333CC', '#3333FF', '#3366CC', '#3366FF', '#3399CC', '#3399FF', '#33CC00', '#33CC33', '#33CC66', '#33CC99', '#33CCCC', '#33CCFF', '#6600CC', '#6600FF', '#6633CC', '#6633FF', '#66CC00', '#66CC33', '#9900CC', '#9900FF', '#9933CC', '#9933FF', '#99CC00', '#99CC33', '#CC0000', '#CC0033', '#CC0066', '#CC0099', '#CC00CC', '#CC00FF', '#CC3300', '#CC3333', '#CC3366', '#CC3399', '#CC33CC', '#CC33FF', '#CC6600', '#CC6633', '#CC9900', '#CC9933', '#CCCC00', '#CCCC33', '#FF0000', '#FF0033', '#FF0066', '#FF0099', '#FF00CC', '#FF00FF', '#FF3300', '#FF3333', '#FF3366', '#FF3399', '#FF33CC', '#FF33FF', '#FF6600', '#FF6633', '#FF9900', '#FF9933', '#FFCC00', '#FFCC33'];
/**
 * Currently only WebKit-based Web Inspectors, Firefox >= v31,
 * and the Firebug extension (any Firefox version) are known
 * to support "%c" CSS customizations.
 *
 * TODO: add a `localStorage` variable to explicitly enable/disable colors
 */
// eslint-disable-next-line complexity

function useColors() {
  // NB: In an Electron preload script, document will be defined but not fully
  // initialized. Since we know we're in Chrome, we'll just detect this case
  // explicitly
  if (typeof window !== 'undefined' && window.process && (window.process.type === 'renderer' || window.process.__nwjs)) {
    return true;
  } // Internet Explorer and Edge do not support colors.


  if (typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/(edge|trident)\/(\d+)/)) {
    return false;
  } // Is webkit? http://stackoverflow.com/a/16459606/376773
  // document is undefined in react-native: https://github.com/facebook/react-native/pull/1632


  return typeof document !== 'undefined' && document.documentElement && document.documentElement.style && document.documentElement.style.WebkitAppearance || // Is firebug? http://stackoverflow.com/a/398120/376773
  typeof window !== 'undefined' && window.console && (window.console.firebug || window.console.exception && window.console.table) || // Is firefox >= v31?
  // https://developer.mozilla.org/en-US/docs/Tools/Web_Console#Styling_messages
  typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/firefox\/(\d+)/) && parseInt(RegExp.$1, 10) >= 31 || // Double check webkit in userAgent just in case we are in a worker
  typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/applewebkit\/(\d+)/);
}
/**
 * Colorize log arguments if enabled.
 *
 * @api public
 */


function formatArgs(args) {
  args[0] = (this.useColors ? '%c' : '') + this.namespace + (this.useColors ? ' %c' : ' ') + args[0] + (this.useColors ? '%c ' : ' ') + '+' + module.exports.humanize(this.diff);

  if (!this.useColors) {
    return;
  }

  const c = 'color: ' + this.color;
  args.splice(1, 0, c, 'color: inherit'); // The final "%c" is somewhat tricky, because there could be other
  // arguments passed either before or after the %c, so we need to
  // figure out the correct index to insert the CSS into

  let index = 0;
  let lastC = 0;
  args[0].replace(/%[a-zA-Z%]/g, match => {
    if (match === '%%') {
      return;
    }

    index++;

    if (match === '%c') {
      // We only are interested in the *last* %c
      // (the user may have provided their own)
      lastC = index;
    }
  });
  args.splice(lastC, 0, c);
}
/**
 * Invokes `console.debug()` when available.
 * No-op when `console.debug` is not a "function".
 * If `console.debug` is not available, falls back
 * to `console.log`.
 *
 * @api public
 */


exports.log = console.debug || console.log || (() => {});
/**
 * Save `namespaces`.
 *
 * @param {String} namespaces
 * @api private
 */


function save(namespaces) {
  try {
    if (namespaces) {
      exports.storage.setItem('debug', namespaces);
    } else {
      exports.storage.removeItem('debug');
    }
  } catch (error) {// Swallow
    // XXX (@Qix-) should we be logging these?
  }
}
/**
 * Load `namespaces`.
 *
 * @return {String} returns the previously persisted debug modes
 * @api private
 */


function load() {
  let r;

  try {
    r = exports.storage.getItem('debug');
  } catch (error) {// Swallow
    // XXX (@Qix-) should we be logging these?
  } // If debug isn't set in LS, and we're in Electron, try to load $DEBUG


  if (!r && typeof process !== 'undefined' && 'env' in process) {
    r = process.env.DEBUG;
  }

  return r;
}
/**
 * Localstorage attempts to return the localstorage.
 *
 * This is necessary because safari throws
 * when a user disables cookies/localstorage
 * and you attempt to access it.
 *
 * @return {LocalStorage}
 * @api private
 */


function localstorage() {
  try {
    // TVMLKit (Apple TV JS Runtime) does not have a window object, just localStorage in the global context
    // The Browser also has localStorage in the global context.
    return localStorage;
  } catch (error) {// Swallow
    // XXX (@Qix-) should we be logging these?
  }
}

module.exports = __webpack_require__(52632)(exports);
const {
  formatters
} = module.exports;
/**
 * Map %j to `JSON.stringify()`, since no Web Inspectors do that by default.
 */

formatters.j = function (v) {
  try {
    return JSON.stringify(v);
  } catch (error) {
    return '[UnexpectedJSONParseError]: ' + error.message;
  }
};

/***/ }),

/***/ 52632:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/**
 * This is the common logic for both the Node.js and web browser
 * implementations of `debug()`.
 */
function setup(env) {
  createDebug.debug = createDebug;
  createDebug.default = createDebug;
  createDebug.coerce = coerce;
  createDebug.disable = disable;
  createDebug.enable = enable;
  createDebug.enabled = enabled;
  createDebug.humanize = __webpack_require__(65881);
  createDebug.destroy = destroy;
  Object.keys(env).forEach(key => {
    createDebug[key] = env[key];
  });
  /**
  * The currently active debug mode names, and names to skip.
  */

  createDebug.names = [];
  createDebug.skips = [];
  /**
  * Map of special "%n" handling functions, for the debug "format" argument.
  *
  * Valid key names are a single, lower or upper-case letter, i.e. "n" and "N".
  */

  createDebug.formatters = {};
  /**
  * Selects a color for a debug namespace
  * @param {String} namespace The namespace string for the debug instance to be colored
  * @return {Number|String} An ANSI color code for the given namespace
  * @api private
  */

  function selectColor(namespace) {
    let hash = 0;

    for (let i = 0; i < namespace.length; i++) {
      hash = (hash << 5) - hash + namespace.charCodeAt(i);
      hash |= 0; // Convert to 32bit integer
    }

    return createDebug.colors[Math.abs(hash) % createDebug.colors.length];
  }

  createDebug.selectColor = selectColor;
  /**
  * Create a debugger with the given `namespace`.
  *
  * @param {String} namespace
  * @return {Function}
  * @api public
  */

  function createDebug(namespace) {
    let prevTime;
    let enableOverride = null;
    let namespacesCache;
    let enabledCache;

    function debug() {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      // Disabled?
      if (!debug.enabled) {
        return;
      }

      const self = debug; // Set `diff` timestamp

      const curr = Number(new Date());
      const ms = curr - (prevTime || curr);
      self.diff = ms;
      self.prev = prevTime;
      self.curr = curr;
      prevTime = curr;
      args[0] = createDebug.coerce(args[0]);

      if (typeof args[0] !== 'string') {
        // Anything else let's inspect with %O
        args.unshift('%O');
      } // Apply any `formatters` transformations


      let index = 0;
      args[0] = args[0].replace(/%([a-zA-Z%])/g, (match, format) => {
        // If we encounter an escaped % then don't increase the array index
        if (match === '%%') {
          return '%';
        }

        index++;
        const formatter = createDebug.formatters[format];

        if (typeof formatter === 'function') {
          const val = args[index];
          match = formatter.call(self, val); // Now we need to remove `args[index]` since it's inlined in the `format`

          args.splice(index, 1);
          index--;
        }

        return match;
      }); // Apply env-specific formatting (colors, etc.)

      createDebug.formatArgs.call(self, args);
      const logFn = self.log || createDebug.log;
      logFn.apply(self, args);
    }

    debug.namespace = namespace;
    debug.useColors = createDebug.useColors();
    debug.color = createDebug.selectColor(namespace);
    debug.extend = extend;
    debug.destroy = createDebug.destroy; // XXX Temporary. Will be removed in the next major release.

    Object.defineProperty(debug, 'enabled', {
      enumerable: true,
      configurable: false,
      get: () => {
        if (enableOverride !== null) {
          return enableOverride;
        }

        if (namespacesCache !== createDebug.namespaces) {
          namespacesCache = createDebug.namespaces;
          enabledCache = createDebug.enabled(namespace);
        }

        return enabledCache;
      },
      set: v => {
        enableOverride = v;
      }
    }); // Env-specific initialization logic for debug instances

    if (typeof createDebug.init === 'function') {
      createDebug.init(debug);
    }

    return debug;
  }

  function extend(namespace, delimiter) {
    const newDebug = createDebug(this.namespace + (typeof delimiter === 'undefined' ? ':' : delimiter) + namespace);
    newDebug.log = this.log;
    return newDebug;
  }
  /**
  * Enables a debug mode by namespaces. This can include modes
  * separated by a colon and wildcards.
  *
  * @param {String} namespaces
  * @api public
  */


  function enable(namespaces) {
    createDebug.save(namespaces);
    createDebug.namespaces = namespaces;
    createDebug.names = [];
    createDebug.skips = [];
    let i;
    const split = (typeof namespaces === 'string' ? namespaces : '').split(/[\s,]+/);
    const len = split.length;

    for (i = 0; i < len; i++) {
      if (!split[i]) {
        // ignore empty strings
        continue;
      }

      namespaces = split[i].replace(/\*/g, '.*?');

      if (namespaces[0] === '-') {
        createDebug.skips.push(new RegExp('^' + namespaces.slice(1) + '$'));
      } else {
        createDebug.names.push(new RegExp('^' + namespaces + '$'));
      }
    }
  }
  /**
  * Disable debug output.
  *
  * @return {String} namespaces
  * @api public
  */


  function disable() {
    const namespaces = [...createDebug.names.map(toNamespace), ...createDebug.skips.map(toNamespace).map(namespace => '-' + namespace)].join(',');
    createDebug.enable('');
    return namespaces;
  }
  /**
  * Returns true if the given mode name is enabled, false otherwise.
  *
  * @param {String} name
  * @return {Boolean}
  * @api public
  */


  function enabled(name) {
    if (name[name.length - 1] === '*') {
      return true;
    }

    let i;
    let len;

    for (i = 0, len = createDebug.skips.length; i < len; i++) {
      if (createDebug.skips[i].test(name)) {
        return false;
      }
    }

    for (i = 0, len = createDebug.names.length; i < len; i++) {
      if (createDebug.names[i].test(name)) {
        return true;
      }
    }

    return false;
  }
  /**
  * Convert regexp to namespace
  *
  * @param {RegExp} regxep
  * @return {String} namespace
  * @api private
  */


  function toNamespace(regexp) {
    return regexp.toString().substring(2, regexp.toString().length - 2).replace(/\.\*\?$/, '*');
  }
  /**
  * Coerce `val`.
  *
  * @param {Mixed} val
  * @return {Mixed}
  * @api private
  */


  function coerce(val) {
    if (val instanceof Error) {
      return val.stack || val.message;
    }

    return val;
  }
  /**
  * XXX DO NOT USE. This is a temporary stub function.
  * XXX It WILL be removed in the next major release.
  */


  function destroy() {
    console.warn('Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`.');
  }

  createDebug.enable(createDebug.load());
  return createDebug;
}

module.exports = setup;

/***/ }),

/***/ 39712:
/***/ (function(module, exports, __webpack_require__) {

/* eslint-env browser */

/**
 * This is the web browser implementation of `debug()`.
 */
exports.log = log;
exports.formatArgs = formatArgs;
exports.save = save;
exports.load = load;
exports.useColors = useColors;
exports.storage = localstorage();
/**
 * Colors.
 */

exports.colors = ['#0000CC', '#0000FF', '#0033CC', '#0033FF', '#0066CC', '#0066FF', '#0099CC', '#0099FF', '#00CC00', '#00CC33', '#00CC66', '#00CC99', '#00CCCC', '#00CCFF', '#3300CC', '#3300FF', '#3333CC', '#3333FF', '#3366CC', '#3366FF', '#3399CC', '#3399FF', '#33CC00', '#33CC33', '#33CC66', '#33CC99', '#33CCCC', '#33CCFF', '#6600CC', '#6600FF', '#6633CC', '#6633FF', '#66CC00', '#66CC33', '#9900CC', '#9900FF', '#9933CC', '#9933FF', '#99CC00', '#99CC33', '#CC0000', '#CC0033', '#CC0066', '#CC0099', '#CC00CC', '#CC00FF', '#CC3300', '#CC3333', '#CC3366', '#CC3399', '#CC33CC', '#CC33FF', '#CC6600', '#CC6633', '#CC9900', '#CC9933', '#CCCC00', '#CCCC33', '#FF0000', '#FF0033', '#FF0066', '#FF0099', '#FF00CC', '#FF00FF', '#FF3300', '#FF3333', '#FF3366', '#FF3399', '#FF33CC', '#FF33FF', '#FF6600', '#FF6633', '#FF9900', '#FF9933', '#FFCC00', '#FFCC33'];
/**
 * Currently only WebKit-based Web Inspectors, Firefox >= v31,
 * and the Firebug extension (any Firefox version) are known
 * to support "%c" CSS customizations.
 *
 * TODO: add a `localStorage` variable to explicitly enable/disable colors
 */
// eslint-disable-next-line complexity

function useColors() {
  // NB: In an Electron preload script, document will be defined but not fully
  // initialized. Since we know we're in Chrome, we'll just detect this case
  // explicitly
  if (typeof window !== 'undefined' && window.process && (window.process.type === 'renderer' || window.process.__nwjs)) {
    return true;
  } // Internet Explorer and Edge do not support colors.


  if (typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/(edge|trident)\/(\d+)/)) {
    return false;
  } // Is webkit? http://stackoverflow.com/a/16459606/376773
  // document is undefined in react-native: https://github.com/facebook/react-native/pull/1632


  return typeof document !== 'undefined' && document.documentElement && document.documentElement.style && document.documentElement.style.WebkitAppearance || // Is firebug? http://stackoverflow.com/a/398120/376773
  typeof window !== 'undefined' && window.console && (window.console.firebug || window.console.exception && window.console.table) || // Is firefox >= v31?
  // https://developer.mozilla.org/en-US/docs/Tools/Web_Console#Styling_messages
  typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/firefox\/(\d+)/) && parseInt(RegExp.$1, 10) >= 31 || // Double check webkit in userAgent just in case we are in a worker
  typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/applewebkit\/(\d+)/);
}
/**
 * Colorize log arguments if enabled.
 *
 * @api public
 */


function formatArgs(args) {
  args[0] = (this.useColors ? '%c' : '') + this.namespace + (this.useColors ? ' %c' : ' ') + args[0] + (this.useColors ? '%c ' : ' ') + '+' + module.exports.humanize(this.diff);

  if (!this.useColors) {
    return;
  }

  const c = 'color: ' + this.color;
  args.splice(1, 0, c, 'color: inherit'); // The final "%c" is somewhat tricky, because there could be other
  // arguments passed either before or after the %c, so we need to
  // figure out the correct index to insert the CSS into

  let index = 0;
  let lastC = 0;
  args[0].replace(/%[a-zA-Z%]/g, match => {
    if (match === '%%') {
      return;
    }

    index++;

    if (match === '%c') {
      // We only are interested in the *last* %c
      // (the user may have provided their own)
      lastC = index;
    }
  });
  args.splice(lastC, 0, c);
}
/**
 * Invokes `console.log()` when available.
 * No-op when `console.log` is not a "function".
 *
 * @api public
 */


function log() {
  // This hackery is required for IE8/9, where
  // the `console.log` function doesn't have 'apply'
  return typeof console === 'object' && console.log && console.log(...arguments);
}
/**
 * Save `namespaces`.
 *
 * @param {String} namespaces
 * @api private
 */


function save(namespaces) {
  try {
    if (namespaces) {
      exports.storage.setItem('debug', namespaces);
    } else {
      exports.storage.removeItem('debug');
    }
  } catch (error) {// Swallow
    // XXX (@Qix-) should we be logging these?
  }
}
/**
 * Load `namespaces`.
 *
 * @return {String} returns the previously persisted debug modes
 * @api private
 */


function load() {
  let r;

  try {
    r = exports.storage.getItem('debug');
  } catch (error) {// Swallow
    // XXX (@Qix-) should we be logging these?
  } // If debug isn't set in LS, and we're in Electron, try to load $DEBUG


  if (!r && typeof process !== 'undefined' && 'env' in process) {
    r = process.env.DEBUG;
  }

  return r;
}
/**
 * Localstorage attempts to return the localstorage.
 *
 * This is necessary because safari throws
 * when a user disables cookies/localstorage
 * and you attempt to access it.
 *
 * @return {LocalStorage}
 * @api private
 */


function localstorage() {
  try {
    // TVMLKit (Apple TV JS Runtime) does not have a window object, just localStorage in the global context
    // The Browser also has localStorage in the global context.
    return localStorage;
  } catch (error) {// Swallow
    // XXX (@Qix-) should we be logging these?
  }
}

module.exports = __webpack_require__(37599)(exports);
const {
  formatters
} = module.exports;
/**
 * Map %j to `JSON.stringify()`, since no Web Inspectors do that by default.
 */

formatters.j = function (v) {
  try {
    return JSON.stringify(v);
  } catch (error) {
    return '[UnexpectedJSONParseError]: ' + error.message;
  }
};

/***/ }),

/***/ 37599:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/**
 * This is the common logic for both the Node.js and web browser
 * implementations of `debug()`.
 */
function setup(env) {
  createDebug.debug = createDebug;
  createDebug.default = createDebug;
  createDebug.coerce = coerce;
  createDebug.disable = disable;
  createDebug.enable = enable;
  createDebug.enabled = enabled;
  createDebug.humanize = __webpack_require__(11378);
  Object.keys(env).forEach(key => {
    createDebug[key] = env[key];
  });
  /**
  * Active `debug` instances.
  */

  createDebug.instances = [];
  /**
  * The currently active debug mode names, and names to skip.
  */

  createDebug.names = [];
  createDebug.skips = [];
  /**
  * Map of special "%n" handling functions, for the debug "format" argument.
  *
  * Valid key names are a single, lower or upper-case letter, i.e. "n" and "N".
  */

  createDebug.formatters = {};
  /**
  * Selects a color for a debug namespace
  * @param {String} namespace The namespace string for the for the debug instance to be colored
  * @return {Number|String} An ANSI color code for the given namespace
  * @api private
  */

  function selectColor(namespace) {
    let hash = 0;

    for (let i = 0; i < namespace.length; i++) {
      hash = (hash << 5) - hash + namespace.charCodeAt(i);
      hash |= 0; // Convert to 32bit integer
    }

    return createDebug.colors[Math.abs(hash) % createDebug.colors.length];
  }

  createDebug.selectColor = selectColor;
  /**
  * Create a debugger with the given `namespace`.
  *
  * @param {String} namespace
  * @return {Function}
  * @api public
  */

  function createDebug(namespace) {
    let prevTime;

    function debug() {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      // Disabled?
      if (!debug.enabled) {
        return;
      }

      const self = debug; // Set `diff` timestamp

      const curr = Number(new Date());
      const ms = curr - (prevTime || curr);
      self.diff = ms;
      self.prev = prevTime;
      self.curr = curr;
      prevTime = curr;
      args[0] = createDebug.coerce(args[0]);

      if (typeof args[0] !== 'string') {
        // Anything else let's inspect with %O
        args.unshift('%O');
      } // Apply any `formatters` transformations


      let index = 0;
      args[0] = args[0].replace(/%([a-zA-Z%])/g, (match, format) => {
        // If we encounter an escaped % then don't increase the array index
        if (match === '%%') {
          return match;
        }

        index++;
        const formatter = createDebug.formatters[format];

        if (typeof formatter === 'function') {
          const val = args[index];
          match = formatter.call(self, val); // Now we need to remove `args[index]` since it's inlined in the `format`

          args.splice(index, 1);
          index--;
        }

        return match;
      }); // Apply env-specific formatting (colors, etc.)

      createDebug.formatArgs.call(self, args);
      const logFn = self.log || createDebug.log;
      logFn.apply(self, args);
    }

    debug.namespace = namespace;
    debug.enabled = createDebug.enabled(namespace);
    debug.useColors = createDebug.useColors();
    debug.color = selectColor(namespace);
    debug.destroy = destroy;
    debug.extend = extend; // Debug.formatArgs = formatArgs;
    // debug.rawLog = rawLog;
    // env-specific initialization logic for debug instances

    if (typeof createDebug.init === 'function') {
      createDebug.init(debug);
    }

    createDebug.instances.push(debug);
    return debug;
  }

  function destroy() {
    const index = createDebug.instances.indexOf(this);

    if (index !== -1) {
      createDebug.instances.splice(index, 1);
      return true;
    }

    return false;
  }

  function extend(namespace, delimiter) {
    const newDebug = createDebug(this.namespace + (typeof delimiter === 'undefined' ? ':' : delimiter) + namespace);
    newDebug.log = this.log;
    return newDebug;
  }
  /**
  * Enables a debug mode by namespaces. This can include modes
  * separated by a colon and wildcards.
  *
  * @param {String} namespaces
  * @api public
  */


  function enable(namespaces) {
    createDebug.save(namespaces);
    createDebug.names = [];
    createDebug.skips = [];
    let i;
    const split = (typeof namespaces === 'string' ? namespaces : '').split(/[\s,]+/);
    const len = split.length;

    for (i = 0; i < len; i++) {
      if (!split[i]) {
        // ignore empty strings
        continue;
      }

      namespaces = split[i].replace(/\*/g, '.*?');

      if (namespaces[0] === '-') {
        createDebug.skips.push(new RegExp('^' + namespaces.substr(1) + '$'));
      } else {
        createDebug.names.push(new RegExp('^' + namespaces + '$'));
      }
    }

    for (i = 0; i < createDebug.instances.length; i++) {
      const instance = createDebug.instances[i];
      instance.enabled = createDebug.enabled(instance.namespace);
    }
  }
  /**
  * Disable debug output.
  *
  * @return {String} namespaces
  * @api public
  */


  function disable() {
    const namespaces = [...createDebug.names.map(toNamespace), ...createDebug.skips.map(toNamespace).map(namespace => '-' + namespace)].join(',');
    createDebug.enable('');
    return namespaces;
  }
  /**
  * Returns true if the given mode name is enabled, false otherwise.
  *
  * @param {String} name
  * @return {Boolean}
  * @api public
  */


  function enabled(name) {
    if (name[name.length - 1] === '*') {
      return true;
    }

    let i;
    let len;

    for (i = 0, len = createDebug.skips.length; i < len; i++) {
      if (createDebug.skips[i].test(name)) {
        return false;
      }
    }

    for (i = 0, len = createDebug.names.length; i < len; i++) {
      if (createDebug.names[i].test(name)) {
        return true;
      }
    }

    return false;
  }
  /**
  * Convert regexp to namespace
  *
  * @param {RegExp} regxep
  * @return {String} namespace
  * @api private
  */


  function toNamespace(regexp) {
    return regexp.toString().substring(2, regexp.toString().length - 2).replace(/\.\*\?$/, '*');
  }
  /**
  * Coerce `val`.
  *
  * @param {Mixed} val
  * @return {Mixed}
  * @api private
  */


  function coerce(val) {
    if (val instanceof Error) {
      return val.stack || val.message;
    }

    return val;
  }

  createDebug.enable(createDebug.load());
  return createDebug;
}

module.exports = setup;

/***/ }),

/***/ 32421:
/***/ (function(module) {

const iconsThatNeedOffset = ['gridicons-add-outline', 'gridicons-add', 'gridicons-align-image-center', 'gridicons-align-image-left', 'gridicons-align-image-none', 'gridicons-align-image-right', 'gridicons-attachment', 'gridicons-bold', 'gridicons-bookmark-outline', 'gridicons-bookmark', 'gridicons-calendar', 'gridicons-cart', 'gridicons-create', 'gridicons-custom-post-type', 'gridicons-external', 'gridicons-folder', 'gridicons-heading', 'gridicons-help-outline', 'gridicons-help', 'gridicons-history', 'gridicons-info-outline', 'gridicons-info', 'gridicons-italic', 'gridicons-layout-blocks', 'gridicons-link-break', 'gridicons-link', 'gridicons-list-checkmark', 'gridicons-list-ordered', 'gridicons-list-unordered', 'gridicons-menus', 'gridicons-minus', 'gridicons-my-sites', 'gridicons-notice-outline', 'gridicons-notice', 'gridicons-plus-small', 'gridicons-plus', 'gridicons-popout', 'gridicons-posts', 'gridicons-scheduled', 'gridicons-share-ios', 'gridicons-star-outline', 'gridicons-star', 'gridicons-stats', 'gridicons-status', 'gridicons-thumbs-up', 'gridicons-textcolor', 'gridicons-time', 'gridicons-trophy', 'gridicons-user-circle', 'gridicons-reader-follow', 'gridicons-reader-following'];
const iconsThatNeedOffsetY = ['gridicons-align-center', 'gridicons-align-justify', 'gridicons-align-left', 'gridicons-align-right', 'gridicons-arrow-left', 'gridicons-arrow-right', 'gridicons-house', 'gridicons-indent-left', 'gridicons-indent-right', 'gridicons-minus-small', 'gridicons-print', 'gridicons-sign-out', 'gridicons-stats-alt', 'gridicons-trash', 'gridicons-underline', 'gridicons-video-camera'];
const iconsThatNeedOffsetX = ['gridicons-arrow-down', 'gridicons-arrow-up', 'gridicons-comment', 'gridicons-clear-formatting', 'gridicons-flag', 'gridicons-menu', 'gridicons-reader', 'gridicons-strikethrough'];
module.exports = {
  iconsThatNeedOffset,
  iconsThatNeedOffsetX,
  iconsThatNeedOffsetY
};

/***/ }),

/***/ 31035:
/***/ (function(module, exports, __webpack_require__) {

/* eslint-env browser */

/**
 * This is the web browser implementation of `debug()`.
 */
exports.log = log;
exports.formatArgs = formatArgs;
exports.save = save;
exports.load = load;
exports.useColors = useColors;
exports.storage = localstorage();
/**
 * Colors.
 */

exports.colors = ['#0000CC', '#0000FF', '#0033CC', '#0033FF', '#0066CC', '#0066FF', '#0099CC', '#0099FF', '#00CC00', '#00CC33', '#00CC66', '#00CC99', '#00CCCC', '#00CCFF', '#3300CC', '#3300FF', '#3333CC', '#3333FF', '#3366CC', '#3366FF', '#3399CC', '#3399FF', '#33CC00', '#33CC33', '#33CC66', '#33CC99', '#33CCCC', '#33CCFF', '#6600CC', '#6600FF', '#6633CC', '#6633FF', '#66CC00', '#66CC33', '#9900CC', '#9900FF', '#9933CC', '#9933FF', '#99CC00', '#99CC33', '#CC0000', '#CC0033', '#CC0066', '#CC0099', '#CC00CC', '#CC00FF', '#CC3300', '#CC3333', '#CC3366', '#CC3399', '#CC33CC', '#CC33FF', '#CC6600', '#CC6633', '#CC9900', '#CC9933', '#CCCC00', '#CCCC33', '#FF0000', '#FF0033', '#FF0066', '#FF0099', '#FF00CC', '#FF00FF', '#FF3300', '#FF3333', '#FF3366', '#FF3399', '#FF33CC', '#FF33FF', '#FF6600', '#FF6633', '#FF9900', '#FF9933', '#FFCC00', '#FFCC33'];
/**
 * Currently only WebKit-based Web Inspectors, Firefox >= v31,
 * and the Firebug extension (any Firefox version) are known
 * to support "%c" CSS customizations.
 *
 * TODO: add a `localStorage` variable to explicitly enable/disable colors
 */
// eslint-disable-next-line complexity

function useColors() {
  // NB: In an Electron preload script, document will be defined but not fully
  // initialized. Since we know we're in Chrome, we'll just detect this case
  // explicitly
  if (typeof window !== 'undefined' && window.process && (window.process.type === 'renderer' || window.process.__nwjs)) {
    return true;
  } // Internet Explorer and Edge do not support colors.


  if (typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/(edge|trident)\/(\d+)/)) {
    return false;
  } // Is webkit? http://stackoverflow.com/a/16459606/376773
  // document is undefined in react-native: https://github.com/facebook/react-native/pull/1632


  return typeof document !== 'undefined' && document.documentElement && document.documentElement.style && document.documentElement.style.WebkitAppearance || // Is firebug? http://stackoverflow.com/a/398120/376773
  typeof window !== 'undefined' && window.console && (window.console.firebug || window.console.exception && window.console.table) || // Is firefox >= v31?
  // https://developer.mozilla.org/en-US/docs/Tools/Web_Console#Styling_messages
  typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/firefox\/(\d+)/) && parseInt(RegExp.$1, 10) >= 31 || // Double check webkit in userAgent just in case we are in a worker
  typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/applewebkit\/(\d+)/);
}
/**
 * Colorize log arguments if enabled.
 *
 * @api public
 */


function formatArgs(args) {
  args[0] = (this.useColors ? '%c' : '') + this.namespace + (this.useColors ? ' %c' : ' ') + args[0] + (this.useColors ? '%c ' : ' ') + '+' + module.exports.humanize(this.diff);

  if (!this.useColors) {
    return;
  }

  const c = 'color: ' + this.color;
  args.splice(1, 0, c, 'color: inherit'); // The final "%c" is somewhat tricky, because there could be other
  // arguments passed either before or after the %c, so we need to
  // figure out the correct index to insert the CSS into

  let index = 0;
  let lastC = 0;
  args[0].replace(/%[a-zA-Z%]/g, match => {
    if (match === '%%') {
      return;
    }

    index++;

    if (match === '%c') {
      // We only are interested in the *last* %c
      // (the user may have provided their own)
      lastC = index;
    }
  });
  args.splice(lastC, 0, c);
}
/**
 * Invokes `console.log()` when available.
 * No-op when `console.log` is not a "function".
 *
 * @api public
 */


function log() {
  // This hackery is required for IE8/9, where
  // the `console.log` function doesn't have 'apply'
  return typeof console === 'object' && console.log && console.log(...arguments);
}
/**
 * Save `namespaces`.
 *
 * @param {String} namespaces
 * @api private
 */


function save(namespaces) {
  try {
    if (namespaces) {
      exports.storage.setItem('debug', namespaces);
    } else {
      exports.storage.removeItem('debug');
    }
  } catch (error) {// Swallow
    // XXX (@Qix-) should we be logging these?
  }
}
/**
 * Load `namespaces`.
 *
 * @return {String} returns the previously persisted debug modes
 * @api private
 */


function load() {
  let r;

  try {
    r = exports.storage.getItem('debug');
  } catch (error) {// Swallow
    // XXX (@Qix-) should we be logging these?
  } // If debug isn't set in LS, and we're in Electron, try to load $DEBUG


  if (!r && typeof process !== 'undefined' && 'env' in process) {
    r = process.env.DEBUG;
  }

  return r;
}
/**
 * Localstorage attempts to return the localstorage.
 *
 * This is necessary because safari throws
 * when a user disables cookies/localstorage
 * and you attempt to access it.
 *
 * @return {LocalStorage}
 * @api private
 */


function localstorage() {
  try {
    // TVMLKit (Apple TV JS Runtime) does not have a window object, just localStorage in the global context
    // The Browser also has localStorage in the global context.
    return localStorage;
  } catch (error) {// Swallow
    // XXX (@Qix-) should we be logging these?
  }
}

module.exports = __webpack_require__(52993)(exports);
const {
  formatters
} = module.exports;
/**
 * Map %j to `JSON.stringify()`, since no Web Inspectors do that by default.
 */

formatters.j = function (v) {
  try {
    return JSON.stringify(v);
  } catch (error) {
    return '[UnexpectedJSONParseError]: ' + error.message;
  }
};

/***/ }),

/***/ 52993:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/**
 * This is the common logic for both the Node.js and web browser
 * implementations of `debug()`.
 */
function setup(env) {
  createDebug.debug = createDebug;
  createDebug.default = createDebug;
  createDebug.coerce = coerce;
  createDebug.disable = disable;
  createDebug.enable = enable;
  createDebug.enabled = enabled;
  createDebug.humanize = __webpack_require__(11378);
  Object.keys(env).forEach(key => {
    createDebug[key] = env[key];
  });
  /**
  * Active `debug` instances.
  */

  createDebug.instances = [];
  /**
  * The currently active debug mode names, and names to skip.
  */

  createDebug.names = [];
  createDebug.skips = [];
  /**
  * Map of special "%n" handling functions, for the debug "format" argument.
  *
  * Valid key names are a single, lower or upper-case letter, i.e. "n" and "N".
  */

  createDebug.formatters = {};
  /**
  * Selects a color for a debug namespace
  * @param {String} namespace The namespace string for the for the debug instance to be colored
  * @return {Number|String} An ANSI color code for the given namespace
  * @api private
  */

  function selectColor(namespace) {
    let hash = 0;

    for (let i = 0; i < namespace.length; i++) {
      hash = (hash << 5) - hash + namespace.charCodeAt(i);
      hash |= 0; // Convert to 32bit integer
    }

    return createDebug.colors[Math.abs(hash) % createDebug.colors.length];
  }

  createDebug.selectColor = selectColor;
  /**
  * Create a debugger with the given `namespace`.
  *
  * @param {String} namespace
  * @return {Function}
  * @api public
  */

  function createDebug(namespace) {
    let prevTime;

    function debug() {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      // Disabled?
      if (!debug.enabled) {
        return;
      }

      const self = debug; // Set `diff` timestamp

      const curr = Number(new Date());
      const ms = curr - (prevTime || curr);
      self.diff = ms;
      self.prev = prevTime;
      self.curr = curr;
      prevTime = curr;
      args[0] = createDebug.coerce(args[0]);

      if (typeof args[0] !== 'string') {
        // Anything else let's inspect with %O
        args.unshift('%O');
      } // Apply any `formatters` transformations


      let index = 0;
      args[0] = args[0].replace(/%([a-zA-Z%])/g, (match, format) => {
        // If we encounter an escaped % then don't increase the array index
        if (match === '%%') {
          return match;
        }

        index++;
        const formatter = createDebug.formatters[format];

        if (typeof formatter === 'function') {
          const val = args[index];
          match = formatter.call(self, val); // Now we need to remove `args[index]` since it's inlined in the `format`

          args.splice(index, 1);
          index--;
        }

        return match;
      }); // Apply env-specific formatting (colors, etc.)

      createDebug.formatArgs.call(self, args);
      const logFn = self.log || createDebug.log;
      logFn.apply(self, args);
    }

    debug.namespace = namespace;
    debug.enabled = createDebug.enabled(namespace);
    debug.useColors = createDebug.useColors();
    debug.color = selectColor(namespace);
    debug.destroy = destroy;
    debug.extend = extend; // Debug.formatArgs = formatArgs;
    // debug.rawLog = rawLog;
    // env-specific initialization logic for debug instances

    if (typeof createDebug.init === 'function') {
      createDebug.init(debug);
    }

    createDebug.instances.push(debug);
    return debug;
  }

  function destroy() {
    const index = createDebug.instances.indexOf(this);

    if (index !== -1) {
      createDebug.instances.splice(index, 1);
      return true;
    }

    return false;
  }

  function extend(namespace, delimiter) {
    const newDebug = createDebug(this.namespace + (typeof delimiter === 'undefined' ? ':' : delimiter) + namespace);
    newDebug.log = this.log;
    return newDebug;
  }
  /**
  * Enables a debug mode by namespaces. This can include modes
  * separated by a colon and wildcards.
  *
  * @param {String} namespaces
  * @api public
  */


  function enable(namespaces) {
    createDebug.save(namespaces);
    createDebug.names = [];
    createDebug.skips = [];
    let i;
    const split = (typeof namespaces === 'string' ? namespaces : '').split(/[\s,]+/);
    const len = split.length;

    for (i = 0; i < len; i++) {
      if (!split[i]) {
        // ignore empty strings
        continue;
      }

      namespaces = split[i].replace(/\*/g, '.*?');

      if (namespaces[0] === '-') {
        createDebug.skips.push(new RegExp('^' + namespaces.substr(1) + '$'));
      } else {
        createDebug.names.push(new RegExp('^' + namespaces + '$'));
      }
    }

    for (i = 0; i < createDebug.instances.length; i++) {
      const instance = createDebug.instances[i];
      instance.enabled = createDebug.enabled(instance.namespace);
    }
  }
  /**
  * Disable debug output.
  *
  * @return {String} namespaces
  * @api public
  */


  function disable() {
    const namespaces = [...createDebug.names.map(toNamespace), ...createDebug.skips.map(toNamespace).map(namespace => '-' + namespace)].join(',');
    createDebug.enable('');
    return namespaces;
  }
  /**
  * Returns true if the given mode name is enabled, false otherwise.
  *
  * @param {String} name
  * @return {Boolean}
  * @api public
  */


  function enabled(name) {
    if (name[name.length - 1] === '*') {
      return true;
    }

    let i;
    let len;

    for (i = 0, len = createDebug.skips.length; i < len; i++) {
      if (createDebug.skips[i].test(name)) {
        return false;
      }
    }

    for (i = 0, len = createDebug.names.length; i < len; i++) {
      if (createDebug.names[i].test(name)) {
        return true;
      }
    }

    return false;
  }
  /**
  * Convert regexp to namespace
  *
  * @param {RegExp} regxep
  * @return {String} namespace
  * @api private
  */


  function toNamespace(regexp) {
    return regexp.toString().substring(2, regexp.toString().length - 2).replace(/\.\*\?$/, '*');
  }
  /**
  * Coerce `val`.
  *
  * @param {Mixed} val
  * @return {Mixed}
  * @api private
  */


  function coerce(val) {
    if (val instanceof Error) {
      return val.stack || val.message;
    }

    return val;
  }

  createDebug.enable(createDebug.load());
  return createDebug;
}

module.exports = setup;

/***/ }),

/***/ 40744:
/***/ (function(module, exports, __webpack_require__) {

/**
 * This is the web browser implementation of `debug()`.
 *
 * Expose `debug()` as the module.
 */
exports = module.exports = __webpack_require__(28128);
exports.log = log;
exports.formatArgs = formatArgs;
exports.save = save;
exports.load = load;
exports.useColors = useColors;
exports.storage = 'undefined' != typeof chrome && 'undefined' != typeof chrome.storage ? chrome.storage.local : localstorage();
/**
 * Colors.
 */

exports.colors = ['#0000CC', '#0000FF', '#0033CC', '#0033FF', '#0066CC', '#0066FF', '#0099CC', '#0099FF', '#00CC00', '#00CC33', '#00CC66', '#00CC99', '#00CCCC', '#00CCFF', '#3300CC', '#3300FF', '#3333CC', '#3333FF', '#3366CC', '#3366FF', '#3399CC', '#3399FF', '#33CC00', '#33CC33', '#33CC66', '#33CC99', '#33CCCC', '#33CCFF', '#6600CC', '#6600FF', '#6633CC', '#6633FF', '#66CC00', '#66CC33', '#9900CC', '#9900FF', '#9933CC', '#9933FF', '#99CC00', '#99CC33', '#CC0000', '#CC0033', '#CC0066', '#CC0099', '#CC00CC', '#CC00FF', '#CC3300', '#CC3333', '#CC3366', '#CC3399', '#CC33CC', '#CC33FF', '#CC6600', '#CC6633', '#CC9900', '#CC9933', '#CCCC00', '#CCCC33', '#FF0000', '#FF0033', '#FF0066', '#FF0099', '#FF00CC', '#FF00FF', '#FF3300', '#FF3333', '#FF3366', '#FF3399', '#FF33CC', '#FF33FF', '#FF6600', '#FF6633', '#FF9900', '#FF9933', '#FFCC00', '#FFCC33'];
/**
 * Currently only WebKit-based Web Inspectors, Firefox >= v31,
 * and the Firebug extension (any Firefox version) are known
 * to support "%c" CSS customizations.
 *
 * TODO: add a `localStorage` variable to explicitly enable/disable colors
 */

function useColors() {
  // NB: In an Electron preload script, document will be defined but not fully
  // initialized. Since we know we're in Chrome, we'll just detect this case
  // explicitly
  if (typeof window !== 'undefined' && window.process && window.process.type === 'renderer') {
    return true;
  } // Internet Explorer and Edge do not support colors.


  if (typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/(edge|trident)\/(\d+)/)) {
    return false;
  } // is webkit? http://stackoverflow.com/a/16459606/376773
  // document is undefined in react-native: https://github.com/facebook/react-native/pull/1632


  return typeof document !== 'undefined' && document.documentElement && document.documentElement.style && document.documentElement.style.WebkitAppearance || // is firebug? http://stackoverflow.com/a/398120/376773
  typeof window !== 'undefined' && window.console && (window.console.firebug || window.console.exception && window.console.table) || // is firefox >= v31?
  // https://developer.mozilla.org/en-US/docs/Tools/Web_Console#Styling_messages
  typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/firefox\/(\d+)/) && parseInt(RegExp.$1, 10) >= 31 || // double check webkit in userAgent just in case we are in a worker
  typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/applewebkit\/(\d+)/);
}
/**
 * Map %j to `JSON.stringify()`, since no Web Inspectors do that by default.
 */


exports.formatters.j = function (v) {
  try {
    return JSON.stringify(v);
  } catch (err) {
    return '[UnexpectedJSONParseError]: ' + err.message;
  }
};
/**
 * Colorize log arguments if enabled.
 *
 * @api public
 */


function formatArgs(args) {
  var useColors = this.useColors;
  args[0] = (useColors ? '%c' : '') + this.namespace + (useColors ? ' %c' : ' ') + args[0] + (useColors ? '%c ' : ' ') + '+' + exports.humanize(this.diff);
  if (!useColors) return;
  var c = 'color: ' + this.color;
  args.splice(1, 0, c, 'color: inherit'); // the final "%c" is somewhat tricky, because there could be other
  // arguments passed either before or after the %c, so we need to
  // figure out the correct index to insert the CSS into

  var index = 0;
  var lastC = 0;
  args[0].replace(/%[a-zA-Z%]/g, function (match) {
    if ('%%' === match) return;
    index++;

    if ('%c' === match) {
      // we only are interested in the *last* %c
      // (the user may have provided their own)
      lastC = index;
    }
  });
  args.splice(lastC, 0, c);
}
/**
 * Invokes `console.log()` when available.
 * No-op when `console.log` is not a "function".
 *
 * @api public
 */


function log() {
  // this hackery is required for IE8/9, where
  // the `console.log` function doesn't have 'apply'
  return 'object' === typeof console && console.log && Function.prototype.apply.call(console.log, console, arguments);
}
/**
 * Save `namespaces`.
 *
 * @param {String} namespaces
 * @api private
 */


function save(namespaces) {
  try {
    if (null == namespaces) {
      exports.storage.removeItem('debug');
    } else {
      exports.storage.debug = namespaces;
    }
  } catch (e) {}
}
/**
 * Load `namespaces`.
 *
 * @return {String} returns the previously persisted debug modes
 * @api private
 */


function load() {
  var r;

  try {
    r = exports.storage.debug;
  } catch (e) {} // If debug isn't set in LS, and we're in Electron, try to load $DEBUG


  if (!r && typeof process !== 'undefined' && 'env' in process) {
    r = process.env.DEBUG;
  }

  return r;
}
/**
 * Enable namespaces listed in `localStorage.debug` initially.
 */


exports.enable(load());
/**
 * Localstorage attempts to return the localstorage.
 *
 * This is necessary because safari throws
 * when a user disables cookies/localstorage
 * and you attempt to access it.
 *
 * @return {LocalStorage}
 * @api private
 */

function localstorage() {
  try {
    return window.localStorage;
  } catch (e) {}
}

/***/ }),

/***/ 28128:
/***/ (function(module, exports, __webpack_require__) {

/**
 * This is the common logic for both the Node.js and web browser
 * implementations of `debug()`.
 *
 * Expose `debug()` as the module.
 */
exports = module.exports = createDebug.debug = createDebug['default'] = createDebug;
exports.coerce = coerce;
exports.disable = disable;
exports.enable = enable;
exports.enabled = enabled;
exports.humanize = __webpack_require__(73160);
/**
 * Active `debug` instances.
 */

exports.instances = [];
/**
 * The currently active debug mode names, and names to skip.
 */

exports.names = [];
exports.skips = [];
/**
 * Map of special "%n" handling functions, for the debug "format" argument.
 *
 * Valid key names are a single, lower or upper-case letter, i.e. "n" and "N".
 */

exports.formatters = {};
/**
 * Select a color.
 * @param {String} namespace
 * @return {Number}
 * @api private
 */

function selectColor(namespace) {
  var hash = 0,
      i;

  for (i in namespace) {
    hash = (hash << 5) - hash + namespace.charCodeAt(i);
    hash |= 0; // Convert to 32bit integer
  }

  return exports.colors[Math.abs(hash) % exports.colors.length];
}
/**
 * Create a debugger with the given `namespace`.
 *
 * @param {String} namespace
 * @return {Function}
 * @api public
 */


function createDebug(namespace) {
  var prevTime;

  function debug() {
    // disabled?
    if (!debug.enabled) return;
    var self = debug; // set `diff` timestamp

    var curr = +new Date();
    var ms = curr - (prevTime || curr);
    self.diff = ms;
    self.prev = prevTime;
    self.curr = curr;
    prevTime = curr; // turn the `arguments` into a proper Array

    var args = new Array(arguments.length);

    for (var i = 0; i < args.length; i++) {
      args[i] = arguments[i];
    }

    args[0] = exports.coerce(args[0]);

    if ('string' !== typeof args[0]) {
      // anything else let's inspect with %O
      args.unshift('%O');
    } // apply any `formatters` transformations


    var index = 0;
    args[0] = args[0].replace(/%([a-zA-Z%])/g, function (match, format) {
      // if we encounter an escaped % then don't increase the array index
      if (match === '%%') return match;
      index++;
      var formatter = exports.formatters[format];

      if ('function' === typeof formatter) {
        var val = args[index];
        match = formatter.call(self, val); // now we need to remove `args[index]` since it's inlined in the `format`

        args.splice(index, 1);
        index--;
      }

      return match;
    }); // apply env-specific formatting (colors, etc.)

    exports.formatArgs.call(self, args);
    var logFn = debug.log || exports.log || console.log.bind(console);
    logFn.apply(self, args);
  }

  debug.namespace = namespace;
  debug.enabled = exports.enabled(namespace);
  debug.useColors = exports.useColors();
  debug.color = selectColor(namespace);
  debug.destroy = destroy; // env-specific initialization logic for debug instances

  if ('function' === typeof exports.init) {
    exports.init(debug);
  }

  exports.instances.push(debug);
  return debug;
}

function destroy() {
  var index = exports.instances.indexOf(this);

  if (index !== -1) {
    exports.instances.splice(index, 1);
    return true;
  } else {
    return false;
  }
}
/**
 * Enables a debug mode by namespaces. This can include modes
 * separated by a colon and wildcards.
 *
 * @param {String} namespaces
 * @api public
 */


function enable(namespaces) {
  exports.save(namespaces);
  exports.names = [];
  exports.skips = [];
  var i;
  var split = (typeof namespaces === 'string' ? namespaces : '').split(/[\s,]+/);
  var len = split.length;

  for (i = 0; i < len; i++) {
    if (!split[i]) continue; // ignore empty strings

    namespaces = split[i].replace(/\*/g, '.*?');

    if (namespaces[0] === '-') {
      exports.skips.push(new RegExp('^' + namespaces.substr(1) + '$'));
    } else {
      exports.names.push(new RegExp('^' + namespaces + '$'));
    }
  }

  for (i = 0; i < exports.instances.length; i++) {
    var instance = exports.instances[i];
    instance.enabled = exports.enabled(instance.namespace);
  }
}
/**
 * Disable debug output.
 *
 * @api public
 */


function disable() {
  exports.enable('');
}
/**
 * Returns true if the given mode name is enabled, false otherwise.
 *
 * @param {String} name
 * @return {Boolean}
 * @api public
 */


function enabled(name) {
  if (name[name.length - 1] === '*') {
    return true;
  }

  var i, len;

  for (i = 0, len = exports.skips.length; i < len; i++) {
    if (exports.skips[i].test(name)) {
      return false;
    }
  }

  for (i = 0, len = exports.names.length; i < len; i++) {
    if (exports.names[i].test(name)) {
      return true;
    }
  }

  return false;
}
/**
 * Coerce `val`.
 *
 * @param {Mixed} val
 * @return {Mixed}
 * @api private
 */


function coerce(val) {
  if (val instanceof Error) return val.stack || val.message;
  return val;
}

/***/ }),

/***/ 33927:
/***/ (function(module, exports, __webpack_require__) {

"use strict";
var __WEBPACK_AMD_DEFINE_RESULT__;

(function (global) {
  // minimal symbol polyfill for IE11 and others
  if (typeof Symbol !== 'function') {
    var Symbol = function (name) {
      return name;
    };

    Symbol.nonNative = true;
  }

  const STATE_PLAINTEXT = Symbol('plaintext');
  const STATE_HTML = Symbol('html');
  const STATE_COMMENT = Symbol('comment');
  const ALLOWED_TAGS_REGEX = /<(\w*)>/g;
  const NORMALIZE_TAG_REGEX = /<\/?([^\s\/>]+)/;

  function striptags(html, allowable_tags, tag_replacement) {
    html = html || '';
    allowable_tags = allowable_tags || [];
    tag_replacement = tag_replacement || '';
    let context = init_context(allowable_tags, tag_replacement);
    return striptags_internal(html, context);
  }

  function init_striptags_stream(allowable_tags, tag_replacement) {
    allowable_tags = allowable_tags || [];
    tag_replacement = tag_replacement || '';
    let context = init_context(allowable_tags, tag_replacement);
    return function striptags_stream(html) {
      return striptags_internal(html || '', context);
    };
  }

  striptags.init_streaming_mode = init_striptags_stream;

  function init_context(allowable_tags, tag_replacement) {
    allowable_tags = parse_allowable_tags(allowable_tags);
    return {
      allowable_tags: allowable_tags,
      tag_replacement: tag_replacement,
      state: STATE_PLAINTEXT,
      tag_buffer: '',
      depth: 0,
      in_quote_char: ''
    };
  }

  function striptags_internal(html, context) {
    let allowable_tags = context.allowable_tags;
    let tag_replacement = context.tag_replacement;
    let state = context.state;
    let tag_buffer = context.tag_buffer;
    let depth = context.depth;
    let in_quote_char = context.in_quote_char;
    let output = '';

    for (let idx = 0, length = html.length; idx < length; idx++) {
      let char = html[idx];

      if (state === STATE_PLAINTEXT) {
        switch (char) {
          case '<':
            state = STATE_HTML;
            tag_buffer += char;
            break;

          default:
            output += char;
            break;
        }
      } else if (state === STATE_HTML) {
        switch (char) {
          case '<':
            // ignore '<' if inside a quote
            if (in_quote_char) {
              break;
            } // we're seeing a nested '<'


            depth++;
            break;

          case '>':
            // ignore '>' if inside a quote
            if (in_quote_char) {
              break;
            } // something like this is happening: '<<>>'


            if (depth) {
              depth--;
              break;
            } // this is closing the tag in tag_buffer


            in_quote_char = '';
            state = STATE_PLAINTEXT;
            tag_buffer += '>';

            if (allowable_tags.has(normalize_tag(tag_buffer))) {
              output += tag_buffer;
            } else {
              output += tag_replacement;
            }

            tag_buffer = '';
            break;

          case '"':
          case '\'':
            // catch both single and double quotes
            if (char === in_quote_char) {
              in_quote_char = '';
            } else {
              in_quote_char = in_quote_char || char;
            }

            tag_buffer += char;
            break;

          case '-':
            if (tag_buffer === '<!-') {
              state = STATE_COMMENT;
            }

            tag_buffer += char;
            break;

          case ' ':
          case '\n':
            if (tag_buffer === '<') {
              state = STATE_PLAINTEXT;
              output += '< ';
              tag_buffer = '';
              break;
            }

            tag_buffer += char;
            break;

          default:
            tag_buffer += char;
            break;
        }
      } else if (state === STATE_COMMENT) {
        switch (char) {
          case '>':
            if (tag_buffer.slice(-2) == '--') {
              // close the comment
              state = STATE_PLAINTEXT;
            }

            tag_buffer = '';
            break;

          default:
            tag_buffer += char;
            break;
        }
      }
    } // save the context for future iterations


    context.state = state;
    context.tag_buffer = tag_buffer;
    context.depth = depth;
    context.in_quote_char = in_quote_char;
    return output;
  }

  function parse_allowable_tags(allowable_tags) {
    let tag_set = new Set();

    if (typeof allowable_tags === 'string') {
      let match;

      while (match = ALLOWED_TAGS_REGEX.exec(allowable_tags)) {
        tag_set.add(match[1]);
      }
    } else if (!Symbol.nonNative && typeof allowable_tags[Symbol.iterator] === 'function') {
      tag_set = new Set(allowable_tags);
    } else if (typeof allowable_tags.forEach === 'function') {
      // IE11 compatible
      allowable_tags.forEach(tag_set.add, tag_set);
    }

    return tag_set;
  }

  function normalize_tag(tag_buffer) {
    let match = NORMALIZE_TAG_REGEX.exec(tag_buffer);
    return match ? match[1].toLowerCase() : null;
  }

  if (true) {
    // AMD
    !(__WEBPACK_AMD_DEFINE_RESULT__ = (function module_factory() {
      return striptags;
    }).call(exports, __webpack_require__, exports, module),
		__WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
  } else {}
})(this);

/***/ }),

/***/ 34386:
/***/ (function(module, exports, __webpack_require__) {

/* eslint-env browser */

/**
 * This is the web browser implementation of `debug()`.
 */
exports.formatArgs = formatArgs;
exports.save = save;
exports.load = load;
exports.useColors = useColors;
exports.storage = localstorage();

exports.destroy = (() => {
  let warned = false;
  return () => {
    if (!warned) {
      warned = true;
      console.warn('Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`.');
    }
  };
})();
/**
 * Colors.
 */


exports.colors = ['#0000CC', '#0000FF', '#0033CC', '#0033FF', '#0066CC', '#0066FF', '#0099CC', '#0099FF', '#00CC00', '#00CC33', '#00CC66', '#00CC99', '#00CCCC', '#00CCFF', '#3300CC', '#3300FF', '#3333CC', '#3333FF', '#3366CC', '#3366FF', '#3399CC', '#3399FF', '#33CC00', '#33CC33', '#33CC66', '#33CC99', '#33CCCC', '#33CCFF', '#6600CC', '#6600FF', '#6633CC', '#6633FF', '#66CC00', '#66CC33', '#9900CC', '#9900FF', '#9933CC', '#9933FF', '#99CC00', '#99CC33', '#CC0000', '#CC0033', '#CC0066', '#CC0099', '#CC00CC', '#CC00FF', '#CC3300', '#CC3333', '#CC3366', '#CC3399', '#CC33CC', '#CC33FF', '#CC6600', '#CC6633', '#CC9900', '#CC9933', '#CCCC00', '#CCCC33', '#FF0000', '#FF0033', '#FF0066', '#FF0099', '#FF00CC', '#FF00FF', '#FF3300', '#FF3333', '#FF3366', '#FF3399', '#FF33CC', '#FF33FF', '#FF6600', '#FF6633', '#FF9900', '#FF9933', '#FFCC00', '#FFCC33'];
/**
 * Currently only WebKit-based Web Inspectors, Firefox >= v31,
 * and the Firebug extension (any Firefox version) are known
 * to support "%c" CSS customizations.
 *
 * TODO: add a `localStorage` variable to explicitly enable/disable colors
 */
// eslint-disable-next-line complexity

function useColors() {
  // NB: In an Electron preload script, document will be defined but not fully
  // initialized. Since we know we're in Chrome, we'll just detect this case
  // explicitly
  if (typeof window !== 'undefined' && window.process && (window.process.type === 'renderer' || window.process.__nwjs)) {
    return true;
  } // Internet Explorer and Edge do not support colors.


  if (typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/(edge|trident)\/(\d+)/)) {
    return false;
  } // Is webkit? http://stackoverflow.com/a/16459606/376773
  // document is undefined in react-native: https://github.com/facebook/react-native/pull/1632


  return typeof document !== 'undefined' && document.documentElement && document.documentElement.style && document.documentElement.style.WebkitAppearance || // Is firebug? http://stackoverflow.com/a/398120/376773
  typeof window !== 'undefined' && window.console && (window.console.firebug || window.console.exception && window.console.table) || // Is firefox >= v31?
  // https://developer.mozilla.org/en-US/docs/Tools/Web_Console#Styling_messages
  typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/firefox\/(\d+)/) && parseInt(RegExp.$1, 10) >= 31 || // Double check webkit in userAgent just in case we are in a worker
  typeof navigator !== 'undefined' && navigator.userAgent && navigator.userAgent.toLowerCase().match(/applewebkit\/(\d+)/);
}
/**
 * Colorize log arguments if enabled.
 *
 * @api public
 */


function formatArgs(args) {
  args[0] = (this.useColors ? '%c' : '') + this.namespace + (this.useColors ? ' %c' : ' ') + args[0] + (this.useColors ? '%c ' : ' ') + '+' + module.exports.humanize(this.diff);

  if (!this.useColors) {
    return;
  }

  const c = 'color: ' + this.color;
  args.splice(1, 0, c, 'color: inherit'); // The final "%c" is somewhat tricky, because there could be other
  // arguments passed either before or after the %c, so we need to
  // figure out the correct index to insert the CSS into

  let index = 0;
  let lastC = 0;
  args[0].replace(/%[a-zA-Z%]/g, match => {
    if (match === '%%') {
      return;
    }

    index++;

    if (match === '%c') {
      // We only are interested in the *last* %c
      // (the user may have provided their own)
      lastC = index;
    }
  });
  args.splice(lastC, 0, c);
}
/**
 * Invokes `console.debug()` when available.
 * No-op when `console.debug` is not a "function".
 * If `console.debug` is not available, falls back
 * to `console.log`.
 *
 * @api public
 */


exports.log = console.debug || console.log || (() => {});
/**
 * Save `namespaces`.
 *
 * @param {String} namespaces
 * @api private
 */


function save(namespaces) {
  try {
    if (namespaces) {
      exports.storage.setItem('debug', namespaces);
    } else {
      exports.storage.removeItem('debug');
    }
  } catch (error) {// Swallow
    // XXX (@Qix-) should we be logging these?
  }
}
/**
 * Load `namespaces`.
 *
 * @return {String} returns the previously persisted debug modes
 * @api private
 */


function load() {
  let r;

  try {
    r = exports.storage.getItem('debug');
  } catch (error) {// Swallow
    // XXX (@Qix-) should we be logging these?
  } // If debug isn't set in LS, and we're in Electron, try to load $DEBUG


  if (!r && typeof process !== 'undefined' && 'env' in process) {
    r = process.env.DEBUG;
  }

  return r;
}
/**
 * Localstorage attempts to return the localstorage.
 *
 * This is necessary because safari throws
 * when a user disables cookies/localstorage
 * and you attempt to access it.
 *
 * @return {LocalStorage}
 * @api private
 */


function localstorage() {
  try {
    // TVMLKit (Apple TV JS Runtime) does not have a window object, just localStorage in the global context
    // The Browser also has localStorage in the global context.
    return localStorage;
  } catch (error) {// Swallow
    // XXX (@Qix-) should we be logging these?
  }
}

module.exports = __webpack_require__(58671)(exports);
const {
  formatters
} = module.exports;
/**
 * Map %j to `JSON.stringify()`, since no Web Inspectors do that by default.
 */

formatters.j = function (v) {
  try {
    return JSON.stringify(v);
  } catch (error) {
    return '[UnexpectedJSONParseError]: ' + error.message;
  }
};

/***/ }),

/***/ 58671:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

/**
 * This is the common logic for both the Node.js and web browser
 * implementations of `debug()`.
 */
function setup(env) {
  createDebug.debug = createDebug;
  createDebug.default = createDebug;
  createDebug.coerce = coerce;
  createDebug.disable = disable;
  createDebug.enable = enable;
  createDebug.enabled = enabled;
  createDebug.humanize = __webpack_require__(21749);
  createDebug.destroy = destroy;
  Object.keys(env).forEach(key => {
    createDebug[key] = env[key];
  });
  /**
  * The currently active debug mode names, and names to skip.
  */

  createDebug.names = [];
  createDebug.skips = [];
  /**
  * Map of special "%n" handling functions, for the debug "format" argument.
  *
  * Valid key names are a single, lower or upper-case letter, i.e. "n" and "N".
  */

  createDebug.formatters = {};
  /**
  * Selects a color for a debug namespace
  * @param {String} namespace The namespace string for the debug instance to be colored
  * @return {Number|String} An ANSI color code for the given namespace
  * @api private
  */

  function selectColor(namespace) {
    let hash = 0;

    for (let i = 0; i < namespace.length; i++) {
      hash = (hash << 5) - hash + namespace.charCodeAt(i);
      hash |= 0; // Convert to 32bit integer
    }

    return createDebug.colors[Math.abs(hash) % createDebug.colors.length];
  }

  createDebug.selectColor = selectColor;
  /**
  * Create a debugger with the given `namespace`.
  *
  * @param {String} namespace
  * @return {Function}
  * @api public
  */

  function createDebug(namespace) {
    let prevTime;
    let enableOverride = null;
    let namespacesCache;
    let enabledCache;

    function debug() {
      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      // Disabled?
      if (!debug.enabled) {
        return;
      }

      const self = debug; // Set `diff` timestamp

      const curr = Number(new Date());
      const ms = curr - (prevTime || curr);
      self.diff = ms;
      self.prev = prevTime;
      self.curr = curr;
      prevTime = curr;
      args[0] = createDebug.coerce(args[0]);

      if (typeof args[0] !== 'string') {
        // Anything else let's inspect with %O
        args.unshift('%O');
      } // Apply any `formatters` transformations


      let index = 0;
      args[0] = args[0].replace(/%([a-zA-Z%])/g, (match, format) => {
        // If we encounter an escaped % then don't increase the array index
        if (match === '%%') {
          return '%';
        }

        index++;
        const formatter = createDebug.formatters[format];

        if (typeof formatter === 'function') {
          const val = args[index];
          match = formatter.call(self, val); // Now we need to remove `args[index]` since it's inlined in the `format`

          args.splice(index, 1);
          index--;
        }

        return match;
      }); // Apply env-specific formatting (colors, etc.)

      createDebug.formatArgs.call(self, args);
      const logFn = self.log || createDebug.log;
      logFn.apply(self, args);
    }

    debug.namespace = namespace;
    debug.useColors = createDebug.useColors();
    debug.color = createDebug.selectColor(namespace);
    debug.extend = extend;
    debug.destroy = createDebug.destroy; // XXX Temporary. Will be removed in the next major release.

    Object.defineProperty(debug, 'enabled', {
      enumerable: true,
      configurable: false,
      get: () => {
        if (enableOverride !== null) {
          return enableOverride;
        }

        if (namespacesCache !== createDebug.namespaces) {
          namespacesCache = createDebug.namespaces;
          enabledCache = createDebug.enabled(namespace);
        }

        return enabledCache;
      },
      set: v => {
        enableOverride = v;
      }
    }); // Env-specific initialization logic for debug instances

    if (typeof createDebug.init === 'function') {
      createDebug.init(debug);
    }

    return debug;
  }

  function extend(namespace, delimiter) {
    const newDebug = createDebug(this.namespace + (typeof delimiter === 'undefined' ? ':' : delimiter) + namespace);
    newDebug.log = this.log;
    return newDebug;
  }
  /**
  * Enables a debug mode by namespaces. This can include modes
  * separated by a colon and wildcards.
  *
  * @param {String} namespaces
  * @api public
  */


  function enable(namespaces) {
    createDebug.save(namespaces);
    createDebug.namespaces = namespaces;
    createDebug.names = [];
    createDebug.skips = [];
    let i;
    const split = (typeof namespaces === 'string' ? namespaces : '').split(/[\s,]+/);
    const len = split.length;

    for (i = 0; i < len; i++) {
      if (!split[i]) {
        // ignore empty strings
        continue;
      }

      namespaces = split[i].replace(/\*/g, '.*?');

      if (namespaces[0] === '-') {
        createDebug.skips.push(new RegExp('^' + namespaces.substr(1) + '$'));
      } else {
        createDebug.names.push(new RegExp('^' + namespaces + '$'));
      }
    }
  }
  /**
  * Disable debug output.
  *
  * @return {String} namespaces
  * @api public
  */


  function disable() {
    const namespaces = [...createDebug.names.map(toNamespace), ...createDebug.skips.map(toNamespace).map(namespace => '-' + namespace)].join(',');
    createDebug.enable('');
    return namespaces;
  }
  /**
  * Returns true if the given mode name is enabled, false otherwise.
  *
  * @param {String} name
  * @return {Boolean}
  * @api public
  */


  function enabled(name) {
    if (name[name.length - 1] === '*') {
      return true;
    }

    let i;
    let len;

    for (i = 0, len = createDebug.skips.length; i < len; i++) {
      if (createDebug.skips[i].test(name)) {
        return false;
      }
    }

    for (i = 0, len = createDebug.names.length; i < len; i++) {
      if (createDebug.names[i].test(name)) {
        return true;
      }
    }

    return false;
  }
  /**
  * Convert regexp to namespace
  *
  * @param {RegExp} regxep
  * @return {String} namespace
  * @api private
  */


  function toNamespace(regexp) {
    return regexp.toString().substring(2, regexp.toString().length - 2).replace(/\.\*\?$/, '*');
  }
  /**
  * Coerce `val`.
  *
  * @param {Mixed} val
  * @return {Mixed}
  * @api private
  */


  function coerce(val) {
    if (val instanceof Error) {
      return val.stack || val.message;
    }

    return val;
  }
  /**
  * XXX DO NOT USE. This is a temporary stub function.
  * XXX It WILL be removed in the next major release.
  */


  function destroy() {
    console.warn('Instance method `debug.destroy()` is deprecated and no longer does anything. It will be removed in the next major version of `debug`.');
  }

  createDebug.enable(createDebug.load());
  return createDebug;
}

module.exports = setup;

/***/ }),

/***/ 61898:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
var isProduction = "production" === 'production';
var prefix = 'Invariant failed';
function invariant(condition, message) {
    if (condition) {
        return;
    }
    if (isProduction) {
        throw new Error(prefix);
    }
    throw new Error(prefix + ": " + (message || ''));
}

/* harmony default export */ __webpack_exports__["Z"] = (invariant);


/***/ }),

/***/ 81396:
/***/ (function(module) {

module.exports = toArray

function toArray(list, index) {
    var array = []

    index = index || 0

    for (var i = index || 0; i < list.length; i++) {
        array[i - index] = list[i]
    }

    return array
}


/***/ }),

/***/ 69699:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ FileReader; }
/* harmony export */ });
/* harmony import */ var _isReactNative__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(30391);
/* harmony import */ var _uriToBlob__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(15701);
/* harmony import */ var _isCordova__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(66558);
/* harmony import */ var _readAsByteArray__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(99686);
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }






var FileSource = /*#__PURE__*/function () {
  // Make this.size a method
  function FileSource(file) {
    _classCallCheck(this, FileSource);

    this._file = file;
    this.size = file.size;
  }

  _createClass(FileSource, [{
    key: "slice",
    value: function slice(start, end) {
      // In Apache Cordova applications, a File must be resolved using
      // FileReader instances, see
      // https://cordova.apache.org/docs/en/8.x/reference/cordova-plugin-file/index.html#read-a-file
      if ((0,_isCordova__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)()) {
        return (0,_readAsByteArray__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(this._file.slice(start, end));
      }

      var value = this._file.slice(start, end);

      return Promise.resolve({
        value: value
      });
    }
  }, {
    key: "close",
    value: function close() {// Nothing to do here since we don't need to release any resources.
    }
  }]);

  return FileSource;
}();

var StreamSource = /*#__PURE__*/function () {
  function StreamSource(reader, chunkSize) {
    _classCallCheck(this, StreamSource);

    this._chunkSize = chunkSize;
    this._buffer = undefined;
    this._bufferOffset = 0;
    this._reader = reader;
    this._done = false;
  }

  _createClass(StreamSource, [{
    key: "slice",
    value: function slice(start, end) {
      if (start < this._bufferOffset) {
        return Promise.reject(new Error("Requested data is before the reader's current offset"));
      }

      return this._readUntilEnoughDataOrDone(start, end);
    }
  }, {
    key: "_readUntilEnoughDataOrDone",
    value: function _readUntilEnoughDataOrDone(start, end) {
      var _this = this;

      var hasEnoughData = end <= this._bufferOffset + len(this._buffer);

      if (this._done || hasEnoughData) {
        var value = this._getDataFromBuffer(start, end);

        var done = value == null ? this._done : false;
        return Promise.resolve({
          value: value,
          done: done
        });
      }

      return this._reader.read().then(function (_ref) {
        var value = _ref.value,
            done = _ref.done;

        if (done) {
          _this._done = true;
        } else if (_this._buffer === undefined) {
          _this._buffer = value;
        } else {
          _this._buffer = concat(_this._buffer, value);
        }

        return _this._readUntilEnoughDataOrDone(start, end);
      });
    }
  }, {
    key: "_getDataFromBuffer",
    value: function _getDataFromBuffer(start, end) {
      // Remove data from buffer before `start`.
      // Data might be reread from the buffer if an upload fails, so we can only
      // safely delete data when it comes *before* what is currently being read.
      if (start > this._bufferOffset) {
        this._buffer = this._buffer.slice(start - this._bufferOffset);
        this._bufferOffset = start;
      } // If the buffer is empty after removing old data, all data has been read.


      var hasAllDataBeenRead = len(this._buffer) === 0;

      if (this._done && hasAllDataBeenRead) {
        return null;
      } // We already removed data before `start`, so we just return the first
      // chunk from the buffer.


      return this._buffer.slice(0, end - start);
    }
  }, {
    key: "close",
    value: function close() {
      if (this._reader.cancel) {
        this._reader.cancel();
      }
    }
  }]);

  return StreamSource;
}();

function len(blobOrArray) {
  if (blobOrArray === undefined) return 0;
  if (blobOrArray.size !== undefined) return blobOrArray.size;
  return blobOrArray.length;
}
/*
  Typed arrays and blobs don't have a concat method.
  This function helps StreamSource accumulate data to reach chunkSize.
*/


function concat(a, b) {
  if (a.concat) {
    // Is `a` an Array?
    return a.concat(b);
  }

  if (a instanceof Blob) {
    return new Blob([a, b], {
      type: a.type
    });
  }

  if (a.set) {
    // Is `a` a typed array?
    var c = new a.constructor(a.length + b.length);
    c.set(a);
    c.set(b, a.length);
    return c;
  }

  throw new Error('Unknown data type');
}

var FileReader = /*#__PURE__*/function () {
  function FileReader() {
    _classCallCheck(this, FileReader);
  }

  _createClass(FileReader, [{
    key: "openFile",
    value: function openFile(input, chunkSize) {
      // In React Native, when user selects a file, instead of a File or Blob,
      // you usually get a file object {} with a uri property that contains
      // a local path to the file. We use XMLHttpRequest to fetch
      // the file blob, before uploading with tus.
      if ((0,_isReactNative__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)() && input && typeof input.uri !== 'undefined') {
        return (0,_uriToBlob__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z)(input.uri).then(function (blob) {
          return new FileSource(blob);
        })["catch"](function (err) {
          throw new Error("tus: cannot fetch `file.uri` as Blob, make sure the uri is correct and accessible. ".concat(err));
        });
      } // Since we emulate the Blob type in our tests (not all target browsers
      // support it), we cannot use `instanceof` for testing whether the input value
      // can be handled. Instead, we simply check is the slice() function and the
      // size property are available.


      if (typeof input.slice === 'function' && typeof input.size !== 'undefined') {
        return Promise.resolve(new FileSource(input));
      }

      if (typeof input.read === 'function') {
        chunkSize = +chunkSize;

        if (!isFinite(chunkSize)) {
          return Promise.reject(new Error('cannot create source for stream without a finite value for the `chunkSize` option'));
        }

        return Promise.resolve(new StreamSource(input, chunkSize));
      }

      return Promise.reject(new Error('source object may only be an instance of File, Blob, or Reader in this environment'));
    }
  }]);

  return FileReader;
}();



/***/ }),

/***/ 21055:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ fingerprint; }
/* harmony export */ });
/* harmony import */ var _isReactNative__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(30391);
 // TODO: Differenciate between input types

/**
 * Generate a fingerprint for a file which will be used the store the endpoint
 *
 * @param {File} file
 * @param {Object} options
 * @param {Function} callback
 */

function fingerprint(file, options) {
  if ((0,_isReactNative__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)()) {
    return Promise.resolve(reactNativeFingerprint(file, options));
  }

  return Promise.resolve(['tus-br', file.name, file.type, file.size, file.lastModified, options.endpoint].join('-'));
}

function reactNativeFingerprint(file, options) {
  var exifHash = file.exif ? hashCode(JSON.stringify(file.exif)) : 'noexif';
  return ['tus-rn', file.name || 'noname', file.size || 'nosize', exifHash, options.endpoint].join('/');
}

function hashCode(str) {
  // from https://stackoverflow.com/a/8831937/151666
  var hash = 0;

  if (str.length === 0) {
    return hash;
  }

  for (var i = 0; i < str.length; i++) {
    var _char = str.charCodeAt(i);

    hash = (hash << 5) - hash + _char;
    hash &= hash; // Convert to 32bit integer
  }

  return hash;
}

/***/ }),

/***/ 60321:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ XHRHttpStack; }
/* harmony export */ });
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/* global window */
var XHRHttpStack = /*#__PURE__*/function () {
  function XHRHttpStack() {
    _classCallCheck(this, XHRHttpStack);
  }

  _createClass(XHRHttpStack, [{
    key: "createRequest",
    value: function createRequest(method, url) {
      return new Request(method, url);
    }
  }, {
    key: "getName",
    value: function getName() {
      return 'XHRHttpStack';
    }
  }]);

  return XHRHttpStack;
}();



var Request = /*#__PURE__*/function () {
  function Request(method, url) {
    _classCallCheck(this, Request);

    this._xhr = new XMLHttpRequest();

    this._xhr.open(method, url, true);

    this._method = method;
    this._url = url;
    this._headers = {};
  }

  _createClass(Request, [{
    key: "getMethod",
    value: function getMethod() {
      return this._method;
    }
  }, {
    key: "getURL",
    value: function getURL() {
      return this._url;
    }
  }, {
    key: "setHeader",
    value: function setHeader(header, value) {
      this._xhr.setRequestHeader(header, value);

      this._headers[header] = value;
    }
  }, {
    key: "getHeader",
    value: function getHeader(header) {
      return this._headers[header];
    }
  }, {
    key: "setProgressHandler",
    value: function setProgressHandler(progressHandler) {
      // Test support for progress events before attaching an event listener
      if (!('upload' in this._xhr)) {
        return;
      }

      this._xhr.upload.onprogress = function (e) {
        if (!e.lengthComputable) {
          return;
        }

        progressHandler(e.loaded);
      };
    }
  }, {
    key: "send",
    value: function send() {
      var _this = this;

      var body = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
      return new Promise(function (resolve, reject) {
        _this._xhr.onload = function () {
          resolve(new Response(_this._xhr));
        };

        _this._xhr.onerror = function (err) {
          reject(err);
        };

        _this._xhr.send(body);
      });
    }
  }, {
    key: "abort",
    value: function abort() {
      this._xhr.abort();

      return Promise.resolve();
    }
  }, {
    key: "getUnderlyingObject",
    value: function getUnderlyingObject() {
      return this._xhr;
    }
  }]);

  return Request;
}();

var Response = /*#__PURE__*/function () {
  function Response(xhr) {
    _classCallCheck(this, Response);

    this._xhr = xhr;
  }

  _createClass(Response, [{
    key: "getStatus",
    value: function getStatus() {
      return this._xhr.status;
    }
  }, {
    key: "getHeader",
    value: function getHeader(header) {
      return this._xhr.getResponseHeader(header);
    }
  }, {
    key: "getBody",
    value: function getBody() {
      return this._xhr.responseText;
    }
  }, {
    key: "getUnderlyingObject",
    value: function getUnderlyingObject() {
      return this._xhr;
    }
  }]);

  return Response;
}();

/***/ }),

/***/ 90801:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "gq": function() { return /* binding */ Upload; }
/* harmony export */ });
/* unused harmony exports defaultOptions, isSupported */
/* harmony import */ var _upload__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(34220);
/* harmony import */ var _noopUrlStorage__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(37967);
/* harmony import */ var _urlStorage__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(42933);
/* harmony import */ var _httpStack__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(60321);
/* harmony import */ var _fileReader__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(69699);
/* harmony import */ var _fingerprint__WEBPACK_IMPORTED_MODULE_5__ = __webpack_require__(21055);
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { return function () { var Super = _getPrototypeOf(Derived), result; if (_isNativeReflectConstruct()) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* global window */








var defaultOptions = _objectSpread({}, _upload__WEBPACK_IMPORTED_MODULE_0__/* ["default"].defaultOptions */ .Z.defaultOptions, {
  httpStack: new _httpStack__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z(),
  fileReader: new _fileReader__WEBPACK_IMPORTED_MODULE_3__/* ["default"] */ .Z(),
  urlStorage: _urlStorage__WEBPACK_IMPORTED_MODULE_1__/* .canStoreURLs */ .H ? new _urlStorage__WEBPACK_IMPORTED_MODULE_1__/* .WebStorageUrlStorage */ .n() : new _noopUrlStorage__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z(),
  fingerprint: _fingerprint__WEBPACK_IMPORTED_MODULE_5__/* ["default"] */ .Z
});

var Upload = /*#__PURE__*/function (_BaseUpload) {
  _inherits(Upload, _BaseUpload);

  var _super = _createSuper(Upload);

  function Upload() {
    var file = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : null;
    var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    _classCallCheck(this, Upload);

    options = _objectSpread({}, defaultOptions, {}, options);
    return _super.call(this, file, options);
  }

  _createClass(Upload, null, [{
    key: "terminate",
    value: function terminate(url, options, cb) {
      options = _objectSpread({}, defaultOptions, {}, options);
      return _upload__WEBPACK_IMPORTED_MODULE_0__/* ["default"].terminate */ .Z.terminate(url, options, cb);
    }
  }]);

  return Upload;
}(_upload__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z);

var _window = window,
    XMLHttpRequest = _window.XMLHttpRequest,
    Blob = _window.Blob;
var isSupported = XMLHttpRequest && Blob && typeof Blob.prototype.slice === 'function';


/***/ }),

/***/ 66558:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
var isCordova = function isCordova() {
  return typeof window != 'undefined' && (typeof window.PhoneGap != 'undefined' || typeof window.Cordova != 'undefined' || typeof window.cordova != 'undefined');
};

/* harmony default export */ __webpack_exports__["Z"] = (isCordova);

/***/ }),

/***/ 30391:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
var isReactNative = function isReactNative() {
  return typeof navigator !== 'undefined' && typeof navigator.product === 'string' && navigator.product.toLowerCase() === 'reactnative';
};

/* harmony default export */ __webpack_exports__["Z"] = (isReactNative);

/***/ }),

/***/ 99686:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ readAsByteArray; }
/* harmony export */ });
/**
 * readAsByteArray converts a File object to a Uint8Array.
 * This function is only used on the Apache Cordova platform.
 * See https://cordova.apache.org/docs/en/latest/reference/cordova-plugin-file/index.html#read-a-file
 */
function readAsByteArray(chunk) {
  return new Promise(function (resolve, reject) {
    var reader = new FileReader();

    reader.onload = function () {
      var value = new Uint8Array(reader.result);
      resolve({
        value: value
      });
    };

    reader.onerror = function (err) {
      reject(err);
    };

    reader.readAsArrayBuffer(chunk);
  });
}

/***/ }),

/***/ 15701:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ uriToBlob; }
/* harmony export */ });
/**
 * uriToBlob resolves a URI to a Blob object. This is used for
 * React Native to retrieve a file (identified by a file://
 * URI) as a blob.
 */
function uriToBlob(uri) {
  return new Promise(function (resolve, reject) {
    var xhr = new XMLHttpRequest();
    xhr.responseType = 'blob';

    xhr.onload = function () {
      var blob = xhr.response;
      resolve(blob);
    };

    xhr.onerror = function (err) {
      reject(err);
    };

    xhr.open('GET', uri);
    xhr.send();
  });
}

/***/ }),

/***/ 42933:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "H": function() { return /* binding */ canStoreURLs; },
/* harmony export */   "n": function() { return /* binding */ WebStorageUrlStorage; }
/* harmony export */ });
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/* global window, localStorage */
var hasStorage = false;

try {
  hasStorage = 'localStorage' in window; // Attempt to store and read entries from the local storage to detect Private
  // Mode on Safari on iOS (see #49)

  var key = 'tusSupport';
  localStorage.setItem(key, localStorage.getItem(key));
} catch (e) {
  // If we try to access localStorage inside a sandboxed iframe, a SecurityError
  // is thrown. When in private mode on iOS Safari, a QuotaExceededError is
  // thrown (see #49)
  if (e.code === e.SECURITY_ERR || e.code === e.QUOTA_EXCEEDED_ERR) {
    hasStorage = false;
  } else {
    throw e;
  }
}

var canStoreURLs = hasStorage;
var WebStorageUrlStorage = /*#__PURE__*/function () {
  function WebStorageUrlStorage() {
    _classCallCheck(this, WebStorageUrlStorage);
  }

  _createClass(WebStorageUrlStorage, [{
    key: "findAllUploads",
    value: function findAllUploads() {
      var results = this._findEntries('tus::');

      return Promise.resolve(results);
    }
  }, {
    key: "findUploadsByFingerprint",
    value: function findUploadsByFingerprint(fingerprint) {
      var results = this._findEntries("tus::".concat(fingerprint, "::"));

      return Promise.resolve(results);
    }
  }, {
    key: "removeUpload",
    value: function removeUpload(urlStorageKey) {
      localStorage.removeItem(urlStorageKey);
      return Promise.resolve();
    }
  }, {
    key: "addUpload",
    value: function addUpload(fingerprint, upload) {
      var id = Math.round(Math.random() * 1e12);
      var key = "tus::".concat(fingerprint, "::").concat(id);
      localStorage.setItem(key, JSON.stringify(upload));
      return Promise.resolve(key);
    }
  }, {
    key: "_findEntries",
    value: function _findEntries(prefix) {
      var results = [];

      for (var i = 0; i < localStorage.length; i++) {
        var _key = localStorage.key(i);

        if (_key.indexOf(prefix) !== 0) continue;

        try {
          var upload = JSON.parse(localStorage.getItem(_key));
          upload.urlStorageKey = _key;
          results.push(upload);
        } catch (e) {// The JSON parse error is intentionally ignored here, so a malformed
          // entry in the storage cannot prevent an upload.
        }
      }

      return results;
    }
  }]);

  return WebStorageUrlStorage;
}();

/***/ }),

/***/ 19677:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _createSuper(Derived) { return function () { var Super = _getPrototypeOf(Derived), result; if (_isNativeReflectConstruct()) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _wrapNativeSuper(Class) { var _cache = typeof Map === "function" ? new Map() : undefined; _wrapNativeSuper = function _wrapNativeSuper(Class) { if (Class === null || !_isNativeFunction(Class)) return Class; if (typeof Class !== "function") { throw new TypeError("Super expression must either be null or a function"); } if (typeof _cache !== "undefined") { if (_cache.has(Class)) return _cache.get(Class); _cache.set(Class, Wrapper); } function Wrapper() { return _construct(Class, arguments, _getPrototypeOf(this).constructor); } Wrapper.prototype = Object.create(Class.prototype, { constructor: { value: Wrapper, enumerable: false, writable: true, configurable: true } }); return _setPrototypeOf(Wrapper, Class); }; return _wrapNativeSuper(Class); }

function _construct(Parent, args, Class) { if (_isNativeReflectConstruct()) { _construct = Reflect.construct; } else { _construct = function _construct(Parent, args, Class) { var a = [null]; a.push.apply(a, args); var Constructor = Function.bind.apply(Parent, a); var instance = new Constructor(); if (Class) _setPrototypeOf(instance, Class.prototype); return instance; }; } return _construct.apply(null, arguments); }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _isNativeFunction(fn) { return Function.toString.call(fn).indexOf("[native code]") !== -1; }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

var DetailedError = /*#__PURE__*/function (_Error) {
  _inherits(DetailedError, _Error);

  var _super = _createSuper(DetailedError);

  function DetailedError(message) {
    var _this;

    var causingErr = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
    var req = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : null;
    var res = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : null;

    _classCallCheck(this, DetailedError);

    _this = _super.call(this, message);
    _this.originalRequest = req;
    _this.originalResponse = res;
    _this.causingError = causingErr;

    if (causingErr != null) {
      message += ", caused by ".concat(causingErr.toString());
    }

    if (req != null) {
      var requestId = req.getHeader('X-Request-ID') || 'n/a';
      var method = req.getMethod();
      var url = req.getURL();
      var status = res ? res.getStatus() : 'n/a';
      var body = res ? res.getBody() || '' : 'n/a';
      message += ", originated from request (method: ".concat(method, ", url: ").concat(url, ", response code: ").concat(status, ", response text: ").concat(body, ", request id: ").concat(requestId, ")");
    }

    _this.message = message;
    return _this;
  }

  return DetailedError;
}( /*#__PURE__*/_wrapNativeSuper(Error));

/* harmony default export */ __webpack_exports__["Z"] = (DetailedError);

/***/ }),

/***/ 38489:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "c": function() { return /* binding */ log; }
/* harmony export */ });
/* unused harmony export enableDebugLog */
/* eslint no-console: "off" */
var isEnabled = false;
function enableDebugLog() {
  isEnabled = true;
}
function log(msg) {
  if (!isEnabled) return;
  console.log(msg);
}

/***/ }),

/***/ 37967:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ NoopUrlStorage; }
/* harmony export */ });
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/* eslint no-unused-vars: "off" */
var NoopUrlStorage = /*#__PURE__*/function () {
  function NoopUrlStorage() {
    _classCallCheck(this, NoopUrlStorage);
  }

  _createClass(NoopUrlStorage, [{
    key: "listAllUploads",
    value: function listAllUploads() {
      return Promise.resolve([]);
    }
  }, {
    key: "findUploadsByFingerprint",
    value: function findUploadsByFingerprint(fingerprint) {
      return Promise.resolve([]);
    }
  }, {
    key: "removeUpload",
    value: function removeUpload(urlStorageKey) {
      return Promise.resolve();
    }
  }, {
    key: "addUpload",
    value: function addUpload(fingerprint, upload) {
      return Promise.resolve(null);
    }
  }]);

  return NoopUrlStorage;
}();



/***/ }),

/***/ 34220:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var js_base64__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(95978);
/* harmony import */ var js_base64__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(js_base64__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var url_parse__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(64846);
/* harmony import */ var url_parse__WEBPACK_IMPORTED_MODULE_1___default = /*#__PURE__*/__webpack_require__.n(url_parse__WEBPACK_IMPORTED_MODULE_1__);
/* harmony import */ var _error__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(19677);
/* harmony import */ var _logger__WEBPACK_IMPORTED_MODULE_3__ = __webpack_require__(38489);
/* harmony import */ var _uuid__WEBPACK_IMPORTED_MODULE_4__ = __webpack_require__(4104);
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/* global window */





var defaultOptions = {
  endpoint: null,
  uploadUrl: null,
  metadata: {},
  fingerprint: null,
  uploadSize: null,
  onProgress: null,
  onChunkComplete: null,
  onSuccess: null,
  onError: null,
  _onUploadUrlAvailable: null,
  overridePatchMethod: false,
  headers: {},
  addRequestId: false,
  onBeforeRequest: null,
  onAfterResponse: null,
  onShouldRetry: null,
  chunkSize: Infinity,
  retryDelays: [0, 1000, 3000, 5000],
  parallelUploads: 1,
  storeFingerprintForResuming: true,
  removeFingerprintOnSuccess: false,
  uploadLengthDeferred: false,
  uploadDataDuringCreation: false,
  urlStorage: null,
  fileReader: null,
  httpStack: null
};

var BaseUpload = /*#__PURE__*/function () {
  function BaseUpload(file, options) {
    _classCallCheck(this, BaseUpload);

    // Warn about removed options from previous versions
    if ('resume' in options) {
      console.log('tus: The `resume` option has been removed in tus-js-client v2. Please use the URL storage API instead.'); // eslint-disable-line no-console
    } // The default options will already be added from the wrapper classes.


    this.options = options; // The storage module used to store URLs

    this._urlStorage = this.options.urlStorage; // The underlying File/Blob object

    this.file = file; // The URL against which the file will be uploaded

    this.url = null; // The underlying request object for the current PATCH request

    this._req = null; // The fingerpinrt for the current file (set after start())

    this._fingerprint = null; // The key that the URL storage returned when saving an URL with a fingerprint,

    this._urlStorageKey = null; // The offset used in the current PATCH request

    this._offset = null; // True if the current PATCH request has been aborted

    this._aborted = false; // The file's size in bytes

    this._size = null; // The Source object which will wrap around the given file and provides us
    // with a unified interface for getting its size and slice chunks from its
    // content allowing us to easily handle Files, Blobs, Buffers and Streams.

    this._source = null; // The current count of attempts which have been made. Zero indicates none.

    this._retryAttempt = 0; // The timeout's ID which is used to delay the next retry

    this._retryTimeout = null; // The offset of the remote upload before the latest attempt was started.

    this._offsetBeforeRetry = 0; // An array of BaseUpload instances which are used for uploading the different
    // parts, if the parallelUploads option is used.

    this._parallelUploads = null; // An array of upload URLs which are used for uploading the different
    // parts, if the parallelUploads option is used.

    this._parallelUploadUrls = null;
  }
  /**
   * Use the Termination extension to delete an upload from the server by sending a DELETE
   * request to the specified upload URL. This is only possible if the server supports the
   * Termination extension. If the `options.retryDelays` property is set, the method will
   * also retry if an error ocurrs.
   *
   * @param {String} url The upload's URL which will be terminated.
   * @param {object} options Optional options for influencing HTTP requests.
   * @return {Promise} The Promise will be resolved/rejected when the requests finish.
   */


  _createClass(BaseUpload, [{
    key: "findPreviousUploads",
    value: function findPreviousUploads() {
      var _this = this;

      return this.options.fingerprint(this.file, this.options).then(function (fingerprint) {
        return _this._urlStorage.findUploadsByFingerprint(fingerprint);
      });
    }
  }, {
    key: "resumeFromPreviousUpload",
    value: function resumeFromPreviousUpload(previousUpload) {
      this.url = previousUpload.uploadUrl || null;
      this._parallelUploadUrls = previousUpload.parallelUploadUrls || null;
      this._urlStorageKey = previousUpload.urlStorageKey;
    }
  }, {
    key: "start",
    value: function start() {
      var _this2 = this;

      var file = this.file;

      if (!file) {
        this._emitError(new Error('tus: no file or stream to upload provided'));

        return;
      }

      if (!this.options.endpoint && !this.options.uploadUrl) {
        this._emitError(new Error('tus: neither an endpoint or an upload URL is provided'));

        return;
      }

      var retryDelays = this.options.retryDelays;

      if (retryDelays != null && Object.prototype.toString.call(retryDelays) !== '[object Array]') {
        this._emitError(new Error('tus: the `retryDelays` option must either be an array or null'));

        return;
      }

      if (this.options.parallelUploads > 1) {
        // Test which options are incompatible with parallel uploads.
        ['uploadUrl', 'uploadSize', 'uploadLengthDeferred'].forEach(function (optionName) {
          if (_this2.options[optionName]) {
            _this2._emitError(new Error("tus: cannot use the ".concat(optionName, " option when parallelUploads is enabled")));
          }
        });
      }

      this.options.fingerprint(file, this.options).then(function (fingerprint) {
        if (fingerprint == null) {
          (0,_logger__WEBPACK_IMPORTED_MODULE_3__/* .log */ .c)('No fingerprint was calculated meaning that the upload cannot be stored in the URL storage.');
        } else {
          (0,_logger__WEBPACK_IMPORTED_MODULE_3__/* .log */ .c)("Calculated fingerprint: ".concat(fingerprint));
        }

        _this2._fingerprint = fingerprint;

        if (_this2._source) {
          return _this2._source;
        }

        return _this2.options.fileReader.openFile(file, _this2.options.chunkSize);
      }).then(function (source) {
        _this2._source = source; // If the upload was configured to use multiple requests or if we resume from
        // an upload which used multiple requests, we start a parallel upload.

        if (_this2.options.parallelUploads > 1 || _this2._parallelUploadUrls != null) {
          _this2._startParallelUpload();
        } else {
          _this2._startSingleUpload();
        }
      })["catch"](function (err) {
        _this2._emitError(err);
      });
    }
    /**
     * Initiate the uploading procedure for a parallelized upload, where one file is split into
     * multiple request which are run in parallel.
     *
     * @api private
     */

  }, {
    key: "_startParallelUpload",
    value: function _startParallelUpload() {
      var _this3 = this;

      var totalSize = this._size = this._source.size;
      var totalProgress = 0;
      this._parallelUploads = [];
      var partCount = this._parallelUploadUrls != null ? this._parallelUploadUrls.length : this.options.parallelUploads; // The input file will be split into multiple slices which are uploaded in separate
      // requests. Here we generate the start and end position for the slices.

      var parts = splitSizeIntoParts(this._source.size, partCount, this._parallelUploadUrls); // Create an empty list for storing the upload URLs

      this._parallelUploadUrls = new Array(parts.length); // Generate a promise for each slice that will be resolve if the respective
      // upload is completed.

      var uploads = parts.map(function (part, index) {
        var lastPartProgress = 0;
        return _this3._source.slice(part.start, part.end).then(function (_ref) {
          var value = _ref.value;
          return new Promise(function (resolve, reject) {
            // Merge with the user supplied options but overwrite some values.
            var options = _objectSpread({}, _this3.options, {
              // If available, the partial upload should be resumed from a previous URL.
              uploadUrl: part.uploadUrl || null,
              // We take manually care of resuming for partial uploads, so they should
              // not be stored in the URL storage.
              storeFingerprintForResuming: false,
              removeFingerprintOnSuccess: false,
              // Reset the parallelUploads option to not cause recursion.
              parallelUploads: 1,
              metadata: {},
              // Add the header to indicate the this is a partial upload.
              headers: _objectSpread({}, _this3.options.headers, {
                'Upload-Concat': 'partial'
              }),
              // Reject or resolve the promise if the upload errors or completes.
              onSuccess: resolve,
              onError: reject,
              // Based in the progress for this partial upload, calculate the progress
              // for the entire final upload.
              onProgress: function onProgress(newPartProgress) {
                totalProgress = totalProgress - lastPartProgress + newPartProgress;
                lastPartProgress = newPartProgress;

                _this3._emitProgress(totalProgress, totalSize);
              },
              // Wait until every partial upload has an upload URL, so we can add
              // them to the URL storage.
              _onUploadUrlAvailable: function _onUploadUrlAvailable() {
                _this3._parallelUploadUrls[index] = upload.url; // Test if all uploads have received an URL

                if (_this3._parallelUploadUrls.filter(function (u) {
                  return !!u;
                }).length === parts.length) {
                  _this3._saveUploadInUrlStorage();
                }
              }
            });

            var upload = new BaseUpload(value, options);
            upload.start(); // Store the upload in an array, so we can later abort them if necessary.

            _this3._parallelUploads.push(upload);
          });
        });
      });
      var req; // Wait until all partial uploads are finished and we can send the POST request for
      // creating the final upload.

      Promise.all(uploads).then(function () {
        req = _this3._openRequest('POST', _this3.options.endpoint);
        req.setHeader('Upload-Concat', "final;".concat(_this3._parallelUploadUrls.join(' '))); // Add metadata if values have been added

        var metadata = encodeMetadata(_this3.options.metadata);

        if (metadata !== '') {
          req.setHeader('Upload-Metadata', metadata);
        }

        return _this3._sendRequest(req, null);
      }).then(function (res) {
        if (!inStatusCategory(res.getStatus(), 200)) {
          _this3._emitHttpError(req, res, 'tus: unexpected response while creating upload');

          return;
        }

        var location = res.getHeader('Location');

        if (location == null) {
          _this3._emitHttpError(req, res, 'tus: invalid or missing Location header');

          return;
        }

        _this3.url = resolveUrl(_this3.options.endpoint, location);
        (0,_logger__WEBPACK_IMPORTED_MODULE_3__/* .log */ .c)("Created upload at ".concat(_this3.url));

        _this3._emitSuccess();
      })["catch"](function (err) {
        _this3._emitError(err);
      });
    }
    /**
     * Initiate the uploading procedure for a non-parallel upload. Here the entire file is
     * uploaded in a sequential matter.
     *
     * @api private
     */

  }, {
    key: "_startSingleUpload",
    value: function _startSingleUpload() {
      // First, we look at the uploadLengthDeferred option.
      // Next, we check if the caller has supplied a manual upload size.
      // Finally, we try to use the calculated size from the source object.
      if (this.options.uploadLengthDeferred) {
        this._size = null;
      } else if (this.options.uploadSize != null) {
        this._size = +this.options.uploadSize;

        if (isNaN(this._size)) {
          this._emitError(new Error('tus: cannot convert `uploadSize` option into a number'));

          return;
        }
      } else {
        this._size = this._source.size;

        if (this._size == null) {
          this._emitError(new Error("tus: cannot automatically derive upload's size from input and must be specified manually using the `uploadSize` option"));

          return;
        }
      } // Reset the aborted flag when the upload is started or else the
      // _performUpload will stop before sending a request if the upload has been
      // aborted previously.


      this._aborted = false; // The upload had been started previously and we should reuse this URL.

      if (this.url != null) {
        (0,_logger__WEBPACK_IMPORTED_MODULE_3__/* .log */ .c)("Resuming upload from previous URL: ".concat(this.url));

        this._resumeUpload();

        return;
      } // A URL has manually been specified, so we try to resume


      if (this.options.uploadUrl != null) {
        (0,_logger__WEBPACK_IMPORTED_MODULE_3__/* .log */ .c)("Resuming upload from provided URL: ".concat(this.options.url));
        this.url = this.options.uploadUrl;

        this._resumeUpload();

        return;
      } // An upload has not started for the file yet, so we start a new one


      (0,_logger__WEBPACK_IMPORTED_MODULE_3__/* .log */ .c)('Creating a new upload');

      this._createUpload();
    }
    /**
     * Abort any running request and stop the current upload. After abort is called, no event
     * handler will be invoked anymore. You can use the `start` method to resume the upload
     * again.
     * If `shouldTerminate` is true, the `terminate` function will be called to remove the
     * current upload from the server.
     *
     * @param {boolean} shouldTerminate True if the upload should be deleted from the server.
     * @return {Promise} The Promise will be resolved/rejected when the requests finish.
     */

  }, {
    key: "abort",
    value: function abort(shouldTerminate) {
      var _this4 = this;

      // Count the number of arguments to see if a callback is being provided in the old style required by tus-js-client 1.x, then throw an error if it is.
      // `arguments` is a JavaScript built-in variable that contains all of the function's arguments.
      if (arguments.length > 1 && typeof arguments[1] === 'function') {
        throw new Error('tus: the abort function does not accept a callback since v2 anymore; please use the returned Promise instead');
      } // Stop any parallel partial uploads, that have been started in _startParallelUploads.


      if (this._parallelUploads != null) {
        this._parallelUploads.forEach(function (upload) {
          upload.abort(shouldTerminate);
        });
      } // Stop any current running request.


      if (this._req !== null) {
        this._req.abort();

        this._source.close();
      }

      this._aborted = true; // Stop any timeout used for initiating a retry.

      if (this._retryTimeout != null) {
        clearTimeout(this._retryTimeout);
        this._retryTimeout = null;
      }

      if (!shouldTerminate || this.url == null) {
        return Promise.resolve();
      }

      return BaseUpload.terminate(this.url, this.options) // Remove entry from the URL storage since the upload URL is no longer valid.
      .then(function () {
        return _this4._removeFromUrlStorage();
      });
    }
  }, {
    key: "_emitHttpError",
    value: function _emitHttpError(req, res, message, causingErr) {
      this._emitError(new _error__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z(message, causingErr, req, res));
    }
  }, {
    key: "_emitError",
    value: function _emitError(err) {
      var _this5 = this;

      // Do not emit errors, e.g. from aborted HTTP requests, if the upload has been stopped.
      if (this._aborted) return; // Check if we should retry, when enabled, before sending the error to the user.

      if (this.options.retryDelays != null) {
        // We will reset the attempt counter if
        // - we were already able to connect to the server (offset != null) and
        // - we were able to upload a small chunk of data to the server
        var shouldResetDelays = this._offset != null && this._offset > this._offsetBeforeRetry;

        if (shouldResetDelays) {
          this._retryAttempt = 0;
        }

        if (shouldRetry(err, this._retryAttempt, this.options)) {
          var delay = this.options.retryDelays[this._retryAttempt++];
          this._offsetBeforeRetry = this._offset;
          this._retryTimeout = setTimeout(function () {
            _this5.start();
          }, delay);
          return;
        }
      }

      if (typeof this.options.onError === 'function') {
        this.options.onError(err);
      } else {
        throw err;
      }
    }
    /**
     * Publishes notification if the upload has been successfully completed.
     *
     * @api private
     */

  }, {
    key: "_emitSuccess",
    value: function _emitSuccess() {
      if (this.options.removeFingerprintOnSuccess) {
        // Remove stored fingerprint and corresponding endpoint. This causes
        // new uploads of the same file to be treated as a different file.
        this._removeFromUrlStorage();
      }

      if (typeof this.options.onSuccess === 'function') {
        this.options.onSuccess();
      }
    }
    /**
     * Publishes notification when data has been sent to the server. This
     * data may not have been accepted by the server yet.
     *
     * @param {number} bytesSent  Number of bytes sent to the server.
     * @param {number} bytesTotal Total number of bytes to be sent to the server.
     * @api private
     */

  }, {
    key: "_emitProgress",
    value: function _emitProgress(bytesSent, bytesTotal) {
      if (typeof this.options.onProgress === 'function') {
        this.options.onProgress(bytesSent, bytesTotal);
      }
    }
    /**
     * Publishes notification when a chunk of data has been sent to the server
     * and accepted by the server.
     * @param {number} chunkSize  Size of the chunk that was accepted by the server.
     * @param {number} bytesAccepted Total number of bytes that have been
     *                                accepted by the server.
     * @param {number} bytesTotal Total number of bytes to be sent to the server.
     * @api private
     */

  }, {
    key: "_emitChunkComplete",
    value: function _emitChunkComplete(chunkSize, bytesAccepted, bytesTotal) {
      if (typeof this.options.onChunkComplete === 'function') {
        this.options.onChunkComplete(chunkSize, bytesAccepted, bytesTotal);
      }
    }
    /**
     * Create a new upload using the creation extension by sending a POST
     * request to the endpoint. After successful creation the file will be
     * uploaded
     *
     * @api private
     */

  }, {
    key: "_createUpload",
    value: function _createUpload() {
      var _this6 = this;

      if (!this.options.endpoint) {
        this._emitError(new Error('tus: unable to create upload because no endpoint is provided'));

        return;
      }

      var req = this._openRequest('POST', this.options.endpoint);

      if (this.options.uploadLengthDeferred) {
        req.setHeader('Upload-Defer-Length', 1);
      } else {
        req.setHeader('Upload-Length', this._size);
      } // Add metadata if values have been added


      var metadata = encodeMetadata(this.options.metadata);

      if (metadata !== '') {
        req.setHeader('Upload-Metadata', metadata);
      }

      var promise;

      if (this.options.uploadDataDuringCreation && !this.options.uploadLengthDeferred) {
        this._offset = 0;
        promise = this._addChunkToRequest(req);
      } else {
        promise = this._sendRequest(req, null);
      }

      promise.then(function (res) {
        if (!inStatusCategory(res.getStatus(), 200)) {
          _this6._emitHttpError(req, res, 'tus: unexpected response while creating upload');

          return;
        }

        var location = res.getHeader('Location');

        if (location == null) {
          _this6._emitHttpError(req, res, 'tus: invalid or missing Location header');

          return;
        }

        _this6.url = resolveUrl(_this6.options.endpoint, location);
        (0,_logger__WEBPACK_IMPORTED_MODULE_3__/* .log */ .c)("Created upload at ".concat(_this6.url));

        if (typeof _this6.options._onUploadUrlAvailable === 'function') {
          _this6.options._onUploadUrlAvailable();
        }

        if (_this6._size === 0) {
          // Nothing to upload and file was successfully created
          _this6._emitSuccess();

          _this6._source.close();

          return;
        }

        _this6._saveUploadInUrlStorage();

        if (_this6.options.uploadDataDuringCreation) {
          _this6._handleUploadResponse(req, res);
        } else {
          _this6._offset = 0;

          _this6._performUpload();
        }
      })["catch"](function (err) {
        _this6._emitHttpError(req, null, 'tus: failed to create upload', err);
      });
    }
    /*
     * Try to resume an existing upload. First a HEAD request will be sent
     * to retrieve the offset. If the request fails a new upload will be
     * created. In the case of a successful response the file will be uploaded.
     *
     * @api private
     */

  }, {
    key: "_resumeUpload",
    value: function _resumeUpload() {
      var _this7 = this;

      var req = this._openRequest('HEAD', this.url);

      var promise = this._sendRequest(req, null);

      promise.then(function (res) {
        var status = res.getStatus();

        if (!inStatusCategory(status, 200)) {
          if (inStatusCategory(status, 400)) {
            // Remove stored fingerprint and corresponding endpoint,
            // on client errors since the file can not be found
            _this7._removeFromUrlStorage();
          } // If the upload is locked (indicated by the 423 Locked status code), we
          // emit an error instead of directly starting a new upload. This way the
          // retry logic can catch the error and will retry the upload. An upload
          // is usually locked for a short period of time and will be available
          // afterwards.


          if (status === 423) {
            _this7._emitHttpError(req, res, 'tus: upload is currently locked; retry later');

            return;
          }

          if (!_this7.options.endpoint) {
            // Don't attempt to create a new upload if no endpoint is provided.
            _this7._emitHttpError(req, res, 'tus: unable to resume upload (new upload cannot be created without an endpoint)');

            return;
          } // Try to create a new upload


          _this7.url = null;

          _this7._createUpload();

          return;
        }

        var offset = parseInt(res.getHeader('Upload-Offset'), 10);

        if (isNaN(offset)) {
          _this7._emitHttpError(req, res, 'tus: invalid or missing offset value');

          return;
        }

        var length = parseInt(res.getHeader('Upload-Length'), 10);

        if (isNaN(length) && !_this7.options.uploadLengthDeferred) {
          _this7._emitHttpError(req, res, 'tus: invalid or missing length value');

          return;
        }

        if (typeof _this7.options._onUploadUrlAvailable === 'function') {
          _this7.options._onUploadUrlAvailable();
        } // Upload has already been completed and we do not need to send additional
        // data to the server


        if (offset === length) {
          _this7._emitProgress(length, length);

          _this7._emitSuccess();

          return;
        }

        _this7._offset = offset;

        _this7._performUpload();
      })["catch"](function (err) {
        _this7._emitHttpError(req, null, 'tus: failed to resume upload', err);
      });
    }
    /**
     * Start uploading the file using PATCH requests. The file will be divided
     * into chunks as specified in the chunkSize option. During the upload
     * the onProgress event handler may be invoked multiple times.
     *
     * @api private
     */

  }, {
    key: "_performUpload",
    value: function _performUpload() {
      var _this8 = this;

      // If the upload has been aborted, we will not send the next PATCH request.
      // This is important if the abort method was called during a callback, such
      // as onChunkComplete or onProgress.
      if (this._aborted) {
        return;
      }

      var req; // Some browser and servers may not support the PATCH method. For those
      // cases, you can tell tus-js-client to use a POST request with the
      // X-HTTP-Method-Override header for simulating a PATCH request.

      if (this.options.overridePatchMethod) {
        req = this._openRequest('POST', this.url);
        req.setHeader('X-HTTP-Method-Override', 'PATCH');
      } else {
        req = this._openRequest('PATCH', this.url);
      }

      req.setHeader('Upload-Offset', this._offset);

      var promise = this._addChunkToRequest(req);

      promise.then(function (res) {
        if (!inStatusCategory(res.getStatus(), 200)) {
          _this8._emitHttpError(req, res, 'tus: unexpected response while uploading chunk');

          return;
        }

        _this8._handleUploadResponse(req, res);
      })["catch"](function (err) {
        // Don't emit an error if the upload was aborted manually
        if (_this8._aborted) {
          return;
        }

        _this8._emitHttpError(req, null, "tus: failed to upload chunk at offset ".concat(_this8._offset), err);
      });
    }
    /**
     * _addChunktoRequest reads a chunk from the source and sends it using the
     * supplied request object. It will not handle the response.
     *
     * @api private
     */

  }, {
    key: "_addChunkToRequest",
    value: function _addChunkToRequest(req) {
      var _this9 = this;

      var start = this._offset;
      var end = this._offset + this.options.chunkSize;
      req.setProgressHandler(function (bytesSent) {
        _this9._emitProgress(start + bytesSent, _this9._size);
      });
      req.setHeader('Content-Type', 'application/offset+octet-stream'); // The specified chunkSize may be Infinity or the calcluated end position
      // may exceed the file's size. In both cases, we limit the end position to
      // the input's total size for simpler calculations and correctness.

      if ((end === Infinity || end > this._size) && !this.options.uploadLengthDeferred) {
        end = this._size;
      }

      return this._source.slice(start, end).then(function (_ref2) {
        var value = _ref2.value,
            done = _ref2.done;

        // If the upload length is deferred, the upload size was not specified during
        // upload creation. So, if the file reader is done reading, we know the total
        // upload size and can tell the tus server.
        if (_this9.options.uploadLengthDeferred && done) {
          _this9._size = _this9._offset + (value && value.size ? value.size : 0);
          req.setHeader('Upload-Length', _this9._size);
        }

        if (value === null) {
          return _this9._sendRequest(req);
        }

        _this9._emitProgress(_this9._offset, _this9._size);

        return _this9._sendRequest(req, value);
      });
    }
    /**
     * _handleUploadResponse is used by requests that haven been sent using _addChunkToRequest
     * and already have received a response.
     *
     * @api private
     */

  }, {
    key: "_handleUploadResponse",
    value: function _handleUploadResponse(req, res) {
      var offset = parseInt(res.getHeader('Upload-Offset'), 10);

      if (isNaN(offset)) {
        this._emitHttpError(req, res, 'tus: invalid or missing offset value');

        return;
      }

      this._emitProgress(offset, this._size);

      this._emitChunkComplete(offset - this._offset, offset, this._size);

      this._offset = offset;

      if (offset == this._size) {
        // Yay, finally done :)
        this._emitSuccess();

        this._source.close();

        return;
      }

      this._performUpload();
    }
    /**
     * Create a new HTTP request object with the given method and URL.
     *
     * @api private
     */

  }, {
    key: "_openRequest",
    value: function _openRequest(method, url) {
      var req = openRequest(method, url, this.options);
      this._req = req;
      return req;
    }
    /**
     * Remove the entry in the URL storage, if it has been saved before.
     *
     * @api private
     */

  }, {
    key: "_removeFromUrlStorage",
    value: function _removeFromUrlStorage() {
      var _this10 = this;

      if (!this._urlStorageKey) return;

      this._urlStorage.removeUpload(this._urlStorageKey)["catch"](function (err) {
        _this10._emitError(err);
      });

      this._urlStorageKey = null;
    }
    /**
     * Add the upload URL to the URL storage, if possible.
     *
     * @api private
     */

  }, {
    key: "_saveUploadInUrlStorage",
    value: function _saveUploadInUrlStorage() {
      var _this11 = this;

      // Only if a fingerprint was calculated for the input (i.e. not a stream), we can store the upload URL.
      if (!this.options.storeFingerprintForResuming || !this._fingerprint) {
        return;
      }

      var storedUpload = {
        size: this._size,
        metadata: this.options.metadata,
        creationTime: new Date().toString()
      };

      if (this._parallelUploads) {
        // Save multiple URLs if the parallelUploads option is used ...
        storedUpload.parallelUploadUrls = this._parallelUploadUrls;
      } else {
        // ... otherwise we just save the one available URL.
        storedUpload.uploadUrl = this.url;
      }

      this._urlStorage.addUpload(this._fingerprint, storedUpload).then(function (urlStorageKey) {
        return _this11._urlStorageKey = urlStorageKey;
      })["catch"](function (err) {
        _this11._emitError(err);
      });
    }
    /**
     * Send a request with the provided body.
     *
     * @api private
     */

  }, {
    key: "_sendRequest",
    value: function _sendRequest(req) {
      var body = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : null;
      return sendRequest(req, body, this.options);
    }
  }], [{
    key: "terminate",
    value: function terminate(url, options) {
      // Count the number of arguments to see if a callback is being provided as the last
      // argument in the old style required by tus-js-client 1.x, then throw an error if it is.
      // `arguments` is a JavaScript built-in variable that contains all of the function's arguments.
      if (arguments.length > 1 && typeof arguments[arguments.length - 1] === 'function') {
        throw new Error('tus: the terminate function does not accept a callback since v2 anymore; please use the returned Promise instead');
      } // Note that in order for the trick above to work, a default value cannot be set for `options`,
      // so the check below replaces the old default `{}`.


      if (options === undefined) {
        options = {};
      }

      var req = openRequest('DELETE', url, options);
      return sendRequest(req, null, options).then(function (res) {
        // A 204 response indicates a successfull request
        if (res.getStatus() === 204) {
          return;
        }

        throw new _error__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z('tus: unexpected response while terminating upload', null, req, res);
      })["catch"](function (err) {
        if (!(err instanceof _error__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z)) {
          err = new _error__WEBPACK_IMPORTED_MODULE_2__/* ["default"] */ .Z('tus: failed to terminate upload', err, req, null);
        }

        if (!shouldRetry(err, 0, options)) {
          throw err;
        } // Instead of keeping track of the retry attempts, we remove the first element from the delays
        // array. If the array is empty, all retry attempts are used up and we will bubble up the error.
        // We recursively call the terminate function will removing elements from the retryDelays array.


        var delay = options.retryDelays[0];
        var remainingDelays = options.retryDelays.slice(1);

        var newOptions = _objectSpread({}, options, {
          retryDelays: remainingDelays
        });

        return new Promise(function (resolve) {
          return setTimeout(resolve, delay);
        }).then(function () {
          return BaseUpload.terminate(url, newOptions);
        });
      });
    }
  }]);

  return BaseUpload;
}();

function encodeMetadata(metadata) {
  var encoded = [];

  for (var key in metadata) {
    encoded.push("".concat(key, " ").concat(js_base64__WEBPACK_IMPORTED_MODULE_0__.Base64.encode(metadata[key])));
  }

  return encoded.join(',');
}
/**
 * Checks whether a given status is in the range of the expected category.
 * For example, only a status between 200 and 299 will satisfy the category 200.
 *
 * @api private
 */


function inStatusCategory(status, category) {
  return status >= category && status < category + 100;
}
/**
 * Create a new HTTP request with the specified method and URL.
 * The necessary headers that are included in every request
 * will be added, including the request ID.
 *
 * @api private
 */


function openRequest(method, url, options) {
  var req = options.httpStack.createRequest(method, url);
  req.setHeader('Tus-Resumable', '1.0.0');
  var headers = options.headers || {};

  for (var name in headers) {
    req.setHeader(name, headers[name]);
  }

  if (options.addRequestId) {
    var requestId = (0,_uuid__WEBPACK_IMPORTED_MODULE_4__/* ["default"] */ .Z)();
    req.setHeader('X-Request-ID', requestId);
  }

  return req;
}
/**
 * Send a request with the provided body while invoking the onBeforeRequest
 * and onAfterResponse callbacks.
 *
 * @api private
 */


function sendRequest(req, body, options) {
  var onBeforeRequestPromise = typeof options.onBeforeRequest === 'function' ? Promise.resolve(options.onBeforeRequest(req)) : Promise.resolve();
  return onBeforeRequestPromise.then(function () {
    return req.send(body).then(function (res) {
      var onAfterResponsePromise = typeof options.onAfterResponse === 'function' ? Promise.resolve(options.onAfterResponse(req, res)) : Promise.resolve();
      return onAfterResponsePromise.then(function () {
        return res;
      });
    });
  });
}
/**
 * Checks whether the browser running this code has internet access.
 * This function will always return true in the node.js environment
 *
 * @api private
 */


function isOnline() {
  var online = true;

  if (typeof window !== 'undefined' && 'navigator' in window && window.navigator.onLine === false) {
    online = false;
  }

  return online;
}
/**
 * Checks whether or not it is ok to retry a request.
 * @param {Error} err the error returned from the last request
 * @param {number} retryAttempt the number of times the request has already been retried
 * @param {object} options tus Upload options
 *
 * @api private
 */


function shouldRetry(err, retryAttempt, options) {
  // We only attempt a retry if
  // - retryDelays option is set
  // - we didn't exceed the maxium number of retries, yet, and
  // - this error was caused by a request or it's response and
  // - the error is server error (i.e. not a status 4xx except a 409 or 423) or
  // a onShouldRetry is specified and returns true
  // - the browser does not indicate that we are offline
  if (options.retryDelays == null || retryAttempt >= options.retryDelays.length || err.originalRequest == null) {
    return false;
  }

  if (options && typeof options.onShouldRetry === 'function') {
    return options.onShouldRetry(err, retryAttempt, options);
  }

  var status = err.originalResponse ? err.originalResponse.getStatus() : 0;
  return (!inStatusCategory(status, 400) || status === 409 || status === 423) && isOnline();
}
/**
 * Resolve a relative link given the origin as source. For example,
 * if a HTTP request to http://example.com/files/ returns a Location
 * header with the value /upload/abc, the resolved URL will be:
 * http://example.com/upload/abc
 */


function resolveUrl(origin, link) {
  return new (url_parse__WEBPACK_IMPORTED_MODULE_1___default())(link, origin).toString();
}
/**
 * Calculate the start and end positions for the parts if an upload
 * is split into multiple parallel requests.
 *
 * @param {number} totalSize The byte size of the upload, which will be split.
 * @param {number} partCount The number in how many parts the upload will be split.
 * @param {string[]} previousUrls The upload URLs for previous parts.
 * @return {object[]}
 * @api private
 */


function splitSizeIntoParts(totalSize, partCount, previousUrls) {
  var partSize = Math.floor(totalSize / partCount);
  var parts = [];

  for (var i = 0; i < partCount; i++) {
    parts.push({
      start: partSize * i,
      end: partSize * (i + 1)
    });
  }

  parts[partCount - 1].end = totalSize; // Attach URLs from previous uploads, if available.

  if (previousUrls) {
    parts.forEach(function (part, index) {
      part.uploadUrl = previousUrls[index] || null;
    });
  }

  return parts;
}

BaseUpload.defaultOptions = defaultOptions;
/* harmony default export */ __webpack_exports__["Z"] = (BaseUpload);

/***/ }),

/***/ 4104:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ uuid; }
/* harmony export */ });
/**
 * Generate a UUID v4 based on random numbers. We intentioanlly use the less
 * secure Math.random function here since the more secure crypto.getRandomNumbers
 * is not available on all platforms.
 * This is not a problem for us since we use the UUID only for generating a
 * request ID, so we can correlate server logs to client errors.
 *
 * This function is taken from following site:
 * https://stackoverflow.com/questions/105034/create-guid-uuid-in-javascript
 *
 * @return {string} The generate UUID
 */
function uuid() {
  return 'xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx'.replace(/[xy]/g, function (c) {
    var r = Math.random() * 16 | 0,
        v = c == 'x' ? r : r & 0x3 | 0x8;
    return v.toString(16);
  });
}

/***/ }),

/***/ 3830:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";

var camelCase = __webpack_require__(956);

module.exports = function () {
	var cased = camelCase.apply(camelCase, arguments);
	return cased.charAt(0).toUpperCase() + cased.slice(1);
};


/***/ }),

/***/ 956:
/***/ (function(module) {

"use strict";

module.exports = function () {
	var str = [].map.call(arguments, function (str) {
		return str.trim();
	}).filter(function (str) {
		return str.length;
	}).join('-');

	if (!str.length) {
		return '';
	}

	if (str.length === 1 || !(/[_.\- ]+/).test(str) ) {
		if (str[0] === str[0].toLowerCase() && str.slice(1) !== str.slice(1).toLowerCase()) {
			return str;
		}

		return str.toLowerCase();
	}

	return str
	.replace(/^[_.\- ]+/, '')
	.toLowerCase()
	.replace(/[_.\- ]+(\w|$)/g, function (m, p1) {
		return p1.toUpperCase();
	});
};


/***/ }),

/***/ 64846:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var required = __webpack_require__(57245)
  , qs = __webpack_require__(97375)
  , controlOrWhitespace = /^[\x00-\x20\u00a0\u1680\u2000-\u200a\u2028\u2029\u202f\u205f\u3000\ufeff]+/
  , CRHTLF = /[\n\r\t]/g
  , slashes = /^[A-Za-z][A-Za-z0-9+-.]*:\/\//
  , port = /:\d+$/
  , protocolre = /^([a-z][a-z0-9.+-]*:)?(\/\/)?([\\/]+)?([\S\s]*)/i
  , windowsDriveLetter = /^[a-zA-Z]:/;

/**
 * Remove control characters and whitespace from the beginning of a string.
 *
 * @param {Object|String} str String to trim.
 * @returns {String} A new string representing `str` stripped of control
 *     characters and whitespace from its beginning.
 * @public
 */
function trimLeft(str) {
  return (str ? str : '').toString().replace(controlOrWhitespace, '');
}

/**
 * These are the parse rules for the URL parser, it informs the parser
 * about:
 *
 * 0. The char it Needs to parse, if it's a string it should be done using
 *    indexOf, RegExp using exec and NaN means set as current value.
 * 1. The property we should set when parsing this value.
 * 2. Indication if it's backwards or forward parsing, when set as number it's
 *    the value of extra chars that should be split off.
 * 3. Inherit from location if non existing in the parser.
 * 4. `toLowerCase` the resulting value.
 */
var rules = [
  ['#', 'hash'],                        // Extract from the back.
  ['?', 'query'],                       // Extract from the back.
  function sanitize(address, url) {     // Sanitize what is left of the address
    return isSpecial(url.protocol) ? address.replace(/\\/g, '/') : address;
  },
  ['/', 'pathname'],                    // Extract from the back.
  ['@', 'auth', 1],                     // Extract from the front.
  [NaN, 'host', undefined, 1, 1],       // Set left over value.
  [/:(\d*)$/, 'port', undefined, 1],    // RegExp the back.
  [NaN, 'hostname', undefined, 1, 1]    // Set left over.
];

/**
 * These properties should not be copied or inherited from. This is only needed
 * for all non blob URL's as a blob URL does not include a hash, only the
 * origin.
 *
 * @type {Object}
 * @private
 */
var ignore = { hash: 1, query: 1 };

/**
 * The location object differs when your code is loaded through a normal page,
 * Worker or through a worker using a blob. And with the blobble begins the
 * trouble as the location object will contain the URL of the blob, not the
 * location of the page where our code is loaded in. The actual origin is
 * encoded in the `pathname` so we can thankfully generate a good "default"
 * location from it so we can generate proper relative URL's again.
 *
 * @param {Object|String} loc Optional default location object.
 * @returns {Object} lolcation object.
 * @public
 */
function lolcation(loc) {
  var globalVar;

  if (typeof window !== 'undefined') globalVar = window;
  else if (typeof window !== 'undefined') globalVar = window;
  else if (typeof self !== 'undefined') globalVar = self;
  else globalVar = {};

  var location = globalVar.location || {};
  loc = loc || location;

  var finaldestination = {}
    , type = typeof loc
    , key;

  if ('blob:' === loc.protocol) {
    finaldestination = new Url(unescape(loc.pathname), {});
  } else if ('string' === type) {
    finaldestination = new Url(loc, {});
    for (key in ignore) delete finaldestination[key];
  } else if ('object' === type) {
    for (key in loc) {
      if (key in ignore) continue;
      finaldestination[key] = loc[key];
    }

    if (finaldestination.slashes === undefined) {
      finaldestination.slashes = slashes.test(loc.href);
    }
  }

  return finaldestination;
}

/**
 * Check whether a protocol scheme is special.
 *
 * @param {String} The protocol scheme of the URL
 * @return {Boolean} `true` if the protocol scheme is special, else `false`
 * @private
 */
function isSpecial(scheme) {
  return (
    scheme === 'file:' ||
    scheme === 'ftp:' ||
    scheme === 'http:' ||
    scheme === 'https:' ||
    scheme === 'ws:' ||
    scheme === 'wss:'
  );
}

/**
 * @typedef ProtocolExtract
 * @type Object
 * @property {String} protocol Protocol matched in the URL, in lowercase.
 * @property {Boolean} slashes `true` if protocol is followed by "//", else `false`.
 * @property {String} rest Rest of the URL that is not part of the protocol.
 */

/**
 * Extract protocol information from a URL with/without double slash ("//").
 *
 * @param {String} address URL we want to extract from.
 * @param {Object} location
 * @return {ProtocolExtract} Extracted information.
 * @private
 */
function extractProtocol(address, location) {
  address = trimLeft(address);
  address = address.replace(CRHTLF, '');
  location = location || {};

  var match = protocolre.exec(address);
  var protocol = match[1] ? match[1].toLowerCase() : '';
  var forwardSlashes = !!match[2];
  var otherSlashes = !!match[3];
  var slashesCount = 0;
  var rest;

  if (forwardSlashes) {
    if (otherSlashes) {
      rest = match[2] + match[3] + match[4];
      slashesCount = match[2].length + match[3].length;
    } else {
      rest = match[2] + match[4];
      slashesCount = match[2].length;
    }
  } else {
    if (otherSlashes) {
      rest = match[3] + match[4];
      slashesCount = match[3].length;
    } else {
      rest = match[4]
    }
  }

  if (protocol === 'file:') {
    if (slashesCount >= 2) {
      rest = rest.slice(2);
    }
  } else if (isSpecial(protocol)) {
    rest = match[4];
  } else if (protocol) {
    if (forwardSlashes) {
      rest = rest.slice(2);
    }
  } else if (slashesCount >= 2 && isSpecial(location.protocol)) {
    rest = match[4];
  }

  return {
    protocol: protocol,
    slashes: forwardSlashes || isSpecial(protocol),
    slashesCount: slashesCount,
    rest: rest
  };
}

/**
 * Resolve a relative URL pathname against a base URL pathname.
 *
 * @param {String} relative Pathname of the relative URL.
 * @param {String} base Pathname of the base URL.
 * @return {String} Resolved pathname.
 * @private
 */
function resolve(relative, base) {
  if (relative === '') return base;

  var path = (base || '/').split('/').slice(0, -1).concat(relative.split('/'))
    , i = path.length
    , last = path[i - 1]
    , unshift = false
    , up = 0;

  while (i--) {
    if (path[i] === '.') {
      path.splice(i, 1);
    } else if (path[i] === '..') {
      path.splice(i, 1);
      up++;
    } else if (up) {
      if (i === 0) unshift = true;
      path.splice(i, 1);
      up--;
    }
  }

  if (unshift) path.unshift('');
  if (last === '.' || last === '..') path.push('');

  return path.join('/');
}

/**
 * The actual URL instance. Instead of returning an object we've opted-in to
 * create an actual constructor as it's much more memory efficient and
 * faster and it pleases my OCD.
 *
 * It is worth noting that we should not use `URL` as class name to prevent
 * clashes with the global URL instance that got introduced in browsers.
 *
 * @constructor
 * @param {String} address URL we want to parse.
 * @param {Object|String} [location] Location defaults for relative paths.
 * @param {Boolean|Function} [parser] Parser for the query string.
 * @private
 */
function Url(address, location, parser) {
  address = trimLeft(address);
  address = address.replace(CRHTLF, '');

  if (!(this instanceof Url)) {
    return new Url(address, location, parser);
  }

  var relative, extracted, parse, instruction, index, key
    , instructions = rules.slice()
    , type = typeof location
    , url = this
    , i = 0;

  //
  // The following if statements allows this module two have compatibility with
  // 2 different API:
  //
  // 1. Node.js's `url.parse` api which accepts a URL, boolean as arguments
  //    where the boolean indicates that the query string should also be parsed.
  //
  // 2. The `URL` interface of the browser which accepts a URL, object as
  //    arguments. The supplied object will be used as default values / fall-back
  //    for relative paths.
  //
  if ('object' !== type && 'string' !== type) {
    parser = location;
    location = null;
  }

  if (parser && 'function' !== typeof parser) parser = qs.parse;

  location = lolcation(location);

  //
  // Extract protocol information before running the instructions.
  //
  extracted = extractProtocol(address || '', location);
  relative = !extracted.protocol && !extracted.slashes;
  url.slashes = extracted.slashes || relative && location.slashes;
  url.protocol = extracted.protocol || location.protocol || '';
  address = extracted.rest;

  //
  // When the authority component is absent the URL starts with a path
  // component.
  //
  if (
    extracted.protocol === 'file:' && (
      extracted.slashesCount !== 2 || windowsDriveLetter.test(address)) ||
    (!extracted.slashes &&
      (extracted.protocol ||
        extracted.slashesCount < 2 ||
        !isSpecial(url.protocol)))
  ) {
    instructions[3] = [/(.*)/, 'pathname'];
  }

  for (; i < instructions.length; i++) {
    instruction = instructions[i];

    if (typeof instruction === 'function') {
      address = instruction(address, url);
      continue;
    }

    parse = instruction[0];
    key = instruction[1];

    if (parse !== parse) {
      url[key] = address;
    } else if ('string' === typeof parse) {
      index = parse === '@'
        ? address.lastIndexOf(parse)
        : address.indexOf(parse);

      if (~index) {
        if ('number' === typeof instruction[2]) {
          url[key] = address.slice(0, index);
          address = address.slice(index + instruction[2]);
        } else {
          url[key] = address.slice(index);
          address = address.slice(0, index);
        }
      }
    } else if ((index = parse.exec(address))) {
      url[key] = index[1];
      address = address.slice(0, index.index);
    }

    url[key] = url[key] || (
      relative && instruction[3] ? location[key] || '' : ''
    );

    //
    // Hostname, host and protocol should be lowercased so they can be used to
    // create a proper `origin`.
    //
    if (instruction[4]) url[key] = url[key].toLowerCase();
  }

  //
  // Also parse the supplied query string in to an object. If we're supplied
  // with a custom parser as function use that instead of the default build-in
  // parser.
  //
  if (parser) url.query = parser(url.query);

  //
  // If the URL is relative, resolve the pathname against the base URL.
  //
  if (
      relative
    && location.slashes
    && url.pathname.charAt(0) !== '/'
    && (url.pathname !== '' || location.pathname !== '')
  ) {
    url.pathname = resolve(url.pathname, location.pathname);
  }

  //
  // Default to a / for pathname if none exists. This normalizes the URL
  // to always have a /
  //
  if (url.pathname.charAt(0) !== '/' && isSpecial(url.protocol)) {
    url.pathname = '/' + url.pathname;
  }

  //
  // We should not add port numbers if they are already the default port number
  // for a given protocol. As the host also contains the port number we're going
  // override it with the hostname which contains no port number.
  //
  if (!required(url.port, url.protocol)) {
    url.host = url.hostname;
    url.port = '';
  }

  //
  // Parse down the `auth` for the username and password.
  //
  url.username = url.password = '';

  if (url.auth) {
    index = url.auth.indexOf(':');

    if (~index) {
      url.username = url.auth.slice(0, index);
      url.username = encodeURIComponent(decodeURIComponent(url.username));

      url.password = url.auth.slice(index + 1);
      url.password = encodeURIComponent(decodeURIComponent(url.password))
    } else {
      url.username = encodeURIComponent(decodeURIComponent(url.auth));
    }

    url.auth = url.password ? url.username +':'+ url.password : url.username;
  }

  url.origin = url.protocol !== 'file:' && isSpecial(url.protocol) && url.host
    ? url.protocol +'//'+ url.host
    : 'null';

  //
  // The href is just the compiled result.
  //
  url.href = url.toString();
}

/**
 * This is convenience method for changing properties in the URL instance to
 * insure that they all propagate correctly.
 *
 * @param {String} part          Property we need to adjust.
 * @param {Mixed} value          The newly assigned value.
 * @param {Boolean|Function} fn  When setting the query, it will be the function
 *                               used to parse the query.
 *                               When setting the protocol, double slash will be
 *                               removed from the final url if it is true.
 * @returns {URL} URL instance for chaining.
 * @public
 */
function set(part, value, fn) {
  var url = this;

  switch (part) {
    case 'query':
      if ('string' === typeof value && value.length) {
        value = (fn || qs.parse)(value);
      }

      url[part] = value;
      break;

    case 'port':
      url[part] = value;

      if (!required(value, url.protocol)) {
        url.host = url.hostname;
        url[part] = '';
      } else if (value) {
        url.host = url.hostname +':'+ value;
      }

      break;

    case 'hostname':
      url[part] = value;

      if (url.port) value += ':'+ url.port;
      url.host = value;
      break;

    case 'host':
      url[part] = value;

      if (port.test(value)) {
        value = value.split(':');
        url.port = value.pop();
        url.hostname = value.join(':');
      } else {
        url.hostname = value;
        url.port = '';
      }

      break;

    case 'protocol':
      url.protocol = value.toLowerCase();
      url.slashes = !fn;
      break;

    case 'pathname':
    case 'hash':
      if (value) {
        var char = part === 'pathname' ? '/' : '#';
        url[part] = value.charAt(0) !== char ? char + value : value;
      } else {
        url[part] = value;
      }
      break;

    case 'username':
    case 'password':
      url[part] = encodeURIComponent(value);
      break;

    case 'auth':
      var index = value.indexOf(':');

      if (~index) {
        url.username = value.slice(0, index);
        url.username = encodeURIComponent(decodeURIComponent(url.username));

        url.password = value.slice(index + 1);
        url.password = encodeURIComponent(decodeURIComponent(url.password));
      } else {
        url.username = encodeURIComponent(decodeURIComponent(value));
      }
  }

  for (var i = 0; i < rules.length; i++) {
    var ins = rules[i];

    if (ins[4]) url[ins[1]] = url[ins[1]].toLowerCase();
  }

  url.auth = url.password ? url.username +':'+ url.password : url.username;

  url.origin = url.protocol !== 'file:' && isSpecial(url.protocol) && url.host
    ? url.protocol +'//'+ url.host
    : 'null';

  url.href = url.toString();

  return url;
}

/**
 * Transform the properties back in to a valid and full URL string.
 *
 * @param {Function} stringify Optional query stringify function.
 * @returns {String} Compiled version of the URL.
 * @public
 */
function toString(stringify) {
  if (!stringify || 'function' !== typeof stringify) stringify = qs.stringify;

  var query
    , url = this
    , host = url.host
    , protocol = url.protocol;

  if (protocol && protocol.charAt(protocol.length - 1) !== ':') protocol += ':';

  var result =
    protocol +
    ((url.protocol && url.slashes) || isSpecial(url.protocol) ? '//' : '');

  if (url.username) {
    result += url.username;
    if (url.password) result += ':'+ url.password;
    result += '@';
  } else if (url.password) {
    result += ':'+ url.password;
    result += '@';
  } else if (
    url.protocol !== 'file:' &&
    isSpecial(url.protocol) &&
    !host &&
    url.pathname !== '/'
  ) {
    //
    // Add back the empty userinfo, otherwise the original invalid URL
    // might be transformed into a valid one with `url.pathname` as host.
    //
    result += '@';
  }

  //
  // Trailing colon is removed from `url.host` when it is parsed. If it still
  // ends with a colon, then add back the trailing colon that was removed. This
  // prevents an invalid URL from being transformed into a valid one.
  //
  if (host[host.length - 1] === ':' || (port.test(url.hostname) && !url.port)) {
    host += ':';
  }

  result += host + url.pathname;

  query = 'object' === typeof url.query ? stringify(url.query) : url.query;
  if (query) result += '?' !== query.charAt(0) ? '?'+ query : query;

  if (url.hash) result += url.hash;

  return result;
}

Url.prototype = { set: set, toString: toString };

//
// Expose the URL parser and some additional properties that might be useful for
// others or testing.
//
Url.extractProtocol = extractProtocol;
Url.location = lolcation;
Url.trimLeft = trimLeft;
Url.qs = qs;

module.exports = Url;


/***/ }),

/***/ 17127:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ useDebounce; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _useDebouncedCallback__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(60669);


function valueEquality(left, right) {
    return left === right;
}
function useDebounce(value, delay, options) {
    var eq = options && options.equalityFn ? options.equalityFn : valueEquality;
    var _a = (0,react__WEBPACK_IMPORTED_MODULE_0__.useState)(value), state = _a[0], dispatch = _a[1];
    var _b = (0,_useDebouncedCallback__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)((0,react__WEBPACK_IMPORTED_MODULE_0__.useCallback)(function (value) { return dispatch(value); }, []), delay, options), callback = _b[0], cancel = _b[1];
    var previousValue = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)(value);
    (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(function () {
        // We need to use this condition otherwise we will run debounce timer for the first render (including maxWait option)
        if (!eq(previousValue.current, value)) {
            callback(value);
            previousValue.current = value;
        }
    }, [value, callback, eq]);
    return [state, cancel];
}


/***/ }),

/***/ 60669:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ useDebouncedCallback; }
/* harmony export */ });
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(99196);
/* harmony import */ var react__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(react__WEBPACK_IMPORTED_MODULE_0__);

function useDebouncedCallback(callback, delay, options) {
    if (options === void 0) { options = {}; }
    var maxWait = options.maxWait;
    var maxWaitHandler = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)(null);
    var maxWaitArgs = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)([]);
    var leading = options.leading;
    var wasLeadingCalled = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)(false);
    var functionTimeoutHandler = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)(null);
    var isComponentUnmounted = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)(false);
    var debouncedFunction = (0,react__WEBPACK_IMPORTED_MODULE_0__.useRef)(callback);
    debouncedFunction.current = callback;
    var cancelDebouncedCallback = (0,react__WEBPACK_IMPORTED_MODULE_0__.useCallback)(function () {
        clearTimeout(functionTimeoutHandler.current);
        clearTimeout(maxWaitHandler.current);
        maxWaitHandler.current = null;
        maxWaitArgs.current = [];
        functionTimeoutHandler.current = null;
        wasLeadingCalled.current = false;
    }, []);
    (0,react__WEBPACK_IMPORTED_MODULE_0__.useEffect)(function () { return function () {
        // we use flag, as we allow to call callPending outside the hook
        isComponentUnmounted.current = true;
    }; }, []);
    var debouncedCallback = (0,react__WEBPACK_IMPORTED_MODULE_0__.useCallback)(function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        maxWaitArgs.current = args;
        clearTimeout(functionTimeoutHandler.current);
        if (!functionTimeoutHandler.current && leading && !wasLeadingCalled.current) {
            debouncedFunction.current.apply(debouncedFunction, args);
            wasLeadingCalled.current = true;
            return;
        }
        functionTimeoutHandler.current = setTimeout(function () {
            cancelDebouncedCallback();
            if (!isComponentUnmounted.current) {
                debouncedFunction.current.apply(debouncedFunction, args);
            }
        }, delay);
        if (maxWait && !maxWaitHandler.current) {
            maxWaitHandler.current = setTimeout(function () {
                var args = maxWaitArgs.current;
                cancelDebouncedCallback();
                if (!isComponentUnmounted.current) {
                    debouncedFunction.current.apply(null, args);
                }
            }, maxWait);
        }
    }, [maxWait, delay, cancelDebouncedCallback, leading]);
    var callPending = function () {
        // Call pending callback only if we have anything in our queue
        if (!functionTimeoutHandler.current) {
            return;
        }
        debouncedFunction.current.apply(null, maxWaitArgs.current);
        cancelDebouncedCallback();
    };
    // At the moment, we use 3 args array so that we save backward compatibility
    return [debouncedCallback, cancelDebouncedCallback, callPending];
}


/***/ }),

/***/ 48186:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

"use strict";
/** @license React vundefined
 * use-subscription.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
var e=__webpack_require__(37320),g=__webpack_require__(99196);
exports.useSubscription=function(a){var c=a.getCurrentValue,d=a.subscribe,b=g.useState(function(){return{getCurrentValue:c,subscribe:d,value:c()}});a=b[0];var f=b[1];b=a.value;if(a.getCurrentValue!==c||a.subscribe!==d)b=c(),f({getCurrentValue:c,subscribe:d,value:b});g.useDebugValue(b);g.useEffect(function(){function b(){if(!a){var b=c();f(function(a){return a.getCurrentValue!==c||a.subscribe!==d||a.value===b?a:e({},a,{value:b})})}}var a=!1,h=d(b);b();return function(){a=!0;h()}},[c,d]);return b};


/***/ }),

/***/ 36718:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


if (true) {
  module.exports = __webpack_require__(48186);
} else {}


/***/ }),

/***/ 10082:
/***/ (function(module) {

module.exports = function isBuffer(arg) {
  return arg && typeof arg === 'object'
    && typeof arg.copy === 'function'
    && typeof arg.fill === 'function'
    && typeof arg.readUInt8 === 'function';
}

/***/ }),

/***/ 54895:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

"use strict";
// Currently in sync with Node.js lib/internal/util/types.js
// https://github.com/nodejs/node/commit/112cc7c27551254aa2b17098fb774867f05ed0d9



var isArgumentsObject = __webpack_require__(52635);
var isGeneratorFunction = __webpack_require__(43138);
var whichTypedArray = __webpack_require__(32094);
var isTypedArray = __webpack_require__(50198);

function uncurryThis(f) {
  return f.call.bind(f);
}

var BigIntSupported = typeof BigInt !== 'undefined';
var SymbolSupported = typeof Symbol !== 'undefined';

var ObjectToString = uncurryThis(Object.prototype.toString);

var numberValue = uncurryThis(Number.prototype.valueOf);
var stringValue = uncurryThis(String.prototype.valueOf);
var booleanValue = uncurryThis(Boolean.prototype.valueOf);

if (BigIntSupported) {
  var bigIntValue = uncurryThis(BigInt.prototype.valueOf);
}

if (SymbolSupported) {
  var symbolValue = uncurryThis(Symbol.prototype.valueOf);
}

function checkBoxedPrimitive(value, prototypeValueOf) {
  if (typeof value !== 'object') {
    return false;
  }
  try {
    prototypeValueOf(value);
    return true;
  } catch(e) {
    return false;
  }
}

exports.isArgumentsObject = isArgumentsObject;
exports.isGeneratorFunction = isGeneratorFunction;
exports.isTypedArray = isTypedArray;

// Taken from here and modified for better browser support
// https://github.com/sindresorhus/p-is-promise/blob/cda35a513bda03f977ad5cde3a079d237e82d7ef/index.js
function isPromise(input) {
	return (
		(
			typeof Promise !== 'undefined' &&
			input instanceof Promise
		) ||
		(
			input !== null &&
			typeof input === 'object' &&
			typeof input.then === 'function' &&
			typeof input.catch === 'function'
		)
	);
}
exports.isPromise = isPromise;

function isArrayBufferView(value) {
  if (typeof ArrayBuffer !== 'undefined' && ArrayBuffer.isView) {
    return ArrayBuffer.isView(value);
  }

  return (
    isTypedArray(value) ||
    isDataView(value)
  );
}
exports.isArrayBufferView = isArrayBufferView;


function isUint8Array(value) {
  return whichTypedArray(value) === 'Uint8Array';
}
exports.isUint8Array = isUint8Array;

function isUint8ClampedArray(value) {
  return whichTypedArray(value) === 'Uint8ClampedArray';
}
exports.isUint8ClampedArray = isUint8ClampedArray;

function isUint16Array(value) {
  return whichTypedArray(value) === 'Uint16Array';
}
exports.isUint16Array = isUint16Array;

function isUint32Array(value) {
  return whichTypedArray(value) === 'Uint32Array';
}
exports.isUint32Array = isUint32Array;

function isInt8Array(value) {
  return whichTypedArray(value) === 'Int8Array';
}
exports.isInt8Array = isInt8Array;

function isInt16Array(value) {
  return whichTypedArray(value) === 'Int16Array';
}
exports.isInt16Array = isInt16Array;

function isInt32Array(value) {
  return whichTypedArray(value) === 'Int32Array';
}
exports.isInt32Array = isInt32Array;

function isFloat32Array(value) {
  return whichTypedArray(value) === 'Float32Array';
}
exports.isFloat32Array = isFloat32Array;

function isFloat64Array(value) {
  return whichTypedArray(value) === 'Float64Array';
}
exports.isFloat64Array = isFloat64Array;

function isBigInt64Array(value) {
  return whichTypedArray(value) === 'BigInt64Array';
}
exports.isBigInt64Array = isBigInt64Array;

function isBigUint64Array(value) {
  return whichTypedArray(value) === 'BigUint64Array';
}
exports.isBigUint64Array = isBigUint64Array;

function isMapToString(value) {
  return ObjectToString(value) === '[object Map]';
}
isMapToString.working = (
  typeof Map !== 'undefined' &&
  isMapToString(new Map())
);

function isMap(value) {
  if (typeof Map === 'undefined') {
    return false;
  }

  return isMapToString.working
    ? isMapToString(value)
    : value instanceof Map;
}
exports.isMap = isMap;

function isSetToString(value) {
  return ObjectToString(value) === '[object Set]';
}
isSetToString.working = (
  typeof Set !== 'undefined' &&
  isSetToString(new Set())
);
function isSet(value) {
  if (typeof Set === 'undefined') {
    return false;
  }

  return isSetToString.working
    ? isSetToString(value)
    : value instanceof Set;
}
exports.isSet = isSet;

function isWeakMapToString(value) {
  return ObjectToString(value) === '[object WeakMap]';
}
isWeakMapToString.working = (
  typeof WeakMap !== 'undefined' &&
  isWeakMapToString(new WeakMap())
);
function isWeakMap(value) {
  if (typeof WeakMap === 'undefined') {
    return false;
  }

  return isWeakMapToString.working
    ? isWeakMapToString(value)
    : value instanceof WeakMap;
}
exports.isWeakMap = isWeakMap;

function isWeakSetToString(value) {
  return ObjectToString(value) === '[object WeakSet]';
}
isWeakSetToString.working = (
  typeof WeakSet !== 'undefined' &&
  isWeakSetToString(new WeakSet())
);
function isWeakSet(value) {
  return isWeakSetToString(value);
}
exports.isWeakSet = isWeakSet;

function isArrayBufferToString(value) {
  return ObjectToString(value) === '[object ArrayBuffer]';
}
isArrayBufferToString.working = (
  typeof ArrayBuffer !== 'undefined' &&
  isArrayBufferToString(new ArrayBuffer())
);
function isArrayBuffer(value) {
  if (typeof ArrayBuffer === 'undefined') {
    return false;
  }

  return isArrayBufferToString.working
    ? isArrayBufferToString(value)
    : value instanceof ArrayBuffer;
}
exports.isArrayBuffer = isArrayBuffer;

function isDataViewToString(value) {
  return ObjectToString(value) === '[object DataView]';
}
isDataViewToString.working = (
  typeof ArrayBuffer !== 'undefined' &&
  typeof DataView !== 'undefined' &&
  isDataViewToString(new DataView(new ArrayBuffer(1), 0, 1))
);
function isDataView(value) {
  if (typeof DataView === 'undefined') {
    return false;
  }

  return isDataViewToString.working
    ? isDataViewToString(value)
    : value instanceof DataView;
}
exports.isDataView = isDataView;

function isSharedArrayBufferToString(value) {
  return ObjectToString(value) === '[object SharedArrayBuffer]';
}
isSharedArrayBufferToString.working = (
  typeof SharedArrayBuffer !== 'undefined' &&
  isSharedArrayBufferToString(new SharedArrayBuffer())
);
function isSharedArrayBuffer(value) {
  if (typeof SharedArrayBuffer === 'undefined') {
    return false;
  }

  return isSharedArrayBufferToString.working
    ? isSharedArrayBufferToString(value)
    : value instanceof SharedArrayBuffer;
}
exports.isSharedArrayBuffer = isSharedArrayBuffer;

function isAsyncFunction(value) {
  return ObjectToString(value) === '[object AsyncFunction]';
}
exports.isAsyncFunction = isAsyncFunction;

function isMapIterator(value) {
  return ObjectToString(value) === '[object Map Iterator]';
}
exports.isMapIterator = isMapIterator;

function isSetIterator(value) {
  return ObjectToString(value) === '[object Set Iterator]';
}
exports.isSetIterator = isSetIterator;

function isGeneratorObject(value) {
  return ObjectToString(value) === '[object Generator]';
}
exports.isGeneratorObject = isGeneratorObject;

function isWebAssemblyCompiledModule(value) {
  return ObjectToString(value) === '[object WebAssembly.Module]';
}
exports.isWebAssemblyCompiledModule = isWebAssemblyCompiledModule;

function isNumberObject(value) {
  return checkBoxedPrimitive(value, numberValue);
}
exports.isNumberObject = isNumberObject;

function isStringObject(value) {
  return checkBoxedPrimitive(value, stringValue);
}
exports.isStringObject = isStringObject;

function isBooleanObject(value) {
  return checkBoxedPrimitive(value, booleanValue);
}
exports.isBooleanObject = isBooleanObject;

function isBigIntObject(value) {
  return BigIntSupported && checkBoxedPrimitive(value, bigIntValue);
}
exports.isBigIntObject = isBigIntObject;

function isSymbolObject(value) {
  return SymbolSupported && checkBoxedPrimitive(value, symbolValue);
}
exports.isSymbolObject = isSymbolObject;

function isBoxedPrimitive(value) {
  return (
    isNumberObject(value) ||
    isStringObject(value) ||
    isBooleanObject(value) ||
    isBigIntObject(value) ||
    isSymbolObject(value)
  );
}
exports.isBoxedPrimitive = isBoxedPrimitive;

function isAnyArrayBuffer(value) {
  return typeof Uint8Array !== 'undefined' && (
    isArrayBuffer(value) ||
    isSharedArrayBuffer(value)
  );
}
exports.isAnyArrayBuffer = isAnyArrayBuffer;

['isProxy', 'isExternal', 'isModuleNamespaceObject'].forEach(function(method) {
  Object.defineProperty(exports, method, {
    enumerable: false,
    value: function() {
      throw new Error(method + ' is not supported in userland');
    }
  });
});


/***/ }),

/***/ 43335:
/***/ (function(__unused_webpack_module, exports, __webpack_require__) {

// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

var getOwnPropertyDescriptors = Object.getOwnPropertyDescriptors ||
  function getOwnPropertyDescriptors(obj) {
    var keys = Object.keys(obj);
    var descriptors = {};
    for (var i = 0; i < keys.length; i++) {
      descriptors[keys[i]] = Object.getOwnPropertyDescriptor(obj, keys[i]);
    }
    return descriptors;
  };

var formatRegExp = /%[sdj%]/g;
exports.format = function(f) {
  if (!isString(f)) {
    var objects = [];
    for (var i = 0; i < arguments.length; i++) {
      objects.push(inspect(arguments[i]));
    }
    return objects.join(' ');
  }

  var i = 1;
  var args = arguments;
  var len = args.length;
  var str = String(f).replace(formatRegExp, function(x) {
    if (x === '%%') return '%';
    if (i >= len) return x;
    switch (x) {
      case '%s': return String(args[i++]);
      case '%d': return Number(args[i++]);
      case '%j':
        try {
          return JSON.stringify(args[i++]);
        } catch (_) {
          return '[Circular]';
        }
      default:
        return x;
    }
  });
  for (var x = args[i]; i < len; x = args[++i]) {
    if (isNull(x) || !isObject(x)) {
      str += ' ' + x;
    } else {
      str += ' ' + inspect(x);
    }
  }
  return str;
};


// Mark that a method should not be used.
// Returns a modified function which warns once by default.
// If --no-deprecation is set, then it is a no-op.
exports.deprecate = function(fn, msg) {
  if (typeof process !== 'undefined' && process.noDeprecation === true) {
    return fn;
  }

  // Allow for deprecating things in the process of starting up.
  if (typeof process === 'undefined') {
    return function() {
      return exports.deprecate(fn, msg).apply(this, arguments);
    };
  }

  var warned = false;
  function deprecated() {
    if (!warned) {
      if (process.throwDeprecation) {
        throw new Error(msg);
      } else if (process.traceDeprecation) {
        console.trace(msg);
      } else {
        console.error(msg);
      }
      warned = true;
    }
    return fn.apply(this, arguments);
  }

  return deprecated;
};


var debugs = {};
var debugEnvRegex = /^$/;

if (process.env.NODE_DEBUG) {
  var debugEnv = process.env.NODE_DEBUG;
  debugEnv = debugEnv.replace(/[|\\{}()[\]^$+?.]/g, '\\$&')
    .replace(/\*/g, '.*')
    .replace(/,/g, '$|^')
    .toUpperCase();
  debugEnvRegex = new RegExp('^' + debugEnv + '$', 'i');
}
exports.debuglog = function(set) {
  set = set.toUpperCase();
  if (!debugs[set]) {
    if (debugEnvRegex.test(set)) {
      var pid = process.pid;
      debugs[set] = function() {
        var msg = exports.format.apply(exports, arguments);
        console.error('%s %d: %s', set, pid, msg);
      };
    } else {
      debugs[set] = function() {};
    }
  }
  return debugs[set];
};


/**
 * Echos the value of a value. Trys to print the value out
 * in the best way possible given the different types.
 *
 * @param {Object} obj The object to print out.
 * @param {Object} opts Optional options object that alters the output.
 */
/* legacy: obj, showHidden, depth, colors*/
function inspect(obj, opts) {
  // default options
  var ctx = {
    seen: [],
    stylize: stylizeNoColor
  };
  // legacy...
  if (arguments.length >= 3) ctx.depth = arguments[2];
  if (arguments.length >= 4) ctx.colors = arguments[3];
  if (isBoolean(opts)) {
    // legacy...
    ctx.showHidden = opts;
  } else if (opts) {
    // got an "options" object
    exports._extend(ctx, opts);
  }
  // set default options
  if (isUndefined(ctx.showHidden)) ctx.showHidden = false;
  if (isUndefined(ctx.depth)) ctx.depth = 2;
  if (isUndefined(ctx.colors)) ctx.colors = false;
  if (isUndefined(ctx.customInspect)) ctx.customInspect = true;
  if (ctx.colors) ctx.stylize = stylizeWithColor;
  return formatValue(ctx, obj, ctx.depth);
}
exports.inspect = inspect;


// http://en.wikipedia.org/wiki/ANSI_escape_code#graphics
inspect.colors = {
  'bold' : [1, 22],
  'italic' : [3, 23],
  'underline' : [4, 24],
  'inverse' : [7, 27],
  'white' : [37, 39],
  'grey' : [90, 39],
  'black' : [30, 39],
  'blue' : [34, 39],
  'cyan' : [36, 39],
  'green' : [32, 39],
  'magenta' : [35, 39],
  'red' : [31, 39],
  'yellow' : [33, 39]
};

// Don't use 'blue' not visible on cmd.exe
inspect.styles = {
  'special': 'cyan',
  'number': 'yellow',
  'boolean': 'yellow',
  'undefined': 'grey',
  'null': 'bold',
  'string': 'green',
  'date': 'magenta',
  // "name": intentionally not styling
  'regexp': 'red'
};


function stylizeWithColor(str, styleType) {
  var style = inspect.styles[styleType];

  if (style) {
    return '\u001b[' + inspect.colors[style][0] + 'm' + str +
           '\u001b[' + inspect.colors[style][1] + 'm';
  } else {
    return str;
  }
}


function stylizeNoColor(str, styleType) {
  return str;
}


function arrayToHash(array) {
  var hash = {};

  array.forEach(function(val, idx) {
    hash[val] = true;
  });

  return hash;
}


function formatValue(ctx, value, recurseTimes) {
  // Provide a hook for user-specified inspect functions.
  // Check that value is an object with an inspect function on it
  if (ctx.customInspect &&
      value &&
      isFunction(value.inspect) &&
      // Filter out the util module, it's inspect function is special
      value.inspect !== exports.inspect &&
      // Also filter out any prototype objects using the circular check.
      !(value.constructor && value.constructor.prototype === value)) {
    var ret = value.inspect(recurseTimes, ctx);
    if (!isString(ret)) {
      ret = formatValue(ctx, ret, recurseTimes);
    }
    return ret;
  }

  // Primitive types cannot have properties
  var primitive = formatPrimitive(ctx, value);
  if (primitive) {
    return primitive;
  }

  // Look up the keys of the object.
  var keys = Object.keys(value);
  var visibleKeys = arrayToHash(keys);

  if (ctx.showHidden) {
    keys = Object.getOwnPropertyNames(value);
  }

  // IE doesn't make error fields non-enumerable
  // http://msdn.microsoft.com/en-us/library/ie/dww52sbt(v=vs.94).aspx
  if (isError(value)
      && (keys.indexOf('message') >= 0 || keys.indexOf('description') >= 0)) {
    return formatError(value);
  }

  // Some type of object without properties can be shortcutted.
  if (keys.length === 0) {
    if (isFunction(value)) {
      var name = value.name ? ': ' + value.name : '';
      return ctx.stylize('[Function' + name + ']', 'special');
    }
    if (isRegExp(value)) {
      return ctx.stylize(RegExp.prototype.toString.call(value), 'regexp');
    }
    if (isDate(value)) {
      return ctx.stylize(Date.prototype.toString.call(value), 'date');
    }
    if (isError(value)) {
      return formatError(value);
    }
  }

  var base = '', array = false, braces = ['{', '}'];

  // Make Array say that they are Array
  if (isArray(value)) {
    array = true;
    braces = ['[', ']'];
  }

  // Make functions say that they are functions
  if (isFunction(value)) {
    var n = value.name ? ': ' + value.name : '';
    base = ' [Function' + n + ']';
  }

  // Make RegExps say that they are RegExps
  if (isRegExp(value)) {
    base = ' ' + RegExp.prototype.toString.call(value);
  }

  // Make dates with properties first say the date
  if (isDate(value)) {
    base = ' ' + Date.prototype.toUTCString.call(value);
  }

  // Make error with message first say the error
  if (isError(value)) {
    base = ' ' + formatError(value);
  }

  if (keys.length === 0 && (!array || value.length == 0)) {
    return braces[0] + base + braces[1];
  }

  if (recurseTimes < 0) {
    if (isRegExp(value)) {
      return ctx.stylize(RegExp.prototype.toString.call(value), 'regexp');
    } else {
      return ctx.stylize('[Object]', 'special');
    }
  }

  ctx.seen.push(value);

  var output;
  if (array) {
    output = formatArray(ctx, value, recurseTimes, visibleKeys, keys);
  } else {
    output = keys.map(function(key) {
      return formatProperty(ctx, value, recurseTimes, visibleKeys, key, array);
    });
  }

  ctx.seen.pop();

  return reduceToSingleString(output, base, braces);
}


function formatPrimitive(ctx, value) {
  if (isUndefined(value))
    return ctx.stylize('undefined', 'undefined');
  if (isString(value)) {
    var simple = '\'' + JSON.stringify(value).replace(/^"|"$/g, '')
                                             .replace(/'/g, "\\'")
                                             .replace(/\\"/g, '"') + '\'';
    return ctx.stylize(simple, 'string');
  }
  if (isNumber(value))
    return ctx.stylize('' + value, 'number');
  if (isBoolean(value))
    return ctx.stylize('' + value, 'boolean');
  // For some reason typeof null is "object", so special case here.
  if (isNull(value))
    return ctx.stylize('null', 'null');
}


function formatError(value) {
  return '[' + Error.prototype.toString.call(value) + ']';
}


function formatArray(ctx, value, recurseTimes, visibleKeys, keys) {
  var output = [];
  for (var i = 0, l = value.length; i < l; ++i) {
    if (hasOwnProperty(value, String(i))) {
      output.push(formatProperty(ctx, value, recurseTimes, visibleKeys,
          String(i), true));
    } else {
      output.push('');
    }
  }
  keys.forEach(function(key) {
    if (!key.match(/^\d+$/)) {
      output.push(formatProperty(ctx, value, recurseTimes, visibleKeys,
          key, true));
    }
  });
  return output;
}


function formatProperty(ctx, value, recurseTimes, visibleKeys, key, array) {
  var name, str, desc;
  desc = Object.getOwnPropertyDescriptor(value, key) || { value: value[key] };
  if (desc.get) {
    if (desc.set) {
      str = ctx.stylize('[Getter/Setter]', 'special');
    } else {
      str = ctx.stylize('[Getter]', 'special');
    }
  } else {
    if (desc.set) {
      str = ctx.stylize('[Setter]', 'special');
    }
  }
  if (!hasOwnProperty(visibleKeys, key)) {
    name = '[' + key + ']';
  }
  if (!str) {
    if (ctx.seen.indexOf(desc.value) < 0) {
      if (isNull(recurseTimes)) {
        str = formatValue(ctx, desc.value, null);
      } else {
        str = formatValue(ctx, desc.value, recurseTimes - 1);
      }
      if (str.indexOf('\n') > -1) {
        if (array) {
          str = str.split('\n').map(function(line) {
            return '  ' + line;
          }).join('\n').substr(2);
        } else {
          str = '\n' + str.split('\n').map(function(line) {
            return '   ' + line;
          }).join('\n');
        }
      }
    } else {
      str = ctx.stylize('[Circular]', 'special');
    }
  }
  if (isUndefined(name)) {
    if (array && key.match(/^\d+$/)) {
      return str;
    }
    name = JSON.stringify('' + key);
    if (name.match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)) {
      name = name.substr(1, name.length - 2);
      name = ctx.stylize(name, 'name');
    } else {
      name = name.replace(/'/g, "\\'")
                 .replace(/\\"/g, '"')
                 .replace(/(^"|"$)/g, "'");
      name = ctx.stylize(name, 'string');
    }
  }

  return name + ': ' + str;
}


function reduceToSingleString(output, base, braces) {
  var numLinesEst = 0;
  var length = output.reduce(function(prev, cur) {
    numLinesEst++;
    if (cur.indexOf('\n') >= 0) numLinesEst++;
    return prev + cur.replace(/\u001b\[\d\d?m/g, '').length + 1;
  }, 0);

  if (length > 60) {
    return braces[0] +
           (base === '' ? '' : base + '\n ') +
           ' ' +
           output.join(',\n  ') +
           ' ' +
           braces[1];
  }

  return braces[0] + base + ' ' + output.join(', ') + ' ' + braces[1];
}


// NOTE: These type checking functions intentionally don't use `instanceof`
// because it is fragile and can be easily faked with `Object.create()`.
exports.types = __webpack_require__(54895);

function isArray(ar) {
  return Array.isArray(ar);
}
exports.isArray = isArray;

function isBoolean(arg) {
  return typeof arg === 'boolean';
}
exports.isBoolean = isBoolean;

function isNull(arg) {
  return arg === null;
}
exports.isNull = isNull;

function isNullOrUndefined(arg) {
  return arg == null;
}
exports.isNullOrUndefined = isNullOrUndefined;

function isNumber(arg) {
  return typeof arg === 'number';
}
exports.isNumber = isNumber;

function isString(arg) {
  return typeof arg === 'string';
}
exports.isString = isString;

function isSymbol(arg) {
  return typeof arg === 'symbol';
}
exports.isSymbol = isSymbol;

function isUndefined(arg) {
  return arg === void 0;
}
exports.isUndefined = isUndefined;

function isRegExp(re) {
  return isObject(re) && objectToString(re) === '[object RegExp]';
}
exports.isRegExp = isRegExp;
exports.types.isRegExp = isRegExp;

function isObject(arg) {
  return typeof arg === 'object' && arg !== null;
}
exports.isObject = isObject;

function isDate(d) {
  return isObject(d) && objectToString(d) === '[object Date]';
}
exports.isDate = isDate;
exports.types.isDate = isDate;

function isError(e) {
  return isObject(e) &&
      (objectToString(e) === '[object Error]' || e instanceof Error);
}
exports.isError = isError;
exports.types.isNativeError = isError;

function isFunction(arg) {
  return typeof arg === 'function';
}
exports.isFunction = isFunction;

function isPrimitive(arg) {
  return arg === null ||
         typeof arg === 'boolean' ||
         typeof arg === 'number' ||
         typeof arg === 'string' ||
         typeof arg === 'symbol' ||  // ES6 symbol
         typeof arg === 'undefined';
}
exports.isPrimitive = isPrimitive;

exports.isBuffer = __webpack_require__(10082);

function objectToString(o) {
  return Object.prototype.toString.call(o);
}


function pad(n) {
  return n < 10 ? '0' + n.toString(10) : n.toString(10);
}


var months = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep',
              'Oct', 'Nov', 'Dec'];

// 26 Feb 16:19:34
function timestamp() {
  var d = new Date();
  var time = [pad(d.getHours()),
              pad(d.getMinutes()),
              pad(d.getSeconds())].join(':');
  return [d.getDate(), months[d.getMonth()], time].join(' ');
}


// log is just a thin wrapper to console.log that prepends a timestamp
exports.log = function() {
  console.log('%s - %s', timestamp(), exports.format.apply(exports, arguments));
};


/**
 * Inherit the prototype methods from one constructor into another.
 *
 * The Function.prototype.inherits from lang.js rewritten as a standalone
 * function (not on Function.prototype). NOTE: If this file is to be loaded
 * during bootstrapping this function needs to be rewritten using some native
 * functions as prototype setup using normal JavaScript does not work as
 * expected during bootstrapping (see mirror.js in r114903).
 *
 * @param {function} ctor Constructor function which needs to inherit the
 *     prototype.
 * @param {function} superCtor Constructor function to inherit prototype from.
 */
exports.inherits = __webpack_require__(91285);

exports._extend = function(origin, add) {
  // Don't do anything if add isn't an object
  if (!add || !isObject(add)) return origin;

  var keys = Object.keys(add);
  var i = keys.length;
  while (i--) {
    origin[keys[i]] = add[keys[i]];
  }
  return origin;
};

function hasOwnProperty(obj, prop) {
  return Object.prototype.hasOwnProperty.call(obj, prop);
}

var kCustomPromisifiedSymbol = typeof Symbol !== 'undefined' ? Symbol('util.promisify.custom') : undefined;

exports.promisify = function promisify(original) {
  if (typeof original !== 'function')
    throw new TypeError('The "original" argument must be of type Function');

  if (kCustomPromisifiedSymbol && original[kCustomPromisifiedSymbol]) {
    var fn = original[kCustomPromisifiedSymbol];
    if (typeof fn !== 'function') {
      throw new TypeError('The "util.promisify.custom" argument must be of type Function');
    }
    Object.defineProperty(fn, kCustomPromisifiedSymbol, {
      value: fn, enumerable: false, writable: false, configurable: true
    });
    return fn;
  }

  function fn() {
    var promiseResolve, promiseReject;
    var promise = new Promise(function (resolve, reject) {
      promiseResolve = resolve;
      promiseReject = reject;
    });

    var args = [];
    for (var i = 0; i < arguments.length; i++) {
      args.push(arguments[i]);
    }
    args.push(function (err, value) {
      if (err) {
        promiseReject(err);
      } else {
        promiseResolve(value);
      }
    });

    try {
      original.apply(this, args);
    } catch (err) {
      promiseReject(err);
    }

    return promise;
  }

  Object.setPrototypeOf(fn, Object.getPrototypeOf(original));

  if (kCustomPromisifiedSymbol) Object.defineProperty(fn, kCustomPromisifiedSymbol, {
    value: fn, enumerable: false, writable: false, configurable: true
  });
  return Object.defineProperties(
    fn,
    getOwnPropertyDescriptors(original)
  );
}

exports.promisify.custom = kCustomPromisifiedSymbol

function callbackifyOnRejected(reason, cb) {
  // `!reason` guard inspired by bluebird (Ref: https://goo.gl/t5IS6M).
  // Because `null` is a special error value in callbacks which means "no error
  // occurred", we error-wrap so the callback consumer can distinguish between
  // "the promise rejected with null" or "the promise fulfilled with undefined".
  if (!reason) {
    var newReason = new Error('Promise was rejected with a falsy value');
    newReason.reason = reason;
    reason = newReason;
  }
  return cb(reason);
}

function callbackify(original) {
  if (typeof original !== 'function') {
    throw new TypeError('The "original" argument must be of type Function');
  }

  // We DO NOT return the promise as it gives the user a false sense that
  // the promise is actually somehow related to the callback's execution
  // and that the callback throwing will reject the promise.
  function callbackified() {
    var args = [];
    for (var i = 0; i < arguments.length; i++) {
      args.push(arguments[i]);
    }

    var maybeCb = args.pop();
    if (typeof maybeCb !== 'function') {
      throw new TypeError('The last argument must be of type Function');
    }
    var self = this;
    var cb = function() {
      return maybeCb.apply(self, arguments);
    };
    // In true node style we process the callback on `nextTick` with all the
    // implications (stack, `uncaughtException`, `async_hooks`)
    original.apply(this, args)
      .then(function(ret) { process.nextTick(cb.bind(null, null, ret)) },
            function(rej) { process.nextTick(callbackifyOnRejected.bind(null, rej, cb)) });
  }

  Object.setPrototypeOf(callbackified, Object.getPrototypeOf(original));
  Object.defineProperties(callbackified,
                          getOwnPropertyDescriptors(original));
  return callbackified;
}
exports.callbackify = callbackify;


/***/ }),

/***/ 82686:
/***/ (function(__unused_webpack_module, __webpack_exports__) {

"use strict";
/* harmony default export */ __webpack_exports__["Z"] = (/^(?:[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}|00000000-0000-0000-0000-000000000000)$/i);

/***/ }),

/***/ 45302:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ rng; }
/* harmony export */ });
// Unique ID creation requires a high quality random # generator. In the browser we therefore
// require the crypto API and do not support built-in fallback to lower quality random number
// generators (like Math.random()).
var getRandomValues;
var rnds8 = new Uint8Array(16);
function rng() {
  // lazy load so that environments that need to polyfill have a chance to do so
  if (!getRandomValues) {
    // getRandomValues needs to be invoked in a context where "this" is a Crypto implementation. Also,
    // find the complete implementation of crypto (msCrypto) on IE11.
    getRandomValues = typeof crypto !== 'undefined' && crypto.getRandomValues && crypto.getRandomValues.bind(crypto) || typeof msCrypto !== 'undefined' && typeof msCrypto.getRandomValues === 'function' && msCrypto.getRandomValues.bind(msCrypto);

    if (!getRandomValues) {
      throw new Error('crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported');
    }
  }

  return getRandomValues(rnds8);
}

/***/ }),

/***/ 20708:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _validate_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(86525);

/**
 * Convert array of 16 byte values to UUID string format of the form:
 * XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX
 */

var byteToHex = [];

for (var i = 0; i < 256; ++i) {
  byteToHex.push((i + 0x100).toString(16).substr(1));
}

function stringify(arr) {
  var offset = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  // Note: Be careful editing this code!  It's been tuned for performance
  // and works in ways you may not expect. See https://github.com/uuidjs/uuid/pull/434
  var uuid = (byteToHex[arr[offset + 0]] + byteToHex[arr[offset + 1]] + byteToHex[arr[offset + 2]] + byteToHex[arr[offset + 3]] + '-' + byteToHex[arr[offset + 4]] + byteToHex[arr[offset + 5]] + '-' + byteToHex[arr[offset + 6]] + byteToHex[arr[offset + 7]] + '-' + byteToHex[arr[offset + 8]] + byteToHex[arr[offset + 9]] + '-' + byteToHex[arr[offset + 10]] + byteToHex[arr[offset + 11]] + byteToHex[arr[offset + 12]] + byteToHex[arr[offset + 13]] + byteToHex[arr[offset + 14]] + byteToHex[arr[offset + 15]]).toLowerCase(); // Consistency check for valid UUID.  If this throws, it's likely due to one
  // of the following:
  // - One or more input array values don't map to a hex octet (leading to
  // "undefined" in the uuid)
  // - Invalid input values for the RFC `version` or `variant` fields

  if (!(0,_validate_js__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(uuid)) {
    throw TypeError('Stringified UUID is invalid');
  }

  return uuid;
}

/* harmony default export */ __webpack_exports__["Z"] = (stringify);

/***/ }),

/***/ 88767:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _rng_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(45302);
/* harmony import */ var _stringify_js__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(20708);



function v4(options, buf, offset) {
  options = options || {};
  var rnds = options.random || (options.rng || _rng_js__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(); // Per 4.4, set bits for version and `clock_seq_hi_and_reserved`

  rnds[6] = rnds[6] & 0x0f | 0x40;
  rnds[8] = rnds[8] & 0x3f | 0x80; // Copy bytes to buffer, if provided

  if (buf) {
    offset = offset || 0;

    for (var i = 0; i < 16; ++i) {
      buf[offset + i] = rnds[i];
    }

    return buf;
  }

  return (0,_stringify_js__WEBPACK_IMPORTED_MODULE_1__/* ["default"] */ .Z)(rnds);
}

/* harmony default export */ __webpack_exports__["Z"] = (v4);

/***/ }),

/***/ 86525:
/***/ (function(__unused_webpack_module, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony import */ var _regex_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(82686);


function validate(uuid) {
  return typeof uuid === 'string' && _regex_js__WEBPACK_IMPORTED_MODULE_0__/* ["default"].test */ .Z.test(uuid);
}

/* harmony default export */ __webpack_exports__["Z"] = (validate);

/***/ }),

/***/ 32094:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var forEach = __webpack_require__(46388);
var availableTypedArrays = __webpack_require__(62191);
var callBound = __webpack_require__(62680);

var $toString = callBound('Object.prototype.toString');
var hasSymbols = __webpack_require__(32636)();
var hasToStringTag = hasSymbols && typeof Symbol.toStringTag === 'symbol';

var typedArrays = availableTypedArrays();

var $slice = callBound('String.prototype.slice');
var toStrTags = {};
var gOPD = __webpack_require__(29765);
var getPrototypeOf = Object.getPrototypeOf; // require('getprototypeof');
if (hasToStringTag && gOPD && getPrototypeOf) {
	forEach(typedArrays, function (typedArray) {
		if (typeof window[typedArray] === 'function') {
			var arr = new window[typedArray]();
			if (!(Symbol.toStringTag in arr)) {
				throw new EvalError('this engine has support for Symbol.toStringTag, but ' + typedArray + ' does not have the property! Please report this.');
			}
			var proto = getPrototypeOf(arr);
			var descriptor = gOPD(proto, Symbol.toStringTag);
			if (!descriptor) {
				var superProto = getPrototypeOf(proto);
				descriptor = gOPD(superProto, Symbol.toStringTag);
			}
			toStrTags[typedArray] = descriptor.get;
		}
	});
}

var tryTypedArrays = function tryAllTypedArrays(value) {
	var foundName = false;
	forEach(toStrTags, function (getter, typedArray) {
		if (!foundName) {
			try {
				var name = getter.call(value);
				if (name === typedArray) {
					foundName = name;
				}
			} catch (e) {}
		}
	});
	return foundName;
};

var isTypedArray = __webpack_require__(50198);

module.exports = function whichTypedArray(value) {
	if (!isTypedArray(value)) { return false; }
	if (!hasToStringTag) { return $slice($toString(value), 8, -1); }
	return tryTypedArrays(value);
};


/***/ }),

/***/ 82884:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

var uppercamelcase = __webpack_require__(3830);
var statusCodes = __webpack_require__(26744);

module.exports = WPError;

function WPError () {
  var self = new Error();

  for (var i = 0; i < arguments.length; i++) {
    process(self, arguments[i]);
  }

  if (typeof Error.captureStackTrace === 'function') {
    Error.captureStackTrace(self, WPError);
  }

  return self;
}

function process ( self, data ) {
  if ( ! data ) { 
    return;
  }
  
  if (typeof data === 'number') {
    setStatusCode( self, data );

  } else {
    // assume it's a plain 'ol Object with some props to copy over
    if ( data.status_code ) {
      setStatusCode( self, data.status_code );
    }

    if ( data.error ) {
      self.name = toName( data.error );
    }

    if ( data.error_description ) {
      self.message = data.error_description;
    }

    var errors = data.errors;
    if ( errors ) {
      var first = errors.length ? errors[0] : errors;
      process( self, first );
    }

    for ( var i in data ) {
      self[i] = data[i];
    }

    if ( self.status && ( data.method || data.path ) ) {
      setStatusCodeMessage( self );
    }
  }
}

function setStatusCode ( self, code ) {
  self.name = toName( statusCodes[ code ] );
  self.status = self.statusCode = code;
  setStatusCodeMessage( self );
}

function setStatusCodeMessage ( self ) {
  var code = self.status;
  var method = self.method;
  var path = self.path;

  var m = code + ' status code';
  var extended = method || path;

  if ( extended ) m += ' for "';
  if ( method ) m += method;
  if ( extended ) m += ' ';
  if ( path ) m += path;
  if ( extended ) m += '"';

  self.message = m;
}

function toName ( str ) {
  return uppercamelcase( String(str).replace(/error$/i, ''), 'error' );
}


/***/ }),

/***/ 51960:
/***/ (function(module) {

module.exports = extend

var hasOwnProperty = Object.prototype.hasOwnProperty;

function extend() {
    var target = {}

    for (var i = 0; i < arguments.length; i++) {
        var source = arguments[i]

        for (var key in source) {
            if (hasOwnProperty.call(source, key)) {
                target[key] = source[key]
            }
        }
    }

    return target
}


/***/ }),

/***/ 34973:
/***/ (function(module) {

"use strict";


var alphabet = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz-_'.split('')
  , length = 64
  , map = {}
  , seed = 0
  , i = 0
  , prev;

/**
 * Return a string representing the specified number.
 *
 * @param {Number} num The number to convert.
 * @returns {String} The string representation of the number.
 * @api public
 */
function encode(num) {
  var encoded = '';

  do {
    encoded = alphabet[num % length] + encoded;
    num = Math.floor(num / length);
  } while (num > 0);

  return encoded;
}

/**
 * Return the integer value specified by the given string.
 *
 * @param {String} str The string to convert.
 * @returns {Number} The integer value represented by the string.
 * @api public
 */
function decode(str) {
  var decoded = 0;

  for (i = 0; i < str.length; i++) {
    decoded = decoded * length + map[str.charAt(i)];
  }

  return decoded;
}

/**
 * Yeast: A tiny growing id generator.
 *
 * @returns {String} A unique id.
 * @api public
 */
function yeast() {
  var now = encode(+new Date());

  if (now !== prev) return seed = 0, prev = now;
  return now +'.'+ encode(seed++);
}

//
// Map each character to its index.
//
for (; i < length; i++) map[alphabet[i]] = i;

//
// Expose the `yeast`, `encode` and `decode` functions.
//
yeast.encode = encode;
yeast.decode = decode;
module.exports = yeast;


/***/ }),

/***/ 21749:
/***/ (function(module) {

/**
 * Helpers.
 */

var s = 1000;
var m = s * 60;
var h = m * 60;
var d = h * 24;
var w = d * 7;
var y = d * 365.25;

/**
 * Parse or format the given `val`.
 *
 * Options:
 *
 *  - `long` verbose formatting [false]
 *
 * @param {String|Number} val
 * @param {Object} [options]
 * @throws {Error} throw an error if val is not a non-empty string or a number
 * @return {String|Number}
 * @api public
 */

module.exports = function(val, options) {
  options = options || {};
  var type = typeof val;
  if (type === 'string' && val.length > 0) {
    return parse(val);
  } else if (type === 'number' && isFinite(val)) {
    return options.long ? fmtLong(val) : fmtShort(val);
  }
  throw new Error(
    'val is not a non-empty string or a valid number. val=' +
      JSON.stringify(val)
  );
};

/**
 * Parse the given `str` and return milliseconds.
 *
 * @param {String} str
 * @return {Number}
 * @api private
 */

function parse(str) {
  str = String(str);
  if (str.length > 100) {
    return;
  }
  var match = /^(-?(?:\d+)?\.?\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|weeks?|w|years?|yrs?|y)?$/i.exec(
    str
  );
  if (!match) {
    return;
  }
  var n = parseFloat(match[1]);
  var type = (match[2] || 'ms').toLowerCase();
  switch (type) {
    case 'years':
    case 'year':
    case 'yrs':
    case 'yr':
    case 'y':
      return n * y;
    case 'weeks':
    case 'week':
    case 'w':
      return n * w;
    case 'days':
    case 'day':
    case 'd':
      return n * d;
    case 'hours':
    case 'hour':
    case 'hrs':
    case 'hr':
    case 'h':
      return n * h;
    case 'minutes':
    case 'minute':
    case 'mins':
    case 'min':
    case 'm':
      return n * m;
    case 'seconds':
    case 'second':
    case 'secs':
    case 'sec':
    case 's':
      return n * s;
    case 'milliseconds':
    case 'millisecond':
    case 'msecs':
    case 'msec':
    case 'ms':
      return n;
    default:
      return undefined;
  }
}

/**
 * Short format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function fmtShort(ms) {
  var msAbs = Math.abs(ms);
  if (msAbs >= d) {
    return Math.round(ms / d) + 'd';
  }
  if (msAbs >= h) {
    return Math.round(ms / h) + 'h';
  }
  if (msAbs >= m) {
    return Math.round(ms / m) + 'm';
  }
  if (msAbs >= s) {
    return Math.round(ms / s) + 's';
  }
  return ms + 'ms';
}

/**
 * Long format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function fmtLong(ms) {
  var msAbs = Math.abs(ms);
  if (msAbs >= d) {
    return plural(ms, msAbs, d, 'day');
  }
  if (msAbs >= h) {
    return plural(ms, msAbs, h, 'hour');
  }
  if (msAbs >= m) {
    return plural(ms, msAbs, m, 'minute');
  }
  if (msAbs >= s) {
    return plural(ms, msAbs, s, 'second');
  }
  return ms + ' ms';
}

/**
 * Pluralization helper.
 */

function plural(ms, msAbs, n, name) {
  var isPlural = msAbs >= n * 1.5;
  return Math.round(ms / n) + ' ' + name + (isPlural ? 's' : '');
}


/***/ }),

/***/ 68785:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";
module.exports = __webpack_require__.p + "images/gridicons-506499ddac13811fee8e.svg";

/***/ }),

/***/ 99196:
/***/ (function(module) {

"use strict";
module.exports = window["React"];

/***/ }),

/***/ 91850:
/***/ (function(module) {

"use strict";
module.exports = window["ReactDOM"];

/***/ }),

/***/ 92819:
/***/ (function(module) {

"use strict";
module.exports = window["lodash"];

/***/ }),

/***/ 76292:
/***/ (function(module) {

"use strict";
module.exports = window["moment"];

/***/ }),

/***/ 25158:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["a11y"];

/***/ }),

/***/ 86989:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["apiFetch"];

/***/ }),

/***/ 55609:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["components"];

/***/ }),

/***/ 94333:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["compose"];

/***/ }),

/***/ 9818:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["data"];

/***/ }),

/***/ 23418:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["dataControls"];

/***/ }),

/***/ 37180:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["deprecated"];

/***/ }),

/***/ 45904:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["dom"];

/***/ }),

/***/ 69307:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["element"];

/***/ }),

/***/ 65736:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["i18n"];

/***/ }),

/***/ 49127:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["isShallowEqual"];

/***/ }),

/***/ 39630:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["keycodes"];

/***/ }),

/***/ 98817:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["plugins"];

/***/ }),

/***/ 55815:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["preferences"];

/***/ }),

/***/ 70444:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["primitives"];

/***/ }),

/***/ 12560:
/***/ (function(module) {

"use strict";
module.exports = window["wp"]["warning"];

/***/ }),

/***/ 18864:
/***/ (function() {

/* (ignored) */

/***/ }),

/***/ 53260:
/***/ (function() {

/* (ignored) */

/***/ }),

/***/ 62191:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var filter = __webpack_require__(33437);

module.exports = function availableTypedArrays() {
	return filter([
		'BigInt64Array',
		'BigUint64Array',
		'Float32Array',
		'Float64Array',
		'Int16Array',
		'Int32Array',
		'Int8Array',
		'Uint16Array',
		'Uint32Array',
		'Uint8Array',
		'Uint8ClampedArray'
	], function (typedArray) {
		return typeof window[typedArray] === 'function';
	});
};


/***/ }),

/***/ 29765:
/***/ (function(module, __unused_webpack_exports, __webpack_require__) {

"use strict";


var GetIntrinsic = __webpack_require__(67286);

var $gOPD = GetIntrinsic('%Object.getOwnPropertyDescriptor%', true);
if ($gOPD) {
	try {
		$gOPD([], 'length');
	} catch (e) {
		// IE 8 has a broken gOPD
		$gOPD = null;
	}
}

module.exports = $gOPD;


/***/ }),

/***/ 56666:
/***/ (function(__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ _defineProperty; }
/* harmony export */ });
function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

/***/ }),

/***/ 7896:
/***/ (function(__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ _extends; }
/* harmony export */ });
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };
  return _extends.apply(this, arguments);
}

/***/ }),

/***/ 81665:
/***/ (function(__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ _inheritsLoose; }
/* harmony export */ });
/* harmony import */ var _setPrototypeOf_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(88960);

function _inheritsLoose(subClass, superClass) {
  subClass.prototype = Object.create(superClass.prototype);
  subClass.prototype.constructor = subClass;
  (0,_setPrototypeOf_js__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(subClass, superClass);
}

/***/ }),

/***/ 33028:
/***/ (function(__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ _objectSpread2; }
/* harmony export */ });
/* harmony import */ var _defineProperty_js__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(56666);


function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    enumerableOnly && (symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    })), keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = null != arguments[i] ? arguments[i] : {};
    i % 2 ? ownKeys(Object(source), !0).forEach(function (key) {
      (0,_defineProperty_js__WEBPACK_IMPORTED_MODULE_0__/* ["default"] */ .Z)(target, key, source[key]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) {
      Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
    });
  }

  return target;
}

/***/ }),

/***/ 31461:
/***/ (function(__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ _objectWithoutPropertiesLoose; }
/* harmony export */ });
function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

/***/ }),

/***/ 88960:
/***/ (function(__unused_webpack___webpack_module__, __webpack_exports__, __webpack_require__) {

"use strict";
/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   "Z": function() { return /* binding */ _setPrototypeOf; }
/* harmony export */ });
function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };
  return _setPrototypeOf(o, p);
}

/***/ })

/******/ 	});
/************************************************************************/
/******/ 	// The module cache
/******/ 	var __webpack_module_cache__ = {};
/******/ 	
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/ 		// Check if module is in cache
/******/ 		var cachedModule = __webpack_module_cache__[moduleId];
/******/ 		if (cachedModule !== undefined) {
/******/ 			return cachedModule.exports;
/******/ 		}
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = __webpack_module_cache__[moduleId] = {
/******/ 			// no module.id needed
/******/ 			// no module.loaded needed
/******/ 			exports: {}
/******/ 		};
/******/ 	
/******/ 		// Execute the module function
/******/ 		__webpack_modules__[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/ 	
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/ 	
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = __webpack_modules__;
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/compat get default export */
/******/ 	!function() {
/******/ 		// getDefaultExport function for compatibility with non-harmony modules
/******/ 		__webpack_require__.n = function(module) {
/******/ 			var getter = module && module.__esModule ?
/******/ 				function() { return module['default']; } :
/******/ 				function() { return module; };
/******/ 			__webpack_require__.d(getter, { a: getter });
/******/ 			return getter;
/******/ 		};
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/define property getters */
/******/ 	!function() {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = function(exports, definition) {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/ensure chunk */
/******/ 	!function() {
/******/ 		__webpack_require__.f = {};
/******/ 		// This file contains only the entry chunk.
/******/ 		// The chunk loading function for additional chunks
/******/ 		__webpack_require__.e = function(chunkId) {
/******/ 			return Promise.all(Object.keys(__webpack_require__.f).reduce(function(promises, key) {
/******/ 				__webpack_require__.f[key](chunkId, promises);
/******/ 				return promises;
/******/ 			}, []));
/******/ 		};
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/get javascript chunk filename */
/******/ 	!function() {
/******/ 		// This function allow to reference async chunks
/******/ 		__webpack_require__.u = function(chunkId) {
/******/ 			// return url for filenames based on template
/******/ 			return "" + {"361":"wpcom-xhr-request","474":"lib-analytics-ad-tracking-record-alias-in-floodlight","874":"lib-analytics-signup"}[chunkId] + ".min.js";
/******/ 		};
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/get mini-css chunk filename */
/******/ 	!function() {
/******/ 		// This function allow to reference all chunks
/******/ 		__webpack_require__.miniCssF = function(chunkId) {
/******/ 			// return url for filenames based on template
/******/ 			return "" + "help-center" + ".css";
/******/ 		};
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/get mini-css chunk filename with rtl */
/******/ 	!function() {
/******/ 		__webpack_require__.miniCssF = (
/******/ 					function(originalFn) { return function(chunkId) {
/******/ 				var isCssRtlEnabled = document.dir === 'rtl';
/******/ 				var originalUrl = originalFn(chunkId);
/******/ 				return isCssRtlEnabled ? originalUrl.replace(".css",".rtl.css") : originalUrl;
/******/ 		}; }
/******/ 				)(__webpack_require__.miniCssF)
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/global */
/******/ 	!function() {
/******/ 		__webpack_require__.g = (function() {
/******/ 			if (typeof globalThis === 'object') return globalThis;
/******/ 			try {
/******/ 				return this || new Function('return this')();
/******/ 			} catch (e) {
/******/ 				if (typeof window === 'object') return window;
/******/ 			}
/******/ 		})();
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	!function() {
/******/ 		__webpack_require__.o = function(obj, prop) { return Object.prototype.hasOwnProperty.call(obj, prop); }
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/load script */
/******/ 	!function() {
/******/ 		var inProgress = {};
/******/ 		var dataWebpackPrefix = "EditingToolkit:";
/******/ 		// loadScript function to load a script via script tag
/******/ 		__webpack_require__.l = function(url, done, key, chunkId) {
/******/ 			if(inProgress[url]) { inProgress[url].push(done); return; }
/******/ 			var script, needAttach;
/******/ 			if(key !== undefined) {
/******/ 				var scripts = document.getElementsByTagName("script");
/******/ 				for(var i = 0; i < scripts.length; i++) {
/******/ 					var s = scripts[i];
/******/ 					if(s.getAttribute("src") == url || s.getAttribute("data-webpack") == dataWebpackPrefix + key) { script = s; break; }
/******/ 				}
/******/ 			}
/******/ 			if(!script) {
/******/ 				needAttach = true;
/******/ 				script = document.createElement('script');
/******/ 		
/******/ 				script.charset = 'utf-8';
/******/ 				script.timeout = 120;
/******/ 				if (__webpack_require__.nc) {
/******/ 					script.setAttribute("nonce", __webpack_require__.nc);
/******/ 				}
/******/ 				script.setAttribute("data-webpack", dataWebpackPrefix + key);
/******/ 				script.src = url;
/******/ 			}
/******/ 			inProgress[url] = [done];
/******/ 			var onScriptComplete = function(prev, event) {
/******/ 				// avoid mem leaks in IE.
/******/ 				script.onerror = script.onload = null;
/******/ 				clearTimeout(timeout);
/******/ 				var doneFns = inProgress[url];
/******/ 				delete inProgress[url];
/******/ 				script.parentNode && script.parentNode.removeChild(script);
/******/ 				doneFns && doneFns.forEach(function(fn) { return fn(event); });
/******/ 				if(prev) return prev(event);
/******/ 			}
/******/ 			;
/******/ 			var timeout = setTimeout(onScriptComplete.bind(null, undefined, { type: 'timeout', target: script }), 120000);
/******/ 			script.onerror = onScriptComplete.bind(null, script.onerror);
/******/ 			script.onload = onScriptComplete.bind(null, script.onload);
/******/ 			needAttach && document.head.appendChild(script);
/******/ 		};
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/make namespace object */
/******/ 	!function() {
/******/ 		// define __esModule on exports
/******/ 		__webpack_require__.r = function(exports) {
/******/ 			if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 				Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 			}
/******/ 			Object.defineProperty(exports, '__esModule', { value: true });
/******/ 		};
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/publicPath */
/******/ 	!function() {
/******/ 		var scriptUrl;
/******/ 		if (__webpack_require__.g.importScripts) scriptUrl = __webpack_require__.g.location + "";
/******/ 		var document = __webpack_require__.g.document;
/******/ 		if (!scriptUrl && document) {
/******/ 			if (document.currentScript)
/******/ 				scriptUrl = document.currentScript.src
/******/ 			if (!scriptUrl) {
/******/ 				var scripts = document.getElementsByTagName("script");
/******/ 				if(scripts.length) scriptUrl = scripts[scripts.length - 1].src
/******/ 			}
/******/ 		}
/******/ 		// When supporting browsers where an automatic publicPath is not supported you must specify an output.publicPath manually via configuration
/******/ 		// or pass an empty string ("") and set the __webpack_public_path__ variable from your code to use your own logic.
/******/ 		if (!scriptUrl) throw new Error("Automatic publicPath is not supported in this browser");
/******/ 		scriptUrl = scriptUrl.replace(/#.*$/, "").replace(/\?.*$/, "").replace(/\/[^\/]+$/, "/");
/******/ 		__webpack_require__.p = scriptUrl;
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/jsonp chunk loading */
/******/ 	!function() {
/******/ 		// no baseURI
/******/ 		
/******/ 		// object to store loaded and loading chunks
/******/ 		// undefined = chunk not loaded, null = chunk preloaded/prefetched
/******/ 		// [resolve, reject, Promise] = chunk loading, 0 = chunk loaded
/******/ 		var installedChunks = {
/******/ 			342: 0
/******/ 		};
/******/ 		
/******/ 		__webpack_require__.f.j = function(chunkId, promises) {
/******/ 				// JSONP chunk loading for javascript
/******/ 				var installedChunkData = __webpack_require__.o(installedChunks, chunkId) ? installedChunks[chunkId] : undefined;
/******/ 				if(installedChunkData !== 0) { // 0 means "already installed".
/******/ 		
/******/ 					// a Promise means "currently loading".
/******/ 					if(installedChunkData) {
/******/ 						promises.push(installedChunkData[2]);
/******/ 					} else {
/******/ 						if(true) { // all chunks have JS
/******/ 							// setup Promise in chunk cache
/******/ 							var promise = new Promise(function(resolve, reject) { installedChunkData = installedChunks[chunkId] = [resolve, reject]; });
/******/ 							promises.push(installedChunkData[2] = promise);
/******/ 		
/******/ 							// start chunk loading
/******/ 							var url = __webpack_require__.p + __webpack_require__.u(chunkId);
/******/ 							// create error before stack unwound to get useful stacktrace later
/******/ 							var error = new Error();
/******/ 							var loadingEnded = function(event) {
/******/ 								if(__webpack_require__.o(installedChunks, chunkId)) {
/******/ 									installedChunkData = installedChunks[chunkId];
/******/ 									if(installedChunkData !== 0) installedChunks[chunkId] = undefined;
/******/ 									if(installedChunkData) {
/******/ 										var errorType = event && (event.type === 'load' ? 'missing' : event.type);
/******/ 										var realSrc = event && event.target && event.target.src;
/******/ 										error.message = 'Loading chunk ' + chunkId + ' failed.\n(' + errorType + ': ' + realSrc + ')';
/******/ 										error.name = 'ChunkLoadError';
/******/ 										error.type = errorType;
/******/ 										error.request = realSrc;
/******/ 										installedChunkData[1](error);
/******/ 									}
/******/ 								}
/******/ 							};
/******/ 							__webpack_require__.l(url, loadingEnded, "chunk-" + chunkId, chunkId);
/******/ 						} else installedChunks[chunkId] = 0;
/******/ 					}
/******/ 				}
/******/ 		};
/******/ 		
/******/ 		// no prefetching
/******/ 		
/******/ 		// no preloaded
/******/ 		
/******/ 		// no HMR
/******/ 		
/******/ 		// no HMR manifest
/******/ 		
/******/ 		// no on chunks loaded
/******/ 		
/******/ 		// install a JSONP callback for chunk loading
/******/ 		var webpackJsonpCallback = function(parentChunkLoadingFunction, data) {
/******/ 			var chunkIds = data[0];
/******/ 			var moreModules = data[1];
/******/ 			var runtime = data[2];
/******/ 			// add "moreModules" to the modules object,
/******/ 			// then flag all "chunkIds" as loaded and fire callback
/******/ 			var moduleId, chunkId, i = 0;
/******/ 			if(chunkIds.some(function(id) { return installedChunks[id] !== 0; })) {
/******/ 				for(moduleId in moreModules) {
/******/ 					if(__webpack_require__.o(moreModules, moduleId)) {
/******/ 						__webpack_require__.m[moduleId] = moreModules[moduleId];
/******/ 					}
/******/ 				}
/******/ 				if(runtime) var result = runtime(__webpack_require__);
/******/ 			}
/******/ 			if(parentChunkLoadingFunction) parentChunkLoadingFunction(data);
/******/ 			for(;i < chunkIds.length; i++) {
/******/ 				chunkId = chunkIds[i];
/******/ 				if(__webpack_require__.o(installedChunks, chunkId) && installedChunks[chunkId]) {
/******/ 					installedChunks[chunkId][0]();
/******/ 				}
/******/ 				installedChunks[chunkId] = 0;
/******/ 			}
/******/ 		
/******/ 		}
/******/ 		
/******/ 		var chunkLoadingGlobal = self["webpackChunkwebpack"] = self["webpackChunkwebpack"] || [];
/******/ 		chunkLoadingGlobal.forEach(webpackJsonpCallback.bind(null, 0));
/******/ 		chunkLoadingGlobal.push = webpackJsonpCallback.bind(null, chunkLoadingGlobal.push.bind(chunkLoadingGlobal));
/******/ 	}();
/******/ 	
/************************************************************************/
var __webpack_exports__ = {};
// This entry need to be wrapped in an IIFE because it need to be in strict mode.
!function() {
"use strict";
__webpack_require__.r(__webpack_exports__);
/* harmony import */ var _src_config__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(36707);
/* harmony import */ var _src_config__WEBPACK_IMPORTED_MODULE_0___default = /*#__PURE__*/__webpack_require__.n(_src_config__WEBPACK_IMPORTED_MODULE_0__);
/* harmony import */ var _automattic_data_stores__WEBPACK_IMPORTED_MODULE_2__ = __webpack_require__(17624);
/* harmony import */ var _src_help_center__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(99477);



_automattic_data_stores__WEBPACK_IMPORTED_MODULE_2__/* .register */ .z();
}();
window.EditingToolkit = __webpack_exports__;
/******/ })()
;